@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Adminpanel\Modules\Info;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Adminpanel\Modules\Info;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Adminpanel\Modules\Info;
+
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Adminpanel\ModuleApi\AbstractSubModule;
 use TYPO3\CMS\Adminpanel\ModuleApi\DataProviderInterface;
@@ -130,7 +131,7 @@ class GeneralInformation extends AbstractSubModule implements DataProviderInterf
         $count = 0;
         $totalImageSize = 0;
         foreach (GeneralUtility::makeInstance(AssetCollector::class)->getMedia() as $file => $information) {
-            $fileSize = @filesize($file);
+            $fileSize = (int)@filesize($file);
             $imagesOnPage['files'][] = [
                 'name' => $file,
                 'size' => $fileSize,
