@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Adminpanel\Modules;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Adminpanel\Modules;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Adminpanel\Modules;
+
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Adminpanel\ModuleApi\AbstractModule;
 use TYPO3\CMS\Adminpanel\ModuleApi\PageSettingsProviderInterface;
@@ -93,7 +94,8 @@ class PreviewModule extends AbstractModule implements RequestEnricherInterface,
             $this->config['showHiddenPages'],
             $this->config['showHiddenRecords'],
             $this->config['simulateDate'],
-            $this->config['simulateUserGroup']
+            $this->config['simulateUserGroup'],
+            $request
         );
 
         return $request;
@@ -155,13 +157,15 @@ class PreviewModule extends AbstractModule implements RequestEnricherInterface,
      * @param bool $showHiddenRecords
      * @param int $simulateDate
      * @param int $simulateUserGroup UID of the fe_group to simulate
+     * @param \Psr\Http\Message\ServerRequestInterface $request
      * @throws \Exception
      */
     protected function initializeFrontendPreview(
         bool $showHiddenPages,
         bool $showHiddenRecords,
         int $simulateDate,
-        int $simulateUserGroup
+        int $simulateUserGroup,
+        ServerRequestInterface $request
     ): void {
         $context = GeneralUtility::makeInstance(Context::class);
         $this->clearPreviewSettings($context);
@@ -193,11 +197,16 @@ class PreviewModule extends AbstractModule implements RequestEnricherInterface,
         }
         // simulate usergroup
         if ($simulateUserGroup) {
+            $frontendUser = $request->getAttribute('frontend.user');
+            $frontendUser->user[$frontendUser->usergroup_column] = $simulateUserGroup;
+            // let's fake having a user with that group, too
+            // This can be removed once #90989 is fixed
+            $frontendUser->user['uid'] = PHP_INT_MAX;
             $context->setAspect(
                 'frontend.user',
                 GeneralUtility::makeInstance(
                     UserAspect::class,
-                    null,
+                    $frontendUser,
                     [$simulateUserGroup]
                 )
             );
