@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Backend\Shortcut;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Backend\Backend\Shortcut;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Backend\Shortcut;
+
 use TYPO3\CMS\Backend\Module\ModuleLoader;
 use TYPO3\CMS\Backend\Routing\Exception\ResourceNotFoundException;
 use TYPO3\CMS\Backend\Routing\Router;
@@ -26,11 +28,12 @@ use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Imaging\IconFactory;
 use TYPO3\CMS\Core\Localization\LanguageService;
+use TYPO3\CMS\Core\Resource\Exception\FolderDoesNotExistException;
+use TYPO3\CMS\Core\Resource\Exception\InsufficientFolderAccessPermissionsException;
 use TYPO3\CMS\Core\Resource\Exception\ResourceDoesNotExistException;
 use TYPO3\CMS\Core\Resource\ResourceFactory;
 use TYPO3\CMS\Core\Type\Bitmask\Permission;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
-use TYPO3\CMS\Core\Utility\MathUtility;
 
 /**
  * Repository for backend shortcuts
@@ -212,7 +215,7 @@ class ShortcutRepository
         $pageId = 0;
 
         if (is_array($queryParameters['edit'])) {
-            $table = key($queryParameters['edit']);
+            $table = (string)key($queryParameters['edit']);
             $recordId = (int)key($queryParameters['edit'][$table]);
             $pageId = (int)BackendUtility::getRecord($table, $recordId)['pid'];
             $languageFile = 'LLL:EXT:core/Resources/Private/Language/locallang_misc.xlf';
@@ -230,11 +233,13 @@ class ShortcutRepository
             }
         }
 
-        // Check if given id is a combined identifier
-        if (!empty($queryParameters['id']) && preg_match('/^[\d]+:/', $queryParameters['id'])) {
+        $moduleName = $module ?: $parentModule;
+        $id = $this->extractIdFromShortcutUrl($moduleName, $url);
+        if ($moduleName === 'file_FilelistList' && $id !== '') {
+            // If filelist module, check if the id is a valid module identifier
             try {
                 $resourceFactory = GeneralUtility::makeInstance(ResourceFactory::class);
-                $resource = $resourceFactory->getObjectFromCombinedIdentifier($queryParameters['id']);
+                $resource = $resourceFactory->getObjectFromCombinedIdentifier($id);
                 $title = trim(sprintf(
                     '%s (%s)',
                     $titlePrefix,
@@ -244,7 +249,7 @@ class ShortcutRepository
             }
         } else {
             // Lookup the title of this page and use it as default description
-            $pageId = $pageId ?: $recordId ?: $this->extractPageIdFromShortcutUrl($url);
+            $pageId = $pageId ?: $recordId ?: (int)$id;
             $page = $pageId ? BackendUtility::getRecord('pages', $pageId) : null;
 
             if (!empty($page)) {
@@ -482,6 +487,7 @@ class ShortcutRepository
             ->execute();
 
         while ($row = $result->fetch()) {
+            $pageId = 0;
             $shortcut = ['raw' => $row];
 
             [$row['module_name'], $row['M_module_name']] = explode('|', $row['module_name']);
@@ -512,26 +518,58 @@ class ShortcutRepository
             $moduleName = $row['M_module_name'] ?: $row['module_name'];
 
             // Check if the user has access to this module
-            if (!is_array($this->moduleLoader->checkMod($moduleName))) {
+            // @todo Hack for EditDocumentController / FormEngine, see issues #91368 and #91210
+            if (!is_array($this->moduleLoader->checkMod($moduleName)) && $moduleName !== 'xMOD_alt_doc.php') {
                 continue;
             }
 
-            $pageId = $this->extractPageIdFromShortcutUrl($row['url']);
-
-            if (!$backendUser->isAdmin()) {
-                if (MathUtility::canBeInterpretedAsInteger($pageId)) {
+            if ($moduleName === 'file_FilelistList') {
+                $combinedIdentifier = $this->extractIdFromShortcutUrl($moduleName, $row['url'] ?? '');
+                if ($combinedIdentifier !== '') {
+                    try {
+                        $resourceFactory = GeneralUtility::makeInstance(ResourceFactory::class);
+                        $storage = $resourceFactory->getStorageObjectFromCombinedIdentifier($combinedIdentifier);
+                        if ($storage === null || $storage->getUid() === 0) {
+                            // Continue, if invalid storage or disallowed fallback storage
+                            continue;
+                        }
+                        $folderIdentifier = substr($combinedIdentifier, strpos($combinedIdentifier, ':') + 1);
+                        // By using $storage->getFolder() we implicitly check whether the folder
+                        // still exists and the user has necessary permissions to access it.
+                        $storage->getFolder($folderIdentifier);
+                    } catch (InsufficientFolderAccessPermissionsException $e) {
+                        // Continue, since current user does not have access to the folder
+                        continue;
+                    } catch (FolderDoesNotExistException $e) {
+                        // Folder does not longer exists. However, the shortcut
+                        // is still displayed, allowing the user to remove it.
+                    }
+                }
+            } else {
+                if ($moduleName === 'xMOD_alt_doc.php' && isset($shortcut['table'], $shortcut['recordid'])) {
+                    // Check if user is allowed to edit the requested record
+                    if (!$backendUser->check('tables_modify', $shortcut['table'])) {
+                        continue;
+                    }
+                    $record = BackendUtility::getRecord($shortcut['table'], (int)$shortcut['recordid']);
+                    // Check if requested record exists
+                    if ($record === null || $record === []) {
+                        continue;
+                    }
+                    // Store the page id of the record in question
+                    $pageId = ($shortcut['table'] === 'pages' ? (int)($record['uid'] ?? 0) : (int)($record['pid']));
+                } else {
+                    // In case this is no record edit shortcut, treat a possible "id" as page id
+                    $pageId = (int)$this->extractIdFromShortcutUrl($moduleName, $row['url'] ?? '');
+                }
+                if ($pageId > 0 && !$backendUser->isAdmin()) {
                     // Check for webmount access
                     if ($backendUser->isInWebMount($pageId) === null) {
                         continue;
                     }
                     // Check for record access
                     $pageRow = BackendUtility::getRecord('pages', $pageId);
-
-                    if ($pageRow === null) {
-                        continue;
-                    }
-
-                    if (!$backendUser->doesUserHaveAccess($pageRow, Permission::PAGE_SHOW)) {
+                    if ($pageRow === null || !$backendUser->doesUserHaveAccess($pageRow, Permission::PAGE_SHOW)) {
                         continue;
                     }
                 }
@@ -555,7 +593,7 @@ class ShortcutRepository
             $shortcut['group'] = $shortcutGroup;
             $shortcut['icon'] = $this->getShortcutIcon($row, $shortcut);
             $shortcut['iconTitle'] = $this->getShortcutIconTitle($shortcut['label'], $row['module_name'], $row['M_module_name']);
-            $shortcut['action'] = 'jump(' . GeneralUtility::quoteJSvalue($this->getTokenUrl($row['url'])) . ',' . GeneralUtility::quoteJSvalue($moduleName) . ',' . GeneralUtility::quoteJSvalue($moduleParts[0]) . ', ' . (int)$pageId . ');';
+            $shortcut['action'] = 'jump(' . GeneralUtility::quoteJSvalue($this->getTokenUrl($row['url'])) . ',' . GeneralUtility::quoteJSvalue($moduleName) . ',' . GeneralUtility::quoteJSvalue($moduleParts[0]) . ', ' . $pageId . ');';
 
             $shortcuts[] = $shortcut;
         }
@@ -601,7 +639,6 @@ class ShortcutRepository
      */
     protected function getShortcutIcon(array $row, array $shortcut): string
     {
-        $selectFields = [];
         switch ($row['module_name']) {
             case 'xMOD_alt_doc.php':
                 $table = $shortcut['table'];
@@ -609,44 +646,8 @@ class ShortcutRepository
                 $icon = '';
 
                 if ($shortcut['type'] === 'edit') {
-                    // Creating the list of fields to include in the SQL query:
-                    $selectFields[] = 'uid';
-                    $selectFields[] = 'pid';
-
-                    if ($table === 'pages') {
-                        $selectFields[] = 'module';
-                        $selectFields[] = 'extendToSubpages';
-                        $selectFields[] = 'doktype';
-                    }
-
-                    if (is_array($GLOBALS['TCA'][$table]['ctrl']['enablecolumns'])) {
-                        $selectFields = array_merge($selectFields, $GLOBALS['TCA'][$table]['ctrl']['enablecolumns']);
-                    }
-
-                    if ($GLOBALS['TCA'][$table]['ctrl']['typeicon_column']) {
-                        $selectFields[] = $GLOBALS['TCA'][$table]['ctrl']['typeicon_column'];
-                    }
-
-                    if (BackendUtility::isTableWorkspaceEnabled($table)) {
-                        $selectFields[] = 't3ver_state';
-                        $selectFields[] = 't3ver_wsid';
-                        $selectFields[] = 't3ver_oid';
-                    }
-
-                    $queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)
-                        ->getQueryBuilderForTable($table);
-                    $queryBuilder->select(...array_unique(array_values($selectFields)))
-                        ->from($table)
-                        ->where(
-                            $queryBuilder->expr()->in(
-                                'uid',
-                                $queryBuilder->createNamedParameter($recordid, \PDO::PARAM_INT)
-                            )
-                        );
-
-                    $row = $queryBuilder->execute()->fetch();
-
-                    $icon = $this->iconFactory->getIconForRecord($table, (array)$row, Icon::SIZE_SMALL)->render();
+                    $row = BackendUtility::getRecordWSOL($table, $recordid) ?? [];
+                    $icon = $this->iconFactory->getIconForRecord($table, $row, Icon::SIZE_SMALL)->render();
                 } elseif ($shortcut['type'] === 'new') {
                     $icon = $this->iconFactory->getIconForRecord($table, [], Icon::SIZE_SMALL)->render();
                 }
@@ -713,14 +714,28 @@ class ShortcutRepository
     }
 
     /**
-     * Return the ID of the page in the URL if found.
+     * Get the id from the shortcut url. This could
+     * either be the page id or the combined identifier.
      *
-     * @param string $url The URL of the current shortcut link
-     * @return int If a page ID was found, it is returned. Otherwise: 0
+     * @param string $moduleName
+     * @param string $shortcutUrl
+     * @return string
      */
-    protected function extractPageIdFromShortcutUrl(string $url): int
+    protected function extractIdFromShortcutUrl(string $moduleName, string $shortcutUrl): string
     {
-        return (int)preg_replace('/.*[\\?&]id=([^&]+).*/', '$1', $url);
+        $parsedUrl = parse_url($shortcutUrl);
+        $queryParams = [];
+        parse_str($parsedUrl['query'] ?? '', $queryParams);
+        $id = (string)($queryParams['id'] ?? '');
+
+        if ($id === '' && $moduleName === 'xMOD_alt_doc.php' && ($queryParams['returnUrl'] ?? '') !== '') {
+            $parsedReturlUrl = parse_url($queryParams['returnUrl']);
+            $returnUrlQueryParams = [];
+            parse_str($parsedReturlUrl['query'] ?? '', $returnUrlQueryParams);
+            $id = (string)($returnUrlQueryParams['id'] ?? '');
+        }
+
+        return $id;
     }
 
     /**
