@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Command;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Command;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Command;
+
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Input\InputOption;
@@ -48,6 +49,7 @@ class ReferenceIndexUpdateCommand extends Command
      *
      * @param InputInterface $input
      * @param OutputInterface $output
+     * @return int
      */
     protected function execute(InputInterface $input, OutputInterface $output)
     {
@@ -66,5 +68,6 @@ class ReferenceIndexUpdateCommand extends Command
             $io->section('Reference Index is now being updated');
         }
         $referenceIndex->updateIndex($isTestOnly, $progressListener);
+        return 0;
     }
 }
