@@ -1,7 +1,5 @@
 <?php
 
-namespace TYPO3\CMS\Backend\Configuration;
-
 /*
  * This file is part of the TYPO3 CMS project.
  *
@@ -15,11 +13,13 @@ namespace TYPO3\CMS\Backend\Configuration;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Configuration;
+
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Database\ConnectionPool;
-use TYPO3\CMS\Core\Database\Query\Restriction\BackendWorkspaceRestriction;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
+use TYPO3\CMS\Core\Database\Query\Restriction\WorkspaceRestriction;
 use TYPO3\CMS\Core\Exception\SiteNotFoundException;
 use TYPO3\CMS\Core\Site\Entity\NullSite;
 use TYPO3\CMS\Core\Site\Entity\SiteInterface;
@@ -33,6 +33,11 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  */
 class TranslationConfigurationProvider
 {
+    /**
+     * @var array
+     */
+    protected $systemLanguageCache = [];
+
     /**
      * Returns array of languages given for a specific site (or "nullSite" if on page=0)
      * The property flagIcon returns a string <flags-xx>.
@@ -42,6 +47,9 @@ class TranslationConfigurationProvider
      */
     public function getSystemLanguages($pageId = 0)
     {
+        if (isset($this->systemLanguageCache[$pageId])) {
+            return $this->systemLanguageCache[$pageId];
+        }
         $allSystemLanguages = [];
         $siteFinder = GeneralUtility::makeInstance(SiteFinder::class);
         if ($pageId === 0) {
@@ -52,7 +60,8 @@ class TranslationConfigurationProvider
                 $allSystemLanguages = $this->addSiteLanguagesToConsolidatedList(
                     $allSystemLanguages,
                     $site->getAvailableLanguages($this->getBackendUserAuthentication()),
-                    $site
+                    $site,
+                    true
                 );
             }
         } else {
@@ -68,14 +77,16 @@ class TranslationConfigurationProvider
             $allSystemLanguages = $this->addSiteLanguagesToConsolidatedList(
                 $allSystemLanguages,
                 $siteLanguages,
-                $site
+                $site,
+                false
             );
         }
         ksort($allSystemLanguages);
+        $this->systemLanguageCache[$pageId] = $allSystemLanguages;
         return $allSystemLanguages;
     }
 
-    protected function addSiteLanguagesToConsolidatedList(array $allSystemLanguages, array $languagesOfSpecificSite, SiteInterface $site): array
+    protected function addSiteLanguagesToConsolidatedList(array $allSystemLanguages, array $languagesOfSpecificSite, SiteInterface $site, bool $includeSiteSuffix): array
     {
         foreach ($languagesOfSpecificSite as $language) {
             $languageId = $language->getLanguageId();
@@ -85,7 +96,7 @@ class TranslationConfigurationProvider
             } else {
                 $allSystemLanguages[$languageId] = [
                     'uid' => $languageId,
-                    'title' => $language->getTitle() . ' [Site: ' . $site->getIdentifier() . ']',
+                    'title' => $language->getTitle() . ($includeSiteSuffix ? ' [Site: ' . $site->getIdentifier() . ']' : ''),
                     'ISOcode' => $language->getTwoLetterIsoCode(),
                     'flagIcon' => $language->getFlagIdentifier(),
                 ];
@@ -133,7 +144,7 @@ class TranslationConfigurationProvider
         $queryBuilder->getRestrictions()
             ->removeAll()
             ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
-            ->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class));
+            ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, $this->getBackendUserAuthentication()->workspace));
         $queryBuilder
             ->select(...GeneralUtility::trimExplode(',', $selFieldList))
             ->from($table)
