@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\ContextMenu\ItemProviders;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Backend\ContextMenu\ItemProviders;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\ContextMenu\ItemProviders;
+
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Domain\Repository\PageRepository;
@@ -27,6 +29,7 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  */
 class PageProvider extends RecordProvider
 {
+
     /**
      * @var string
      */
@@ -288,6 +291,11 @@ class PageProvider extends RecordProvider
         if (!$this->backendUser->checkLanguageAccess(0)) {
             return false;
         }
+        if (isset($GLOBALS['TCA'][$this->table]['ctrl']['languageField'])
+            && !in_array($this->record[$GLOBALS['TCA'][$this->table]['ctrl']['languageField']], [0, -1])
+        ) {
+            return false;
+        }
         return $this->hasPagePermission(Permission::PAGE_NEW);
     }
 
@@ -427,7 +435,8 @@ class PageProvider extends RecordProvider
         if (!$this->languageAccess) {
             return false;
         }
-        return !$this->isDeletePlaceholder()
+        return !$this->isRoot()
+            && !$this->isDeletePlaceholder()
             && !$this->isRecordLocked()
             && !$this->isDeletionDisabledInTS()
             && $this->hasPagePermission(Permission::PAGE_DELETE);
@@ -440,7 +449,9 @@ class PageProvider extends RecordProvider
      */
     protected function canBeViewed(): bool
     {
-        return !$this->isRoot() && !$this->isDeleted();
+        return !$this->isRoot()
+            && !$this->isDeleted()
+            && !$this->isExcludedDoktype();
     }
 
     /**
@@ -579,7 +590,7 @@ class PageProvider extends RecordProvider
      */
     protected function canBeToggled(string $fieldName, int $value): bool
     {
-        if (!$this->languageAccess) {
+        if (!$this->languageAccess || $this->isRoot()) {
             return false;
         }
         if (!empty($GLOBALS['TCA'][$this->table]['columns'][$fieldName]['exclude'])
@@ -608,4 +619,20 @@ class PageProvider extends RecordProvider
         }
         return true;
     }
+
+    /**
+     * Returns true if the page doktype is excluded
+     *
+     * @return bool
+     */
+    protected function isExcludedDoktype(): bool
+    {
+        $excludeDoktypes = [
+            PageRepository::DOKTYPE_RECYCLER,
+            PageRepository::DOKTYPE_SYSFOLDER,
+            PageRepository::DOKTYPE_SPACER
+        ];
+
+        return in_array((int)($this->record['doktype'] ?? 0), $excludeDoktypes, true);
+    }
 }
