@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\ContextMenu\ItemProviders;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,8 +15,11 @@ namespace TYPO3\CMS\Backend\ContextMenu\ItemProviders;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\ContextMenu\ItemProviders;
+
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
+use TYPO3\CMS\Core\Domain\Repository\PageRepository;
 use TYPO3\CMS\Core\Routing\UnableToLinkToPageException;
 use TYPO3\CMS\Core\Type\Bitmask\JsConfirmation;
 use TYPO3\CMS\Core\Type\Bitmask\Permission;
@@ -154,7 +157,7 @@ class RecordProvider extends AbstractProvider
      */
     public function canHandle(): bool
     {
-        if (in_array($this->table, ['sys_file', 'sys_filemounts', 'sys_file_storage', 'pages'], true)
+        if (in_array($this->table, ['sys_file', 'pages'], true)
             || strpos($this->table, '-drag') !== false) {
             return false;
         }
@@ -167,7 +170,7 @@ class RecordProvider extends AbstractProvider
     protected function initialize()
     {
         parent::initialize();
-        $this->record = BackendUtility::getRecordWSOL($this->table, $this->identifier);
+        $this->record = BackendUtility::getRecordWSOL($this->table, (int)$this->identifier);
         $this->initPermissions();
     }
 
@@ -217,9 +220,11 @@ class RecordProvider extends AbstractProvider
                 $canRender = $this->canBeViewed();
                 break;
             case 'edit':
-            case 'new':
                 $canRender = $this->canBeEdited();
                 break;
+            case 'new':
+                $canRender = $this->canBeNew();
+                break;
             case 'newWizard':
                 $canRender = $this->canOpenNewCEWizard();
                 break;
@@ -493,7 +498,7 @@ class RecordProvider extends AbstractProvider
      */
     protected function canBeViewed(): bool
     {
-        return $this->table === 'tt_content';
+        return $this->table === 'tt_content' && $this->parentPageCanBeViewed();
     }
 
     /**
@@ -520,6 +525,16 @@ class RecordProvider extends AbstractProvider
         return $access;
     }
 
+    /**
+     * Whether a record can be created
+     *
+     * @return bool
+     */
+    protected function canBeNew(): bool
+    {
+        return $this->canBeEdited() && !$this->isRecordATranslation();
+    }
+
     /**
      * Checks if disableDelete flag is set in TSConfig for the current table
      *
@@ -535,13 +550,15 @@ class RecordProvider extends AbstractProvider
     }
 
     /**
-     * Checks if the user has the right to delete the page
+     * Checks if the user has the right to delete the record
      *
      * @return bool
      */
     protected function canBeDeleted(): bool
     {
-        return !$this->isDeletionDisabledInTS() && $this->canBeEdited();
+        return !$this->isDeletionDisabledInTS()
+            && !$this->isRecordCurrentBackendUser()
+            && $this->canBeEdited();
     }
 
     /**
@@ -561,7 +578,9 @@ class RecordProvider extends AbstractProvider
      */
     protected function canBeDisabled(): bool
     {
-        return $this->hasDisableColumnWithValue(0) && $this->canBeEdited();
+        return $this->hasDisableColumnWithValue(0)
+            && !$this->isRecordCurrentBackendUser()
+            && $this->canBeEdited();
     }
 
     /**
@@ -573,7 +592,7 @@ class RecordProvider extends AbstractProvider
     {
         return $this->table === 'tt_content'
             && (bool)(BackendUtility::getPagesTSconfig($this->record['pid'])['mod.']['web_layout.']['disableNewContentElementWizard'] ?? true)
-            && $this->canBeEdited();
+            && $this->canBeEdited() && !$this->isRecordATranslation();
     }
 
     /**
@@ -691,6 +710,37 @@ class RecordProvider extends AbstractProvider
         return BackendUtility::isTableLocalizable($this->table) && (int)$this->record[$GLOBALS['TCA'][$this->table]['ctrl']['transOrigPointerField']] !== 0;
     }
 
+    /**
+     * Return true in case the current record is the current backend user
+     *
+     * @return bool
+     */
+    protected function isRecordCurrentBackendUser(): bool
+    {
+        return $this->table === 'be_users'
+            && (int)($this->record['uid'] ?? 0) === (int)$this->backendUser->user[$this->backendUser->userid_column];
+    }
+
+    /**
+     * Check whether the elements' parent page can be viewed
+     *
+     * @return bool
+     */
+    protected function parentPageCanBeViewed(): bool
+    {
+        if (!isset($this->pageRecord['uid']) || !($this->pageRecord['doktype'] ?? false)) {
+            // In case parent page record is invalid, the element can not be viewed
+            return false;
+        }
+
+        // Finally, we check whether the parent page has a "no view doktype" assigned
+        return !in_array((int)$this->pageRecord['doktype'], [
+            PageRepository::DOKTYPE_SPACER,
+            PageRepository::DOKTYPE_SYSFOLDER,
+            PageRepository::DOKTYPE_RECYCLER
+        ], true);
+    }
+
     /**
      * @return string
      */
