@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Controller;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,8 +13,12 @@ namespace TYPO3\CMS\Backend\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Controller;
+
 use Psr\Http\Message\ResponseInterface;
+use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Domain\Repository\Module\BackendModuleRepository;
+use TYPO3\CMS\Backend\Module\ModuleLoader;
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Template\ModuleTemplate;
 use TYPO3\CMS\Backend\Toolbar\ToolbarItemInterface;
@@ -85,6 +88,16 @@ class BackendController
      */
     protected $uriBuilder;
 
+    /**
+     * @var \SplObjectStorage
+     */
+    protected $moduleStorage;
+
+    /**
+     * @var ModuleLoader
+     */
+    protected $moduleLoader;
+
     /**
      * Constructor
      */
@@ -96,6 +109,10 @@ class BackendController
         $this->uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
         $this->typo3Version = GeneralUtility::makeInstance(Typo3Version::class);
         $this->pageRenderer = GeneralUtility::makeInstance(PageRenderer::class);
+        $this->moduleLoader = GeneralUtility::makeInstance(ModuleLoader::class);
+        $this->moduleLoader->observeWorkspaces = true;
+        $this->moduleLoader->load($GLOBALS['TBE_MODULES']);
+
         // Add default BE javascript
         $this->pageRenderer->addJsFile('EXT:backend/Resources/Public/JavaScript/md5.js');
         $this->pageRenderer->addJsFile('EXT:backend/Resources/Public/JavaScript/backend.js');
@@ -139,6 +156,8 @@ class BackendController
 
         $this->initializeToolbarItems();
         $this->executeHook('constructPostProcess');
+
+        $this->moduleStorage = $this->backendModuleRepository->loadAllowedModules(['user', 'help']);
     }
 
     /**
@@ -178,9 +197,10 @@ class BackendController
     /**
      * Main function generating the BE scaffolding
      *
+     * @param ServerRequestInterface $request
      * @return ResponseInterface the response with the content
      */
-    public function mainAction(): ResponseInterface
+    public function mainAction(ServerRequestInterface $request): ResponseInterface
     {
         $this->executeHook('renderPreProcess');
 
@@ -192,11 +212,12 @@ class BackendController
         $view->assign('moduleMenuCollapsed', $this->getCollapseStateOfMenu());
         $view->assign('moduleMenu', $this->generateModuleMenu());
         $view->assign('topbar', $this->renderTopbar());
+        $view->assign('hasModules', count($this->moduleStorage) > 0);
 
         if (!empty($this->css)) {
             $this->pageRenderer->addCssInlineBlock('BackendInlineCSS', $this->css);
         }
-        $this->generateJavascript();
+        $this->generateJavascript($request);
 
         // Set document title
         $typo3Version = 'TYPO3 CMS ' . $this->typo3Version->getVersion();
@@ -245,6 +266,8 @@ class BackendController
             }
         }
 
+        $view->assign('hasModules', count($this->moduleStorage) > 0);
+        $view->assign('modulesHaveNavigationComponent', $this->backendModuleRepository->modulesHaveNavigationComponent());
         $view->assign('logoUrl', PathUtility::getAbsoluteWebPath($logoPath));
         $view->assign('logoWidth', $logoWidth);
         $view->assign('logoHeight', $logoHeight);
@@ -283,7 +306,7 @@ class BackendController
 
                 // Add further attributes
                 foreach ($additionalAttributes as $name => $value) {
-                    $liAttributes[$name] = $value;
+                    $liAttributes[(string)$name] = (string)$value;
                 }
 
                 // Create a unique id from class name
@@ -294,7 +317,7 @@ class BackendController
                 $liAttributes['id'] = $className;
 
                 // Create data attribute identifier
-                $shortName = substr($fullyQualifiedClassName, strrpos($fullyQualifiedClassName, '\\') + 1);
+                $shortName = substr($fullyQualifiedClassName, (int)strrpos($fullyQualifiedClassName, '\\') + 1);
                 $dataToolbarIdentifier = GeneralUtility::camelCaseToLowerCaseUnderscored($shortName);
                 $dataToolbarIdentifier = str_replace('_', '-', $dataToolbarIdentifier);
                 $liAttributes['data-toolbar-identifier'] = $dataToolbarIdentifier;
@@ -319,8 +342,10 @@ class BackendController
 
     /**
      * Generates the JavaScript code for the backend.
+     *
+     * @param ServerRequestInterface $request
      */
-    protected function generateJavascript()
+    protected function generateJavascript(ServerRequestInterface $request)
     {
         $beUser = $this->getBackendUser();
         // Needed for FormEngine manipulation (date picker)
@@ -365,8 +390,8 @@ class BackendController
         top.goToModule = function(modName, cMR_flag, addGetVars) {
             TYPO3.ModuleMenu.App.showModule(modName, addGetVars);
         }
-        ' . $this->setStartupModule()
-          . $this->handlePageEditing(),
+        ' . $this->setStartupModule($request)
+          . $this->handlePageEditing($request),
             false
         );
     }
@@ -374,18 +399,18 @@ class BackendController
     /**
      * Checking if the "&edit" variable was sent so we can open it for editing the page.
      */
-    protected function handlePageEditing(): string
+    protected function handlePageEditing(ServerRequestInterface $request): string
     {
         $beUser = $this->getBackendUser();
         $userTsConfig = $this->getBackendUser()->getTSConfig();
-        // EDIT page:
-        $editId = preg_replace('/[^[:alnum:]_]/', '', GeneralUtility::_GET('edit'));
+        // EDIT page
+        $editId = preg_replace('/[^[:alnum:]_]/', '', $request->getQueryParams()['edit'] ?? '') ?? '';
         if ($editId) {
             // Looking up the page to edit, checking permissions:
             $where = ' AND (' . $beUser->getPagePermsClause(Permission::PAGE_EDIT) . ' OR ' . $beUser->getPagePermsClause(Permission::CONTENT_EDIT) . ')';
             $editRecord = null;
             if (MathUtility::canBeInterpretedAsInteger($editId)) {
-                $editRecord = BackendUtility::getRecordWSOL('pages', $editId, '*', $where);
+                $editRecord = BackendUtility::getRecordWSOL('pages', (int)$editId, '*', $where);
             }
             // If the page was accessible, then let the user edit it.
             if (is_array($editRecord) && $beUser->isInWebMount($editRecord)) {
@@ -404,7 +429,7 @@ class BackendController
             return '
             // Warning about page editing:
             require(["TYPO3/CMS/Backend/Modal", "TYPO3/CMS/Backend/Severity"], function(Modal, Severity) {
-                Modal.show("", ' . GeneralUtility::quoteJSvalue(sprintf($this->getLanguageService()->getLL('noEditPage'), $editId)) . ', Severity.notice, [{
+                Modal.show("", ' . GeneralUtility::quoteJSvalue(sprintf($this->getLanguageService()->getLL('noEditPage'), (string)$editId)) . ', Severity.notice, [{
                     text: ' . GeneralUtility::quoteJSvalue($this->getLanguageService()->sL('LLL:EXT:core/Resources/Private/Language/locallang_common.xlf:close')) . ',
                     active: true,
                     btnClass: "btn-info",
@@ -421,11 +446,12 @@ class BackendController
     /**
      * Sets the startup module from either GETvars module and modParams or user configuration.
      *
+     * @param ServerRequestInterface $request
      * @return string the JavaScript code for the startup module
      */
-    protected function setStartupModule()
+    protected function setStartupModule(ServerRequestInterface $request)
     {
-        $startModule = preg_replace('/[^[:alnum:]_]/', '', GeneralUtility::_GET('module'));
+        $startModule = preg_replace('/[^[:alnum:]_]/', '', $request->getQueryParams()['module'] ?? '');
         $startModuleParameters = '';
         if (!$startModule) {
             $beUser = $this->getBackendUser();
@@ -434,8 +460,10 @@ class BackendController
                 $startModule = $beUser->uc['startModuleOnFirstLogin'];
                 unset($beUser->uc['startModuleOnFirstLogin']);
                 $beUser->writeUC();
-            } elseif ($beUser->uc['startModule']) {
+            } elseif ($this->moduleLoader->checkMod($beUser->uc['startModule']) !== 'notFound') {
                 $startModule = $beUser->uc['startModule'];
+            } else {
+                $startModule = $this->determineFirstAvailableBackendModule();
             }
 
             // check if the start module has additional parameters, so a redirect to a specific
@@ -445,7 +473,7 @@ class BackendController
             }
         }
 
-        $moduleParameters = GeneralUtility::_GET('modParams');
+        $moduleParameters = $request->getQueryParams()['modParams'] ?? '';
         // if no GET parameters are set, check if there are parameters given from the UC
         if (!$moduleParameters && $startModuleParameters) {
             $moduleParameters = $startModuleParameters;
@@ -460,6 +488,24 @@ class BackendController
         return '';
     }
 
+    protected function determineFirstAvailableBackendModule(): string
+    {
+        foreach ($this->moduleLoader->modules as $mainMod => $modData) {
+            $hasSubmodules = !empty($modData['sub']) && is_array($modData['sub']);
+            $isStandalone = $modData['standalone'] ?? false;
+            if ($isStandalone) {
+                return $modData['name'];
+            }
+
+            if ($hasSubmodules) {
+                $firstSubmodule = reset($modData['sub']);
+                return $firstSubmodule['name'];
+            }
+        }
+
+        return '';
+    }
+
     /**
      * Adds a css snippet to the backend
      *
@@ -501,17 +547,14 @@ class BackendController
      */
     protected function generateModuleMenu()
     {
-        // get all modules except the user modules for the side menu
-        $moduleStorage = $this->backendModuleRepository->loadAllowedModules(['user', 'help', 'dashboard']);
-
         $view = $this->getFluidTemplateObject($this->templatePath . 'ModuleMenu/Main.html');
-        $view->assign('modules', $moduleStorage);
+        $view->assign('modules', $this->moduleStorage);
         return $view->render();
     }
 
     protected function getCollapseStateOfMenu(): bool
     {
-        $uc = json_decode(json_encode($this->getBackendUser()->uc), true);
+        $uc = json_decode((string)json_encode($this->getBackendUser()->uc), true);
         $collapseState = $uc['BackendComponents']['States']['typo3-module-menu']['collapsed'] ?? false;
 
         return $collapseState === true || $collapseState === 'true';
