@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Controller\ContentElement;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Backend\Controller\ContentElement;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Controller\ContentElement;
+
 use Doctrine\DBAL\Connection;
 use Exception;
 use Psr\Http\Message\ResponseInterface;
@@ -102,7 +104,7 @@ class ElementInformationController
     protected $row;
 
     /**
-     * @var \TYPO3\CMS\Core\Resource\File
+     * @var \TYPO3\CMS\Core\Resource\File|null
      */
     protected $fileObject;
 
@@ -122,7 +124,6 @@ class ElementInformationController
     public function __construct()
     {
         $this->iconFactory = GeneralUtility::makeInstance(IconFactory::class);
-        $GLOBALS['SOBE'] = $this;
     }
 
     /**
@@ -180,13 +181,11 @@ class ElementInformationController
             } else {
                 $this->row = BackendUtility::getRecordWSOL($this->table, $this->uid);
                 if ($this->row) {
-                    // Find the correct "pid" when a versionized record is given, otherwise "pid = -1" always fails
                     if (!empty($this->row['t3ver_oid'])) {
-                        $t3OrigRow = BackendUtility::getRecord($this->table, (int)$this->row['t3ver_oid']);
-                        $this->pageInfo = BackendUtility::readPageAccess((int)$t3OrigRow['pid'], $this->permsClause);
-                    } else {
-                        $this->pageInfo = BackendUtility::readPageAccess($this->row['pid'], $this->permsClause);
+                        // Make $this->uid the uid of the versioned record, while $this->row['uid'] is live record uid
+                        $this->uid = (int)$this->row['_ORIG_uid'];
                     }
+                    $this->pageInfo = BackendUtility::readPageAccess((int)$this->row['pid'], $this->permsClause);
                     $this->access = is_array($this->pageInfo);
                 }
             }
@@ -278,6 +277,7 @@ class ElementInformationController
             'title' => BackendUtility::getRecordTitle($this->table, $this->row)
         ];
         if ($this->type === 'folder') {
+            $pageTitle['title'] = htmlspecialchars($this->folderObject->getName());
             $pageTitle['table'] = $this->getLanguageService()->sL('LLL:EXT:core/Resources/Private/Language/locallang_common.xlf:folder');
             $pageTitle['icon'] = $this->iconFactory->getIconForResource($this->folderObject, Icon::SIZE_SMALL)->render();
         } elseif ($this->type === 'file') {
@@ -310,27 +310,26 @@ class ElementInformationController
         } else {
             $rendererRegistry = GeneralUtility::makeInstance(RendererRegistry::class);
             $fileRenderer = $rendererRegistry->getRenderer($this->fileObject);
-            $fileExtension = $this->fileObject->getExtension();
             $preview['url'] = $this->fileObject->getPublicUrl(true);
 
-            $width = '590m';
-            $heigth = '400m';
+            $width = min(590, $this->fileObject->getMetaData()['width'] ?? 590) . 'm';
+            $height = min(400, $this->fileObject->getMetaData()['height'] ?? 400) . 'm';
 
             // Check if there is a FileRenderer
             if ($fileRenderer !== null) {
                 $preview['fileRenderer'] = $fileRenderer->render(
                     $this->fileObject,
                     $width,
-                    $heigth,
+                    $height,
                     [],
                     true
                 );
 
             // else check if we can create an Image preview
-            } elseif (GeneralUtility::inList($GLOBALS['TYPO3_CONF_VARS']['GFX']['imagefile_ext'], $fileExtension)) {
+            } elseif ($this->fileObject->isImage()) {
                 $preview['fileObject'] = $this->fileObject;
                 $preview['width'] = $width;
-                $preview['heigth'] = $heigth;
+                $preview['height'] = $height;
             }
         }
         return $preview;
@@ -371,7 +370,7 @@ class ElementInformationController
             $label = $label ?: $name;
 
             $propertiesForTable['fields'][] = [
-                'fieldValue' => BackendUtility::getProcessedValue($this->table, $name, $this->row[$name], 0, 0, false, $uid),
+                'fieldValue' => BackendUtility::getProcessedValue($this->table, $name, $this->row[$name], 0, false, false, $uid),
                 'fieldLabel' => htmlspecialchars($label)
             ];
         }
@@ -415,6 +414,7 @@ class ElementInformationController
                 // show the metadata of a file as well
                 $table = 'sys_file_metadata';
                 $metaDataRepository = GeneralUtility::makeInstance(MetaDataRepository::class);
+                /** @var array<string, string> $metaData */
                 $metaData = $metaDataRepository->findByFileUid($this->row['uid']);
                 $allowedFields = $this->getFieldList($table, (int)$metaData['uid']);
 
@@ -433,7 +433,7 @@ class ElementInformationController
                         $label = $label ?: $name;
 
                         $propertiesForTable['fields'][] = [
-                            'fieldValue' => BackendUtility::getProcessedValue($table, $name, $metaData[$name], 0, 0, false, $metaData['uid']),
+                            'fieldValue' => BackendUtility::getProcessedValue($table, $name, $metaData[$name], 0, false, false, (int)$metaData['uid']),
                             'fieldLabel' => htmlspecialchars($label)
                         ];
                     }
@@ -488,52 +488,56 @@ class ElementInformationController
     {
         $lang = $this->getLanguageService();
         $keyLabelPair = [];
-        $extraFields = [
-            'uid' => htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:show_item.php.uid'))
-        ];
-
         if (in_array($this->type, ['folder', 'file'], true)) {
             if ($this->type === 'file') {
-                $extraFields['creation_date'] = htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.creationDate'));
-                $extraFields['modification_date'] = htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.timestamp'));
-            }
-        } else {
-            foreach (['crdate' => 'creationDate', 'tstamp' => 'timestamp', 'cruser_id' => 'creationUserId'] as $field => $label) {
-                if (isset($GLOBALS['TCA'][$this->table]['ctrl'][$field])) {
-                    $extraFields[$GLOBALS['TCA'][$this->table]['ctrl'][$field]] = htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.' . $label));
-                }
-            }
-        }
-
-        foreach ($extraFields as $name => $fieldLabel) {
-            if (in_array($name, ['creation_date', 'modification_date', 'tstamp', 'crdate'], true)) {
-                $rowValue = BackendUtility::datetime($this->row[$name]);
-                $keyLabelPair[$name] = [
-                    'value' => $rowValue,
-                    'fieldLabel' => rtrim($fieldLabel, ':'),
+                $keyLabelPair['uid'] = [
+                    'value' => BackendUtility::getProcessedValueExtra($this->table, 'uid', $this->row['uid']),
+                    'fieldLabel' => rtrim(htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:show_item.php.uid')), ':'),
+                ];
+                $keyLabelPair['creation_date'] = [
+                    'value' => BackendUtility::datetime($this->row['creation_date']),
+                    'fieldLabel' => rtrim(htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.creationDate')), ':'),
                     'isDatetime' => true,
                 ];
-            } else {
-                $rowValue = BackendUtility::getProcessedValueExtra($this->table, $name, $this->row[$name]);
-
-                // show the backend username who created the issue
-                if ($name === 'cruser_id' && $rowValue) {
-                    $creatorRecord = BackendUtility::getRecord('be_users', $rowValue);
-                    if ($creatorRecord) {
-                        /** @var Avatar $avatar */
-                        $avatar = GeneralUtility::makeInstance(Avatar::class);
-                        $creatorRecord['icon'] = $avatar->render($creatorRecord);
-                        $name = 'creatorRecord';
-                        $rowValue = $creatorRecord;
-                    }
-                }
-                $keyLabelPair[$name] = [
-                    'value' => $rowValue,
-                    'fieldLabel' => rtrim($fieldLabel, ':'),
+                $keyLabelPair['modification_date'] = [
+                    'value' => BackendUtility::datetime($this->row['modification_date']),
+                    'fieldLabel' => rtrim(htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.timestamp')), ':'),
+                    'isDatetime' => true,
                 ];
             }
+        } else {
+            $keyLabelPair['uid'] = [
+                'value' => BackendUtility::getProcessedValueExtra($this->table, 'uid', $this->row['uid']),
+                'fieldLabel' => rtrim(htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:show_item.php.uid')), ':'),
+            ];
+            foreach (['crdate' => 'creationDate', 'tstamp' => 'timestamp', 'cruser_id' => 'creationUserId'] as $field => $label) {
+                if (isset($GLOBALS['TCA'][$this->table]['ctrl'][$field])) {
+                    if ($field === 'crdate' || $field === 'tstamp') {
+                        $keyLabelPair[$field] = [
+                            'value' => BackendUtility::datetime($this->row[$GLOBALS['TCA'][$this->table]['ctrl'][$field]]),
+                            'fieldLabel' => rtrim(htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.' . $label)), ':'),
+                            'isDatetime' => true,
+                        ];
+                    }
+                    if ($field === 'cruser_id') {
+                        $rowValue = BackendUtility::getProcessedValueExtra($this->table, $GLOBALS['TCA'][$this->table]['ctrl'][$field], $this->row[$GLOBALS['TCA'][$this->table]['ctrl'][$field]]);
+                        if ($rowValue) {
+                            $creatorRecord = BackendUtility::getRecord('be_users', (int)$rowValue);
+                            if ($creatorRecord) {
+                                /** @var Avatar $avatar */
+                                $avatar = GeneralUtility::makeInstance(Avatar::class);
+                                $creatorRecord['icon'] = $avatar->render($creatorRecord);
+                                $rowValue = $creatorRecord;
+                                $keyLabelPair['creatorRecord'] = [
+                                    'value' => $rowValue,
+                                    'fieldLabel' => rtrim(htmlspecialchars($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.' . $label)), ':'),
+                                ];
+                            }
+                        }
+                    }
+                }
+            }
         }
-
         return $keyLabelPair;
     }
 
@@ -548,8 +552,8 @@ class ElementInformationController
         $references = [];
         switch ($this->type) {
             case 'db': {
-                $references['refLines'] = $this->makeRef($this->table, $this->row['uid'], $request);
-                $references['refFromLines'] = $this->makeRefFrom($this->table, $this->row['uid'], $request);
+                $references['refLines'] = $this->makeRef($this->table, $this->uid, $request);
+                $references['refFromLines'] = $this->makeRefFrom($this->table, $this->uid, $request);
                 break;
             }
 
@@ -633,7 +637,7 @@ class ElementInformationController
      * Make reference display
      *
      * @param string $table Table name
-     * @param string|\TYPO3\CMS\Core\Resource\File $ref Filename or uid
+     * @param int|\TYPO3\CMS\Core\Resource\File $ref Filename or uid
      * @param ServerRequestInterface $request
      * @return array
      * @throws RouteNotFoundException
@@ -738,7 +742,7 @@ class ElementInformationController
      * Make reference display (what this elements points to)
      *
      * @param string $table Table name
-     * @param string $ref Filename or uid
+     * @param int $ref Filename or uid
      * @param ServerRequestInterface $request
      * @return array
      */
