@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Controller\ContentElement;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Backend\Controller\ContentElement;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Controller\ContentElement;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Routing\UriBuilder;
@@ -31,6 +33,7 @@ use TYPO3\CMS\Core\Service\DependencyOrderingService;
 use TYPO3\CMS\Core\Type\Bitmask\Permission;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\HttpUtility;
+use TYPO3\CMS\Core\Utility\StringUtility;
 use TYPO3\CMS\Fluid\View\StandaloneView;
 
 /**
@@ -259,10 +262,10 @@ class NewContentElementController
                         $aOnClick = "document.editForm.defValues.value=unescape('" . rawurlencode($wInfo['params']) . "');goToalt_doc();";
                     }
 
-                    // Go to DataHandler directly instead of FormEngine
-                    if ($wInfo['saveAndClose'] ?? false) {
+                    // Go to DataHandler directly instead of FormEngine - Only when colPos must not be selected
+                    if (($wInfo['saveAndClose'] ?? false) && $onClickEvent !== '') {
                         $urlParams = [];
-                        $id = uniqid('NEW');
+                        $id = StringUtility::getUniqueId('NEW');
                         parse_str($wInfo['params'], $urlParams);
                         $urlParams['data']['tt_content'][$id] = $urlParams['defVals']['tt_content'] ?? [];
                         $urlParams['data']['tt_content'][$id]['colPos'] = $this->colPos;
