@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Backend\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Form\FormDataCompiler;
@@ -48,7 +50,7 @@ class FormInlineAjaxController extends AbstractFormEngineAjaxController
 
         $domObjectId = $ajaxArguments[0];
         $inlineFirstPid = $this->getInlineFirstPidFromDomObjectId($domObjectId);
-        if (!MathUtility::canBeInterpretedAsInteger($inlineFirstPid) && strpos($inlineFirstPid, 'NEW') !== 0) {
+        if (!MathUtility::canBeInterpretedAsInteger($inlineFirstPid) && strpos((string)$inlineFirstPid, 'NEW') !== 0) {
             throw new \RuntimeException(
                 'inlineFirstPid should either be an integer or a "NEW..." string',
                 1521220491
@@ -191,6 +193,7 @@ class FormInlineAjaxController extends AbstractFormEngineAjaxController
                     ],
                 ],
             ],
+            'uid' => $parent['uid'],
             'tableName' => $parent['table'],
             'inlineFirstPid' => $inlineFirstPid,
             // Hand over given original return url to compile stack. Needed if inline children compile links to
@@ -364,6 +367,15 @@ class FormInlineAjaxController extends AbstractFormEngineAjaxController
                     $transOrigPointerFieldValue = $childData['databaseRow'][$transOrigPointerFieldName];
                     if (is_array($transOrigPointerFieldValue)) {
                         $transOrigPointerFieldValue = $transOrigPointerFieldValue[0];
+                        if (is_array($transOrigPointerFieldValue) && ($transOrigPointerFieldValue['uid'] ?? false)) {
+                            // With nested inline containers (eg. fal sys_file_reference), row[l10n_parent][0] is sometimes
+                            // a table / row combination again. See tx_styleguide_inline_fal inline_5. If this happens we
+                            // pick the uid field from the array ... Basically, we need the uid of the 'default language' record,
+                            // since this is used in JS to locate and remove the 'shadowed' container.
+                            // @todo: Find out if this is really necessary that sometimes ['databaseRow']['l10n_parent'][0]
+                            // is resolved to a direct uid, and sometimes it's a array with items. Could this be harmonized?
+                            $transOrigPointerFieldValue = $transOrigPointerFieldValue['uid'];
+                        }
                     }
                     $jsonArray['compilerInput']['localize'][$i]['remove'] = $transOrigPointerFieldValue;
                 }
@@ -461,7 +473,7 @@ class FormInlineAjaxController extends AbstractFormEngineAjaxController
 
             // values of the current parent element
             // it is always a string either an id or new...
-            'inlineParentUid' => $parentData['databaseRow']['uid'],
+            'inlineParentUid' => $parentData['databaseRow']['uid'] ?? $parentData['uid'],
             'inlineParentTableName' => $parentData['tableName'],
             'inlineParentFieldName' => $parentFieldName,
 
@@ -672,7 +684,7 @@ class FormInlineAjaxController extends AbstractFormEngineAjaxController
      * Get inlineFirstPid from a given objectId string
      *
      * @param string $domObjectId The id attribute of an element
-     * @return int|null Pid or null
+     * @return int|string|null Pid or null
      */
     protected function getInlineFirstPidFromDomObjectId($domObjectId)
     {
@@ -703,10 +715,10 @@ class FormInlineAjaxController extends AbstractFormEngineAjaxController
         if (empty($context['config'])) {
             throw new \RuntimeException('Empty context config section given', 1489751362);
         }
-        if (!hash_equals(GeneralUtility::hmac(json_encode($context['config']), 'InlineContext'), $context['hmac'])) {
+        if (!hash_equals(GeneralUtility::hmac((string)$context['config'], 'InlineContext'), (string)$context['hmac'])) {
             throw new \RuntimeException('Hash does not validate', 1489751363);
         }
-        return $context['config'];
+        return json_decode($context['config'], true);
     }
 
     /**
