@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,18 +15,23 @@ namespace TYPO3\CMS\Backend\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Controller;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
 use Symfony\Component\HttpFoundation\Cookie;
+use TYPO3\CMS\Backend\Authentication\PasswordReset;
 use TYPO3\CMS\Backend\LoginProvider\Event\ModifyPageLayoutOnLoginProviderSelectionEvent;
 use TYPO3\CMS\Backend\LoginProvider\LoginProviderInterface;
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Template\ModuleTemplate;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Configuration\ExtensionConfiguration;
+use TYPO3\CMS\Core\Configuration\Features;
+use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\FormProtection\BackendFormProtection;
 use TYPO3\CMS\Core\FormProtection\FormProtectionFactory;
@@ -118,16 +123,26 @@ class LoginController implements LoggerAwareInterface
      */
     protected $uriBuilder;
 
+    /**
+     * @var Features
+     */
+    protected $features;
+
     /**
      * @var PageRenderer
      */
     protected $pageRenderer;
 
-    public function __construct(Typo3Information $typo3Information, EventDispatcherInterface $eventDispatcher, UriBuilder $uriBuilder)
-    {
+    public function __construct(
+        Typo3Information $typo3Information,
+        EventDispatcherInterface $eventDispatcher,
+        UriBuilder $uriBuilder,
+        Features $features
+    ) {
         $this->typo3Information = $typo3Information;
         $this->eventDispatcher = $eventDispatcher;
         $this->uriBuilder = $uriBuilder;
+        $this->features = $features;
     }
 
     /**
@@ -156,6 +171,122 @@ class LoginController implements LoggerAwareInterface
         return new HtmlResponse($this->createLoginLogoutForm($request));
     }
 
+    /**
+     * Show a form to enter an email address to request an email.
+     *
+     * @param ServerRequestInterface $request
+     * @return ResponseInterface
+     */
+    public function forgetPasswordFormAction(ServerRequestInterface $request): ResponseInterface
+    {
+        // Only allow to execute this if not logged in as a user right now
+        $context = GeneralUtility::makeInstance(Context::class);
+        if ($context->getAspect('backend.user')->isLoggedIn()) {
+            return $this->formAction($request);
+        }
+        $this->init($request);
+        // Enable the switch in the template
+        $this->view->assign('enablePasswordReset', GeneralUtility::makeInstance(PasswordReset::class)->isEnabled());
+        $this->view->setTemplate('Login/ForgetPasswordForm');
+        $this->moduleTemplate->setContent($this->view->render());
+        return new HtmlResponse($this->moduleTemplate->renderContent());
+    }
+
+    /**
+     * Validate the email address.
+     *
+     * @param ServerRequestInterface $request
+     * @return ResponseInterface
+     */
+    public function initiatePasswordResetAction(ServerRequestInterface $request): ResponseInterface
+    {
+        // Only allow to execute this if not logged in as a user right now
+        $context = GeneralUtility::makeInstance(Context::class);
+        if ($context->getAspect('backend.user')->isLoggedIn()) {
+            return $this->formAction($request);
+        }
+        $this->init($request);
+        $passwordReset = GeneralUtility::makeInstance(PasswordReset::class);
+        $this->view->assign('enablePasswordReset', $passwordReset->isEnabled());
+        $this->view->setTemplate('Login/ForgetPasswordForm');
+
+        $emailAddress = $request->getParsedBody()['email'] ?? '';
+        $this->view->assign('email', $emailAddress);
+        if (!GeneralUtility::validEmail($emailAddress)) {
+            $this->view->assign('invalidEmail', true);
+        } else {
+            $passwordReset->initiateReset($request, $context, $emailAddress);
+            $this->view->assign('resetInitiated', true);
+        }
+        $this->moduleTemplate->setContent($this->view->render());
+        // Prevent time based information disclosure by waiting a random time
+        // before sending a response. This prevents that the reponse time
+        // can be an indicator if the used email exists or not.
+        // wait a random time between 200 milliseconds and 3 seconds.
+        usleep(random_int(200000, 3000000));
+        return new HtmlResponse($this->moduleTemplate->renderContent());
+    }
+
+    /**
+     * Validates the link and show a form to enter the new password.
+     *
+     * @param ServerRequestInterface $request
+     * @return ResponseInterface
+     */
+    public function passwordResetAction(ServerRequestInterface $request): ResponseInterface
+    {
+        // Only allow to execute this if not logged in as a user right now
+        $context = GeneralUtility::makeInstance(Context::class);
+        if ($context->getAspect('backend.user')->isLoggedIn()) {
+            return $this->formAction($request);
+        }
+        $this->init($request);
+        $passwordReset = GeneralUtility::makeInstance(PasswordReset::class);
+        $this->view->setTemplate('Login/ResetPasswordForm');
+        $this->view->assign('enablePasswordReset', $passwordReset->isEnabled());
+        if (!$passwordReset->isValidResetTokenFromRequest($request)) {
+            $this->view->assign('invalidToken', true);
+        }
+        $this->view->assign('token', $request->getQueryParams()['t'] ?? '');
+        $this->view->assign('identity', $request->getQueryParams()['i'] ?? '');
+        $this->view->assign('expirationDate', $request->getQueryParams()['e'] ?? '');
+        $this->moduleTemplate->setContent($this->view->render());
+        return new HtmlResponse($this->moduleTemplate->renderContent());
+    }
+
+    /**
+     * Updates the password in the database.
+     *
+     * @param ServerRequestInterface $request
+     * @return ResponseInterface
+     */
+    public function passwordResetFinishAction(ServerRequestInterface $request): ResponseInterface
+    {
+        // Only allow to execute this if not logged in as a user right now
+        $context = GeneralUtility::makeInstance(Context::class);
+        if ($context->getAspect('backend.user')->isLoggedIn()) {
+            return $this->formAction($request);
+        }
+        $passwordReset = GeneralUtility::makeInstance(PasswordReset::class);
+        // Token is invalid
+        if ($request->getMethod() !== 'POST' || !$passwordReset->isValidResetTokenFromRequest($request)) {
+            return $this->passwordResetAction($request);
+        }
+        $this->init($request);
+        $this->view->setTemplate('Login/ResetPasswordForm');
+        $this->view->assign('enablePasswordReset', $passwordReset->isEnabled());
+        $this->view->assign('token', $request->getQueryParams()['t'] ?? '');
+        $this->view->assign('identity', $request->getQueryParams()['i'] ?? '');
+        $this->view->assign('expirationDate', $request->getQueryParams()['e'] ?? '');
+        if ($passwordReset->resetPassword($request, $context)) {
+            $this->view->assign('resetExecuted', true);
+        } else {
+            $this->view->assign('error', true);
+        }
+        $this->moduleTemplate->setContent($this->view->render());
+        return new HtmlResponse($this->moduleTemplate->renderContent());
+    }
+
     /**
      * This can be called by single login providers, they receive an instance of $this
      *
@@ -203,6 +334,7 @@ class LoginController implements LoggerAwareInterface
         if ($this->redirectUrl) {
             $this->redirectToURL = $this->redirectUrl;
         } else {
+            // (consolidate RouteDispatcher::evaluateReferrer() when changing 'main' to something different)
             $this->redirectToURL = (string)$this->uriBuilder->buildUriFromRoute('main');
         }
 
@@ -214,6 +346,11 @@ class LoginController implements LoggerAwareInterface
 
         $this->view = $this->moduleTemplate->getView();
         $this->view->getRequest()->setControllerExtensionName('Backend');
+        $this->provideCustomLoginStyling();
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Login');
+        $this->view->assign('referrerCheckEnabled', $this->features->isFeatureEnabled('security.backend.enforceReferrer'));
+        $this->view->assign('loginUrl', (string)$request->getUri());
+        $this->view->assign('loginProviderIdentifier', $this->loginProviderIdentifier);
     }
 
     protected function provideCustomLoginStyling()
@@ -287,7 +424,6 @@ class LoginController implements LoggerAwareInterface
                 'typo3' => $this->getUriForFileName('EXT:backend/Resources/Public/Images/typo3_orange.svg'),
             ],
             'copyright' => $this->typo3Information->getCopyrightNotice(),
-            'loginNewsItems' => $this->getSystemNews(),
         ]);
     }
 
@@ -299,14 +435,10 @@ class LoginController implements LoggerAwareInterface
      */
     protected function createLoginLogoutForm(ServerRequestInterface $request): string
     {
-        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Login');
-
         // Checking, if we should make a redirect.
         // Might set JavaScript in the header to close window.
         $this->checkRedirect($request);
 
-        $this->provideCustomLoginStyling();
-
         // Start form
         $formType = empty($this->getBackendUserAuthentication()->user['uid']) ? 'LoginForm' : 'LogoutForm';
         $this->view->assignMultiple([
@@ -315,8 +447,8 @@ class LoginController implements LoggerAwareInterface
             'formType' => $formType,
             'redirectUrl' => $this->redirectUrl,
             'loginRefresh' => $this->loginRefresh,
-            'loginProviderIdentifier' => $this->loginProviderIdentifier,
-            'loginProviders' => $this->loginProviders
+            'loginProviders' => $this->loginProviders,
+            'loginNewsItems' => $this->getSystemNews(),
         ]);
 
         // Initialize interface selectors:
@@ -383,6 +515,7 @@ class LoginController implements LoggerAwareInterface
                     $this->redirectToURL = '../';
                     break;
                 case 'backend':
+                    // (consolidate RouteDispatcher::evaluateReferrer() when changing 'main' to something different)
                     $this->redirectToURL = (string)$this->uriBuilder->buildUriFromRoute('main');
                     break;
             }
@@ -570,28 +703,31 @@ class LoginController implements LoggerAwareInterface
         if ((empty($loginProvider) || !isset($this->loginProviders[$loginProvider])) && !empty($_COOKIE['be_lastLoginProvider'])) {
             $loginProvider = $_COOKIE['be_lastLoginProvider'];
         }
+        reset($this->loginProviders);
+        $primaryLoginProvider = (string)key($this->loginProviders);
         if (empty($loginProvider) || !isset($this->loginProviders[$loginProvider])) {
-            reset($this->loginProviders);
-            $loginProvider = key($this->loginProviders);
+            $loginProvider = $primaryLoginProvider;
         }
-        // Use the secure option when the current request is served by a secure connection
-        /** @var NormalizedParams $normalizedParams */
-        $normalizedParams = $request->getAttribute('normalizedParams');
-        $isHttps = $normalizedParams->isHttps();
-        $cookieSecure = (bool)$GLOBALS['TYPO3_CONF_VARS']['SYS']['cookieSecure'] && $isHttps;
-        $cookie = new Cookie(
-            'be_lastLoginProvider',
-            (string)$loginProvider,
-            $GLOBALS['EXEC_TIME'] + 7776000, // 90 days
-            $normalizedParams->getSitePath() . TYPO3_mainDir,
-            '',
-            $cookieSecure,
-            true,
-            false,
-            Cookie::SAMESITE_STRICT
-        );
-        header('Set-Cookie: ' . $cookie->__toString(), false);
 
+        if ($loginProvider !== $primaryLoginProvider) {
+            // Use the secure option when the current request is served by a secure connection
+            /** @var NormalizedParams $normalizedParams */
+            $normalizedParams = $request->getAttribute('normalizedParams');
+            $isHttps = $normalizedParams->isHttps();
+            $cookieSecure = (bool)$GLOBALS['TYPO3_CONF_VARS']['SYS']['cookieSecure'] && $isHttps;
+            $cookie = new Cookie(
+                'be_lastLoginProvider',
+                $loginProvider,
+                $GLOBALS['EXEC_TIME'] + 7776000, // 90 days
+                $normalizedParams->getSitePath() . TYPO3_mainDir,
+                '',
+                $cookieSecure,
+                true,
+                false,
+                Cookie::SAMESITE_STRICT
+            );
+            header('Set-Cookie: ' . $cookie->__toString(), false);
+        }
         return (string)$loginProvider;
     }
 
