@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Backend\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Routing\UriBuilder;
@@ -114,11 +116,6 @@ class NewRecordController
      */
     protected $code;
 
-    /**
-     * @var string
-     */
-    protected $R_URI;
-
     /**
      * @var int
      *
@@ -170,9 +167,6 @@ class NewRecordController
     {
         $this->moduleTemplate = GeneralUtility::makeInstance(ModuleTemplate::class);
         $this->getLanguageService()->includeLLFile('EXT:core/Resources/Private/Language/locallang_misc.xlf');
-
-        // @see \TYPO3\CMS\Backend\Tree\View\NewRecordPageTreeView::expandNext()
-        $GLOBALS['SOBE'] = $this;
     }
 
     /**
@@ -415,7 +409,6 @@ class NewRecordController
 
         if ($numberOfPages > 0) {
             $this->code .= '<h3>' . htmlspecialchars($this->getLanguageService()->getLL('selectPosition')) . ':</h3>';
-            /** @var \TYPO3\CMS\Backend\Tree\View\PagePositionMap $positionMap */
             $positionMap = GeneralUtility::makeInstance(PagePositionMap::class, NewRecordPageTreeView::class);
             $this->code .= $positionMap->positionTree(
                 $this->id,
@@ -424,8 +417,7 @@ class NewRecordController
                 $this->returnUrl
             );
         } else {
-            /** @var \TYPO3\CMS\Backend\Routing\UriBuilder $uriBuilder */
-            $uriBuilder = GeneralUtility::makeInstance(\TYPO3\CMS\Backend\Routing\UriBuilder::class);
+            $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
             // No pages yet, no need to prompt for position, redirect to page creation.
             $urlParameters = [
                 'edit' => [
@@ -531,6 +523,7 @@ class NewRecordController
             if (is_array($GLOBALS['TCA'])) {
                 $groupName = '';
                 foreach ($GLOBALS['TCA'] as $table => $v) {
+                    /** @var string $table */
                     $rootLevelConfiguration = isset($v['ctrl']['rootLevel']) ? (int)$v['ctrl']['rootLevel'] : 0;
                     if ($table !== 'pages'
                         && $this->isRecordCreationAllowedForTable($table)
@@ -563,7 +556,7 @@ class NewRecordController
                             $title = htmlspecialchars($this->getLanguageService()->getLL('newContentElement'));
                             $rowContent .= '<li>' . $newLink . ' ' . BackendUtility::wrapInHelp($table, '') . '</li>'
                                 . '<li>'
-                                . '<a href="' . htmlspecialchars($url) . '" title="' . $title . '" data-title="' . $title . '" class="t3js-toggle-new-content-element-wizard">'
+                                . '<a href="' . htmlspecialchars($url) . '" title="' . $title . '" data-title="' . $title . '" class="t3js-toggle-new-content-element-wizard disabled">'
                                 . $newContentIcon . htmlspecialchars($lang->getLL('clickForWizard'))
                                 . '</a>'
                                 . '</li>'
@@ -584,7 +577,7 @@ class NewRecordController
                                 $title = (string)($v['ctrl']['title'] ?? '');
                                 if (strpos($title, 'LLL:EXT:') === 0) {
                                     $_EXTKEY = substr($title, 8);
-                                    $_EXTKEY = substr($_EXTKEY, 0, strpos($_EXTKEY, '/'));
+                                    $_EXTKEY = substr($_EXTKEY, 0, (int)strpos($_EXTKEY, '/'));
                                     if ($_EXTKEY !== '') {
                                         // First try to get localisation of extension title
                                         $temp = explode(':', substr($title, 9 + strlen($_EXTKEY)));
