@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Backend\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Module\ModuleLoader;
@@ -23,12 +25,13 @@ use TYPO3\CMS\Backend\Template\Components\ButtonBar;
 use TYPO3\CMS\Backend\Template\ModuleTemplate;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Backend\View\BackendLayoutView;
+use TYPO3\CMS\Backend\View\PageLayoutContext;
 use TYPO3\CMS\Backend\View\PageLayoutView;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Configuration\Features;
 use TYPO3\CMS\Core\Database\ConnectionPool;
-use TYPO3\CMS\Core\Database\Query\Restriction\BackendWorkspaceRestriction;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
+use TYPO3\CMS\Core\Database\Query\Restriction\WorkspaceRestriction;
 use TYPO3\CMS\Core\Domain\Repository\PageRepository;
 use TYPO3\CMS\Core\Http\HtmlResponse;
 use TYPO3\CMS\Core\Imaging\Icon;
@@ -73,7 +76,7 @@ class PageLayoutController
     /**
      * Current ids page record
      *
-     * @var array
+     * @var array|bool
      * @internal
      */
     public $pageinfo;
@@ -158,9 +161,9 @@ class PageLayoutController
     protected $uriBuilder;
 
     /**
-     * @var BackendLayoutView
+     * @var PageLayoutContext|null
      */
-    protected $backendLayouts;
+    protected $context;
 
     /**
      * Injects the request object for the current request or subrequest
@@ -177,13 +180,21 @@ class PageLayoutController
         $this->iconFactory = $this->moduleTemplate->getIconFactory();
         $this->uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
         $this->buttonBar = $this->moduleTemplate->getDocHeaderComponent()->getButtonBar();
-        $this->backendLayouts = GeneralUtility::makeInstance(BackendLayoutView::class);
         $this->getLanguageService()->includeLLFile('EXT:backend/Resources/Private/Language/locallang_layout.xlf');
         // Setting module configuration / page select clause
         $this->id = (int)($request->getParsedBody()['id'] ?? $request->getQueryParams()['id'] ?? 0);
 
         // Load page info array
         $this->pageinfo = BackendUtility::readPageAccess($this->id, $this->getBackendUser()->getPagePermsClause(Permission::PAGE_SHOW));
+        if ($this->pageinfo !== false) {
+            // If page info is not resolved, user has no access or the ID parameter was malformed.
+            $this->context = GeneralUtility::makeInstance(
+                PageLayoutContext::class,
+                $this->pageinfo,
+                GeneralUtility::makeInstance(BackendLayoutView::class)->getBackendLayoutForPage($this->id)
+            );
+        }
+
         /** @var SiteInterface $currentSite */
         $currentSite = $request->getAttribute('site');
         $this->availableLanguages = $currentSite->getAvailableLanguages($this->getBackendUser(), false, $this->id);
@@ -229,7 +240,7 @@ class PageLayoutController
             $queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable('pages');
             $queryBuilder->getRestrictions()->removeAll()
                 ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
-                ->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class));
+                ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, (int)$this->getBackendUser()->workspace));
             $statement = $queryBuilder->select('uid', $GLOBALS['TCA']['pages']['ctrl']['languageField'])
                 ->from('pages')
                 ->where(
@@ -393,7 +404,7 @@ class PageLayoutController
                     $path = BackendUtility::getRecordPath($targetPage['uid'], $this->getBackendUser()->getPagePermsClause(Permission::PAGE_SHOW), 1000);
                     $linkedPath = '<a href="' . htmlspecialchars($linkToPid) . '">' . htmlspecialchars($path) . '</a>';
                     $message .= sprintf(htmlspecialchars($lang->getLL('pageIsInternalLinkMessage')), $linkedPath);
-                    $message .= ' (' . htmlspecialchars($lang->sL(BackendUtility::getLabelFromItemlist('pages', 'shortcut_mode', $shortcutMode))) . ')';
+                    $message .= ' (' . htmlspecialchars($lang->sL(BackendUtility::getLabelFromItemlist('pages', 'shortcut_mode', (string)$shortcutMode))) . ')';
                     $state = InfoboxViewHelper::STATE_INFO;
                 }
             } else {
@@ -416,8 +427,9 @@ class PageLayoutController
                 ]);
                 $content .= $view->render();
             } else {
-                $externalUrl = htmlspecialchars(GeneralUtility::makeInstance(PageRepository::class)->getExtURL($this->pageinfo));
-                if ($externalUrl !== false) {
+                $externalUrl = GeneralUtility::makeInstance(PageRepository::class)->getExtURL($this->pageinfo);
+                if (is_string($externalUrl)) {
+                    $externalUrl = htmlspecialchars($externalUrl);
                     $externalUrlHtml = '<a href="' . $externalUrl . '" target="_blank" rel="noreferrer">' . $externalUrl . '</a>';
                     $view->assignMultiple([
                         'title' => $this->pageinfo['title'],
@@ -430,7 +442,7 @@ class PageLayoutController
         }
         // If content from different pid is displayed
         if ($this->pageinfo['content_from_pid']) {
-            $contentPage = BackendUtility::getRecord('pages', (int)$this->pageinfo['content_from_pid']);
+            $contentPage = (array)BackendUtility::getRecord('pages', (int)$this->pageinfo['content_from_pid']);
             $linkToPid = GeneralUtility::linkThisScript(['id' => $this->pageinfo['content_from_pid']]);
             $title = BackendUtility::getRecordTitle('pages', $contentPage);
             $link = '<a href="' . htmlspecialchars($linkToPid) . '">' . htmlspecialchars($title) . ' (PID ' . (int)$this->pageinfo['content_from_pid'] . ')</a>';
@@ -496,7 +508,7 @@ class PageLayoutController
             $queryBuilder->getRestrictions()
                 ->removeAll()
                 ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
-                ->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class));
+                ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, (int)$this->getBackendUser()->workspace));
             $localizedPage = $queryBuilder
                 ->select('*')
                 ->from('pages')
@@ -545,28 +557,31 @@ class PageLayoutController
                 }
             ');
 
-            // Find backend layout / columns
-            $backendLayout = $this->backendLayouts->getSelectedBackendLayout($this->id);
-            if (!empty($backendLayout['__colPosList'])) {
-                $this->colPosList = implode(',', $backendLayout['__colPosList']);
-            }
-            // Removing duplicates, if any
-            $this->colPosList = array_unique(GeneralUtility::intExplode(',', $this->colPosList));
-            // Accessible columns
-            if (isset($this->modSharedTSconfig['properties']['colPos_list']) && trim($this->modSharedTSconfig['properties']['colPos_list']) !== '') {
-                $this->activeColPosList = array_unique(GeneralUtility::intExplode(',', trim($this->modSharedTSconfig['properties']['colPos_list'])));
-                // Match with the list which is present in the colPosList for the current page
-                if (!empty($this->colPosList) && !empty($this->activeColPosList)) {
-                    $this->activeColPosList = array_unique(array_intersect(
-                        $this->activeColPosList,
-                        $this->colPosList
-                    ));
+            if ($this->context instanceof PageLayoutContext) {
+                $backendLayout = $this->context->getBackendLayout();
+
+                // Find backend layout / columns
+                if (!empty($backendLayout->getColumnPositionNumbers())) {
+                    $this->colPosList = implode(',', $backendLayout->getColumnPositionNumbers());
                 }
-            } else {
-                $this->activeColPosList = $this->colPosList;
+                // Removing duplicates, if any
+                $this->colPosList = array_unique(GeneralUtility::intExplode(',', $this->colPosList));
+                // Accessible columns
+                if (isset($this->modSharedTSconfig['properties']['colPos_list']) && trim($this->modSharedTSconfig['properties']['colPos_list']) !== '') {
+                    $this->activeColPosList = array_unique(GeneralUtility::intExplode(',', trim($this->modSharedTSconfig['properties']['colPos_list'])));
+                    // Match with the list which is present in the colPosList for the current page
+                    if (!empty($this->colPosList) && !empty($this->activeColPosList)) {
+                        $this->activeColPosList = array_unique(array_intersect(
+                            $this->activeColPosList,
+                            $this->colPosList
+                        ));
+                    }
+                } else {
+                    $this->activeColPosList = $this->colPosList;
+                }
+                $this->activeColPosList = implode(',', $this->activeColPosList);
+                $this->colPosList = implode(',', $this->colPosList);
             }
-            $this->activeColPosList = implode(',', $this->activeColPosList);
-            $this->colPosList = implode(',', $this->colPosList);
 
             $content .= $this->getHeaderFlashMessagesForCurrentPid();
 
@@ -610,114 +625,78 @@ class PageLayoutController
     protected function renderContent(): string
     {
         $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/ContextMenu');
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Tooltip');
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Localization');
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/LayoutModule/DragDrop');
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Modal');
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/LayoutModule/Paste');
+        $this->pageRenderer->addInlineLanguageLabelFile('EXT:backend/Resources/Private/Language/locallang_layout.xlf');
 
-        if (GeneralUtility::makeInstance(Features::class)->isFeatureEnabled('fluidBasedPageModule')) {
-            $selectedCombinedIdentifier = $this->backendLayouts->getSelectedCombinedIdentifier($this->id);
-            // If no backend layout is selected, use default
-            if (empty($selectedCombinedIdentifier)) {
-                $selectedCombinedIdentifier = 'default';
-            }
+        $tableOutput = '';
+        $numberOfHiddenElements = 0;
 
-            $backendLayout = $this->backendLayouts->getDataProviderCollection()->getBackendLayout(
-                $selectedCombinedIdentifier,
-                $this->id
-            );
+        if ($this->context instanceof PageLayoutContext) {
+            // Context may not be set, which happens if the page module is viewed by a user with no access to the
+            // current page, or if the ID parameter is malformed. In this case we do not resolve any backend layout
+            // or other page structure information and we do not render any "table output" for the module.
+            $backendLayout = $this->context->getBackendLayout();
 
-            // If backend layout is not found available anymore, use default
-            if ($backendLayout === null) {
-                $backendLayout = $this->backendLayouts->getDataProviderCollection()->getBackendLayout(
-                    'default',
-                    $this->id
-                );
-            }
-
-            $configuration = $backendLayout->getDrawingConfiguration();
-            $configuration->setPageId($this->id);
+            $configuration = $this->context->getDrawingConfiguration();
             $configuration->setDefaultLanguageBinding(!empty($this->modTSconfig['properties']['defLangBinding']));
             $configuration->setActiveColumns(GeneralUtility::trimExplode(',', $this->activeColPosList));
             $configuration->setShowHidden((bool)$this->MOD_SETTINGS['tt_content_showHidden']);
-            $configuration->setLanguageColumns(array_combine(array_keys($this->MOD_MENU['language']), array_keys($this->MOD_MENU['language'])));
-            $configuration->setLanguageColumnsPointer((int)$this->current_sys_language);
-            if ($this->MOD_SETTINGS['function'] == 2) {
-                $configuration->setLanguageMode($this->MOD_SETTINGS['function'] == 2);
-            }
-
-            $pageLayoutDrawer = $backendLayout->getBackendLayoutRenderer();
+            $configuration->setLanguageColumns($this->MOD_MENU['language']);
             $configuration->setShowNewContentWizard(empty($this->modTSconfig['properties']['disableNewContentElementWizard']));
-
-            $pageActionsCallback = null;
-            if ($configuration->isPageEditable()) {
-                $languageOverlayId = 0;
-                $pageLocalizationRecord = BackendUtility::getRecordLocalization('pages', $this->id, (int)$this->current_sys_language);
-                if (is_array($pageLocalizationRecord)) {
-                    $pageLocalizationRecord = reset($pageLocalizationRecord);
-                }
-                if (!empty($pageLocalizationRecord['uid'])) {
-                    $languageOverlayId = $pageLocalizationRecord['uid'];
-                }
-                $pageActionsCallback = 'function(PageActions) {
-                    PageActions.setPageId(' . (int)$this->id . ');
-                    PageActions.setLanguageOverlayId(' . $languageOverlayId . ');
-                }';
-            }
-            $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/PageActions', $pageActionsCallback);
-            $numberOfHiddenElements = $this->getNumberOfHiddenElements($configuration->getLanguageColumns());
-            $tableOutput = $pageLayoutDrawer->drawContent();
-        } else {
-            $dbList = GeneralUtility::makeInstance(PageLayoutView::class);
-            $dbList->doEdit = $this->isContentEditable($this->current_sys_language);
-            $dbList->option_newWizard = empty($this->modTSconfig['properties']['disableNewContentElementWizard']);
-            $dbList->defLangBinding = !empty($this->modTSconfig['properties']['defLangBinding']);
-            $tcaItems = $this->backendLayouts->getColPosListItemsParsed($this->id);
-            $numberOfHiddenElements = $this->getNumberOfHiddenElements(is_array($dbList->tt_contentConfig['languageCols']) ? $dbList->tt_contentConfig['languageCols'] : []);
-            // Setting up the tt_content columns to show:
-            if (is_array($GLOBALS['TCA']['tt_content']['columns']['colPos']['config']['items'])) {
-                $colList = [];
-                foreach ($tcaItems as $temp) {
-                    $colList[] = $temp[1];
-                }
-            } else {
-                // ... should be impossible that colPos has no array. But this is the fallback should it make any sense:
-                $colList = ['1', '0', '2', '3'];
-            }
-            if ($this->colPosList !== '') {
-                $colList = array_intersect(GeneralUtility::intExplode(',', $this->colPosList), $colList);
-            }
-            // The order of the rows: Default is left(1), Normal(0), right(2), margin(3)
-            $dbList->tt_contentConfig['cols'] = implode(',', $colList);
-            $dbList->tt_contentConfig['activeCols'] = $this->activeColPosList;
-            $dbList->tt_contentConfig['showHidden'] = $this->MOD_SETTINGS['tt_content_showHidden'];
-            $dbList->tt_contentConfig['sys_language_uid'] = (int)$this->current_sys_language;
-            // If the function menu is set to "Language":
+            $configuration->setSelectedLanguageId((int)$this->MOD_SETTINGS['language']);
             if ($this->MOD_SETTINGS['function'] == 2) {
-                $dbList->tt_contentConfig['languageMode'] = 1;
-                $dbList->tt_contentConfig['languageCols'] = $this->MOD_MENU['language'];
-                $dbList->tt_contentConfig['languageColsPointer'] = $this->current_sys_language;
+                $configuration->setLanguageMode(true);
+            }
+
+            $numberOfHiddenElements = $this->getNumberOfHiddenElements($configuration->getLanguageColumns());
+
+            if (GeneralUtility::makeInstance(Features::class)->isFeatureEnabled('fluidBasedPageModule')) {
+                $pageLayoutDrawer = $this->context->getBackendLayoutRenderer();
+
+                $pageActionsCallback = null;
+                if ($this->context->isPageEditable()) {
+                    $languageOverlayId = 0;
+                    $pageLocalizationRecord = BackendUtility::getRecordLocalization('pages', $this->id, (int)$this->current_sys_language);
+                    if (is_array($pageLocalizationRecord)) {
+                        $pageLocalizationRecord = reset($pageLocalizationRecord);
+                    }
+                    if (!empty($pageLocalizationRecord['uid'])) {
+                        $languageOverlayId = $pageLocalizationRecord['uid'];
+                    }
+                    $pageActionsCallback = 'function(PageActions) {
+                        PageActions.setPageId(' . (int)$this->id . ');
+                        PageActions.setLanguageOverlayId(' . $languageOverlayId . ');
+                    }';
+                }
+                $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/PageActions', $pageActionsCallback);
+                $tableOutput = $pageLayoutDrawer->drawContent();
+            } else {
+                $dbList = PageLayoutView::createFromPageLayoutContext($this->context);
+                // Setting up the tt_content columns to show
+                $colList = array_keys($backendLayout->getUsedColumns());
+                if ($this->colPosList !== '') {
+                    $colList = array_intersect(GeneralUtility::intExplode(',', $this->colPosList), $colList);
+                }
+                // The order of the rows: Default is left(1), Normal(0), right(2), margin(3)
+                $dbList->tt_contentConfig['cols'] = implode(',', $colList);
+                $tableOutput = $dbList->getTable_tt_content($this->id);
             }
-            $tableOutput = $dbList->getTable_tt_content($this->id);
-            $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Tooltip');
-            $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Localization');
-            $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/LayoutModule/DragDrop');
-            $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Modal');
-            $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/LayoutModule/Paste');
         }
 
-        $this->pageRenderer->addInlineLanguageLabelFile('EXT:backend/Resources/Private/Language/locallang_layout.xlf');
-        if ($this->getBackendUser()->check('tables_select', 'tt_content')) {
-            $h_func_b = '';
+        if ($this->getBackendUser()->check('tables_select', 'tt_content') && $numberOfHiddenElements > 0) {
             // Toggle hidden ContentElements
-
-            if ($numberOfHiddenElements > 0) {
-                $h_func_b = '
-                    <div class="checkbox">
-                        <label for="checkTt_content_showHidden">
-                            <input type="checkbox" id="checkTt_content_showHidden" class="checkbox" name="SET[tt_content_showHidden]" value="1" ' . ($this->MOD_SETTINGS['tt_content_showHidden'] ? 'checked="checked"' : '') . ' />
-                            ' . htmlspecialchars($this->getLanguageService()->getLL('hiddenCE')) . ' (<span class="t3js-hidden-counter">' . $numberOfHiddenElements . '</span>)
-                        </label>
-                    </div>';
-            }
+            $tableOutput .= '
+                <div class="checkbox">
+                    <label for="checkTt_content_showHidden">
+                        <input type="checkbox" id="checkTt_content_showHidden" class="checkbox" name="SET[tt_content_showHidden]" value="1" ' . ($this->MOD_SETTINGS['tt_content_showHidden'] ? 'checked="checked"' : '') . ' />
+                        ' . htmlspecialchars($this->getLanguageService()->getLL('hiddenCE')) . ' (<span class="t3js-hidden-counter">' . $numberOfHiddenElements . '</span>)
+                    </label>
+                </div>';
         }
-        $tableOutput .= $h_func_b;
 
         // Init the content
         $content = '';
@@ -766,7 +745,26 @@ class PageLayoutController
         $this->buttonBar->addButton($contextSensitiveHelpButton);
         $lang = $this->getLanguageService();
         // View page
-        if (!VersionState::cast($this->pageinfo['t3ver_state'])->equals(VersionState::DELETE_PLACEHOLDER)) {
+        $pageTsConfig = BackendUtility::getPagesTSconfig($this->id);
+        // Exclude sysfolders, spacers and recycler by default
+        $excludeDokTypes = [
+            PageRepository::DOKTYPE_RECYCLER,
+            PageRepository::DOKTYPE_SYSFOLDER,
+            PageRepository::DOKTYPE_SPACER
+        ];
+        // Custom override of values
+        if (isset($pageTsConfig['TCEMAIN.']['preview.']['disableButtonForDokType'])) {
+            $excludeDokTypes = GeneralUtility::intExplode(
+                ',',
+                $pageTsConfig['TCEMAIN.']['preview.']['disableButtonForDokType'],
+                true
+            );
+        }
+
+        if (
+            !in_array((int)$this->pageinfo['doktype'], $excludeDokTypes, true)
+            && !VersionState::cast($this->pageinfo['t3ver_state'])->equals(VersionState::DELETE_PLACEHOLDER)
+        ) {
             $languageParameter = $this->current_sys_language ? ('&L=' . $this->current_sys_language) : '';
             $onClick = BackendUtility::viewOnClick(
                 $this->pageinfo['uid'],
@@ -819,7 +817,7 @@ class PageLayoutController
                     $queryBuilder->getRestrictions()
                         ->removeAll()
                         ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
-                        ->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class));
+                        ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, (int)$this->getBackendUser()->workspace));
                     $overlayRecord = $queryBuilder
                         ->select('uid')
                         ->from('pages')
@@ -836,6 +834,7 @@ class PageLayoutController
                         ->setMaxResults(1)
                         ->execute()
                         ->fetch();
+                    BackendUtility::workspaceOL('pages', $overlayRecord, (int)$this->getBackendUser()->workspace);
                     // Edit button
                     $urlParameters = [
                         'edit' => [
@@ -890,7 +889,7 @@ class PageLayoutController
         $queryBuilder->getRestrictions()
             ->removeAll()
             ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
-            ->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class));
+            ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, (int)$this->getBackendUser()->workspace));
 
         $queryBuilder
             ->count('uid')
@@ -970,7 +969,7 @@ class PageLayoutController
     /**
      * Check if page can be edited by current user
      *
-     * @param int|null $languageId
+     * @param int $languageId
      * @return bool
      */
     protected function isPageEditable(int $languageId): bool
