@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Backend\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Configuration\SiteTcaConfiguration;
@@ -29,10 +31,9 @@ use TYPO3\CMS\Backend\Template\ModuleTemplate;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Configuration\SiteConfiguration;
-use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Database\ConnectionPool;
-use TYPO3\CMS\Core\Database\Query\Restriction\BackendWorkspaceRestriction;
 use TYPO3\CMS\Core\Database\Query\Restriction\HiddenRestriction;
+use TYPO3\CMS\Core\Database\Query\Restriction\WorkspaceRestriction;
 use TYPO3\CMS\Core\Domain\Repository\PageRepository;
 use TYPO3\CMS\Core\Exception\SiteNotFoundException;
 use TYPO3\CMS\Core\Http\HtmlResponse;
@@ -41,9 +42,11 @@ use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Localization\LanguageService;
 use TYPO3\CMS\Core\Messaging\FlashMessage;
 use TYPO3\CMS\Core\Messaging\FlashMessageService;
+use TYPO3\CMS\Core\Site\Entity\Site;
 use TYPO3\CMS\Core\Site\SiteFinder;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
+use TYPO3\CMS\Core\Utility\StringUtility;
 use TYPO3\CMS\Fluid\View\StandaloneView;
 use TYPO3Fluid\Fluid\View\ViewInterface;
 
@@ -56,6 +59,8 @@ use TYPO3Fluid\Fluid\View\ViewInterface;
  */
 class SiteConfigurationController
 {
+    protected const ALLOWED_ACTIONS = ['overview', 'edit', 'save', 'delete'];
+
     /**
      * @var ModuleTemplate
      */
@@ -94,8 +99,14 @@ class SiteConfigurationController
         $this->moduleTemplate->getPageRenderer()->loadRequireJsModule('TYPO3/CMS/Backend/ContextMenu');
         $this->moduleTemplate->getPageRenderer()->loadRequireJsModule('TYPO3/CMS/Backend/Modal');
         $action = $request->getQueryParams()['action'] ?? $request->getParsedBody()['action'] ?? 'overview';
+
+        if (!in_array($action, self::ALLOWED_ACTIONS, true)) {
+            return new HtmlResponse('Action not allowed', 400);
+        }
+
         $this->initializeView($action);
-        $result = call_user_func_array([$this, $action . 'Action'], [$request]);
+
+        $result = $this->{$action . 'Action'}($request);
         if ($result instanceof ResponseInterface) {
             return $result;
         }
@@ -122,9 +133,11 @@ class SiteConfigurationController
                 $unassignedSites[] = $site;
             }
         }
+
         $this->view->assignMultiple([
             'pages' => $pages,
-            'unassignedSites' => $unassignedSites
+            'unassignedSites' => $unassignedSites,
+            'duplicatedEntryPoints' => $this->getDuplicatedEntryPoints($allSites, $pages),
         ]);
     }
 
@@ -304,7 +317,13 @@ class SiteConfigurationController
                         break;
 
                     case 'select':
-                        $newSysSiteData[$fieldName] = MathUtility::canBeInterpretedAsInteger($fieldValue) ? (int)$fieldValue : $fieldValue;
+                        if (MathUtility::canBeInterpretedAsInteger($fieldValue)) {
+                            $fieldValue = (int)$fieldValue;
+                        } elseif (is_array($fieldValue)) {
+                            $fieldValue = implode(',', $fieldValue);
+                        }
+
+                        $newSysSiteData[$fieldName] = $fieldValue;
                         break;
 
                     case 'check':
@@ -324,7 +343,7 @@ class SiteConfigurationController
             $newSiteConfiguration = $this->validateFullStructure($newSysSiteData);
 
             // Persist the configuration
-            $siteConfigurationManager = GeneralUtility::makeInstance(SiteConfiguration::class, Environment::getConfigPath() . '/sites');
+            $siteConfigurationManager = GeneralUtility::makeInstance(SiteConfiguration::class);
             if (!$isNewConfiguration && $currentIdentifier !== $siteIdentifier) {
                 $siteConfigurationManager->rename($currentIdentifier, $siteIdentifier);
             }
@@ -360,7 +379,7 @@ class SiteConfigurationController
                 $this->siteFinder->getSiteByIdentifier($identifier);
                 // Force this identifier to be unique
                 $originalIdentifier = $identifier;
-                $identifier = $identifier . '-' . str_replace('.', '', uniqid((string)random_int(0, mt_getrandmax()), true));
+                $identifier = StringUtility::getUniqueId($identifier . '-');
                 $message = sprintf(
                     $languageService->sL('LLL:EXT:backend/Resources/Private/Language/locallang_siteconfiguration.xlf:validation.identifierRenamed.message'),
                     $originalIdentifier,
@@ -493,6 +512,7 @@ class SiteConfigurationController
                 }
                 if (!in_array((int)$child['errorCode'], $uniqueCriteria, true)) {
                     $uniqueCriteria[] = (int)$child['errorCode'];
+                    $child['errorCode'] = (int)$child['errorCode'];
                     $validChildren[] = $child;
                 } else {
                     $message = sprintf(
@@ -524,6 +544,7 @@ class SiteConfigurationController
             }
             if (!in_array((int)$child['languageId'], $uniqueCriteria, true)) {
                 $uniqueCriteria[] = (int)$child['languageId'];
+                $child['languageId'] = (int)$child['languageId'];
                 $validChildren[] = $child;
             } else {
                 $message = sprintf(
@@ -539,6 +560,13 @@ class SiteConfigurationController
         }
         $newSysSiteData['languages'] = $validChildren;
 
+        // cleanup configuration
+        foreach ($newSysSiteData as $identifier => $value) {
+            if (is_array($value) && empty($value)) {
+                unset($newSysSiteData[$identifier]);
+            }
+        }
+
         return $newSysSiteData;
     }
 
@@ -555,7 +583,7 @@ class SiteConfigurationController
             throw new \RuntimeException('Not site identifier given', 1521565182);
         }
         // Verify site does exist, method throws if not
-        GeneralUtility::makeInstance(SiteConfiguration::class, Environment::getConfigPath() . '/sites')->delete($siteIdentifier);
+        GeneralUtility::makeInstance(SiteConfiguration::class)->delete($siteIdentifier);
         $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
         $overviewRoute = $uriBuilder->buildUriFromRoute('site_configuration', ['action' => 'overview']);
         return new RedirectResponse($overviewRoute);
@@ -630,7 +658,7 @@ class SiteConfigurationController
     {
         $queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable('pages');
         $queryBuilder->getRestrictions()->removeByType(HiddenRestriction::class);
-        $queryBuilder->getRestrictions()->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class, 0, false));
+        $queryBuilder->getRestrictions()->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, 0));
         $statement = $queryBuilder
             ->select('*')
             ->from('pages')
@@ -662,6 +690,38 @@ class SiteConfigurationController
         return $pages;
     }
 
+    /**
+     * Get all entry duplicates which are used multiple times
+     *
+     * @param Site[] $allSites
+     * @param array $pages
+     * @return array
+     */
+    protected function getDuplicatedEntryPoints(array $allSites, array $pages): array
+    {
+        $duplicatedEntryPoints = [];
+
+        foreach ($allSites as $identifier => $site) {
+            if (!isset($pages[$site->getRootPageId()])) {
+                continue;
+            }
+            foreach ($site->getAllLanguages() as $language) {
+                $base = $language->getBase();
+                $entryPoint = rtrim((string)$language->getBase(), '/');
+                $scheme = $base->getScheme() ? $base->getScheme() . '://' : '//';
+                $entryPointWithoutScheme = str_replace($scheme, '', $entryPoint);
+                if (!isset($duplicatedEntryPoints[$entryPointWithoutScheme][$entryPoint])) {
+                    $duplicatedEntryPoints[$entryPointWithoutScheme][$entryPoint] = 1;
+                } else {
+                    $duplicatedEntryPoints[$entryPointWithoutScheme][$entryPoint]++;
+                }
+            }
+        }
+        return array_filter($duplicatedEntryPoints, static function (array $variants): bool {
+            return count($variants) > 1 || reset($variants) > 1;
+        }, ARRAY_FILTER_USE_BOTH);
+    }
+
     /**
      * @return LanguageService
      */
