@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\Container;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Form\Container;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\Container;
+
 use TYPO3\CMS\Backend\Form\InlineStackProcessor;
 use TYPO3\CMS\Backend\Form\NodeFactory;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
@@ -175,6 +176,7 @@ class InlineControlContainer extends AbstractContainer
         $this->inlineData['config'][$nameObject] = [
             'table' => $foreign_table,
         ];
+        $configJson = (string)json_encode($config);
         $this->inlineData['config'][$nameObject . '-' . $foreign_table] = [
             'min' => $config['minitems'],
             'max' => $config['maxitems'],
@@ -184,8 +186,8 @@ class InlineControlContainer extends AbstractContainer
                 'uid' => $top['uid']
             ],
             'context' => [
-                'config' => $config,
-                'hmac' => GeneralUtility::hmac(json_encode($config), 'InlineContext'),
+                'config' => $configJson,
+                'hmac' => GeneralUtility::hmac($configJson, 'InlineContext'),
             ],
         ];
         $this->inlineData['nested'][$nameObject] = $this->data['tabAndInlineStack'];
@@ -259,41 +261,42 @@ class InlineControlContainer extends AbstractContainer
             }
         }
 
-        // Render the localization links if needed
-        $localizationLinks = '';
+        // Render the localization buttons if needed
+        $localizationButtons = '';
         if ($numberOfNotYetLocalizedChildren) {
-            // Add the "Localize all records" link before all child records:
+            // Add the "Localize all records" button before all child records:
             if (isset($config['appearance']['showAllLocalizationLink']) && $config['appearance']['showAllLocalizationLink']) {
-                $localizationLinks = ' ' . $this->getLevelInteractionLink('localize', $nameObject . '-' . $foreign_table, $config);
+                $localizationButtons = ' ' . $this->getLevelInteractionButton('localize', $config);
             }
-            // Add the "Synchronize with default language" link before all child records:
+            // Add the "Synchronize with default language" button before all child records:
             if (isset($config['appearance']['showSynchronizationLink']) && $config['appearance']['showSynchronizationLink']) {
-                $localizationLinks .= ' ' . $this->getLevelInteractionLink('synchronize', $nameObject . '-' . $foreign_table, $config);
+                $localizationButtons .= ' ' . $this->getLevelInteractionButton('synchronize', $config);
             }
         }
 
-        // Define how to show the "Create new record" link - if there are more than maxitems, hide it
+        // Define how to show the "Create new record" button - if there are more than maxitems, hide it
         if ($isReadOnly || $numberOfFullLocalizedChildren >= $config['maxitems'] || ($uniqueMax > 0 && $numberOfFullLocalizedChildren >= $uniqueMax)) {
             $config['inline']['inlineNewButtonStyle'] = 'display: none;';
             $config['inline']['inlineNewRelationButtonStyle'] = 'display: none;';
             $config['inline']['inlineOnlineMediaAddButtonStyle'] = 'display: none;';
         }
 
-        // Render the level links (create new record):
-        $levelLinks = '';
+        // Render the "new record" level button:
+        $newRecordButton = '';
         if (!empty($config['appearance']['enabledControls']['new'])) {
-            $levelLinks = $this->getLevelInteractionLink('newRecord', $nameObject . '-' . $foreign_table, $config);
+            $newRecordButton = $this->getLevelInteractionButton('newRecord', $config);
         }
+
         // Wrap all inline fields of a record with a <div> (like a container)
-        $html = '<div class="form-group" id="' . htmlspecialchars($nameObject) . '" data-uid="' . htmlspecialchars($row['uid']) . '" data-foreign-table="' . htmlspecialchars($foreign_table) . '" data-object-group="' . htmlspecialchars($nameObject) . '-' . htmlspecialchars($foreign_table) . '" data-form-field="' . htmlspecialchars($nameForm) . '" data-appearance="' . htmlspecialchars(json_encode($config['appearance'])) . '">';
+        $html = '<div class="form-group" id="' . htmlspecialchars($nameObject) . '" data-uid="' . htmlspecialchars((string)$row['uid']) . '" data-foreign-table="' . htmlspecialchars($foreign_table) . '" data-object-group="' . htmlspecialchars($nameObject) . '-' . htmlspecialchars((string)$foreign_table) . '" data-form-field="' . htmlspecialchars($nameForm) . '" data-appearance="' . htmlspecialchars((string)json_encode($config['appearance'])) . '">';
 
         $fieldInformationResult = $this->renderFieldInformation();
         $html .= $fieldInformationResult['html'];
         $resultArray = $this->mergeChildReturnIntoExistingResult($resultArray, $fieldInformationResult, false);
 
-        // Add the level links before all child records:
+        // Add the level buttons before all child records:
         if ($config['appearance']['levelLinksPosition'] === 'both' || $config['appearance']['levelLinksPosition'] === 'top') {
-            $html .= '<div class="form-group t3js-formengine-validation-marker">' . $levelLinks . $localizationLinks . '</div>';
+            $html .= '<div class="form-group t3js-formengine-validation-marker">' . $newRecordButton . $localizationButtons . '</div>';
         }
 
         // If it's required to select from possible child records (reusable children), add a selector box
@@ -303,7 +306,7 @@ class InlineControlContainer extends AbstractContainer
             } else {
                 $selectorBox = $this->renderPossibleRecordsSelectorTypeGroupDB($config);
             }
-            $html .= $selectorBox . $localizationLinks;
+            $html .= $selectorBox . $localizationButtons;
         }
 
         $title = $languageService->sL(trim($parameterArray['fieldConf']['label']));
@@ -336,9 +339,9 @@ class InlineControlContainer extends AbstractContainer
         $resultArray = $this->mergeChildReturnIntoExistingResult($resultArray, $fieldWizardResult, false);
         $html .= $fieldWizardHtml;
 
-        // Add the level links after all child records:
+        // Add the level buttons after all child records:
         if (!$isReadOnly && ($config['appearance']['levelLinksPosition'] === 'both' || $config['appearance']['levelLinksPosition'] === 'bottom')) {
-            $html .= $levelLinks . $localizationLinks;
+            $html .= $newRecordButton . $localizationButtons;
         }
         if (is_array($config['customControls'])) {
             $html .= '<div id="' . $nameObject . '_customControls">';
@@ -378,15 +381,14 @@ class InlineControlContainer extends AbstractContainer
     }
 
     /**
-     * Creates the HTML code of a general link to be used on a level of inline children.
+     * Creates the HTML code of a general button to be used on a level of inline children.
      * The possible keys for the parameter $type are 'newRecord', 'localize' and 'synchronize'.
      *
-     * @param string $type The link type, values are 'newRecord', 'localize' and 'synchronize'.
-     * @param string $objectPrefix The "path" to the child record to create (e.g. 'data-parentPageId-parentTable-parentUid-parentField-childTable]')
+     * @param string $type The button type, values are 'newRecord', 'localize' and 'synchronize'.
      * @param array $conf TCA configuration of the parent(!) field
-     * @return string The HTML code of the new link, wrapped in a div
+     * @return string The HTML code of the new button, wrapped in a div
      */
-    protected function getLevelInteractionLink($type, $objectPrefix, $conf = [])
+    protected function getLevelInteractionButton(string $type, array $conf = []): string
     {
         $languageService = $this->getLanguageService();
         $attributes = [];
@@ -394,7 +396,7 @@ class InlineControlContainer extends AbstractContainer
             case 'newRecord':
                 $title = htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:cm.createnew'));
                 $icon = 'actions-add';
-                $className = 'typo3-newRecordLink';
+                $className = 'typo3-newRecordLink t3js-inline-controls';
                 $attributes['class'] = 'btn btn-default t3js-create-new-button';
                 if (!empty($conf['inline']['inlineNewButtonStyle'])) {
                     $attributes['style'] = $conf['inline']['inlineNewButtonStyle'];
@@ -427,32 +429,30 @@ class InlineControlContainer extends AbstractContainer
                 $icon = '';
                 $className = '';
         }
-        // Create the link:
+        // Create the button:
         $icon = $icon ? $this->iconFactory->getIcon($icon, Icon::SIZE_SMALL)->render() : '';
-        $link = $this->wrapWithAnchor($icon . ' ' . $title, '#', $attributes);
-        return '<div' . ($className ? ' class="' . $className . '"' : '') . 'title="' . $title . '">' . $link . '</div>';
+        $button = $this->wrapWithButton($icon . ' ' . $title, $attributes);
+        return '<div' . ($className ? ' class="' . $className . '"' : '') . 'title="' . $title . '">' . $button . '</div>';
     }
 
     /**
-     * Wraps a text with an anchor and returns the HTML representation.
+     * Wraps a text with a button and returns the HTML representation.
      *
-     * @param string $text The text to be wrapped by an anchor
-     * @param string $link The link to be used in the anchor
-     * @param array $attributes Array of attributes to be used in the anchor
+     * @param string $text The text to be wrapped by a button
+     * @param array<string, string> $attributes Array of attributes to be used in the anchor
      * @return string The wrapped text as HTML representation
      */
-    protected function wrapWithAnchor($text, $link, $attributes = [])
+    protected function wrapWithButton(string $text, array $attributes = []): string
     {
-        $attributes['href'] = trim($link ?: '#');
-        return '<a ' . GeneralUtility::implodeAttributes($attributes, true, true) . '>' . $text . '</a>';
+        return '<button type="button" ' . GeneralUtility::implodeAttributes($attributes, true, true) . '>' . $text . '</button>';
     }
 
     /**
-     * Generate a link that opens an element browser in a new window.
+     * Generate a button that opens an element browser in a new window.
      * For group/db there is no way to use a "selector" like a <select>|</select>-box.
      *
      * @param array $inlineConfiguration TCA inline configuration of the parent(!) field
-     * @return string A HTML link that opens an element browser in a new window
+     * @return string A HTML button that opens an element browser in a new window
      */
     protected function renderPossibleRecordsSelectorTypeGroupDB(array $inlineConfiguration)
     {
@@ -505,11 +505,11 @@ class InlineControlContainer extends AbstractContainer
         $item = '';
         if ($elementBrowserEnabled) {
             $item .= '
-			<a href="#" class="btn btn-default t3js-element-browser" data-mode="' . htmlspecialchars($mode) . '" data-params="' . htmlspecialchars($browserParams) . '"
+			<button type="button" class="btn btn-default t3js-element-browser" data-mode="' . htmlspecialchars($mode) . '" data-params="' . htmlspecialchars($browserParams) . '"
 				' . $buttonStyle . ' title="' . $createNewRelationText . '">
 				' . $this->iconFactory->getIcon('actions-insert-record', Icon::SIZE_SMALL)->render() . '
 				' . $createNewRelationText . '
-			</a>';
+			</button>';
         }
 
         $isDirectFileUploadEnabled = (bool)$backendUser->uc['edit_docModuleUpload'];
@@ -520,7 +520,7 @@ class InlineControlContainer extends AbstractContainer
         }
         if (($showUpload || $showByUrl) && $isDirectFileUploadEnabled) {
             $folder = $backendUser->getDefaultUploadFolder(
-                $this->data['parentPageRow']['uid'],
+                $this->data['tableName'] === 'pages' ? $this->data['vanillaUid'] : $this->data['parentPageRow']['uid'],
                 $this->data['tableName'],
                 $this->data['fieldName']
             );
@@ -530,18 +530,18 @@ class InlineControlContainer extends AbstractContainer
             ) {
                 if ($showUpload) {
                     $maxFileSize = GeneralUtility::getMaxUploadFileSize() * 1024;
-                    $item .= ' <a href="#" class="btn btn-default t3js-drag-uploader inlineNewFileUploadButton"
+                    $item .= ' <button type="button" class="btn btn-default t3js-drag-uploader inlineNewFileUploadButton"
 					' . $buttonStyle . '
 					data-dropzone-target="#' . htmlspecialchars(StringUtility::escapeCssSelector($currentStructureDomObjectIdPrefix)) . '"
 					data-insert-dropzone-before="1"
 					data-file-irre-object="' . htmlspecialchars($objectPrefix) . '"
 					data-file-allowed="' . htmlspecialchars($allowed) . '"
 					data-target-folder="' . htmlspecialchars($folder->getCombinedIdentifier()) . '"
-					data-max-file-size="' . htmlspecialchars($maxFileSize) . '"
+					data-max-file-size="' . htmlspecialchars((string)$maxFileSize) . '"
 					>';
                     $item .= $this->iconFactory->getIcon('actions-upload', Icon::SIZE_SMALL)->render() . ' ';
                     $item .= htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:file_upload.select-and-submit'));
-                    $item .= '</a>';
+                    $item .= '</button>';
 
                     $this->requireJsModules[] = ['TYPO3/CMS/Backend/DragUploader' => 'function(dragUploader){dragUploader.initialize()}'];
                 }
@@ -556,7 +556,7 @@ class InlineControlContainer extends AbstractContainer
                     $buttonSubmit = htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:online_media.new_media.submit'));
                     $allowedMediaUrl = htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:cm.allowEmbedSources'));
                     $item .= '
-						<span class="btn btn-default t3js-online-media-add-btn"
+						<button type="button" class="btn btn-default t3js-online-media-add-btn"
 							' . $buttonStyle . '
 							data-file-irre-object="' . htmlspecialchars($objectPrefix) . '"
 							data-online-media-allowed="' . htmlspecialchars(implode(',', $onlineMediaAllowed)) . '"
@@ -567,7 +567,7 @@ class InlineControlContainer extends AbstractContainer
 							data-placeholder="' . $placeholder . '"
 							>
 							' . $this->iconFactory->getIcon('actions-online-media-add', Icon::SIZE_SMALL)->render() . '
-							' . $buttonText . '</span>';
+							' . $buttonText . '</button>';
                 }
             }
         }
@@ -596,7 +596,6 @@ class InlineControlContainer extends AbstractContainer
      */
     protected function renderPossibleRecordsSelectorTypeSelect(array $config, array $uniqueIds)
     {
-        $onChange = '';
         $possibleRecords = $config['selectorOrUniquePossibleRecords'];
         $nameObject = $this->inlineStackProcessor->getCurrentStructureDomObjectIdPrefix($this->data['inlineFirstPid']);
         // Create option tags:
@@ -615,7 +614,7 @@ class InlineControlContainer extends AbstractContainer
             </select>';
 
         if ($size <= 1) {
-            // Add a "Create new relation" link for adding new relations
+            // Add a "Create new relation" button for adding new relations
             // This is necessary, if the size of the selector is "1" or if
             // there is only one record item in the select-box, that is selected by default
             // The selector-box creates a new relation on using an onChange event (see some line above)
@@ -626,9 +625,9 @@ class InlineControlContainer extends AbstractContainer
             }
             $item .= '
             <span class="input-group-btn">
-                <a href="#" class="btn btn-default" onclick="' . htmlspecialchars($onChange) . '" title="' . $createNewRelationText . '">
+                <button type="button" class="btn btn-default t3js-create-new-button" title="' . $createNewRelationText . '">
                     ' . $this->iconFactory->getIcon('actions-add', Icon::SIZE_SMALL)->render() . $createNewRelationText . '
-                </a>
+                </button>
             </span>';
         } else {
             $item .= '
