@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\Container;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,15 +13,19 @@ namespace TYPO3\CMS\Backend\Form\Container;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\Container;
+
 use TYPO3\CMS\Backend\Form\Element\InlineElementHookInterface;
 use TYPO3\CMS\Backend\Form\Exception\AccessDeniedContentEditException;
 use TYPO3\CMS\Backend\Form\InlineStackProcessor;
 use TYPO3\CMS\Backend\Form\NodeFactory;
+use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Imaging\IconFactory;
+use TYPO3\CMS\Core\Imaging\ImageManipulation\CropVariantCollection;
 use TYPO3\CMS\Core\Localization\LanguageService;
 use TYPO3\CMS\Core\Resource\ProcessedFile;
 use TYPO3\CMS\Core\Resource\ResourceFactory;
@@ -122,7 +125,7 @@ class InlineRecordContainer extends AbstractContainer
         // Get the current naming scheme for DOM name/id attributes:
         $appendFormFieldNames = '[' . $foreignTable . '][' . $record['uid'] . ']';
         $objectId = $domObjectId . '-' . $foreignTable . '-' . $record['uid'];
-        $class = '';
+        $classes = [];
         $html = '';
         $combinationHtml = '';
         $isNewRecord = $data['command'] === 'new';
@@ -143,8 +146,8 @@ class InlineRecordContainer extends AbstractContainer
                 $html = $childArray['html'];
                 $resultArray = $this->mergeChildReturnIntoExistingResult($resultArray, $childArray, false);
             } else {
-                // This string is the marker for the JS-function to check if the full content has already been loaded
-                $html = '<!--notloaded-->';
+                // This class is the marker for the JS-function to check if the full content has already been loaded
+                $classes[] = 't3js-not-loaded';
             }
             if ($isNewRecord) {
                 // Add pid of record as hidden field
@@ -171,7 +174,7 @@ class InlineRecordContainer extends AbstractContainer
                 }
             }
             // If this record should be shown collapsed
-            $class = $data['isInlineChildExpanded'] ? 'panel-visible' : 'panel-collapsed';
+            $classes[] = $data['isInlineChildExpanded'] ? 'panel-visible' : 'panel-collapsed';
         }
         $hiddenFieldHtml = implode(LF, $resultArray['additionalHiddenFields'] ?? []);
 
@@ -181,12 +184,14 @@ class InlineRecordContainer extends AbstractContainer
         } else {
             // Render header row and content (if expanded)
             if ($data['isInlineDefaultLanguageRecordInLocalizedParentContext']) {
-                $class .= ' t3-form-field-container-inline-placeHolder';
+                $classes[] = 't3-form-field-container-inline-placeHolder';
             }
             if (!empty($hiddenField) && isset($record[$hiddenField]) && (int)$record[$hiddenField]) {
-                $class .= ' t3-form-field-container-inline-hidden';
+                $classes[] = 't3-form-field-container-inline-hidden';
+            }
+            if ($isNewRecord) {
+                $classes[] = 'inlineIsNewRecord';
             }
-            $class .= ($isNewRecord ? ' inlineIsNewRecord' : '');
 
             $originalUniqueValue = '';
             if (isset($data['inlineData']['unique'][$domObjectId . '-' . $foreignTable]['used'][$record['uid']])) {
@@ -194,20 +199,29 @@ class InlineRecordContainer extends AbstractContainer
                 // in case of site_language we don't have the full form engine options, so fallbacks need to be taken into account
                 $originalUniqueValue = ($uniqueValueValues['table'] ?? $foreignTable) . '_' . ($uniqueValueValues['uid'] ?? $uniqueValueValues);
             }
+
+            // The hashed object id needs a non-numeric prefix, the value is used as ID selector in JavaScript
+            $hashedObjectId = 'hash-' . md5($objectId);
             $containerAttributes = [
                 'id' => $objectId . '_div',
-                'class' => 'form-irre-object panel panel-default panel-condensed ' . trim($class),
+                'class' => 'form-irre-object panel panel-default panel-condensed ' . trim(implode(' ', $classes)),
                 'data-object-uid' => $record['uid'],
                 'data-object-id' => $objectId,
+                'data-object-id-hash' => $hashedObjectId,
+                'data-object-parent-group' => $domObjectId . '-' . $foreignTable,
                 'data-field-name' => $appendFormFieldNames,
                 'data-topmost-parent-table' => $data['inlineTopMostParentTableName'],
                 'data-topmost-parent-uid' => $data['inlineTopMostParentUid'],
                 'data-table-unique-original-value' => $originalUniqueValue,
+                'data-placeholder-record' => $data['isInlineDefaultLanguageRecordInLocalizedParentContext'] ? '1' : '0'
             ];
 
+            $ariaExpanded = $data['isInlineChildExpanded'] ? 'true' : 'false';
+            $ariaControls = htmlspecialchars($objectId . '_fields', ENT_QUOTES | ENT_HTML5);
+            $data['ariaAttributesString'] = 'aria-expanded="' . $ariaExpanded . '" aria-controls="' . $ariaControls . '"';
             $html = '
 				<div ' . GeneralUtility::implodeAttributes($containerAttributes, true) . '>
-					<div class="panel-heading" data-toggle="formengine-inline" id="' . htmlspecialchars($objectId) . '_header" data-expandSingle="' . ($inlineConfig['appearance']['expandSingle'] ? 1 : 0) . '">
+					<div class="panel-heading" data-toggle="formengine-inline" id="' . htmlspecialchars($hashedObjectId, ENT_QUOTES | ENT_HTML5) . '_header" data-expandSingle="' . ($inlineConfig['appearance']['expandSingle'] ? 1 : 0) . '">
 						<div class="form-irre-header">
 							<div class="form-irre-header-cell form-irre-header-icon">
 								<span class="caret"></span>
@@ -215,7 +229,7 @@ class InlineRecordContainer extends AbstractContainer
 							' . $this->renderForeignRecordHeader($data) . '
 						</div>
 					</div>
-					<div class="panel-collapse" id="' . htmlspecialchars($objectId) . '_fields">' . $html . $hiddenFieldHtml . $combinationHtml . '</div>
+					<div class="panel-collapse" id="' . $ariaControls . '">' . $html . $hiddenFieldHtml . $combinationHtml . '</div>
 				</div>';
         }
 
@@ -357,19 +371,19 @@ class InlineRecordContainer extends AbstractContainer
                 }
                 if ($fileObject && $fileObject->isMissing()) {
                     $thumbnail .= '<span class="label label-danger">'
-                        . htmlspecialchars(static::getLanguageService()->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:warning.file_missing'))
+                        . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:warning.file_missing'))
                         . '</span>&nbsp;' . htmlspecialchars($fileObject->getName()) . '<br />';
                 } elseif ($fileObject) {
                     $imageSetup = $inlineConfig['appearance']['headerThumbnail'];
                     unset($imageSetup['field']);
-                    if (!empty($rec['crop'])) {
-                        $imageSetup['crop'] = $rec['crop'];
+                    $cropVariantCollection = CropVariantCollection::create($rec['crop'] ?? '');
+                    if (!$cropVariantCollection->getCropArea()->isEmpty()) {
+                        $imageSetup['crop'] = $cropVariantCollection->getCropArea()->makeAbsoluteBasedOnFile($fileObject);
                     }
-                    $imageSetup = array_merge(['width' => '45', 'height' => '45c'], $imageSetup);
+                    $imageSetup = array_merge(['maxWidth' => '145', 'maxHeight' => '45'], $imageSetup);
 
-                    if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['thumbnails']
-                        && GeneralUtility::inList($GLOBALS['TYPO3_CONF_VARS']['GFX']['imagefile_ext'], $fileObject->getExtension())) {
-                        $processedImage = $fileObject->process(ProcessedFile::CONTEXT_IMAGEPREVIEW, $imageSetup);
+                    if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['thumbnails'] && $fileObject->isImage()) {
+                        $processedImage = $fileObject->process(ProcessedFile::CONTEXT_IMAGECROPSCALEMASK, $imageSetup);
                         // Only use a thumbnail if the processing process was successful by checking if image width is set
                         if ($processedImage->getProperty('width')) {
                             $imageUrl = $processedImage->getPublicUrl(true);
@@ -387,13 +401,15 @@ class InlineRecordContainer extends AbstractContainer
         }
 
         if (!empty($inlineConfig['appearance']['headerThumbnail']['field']) && $thumbnail) {
-            $mediaContainer = '<div class="form-irre-header-cell form-irre-header-thumbnail" id="' . $objectId . '_thumbnailcontainer">' . $thumbnail . '</div>';
+            $mediaContainer = '<div class="form-irre-header-thumbnail" id="' . $objectId . '_thumbnailcontainer">' . $thumbnail . '</div>';
         } else {
-            $mediaContainer = '<div class="form-irre-header-cell form-irre-header-icon" id="' . $objectId . '_iconcontainer">' . $iconImg . '</div>';
+            $mediaContainer = '<div class="form-irre-header-icon" id="' . $objectId . '_iconcontainer">' . $iconImg . '</div>';
         }
-        $header = $mediaContainer . '
-				<div class="form-irre-header-cell form-irre-header-body">' . $label . '</div>
-				<div class="form-irre-header-cell form-irre-header-control t3js-formengine-irre-control">' . $ctrl . '</div>';
+        $header = '<button class="form-irre-header-cell form-irre-header-button" ' . $data['ariaAttributesString'] . '>' .
+            $mediaContainer .
+            '<div class="form-irre-header-body">' . $label . '</div>' .
+            '</button>' .
+            '<div class="form-irre-header-cell form-irre-header-control t3js-formengine-irre-control">' . $ctrl . '</div>';
 
         return $header;
     }
@@ -435,7 +451,7 @@ class InlineRecordContainer extends AbstractContainer
         $isSysFileReferenceTable = $foreignTable === 'sys_file_reference';
         $enableManualSorting = $tcaTableCtrl['sortby'] || $inlineConfig['MM'] || !$data['isOnSymmetricSide']
             && $inlineConfig['foreign_sortby'] || $data['isOnSymmetricSide'] && $inlineConfig['symmetric_sortby'];
-        $calcPerms = $backendUser->calcPerms(BackendUtility::readPageAccess($rec['pid'], $backendUser->getPagePermsClause(Permission::PAGE_SHOW)));
+        $calcPerms = $backendUser->calcPerms(BackendUtility::readPageAccess((int)($data['parentPageRow']['uid'] ?? 0), $backendUser->getPagePermsClause(Permission::PAGE_SHOW)));
         // If the listed table is 'pages' we have to request the permission settings for each page:
         $localCalcPerms = false;
         if ($isPagesTable) {
@@ -469,9 +485,9 @@ class InlineRecordContainer extends AbstractContainer
                 $cells['info'] = '<span class="btn btn-default disabled">' . $this->iconFactory->getIcon('empty-empty', Icon::SIZE_SMALL)->render() . '</span>';
             } else {
                 $cells['info'] = '
-				<a class="btn btn-default" href="#" data-action="infowindow" data-info-table="' . htmlspecialchars($table) . '" data-info-uid="' . htmlspecialchars($uid) . '" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:showInfo')) . '">
+				<button type="button" class="btn btn-default" data-action="infowindow" data-info-table="' . htmlspecialchars($table) . '" data-info-uid="' . htmlspecialchars($uid) . '" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:showInfo')) . '">
 					' . $this->iconFactory->getIcon('actions-document-info', Icon::SIZE_SMALL)->render() . '
-				</a>';
+				</button>';
             }
         }
         // If the table is NOT a read-only table, then show these links:
@@ -484,9 +500,9 @@ class InlineRecordContainer extends AbstractContainer
                         $style = ' style="' . $inlineConfig['inline']['inlineNewButtonStyle'] . '"';
                     }
                     $cells['new'] = '
-                        <a class="btn btn-default t3js-create-new-button" href="#" data-record-uid="' . htmlspecialchars($rec['uid']) . '" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:new' . ($isPagesTable ? 'Page' : 'Record'))) . '" ' . $style . '>
+                        <button type="button" class="btn btn-default t3js-create-new-button" data-record-uid="' . htmlspecialchars($rec['uid']) . '" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:new' . ($isPagesTable ? 'Page' : 'Record'))) . '" ' . $style . '>
                             ' . $this->iconFactory->getIcon('actions-' . ($isPagesTable ? 'page-new' : 'add'), Icon::SIZE_SMALL)->render() . '
-                        </a>';
+                        </button>';
                 }
             }
             // "Up/Down" links
@@ -499,9 +515,9 @@ class InlineRecordContainer extends AbstractContainer
                     $icon = 'empty-empty';
                 }
                 $cells['sort.up'] = '
-                    <a class="btn btn-default' . $class . '" href="#" data-action="sort" data-direction="up" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:moveUp')) . '">
+                    <button type="button" class="btn btn-default' . $class . '" data-action="sort" data-direction="up" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:moveUp')) . '">
                         ' . $this->iconFactory->getIcon($icon, Icon::SIZE_SMALL)->render() . '
-                    </a>';
+                    </button>';
                 // Down
                 $icon = 'actions-move-down';
                 $class = '';
@@ -511,9 +527,9 @@ class InlineRecordContainer extends AbstractContainer
                 }
 
                 $cells['sort.down'] = '
-                    <a class="btn btn-default' . $class . '" href="#" data-action="sort" data-direction="down" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:moveDown')) . '">
+                    <button type="button" class="btn btn-default' . $class . '" data-action="sort" data-direction="down" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:moveDown')) . '">
                         ' . $this->iconFactory->getIcon($icon, Icon::SIZE_SMALL)->render() . '
-                    </a>';
+                    </button>';
             }
             // "Edit" link:
             if (($rec['table_local'] === 'sys_file') && !$isNewItem && $backendUser->check('tables_modify', 'sys_file_metadata')) {
@@ -540,7 +556,7 @@ class InlineRecordContainer extends AbstractContainer
                     ->execute()
                     ->fetch();
                 if (!empty($recordInDatabase)) {
-                    $uriBuilder = GeneralUtility::makeInstance(\TYPO3\CMS\Backend\Routing\UriBuilder::class);
+                    $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
                     $url = (string)$uriBuilder->buildUriFromRoute('record_edit', [
                         'edit[sys_file_metadata][' . (int)$recordInDatabase['uid'] . ']' => 'edit',
                         'returnUrl' => $this->data['returnUrl']
@@ -559,7 +575,7 @@ class InlineRecordContainer extends AbstractContainer
             ) {
                 $title = htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:delete'));
                 $icon = $this->iconFactory->getIcon('actions-edit-delete', Icon::SIZE_SMALL)->render();
-                $cells['delete'] = '<a href="#" class="btn btn-default t3js-editform-delete-inline-record" title="' . $title . '">' . $icon . '</a>';
+                $cells['delete'] = '<button type="button" class="btn btn-default t3js-editform-delete-inline-record" title="' . $title . '">' . $icon . '</button>';
             }
 
             // "Hide/Unhide" links:
@@ -568,15 +584,15 @@ class InlineRecordContainer extends AbstractContainer
                 if ($rec[$hiddenField]) {
                     $title = htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:unHide' . ($isPagesTable ? 'Page' : '')));
                     $cells['hide'] = '
-                        <a class="btn btn-default t3js-toggle-visibility-button" data-hidden-field="' . htmlspecialchars($hiddenField) . '" href="#" title="' . $title . '">
+                        <button type="button" class="btn btn-default t3js-toggle-visibility-button" data-hidden-field="' . htmlspecialchars($hiddenField) . '" title="' . $title . '">
                             ' . $this->iconFactory->getIcon('actions-edit-unhide', Icon::SIZE_SMALL)->render() . '
-                        </a>';
+                        </button>';
                 } else {
                     $title = htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_mod_web_list.xlf:hide' . ($isPagesTable ? 'Page' : '')));
                     $cells['hide'] = '
-                        <a class="btn btn-default t3js-toggle-visibility-button" data-hidden-field="' . htmlspecialchars($hiddenField) . '" href="#" title="' . $title . '">
+                        <button type="button" class="btn btn-default t3js-toggle-visibility-button" data-hidden-field="' . htmlspecialchars($hiddenField) . '" title="' . $title . '">
                             ' . $this->iconFactory->getIcon('actions-edit-hide', Icon::SIZE_SMALL)->render() . '
-                        </a>';
+                        </button>';
                 }
             }
             // Drag&Drop Sorting: Sortable handler for script.aculo.us
@@ -589,17 +605,17 @@ class InlineRecordContainer extends AbstractContainer
         } elseif ($data['isInlineDefaultLanguageRecordInLocalizedParentContext'] && $isParentExisting) {
             if ($enabledControls['localize'] && $data['isInlineDefaultLanguageRecordInLocalizedParentContext']) {
                 $cells['localize'] = '
-                    <a class="btn btn-default t3js-synchronizelocalize-button" href="#" data-type="' . htmlspecialchars($rec['uid']) . '" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_misc.xlf:localize')) . '">
+                    <button type="button" class="btn btn-default t3js-synchronizelocalize-button" data-type="' . htmlspecialchars($rec['uid']) . '" title="' . htmlspecialchars($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_misc.xlf:localize')) . '">
                         ' . $this->iconFactory->getIcon('actions-document-localize', Icon::SIZE_SMALL)->render() . '
-                    </a>';
+                    </button>';
             }
         }
         // If the record is edit-locked by another user, we will show a little warning sign:
         if ($lockInfo = BackendUtility::isRecordLocked($foreignTable, $rec['uid'])) {
             $cells['locked'] = '
-				<a class="btn btn-default" href="#" data-toggle="tooltip" data-title="' . htmlspecialchars($lockInfo['msg']) . '">
+				<button type="button" class="btn btn-default" data-toggle="tooltip" data-title="' . htmlspecialchars($lockInfo['msg']) . '">
 					<span title="' . htmlspecialchars($lockInfo['msg']) . '">' . $this->iconFactory->getIcon('warning-in-use', Icon::SIZE_SMALL)->render() . '</span>
-				</a>';
+				</button>';
         }
         // Hook: Post-processing of single controls for specific child records:
         foreach ($this->hookObjects as $hookObj) {
