@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\Element;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Form\Element;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\Element;
+
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Localization\LanguageService;
@@ -245,9 +246,8 @@ class GroupElement extends AbstractFormElement
         $selectorAttributes = [
             'id' => $fieldId,
             'data-formengine-input-name' => htmlspecialchars($elementName),
-            'data-formengine-validation-rules' => $this->getValidationDataAsJsonString($config),
-            'data-maxitems' => $maxItems,
-            'size' => $size,
+            'data-maxitems' => (string)$maxItems,
+            'size' => (string)$size,
         ];
         $selectorClasses = [
             'form-control',
@@ -286,9 +286,9 @@ class GroupElement extends AbstractFormElement
             $html[] =                   ' data-tablename="' . htmlspecialchars($table) . '"';
             $html[] =                   ' data-field="' . htmlspecialchars($elementName) . '"';
             $html[] =                   ' data-uid="' . htmlspecialchars($this->data['databaseRow']['uid']) . '"';
-            $html[] =                   ' data-pid="' . htmlspecialchars($this->data['effectivePid']) . '"';
+            $html[] =                   ' data-pid="' . htmlspecialchars($this->data['parentPageRow']['uid'] ?? 0) . '"';
             $html[] =                   ' data-fieldtype="' . htmlspecialchars($config['type']) . '"';
-            $html[] =                   ' data-minchars="' . htmlspecialchars($suggestMinimumCharacters) . '"';
+            $html[] =                   ' data-minchars="' . htmlspecialchars((string)$suggestMinimumCharacters) . '"';
             $html[] =                   ' data-datastructureidentifier="' . htmlspecialchars($dataStructureIdentifier) . '"';
             $html[] =                   ' data-flexformsheetname="' . htmlspecialchars($flexFormSheetName) . '"';
             $html[] =                   ' data-flexformfieldname="' . htmlspecialchars($flexFormFieldName) . '"';
@@ -364,7 +364,12 @@ class GroupElement extends AbstractFormElement
             $html[] = '</div>';
         }
         $html[] =   '</div>';
-        $html[] =   '<input type="hidden" name="' . htmlspecialchars($elementName) . '" value="' . htmlspecialchars(implode(',', $listOfSelectedValues)) . '" />';
+        $html[] =   '<input type="hidden"';
+        $html[] =       ' data-formengine-validation-rules="' . htmlspecialchars($this->getValidationDataAsJsonString($config)) . '"';
+        $html[] =       ' name="' . htmlspecialchars($elementName) . '"';
+        $html[] =       ' value="' . htmlspecialchars(implode(',', $listOfSelectedValues)) . '"';
+        $html[] =       ' onchange="' . htmlspecialchars(implode('', $parameterArray['fieldChangeFunc'])) . '"';
+        $html[] =   ' />';
         $html[] = '</div>';
 
         $resultArray['requireJsModules'][] = ['TYPO3/CMS/Backend/FormEngine/Element/GroupElement' => '
