@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\Element;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,9 +13,12 @@ namespace TYPO3\CMS\Backend\Form\Element;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\Element;
+
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Localization\LanguageService;
+use TYPO3\CMS\Core\Utility\ArrayUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
 use TYPO3\CMS\Core\Utility\StringUtility;
@@ -52,7 +54,6 @@ class SelectMultipleSideBySideElement extends AbstractFormElement
         'addRecord' => [
             'renderType' => 'addRecord',
             'disabled' => true,
-            'after' => [ 'editPopup' ],
         ],
         'listModule' => [
             'renderType' => 'listModule',
@@ -84,6 +85,38 @@ class SelectMultipleSideBySideElement extends AbstractFormElement
         ],
     ];
 
+    /**
+     * Merge field control configuration with default controls and render them.
+     *
+     * @return array Result array
+     */
+    protected function renderFieldControl(): array
+    {
+        $alternativeResult =  [
+            'additionalJavaScriptPost' => [],
+            'additionalHiddenFields' => [],
+            'additionalInlineLanguageLabelFiles' => [],
+            'stylesheetFiles' => [],
+            'requireJsModules' => [],
+            'inlineData' => [],
+            'html' => '',
+        ];
+        $options = $this->data;
+        $fieldControl = $this->defaultFieldControl;
+        $fieldControlFromTca = $options['parameterArray']['fieldConf']['config']['fieldControl'] ?? [];
+        ArrayUtility::mergeRecursiveWithOverrule($fieldControl, $fieldControlFromTca);
+        $options['renderType'] = 'fieldControl';
+        if (isset($fieldControl['editPopup'])) {
+            $editPopupControl = $fieldControl['editPopup'];
+            unset($fieldControl['editPopup']);
+            $alternativeOptions = $options;
+            $alternativeOptions['renderData']['fieldControl'] = ['editPopup' => $editPopupControl];
+            $alternativeResult = $this->nodeFactory->create($alternativeOptions)->render();
+        }
+        $options['renderData']['fieldControl'] = $fieldControl;
+        return [$this->nodeFactory->create($options)->render(), $alternativeResult];
+    }
+
     /**
      * Render side by side element.
      *
@@ -126,7 +159,7 @@ class SelectMultipleSideBySideElement extends AbstractFormElement
                 if ($possibleItem[1] == $itemValue) {
                     $title = $possibleItem[0];
                     $listOfSelectedValues[] = $itemValue;
-                    $selectedItemsHtml[] = '<option value="' . htmlspecialchars($itemValue) . '" title="' . htmlspecialchars($title) . '">' . htmlspecialchars($this->appendValueToLabelInDebugMode($title, $itemValue)) . '</option>';
+                    $selectedItemsHtml[] = '<option value="' . htmlspecialchars((string)$itemValue) . '" title="' . htmlspecialchars((string)$title) . '">' . htmlspecialchars($this->appendValueToLabelInDebugMode($title, $itemValue)) . '</option>';
                     break;
                 }
             }
@@ -202,9 +235,11 @@ class SelectMultipleSideBySideElement extends AbstractFormElement
         $fieldInformationHtml = $fieldInformationResult['html'];
         $resultArray = $this->mergeChildReturnIntoExistingResult($resultArray, $fieldInformationResult, false);
 
-        $fieldControlResult = $this->renderFieldControl();
+        [$fieldControlResult, $alternativeControlResult] = $this->renderFieldControl();
         $fieldControlHtml = $fieldControlResult['html'];
         $resultArray = $this->mergeChildReturnIntoExistingResult($resultArray, $fieldControlResult, false);
+        $alternativeFieldControlHtml = $alternativeControlResult['html'];
+        $resultArray = $this->mergeChildReturnIntoExistingResult($resultArray, $alternativeControlResult, false);
 
         $fieldWizardResult = $this->renderFieldWizard();
         $fieldWizardHtml = $fieldWizardResult['html'];
@@ -272,6 +307,7 @@ class SelectMultipleSideBySideElement extends AbstractFormElement
             $html[] =                               $this->iconFactory->getIcon('actions-move-to-bottom', Icon::SIZE_SMALL)->render();
             $html[] =                           '</a>';
         }
+        $html[] =                                $alternativeFieldControlHtml;
         $html[] =                               '<a href="#"';
         $html[] =                                   ' class="btn btn-default t3js-btn-option t3js-btn-removeoption"';
         $html[] =                                   ' data-fieldname="' . htmlspecialchars($elementName) . '"';
