@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\Element;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Form\Element;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\Element;
+
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
@@ -101,7 +102,7 @@ class TextTableElement extends AbstractFormElement
         $itemFormElementValueLength = strlen($itemValue);
         if ($itemFormElementValueLength > $this->charactersPerRow * 2) {
             $rows = MathUtility::forceIntegerInRange(
-                round($itemFormElementValueLength / $this->charactersPerRow),
+                (int)round($itemFormElementValueLength / $this->charactersPerRow),
                 count(explode(LF, $itemValue)),
                 20
             );
@@ -158,8 +159,8 @@ class TextTableElement extends AbstractFormElement
             'name' => htmlspecialchars($parameterArray['itemFormElName']),
             'data-formengine-validation-rules' => $this->getValidationDataAsJsonString($config),
             'data-formengine-input-name' => htmlspecialchars($parameterArray['itemFormElName']),
-            'rows' => $rows,
-            'wrap' => $config['wrap'] ?: 'virtual',
+            'rows' => (string)$rows,
+            'wrap' => (string)($config['wrap'] ?: 'virtual'),
             'onChange' => implode('', $parameterArray['fieldChangeFunc']),
         ];
         $classes = [
@@ -180,7 +181,7 @@ class TextTableElement extends AbstractFormElement
             $attributes['style'] = 'max-height: ' . $maximumHeight . 'px';
         }
         if (isset($config['max']) && (int)$config['max'] > 0) {
-            $attributes['maxlength'] = (int)$config['max'];
+            $attributes['maxlength'] = (string)(int)$config['max'];
         }
         if (!empty($config['placeholder'])) {
             $attributes['placeholder'] = htmlspecialchars(trim($config['placeholder']));
