@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\FormDataProvider;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Form\FormDataProvider;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\FormDataProvider;
+
 use Doctrine\DBAL\DBALException;
 use TYPO3\CMS\Backend\Module\ModuleLoader;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
@@ -24,6 +25,7 @@ use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\QueryBuilder;
 use TYPO3\CMS\Core\Database\Query\QueryHelper;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
+use TYPO3\CMS\Core\Database\Query\Restriction\WorkspaceRestriction;
 use TYPO3\CMS\Core\Database\RelationHandler;
 use TYPO3\CMS\Core\Imaging\IconFactory;
 use TYPO3\CMS\Core\Imaging\IconRegistry;
@@ -32,11 +34,13 @@ use TYPO3\CMS\Core\Messaging\FlashMessage;
 use TYPO3\CMS\Core\Messaging\FlashMessageQueue;
 use TYPO3\CMS\Core\Messaging\FlashMessageService;
 use TYPO3\CMS\Core\Resource\FileRepository;
+use TYPO3\CMS\Core\Resource\ResourceStorage;
 use TYPO3\CMS\Core\Site\SiteFinder;
 use TYPO3\CMS\Core\Type\Bitmask\Permission;
 use TYPO3\CMS\Core\Utility\ArrayUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
+use TYPO3\CMS\Core\Versioning\VersionState;
 
 /**
  * Contains methods used by Data providers that handle elements
@@ -69,6 +73,21 @@ abstract class AbstractItemProvider
             'table' => $table,
             'row' => $result['databaseRow'],
             'field' => $fieldName,
+            // IMPORTANT: Below fields are only available in FormEngine context.
+            // They are not used by the DataHandler when processing itemsProcFunc
+            // for checking if a submitted value is valid. This means, in case
+            // an item is added based on one of these fields, it won't be persisted
+            // by the DataHandler. This currently(!) only concerns columns of type "check"
+            // and type "radio", see checkValueForCheck() and checkValueForRadio().
+            // Therefore, no limitations when using those fields with other types
+            // like "select", but this may change in the future.
+            'inlineParentUid' => $result['inlineParentUid'],
+            'inlineParentTableName' => $result['inlineParentTableName'],
+            'inlineParentFieldName' => $result['inlineParentFieldName'],
+            'inlineParentConfig' => $result['inlineParentConfig'],
+            'inlineTopMostParentUid' => $result['inlineTopMostParentUid'],
+            'inlineTopMostParentTableName' => $result['inlineTopMostParentTableName'],
+            'inlineTopMostParentFieldName' => $result['inlineTopMostParentFieldName'],
         ];
         if (!empty($result['flexParentDatabaseRow'])) {
             $processorParameters['flexParentDatabaseRow'] = $result['flexParentDatabaseRow'];
@@ -178,14 +197,9 @@ abstract class AbstractItemProvider
                     }
                     $label = !empty($GLOBALS['TCA'][$currentTable]['ctrl']['title']) ? $GLOBALS['TCA'][$currentTable]['ctrl']['title'] : '';
                     $icon = $iconFactory->mapRecordTypeToIconIdentifier($currentTable, []);
-                    $helpText = [];
                     $languageService->loadSingleTableDescription($currentTable);
-                    // @todo: check if this actually works, currently help texts are missing
-                    $helpTextArray = $GLOBALS['TCA_DESCR'][$currentTable]['columns'][''];
-                    if (!empty($helpTextArray['description'])) {
-                        $helpText['description'] = $helpTextArray['description'];
-                    }
-                    $items[] = [$label, $currentTable, $icon, $helpText];
+                    $helpText = (string)($GLOBALS['TCA_DESCR'][$currentTable]['columns']['']['description'] ?? '');
+                    $items[] = [$label, $currentTable, $icon, null, $helpText];
                 }
                 break;
             case $special === 'pagetypes':
@@ -233,17 +247,14 @@ abstract class AbstractItemProvider
                         }
                     }
                     // Add help text
-                    $helpText = [];
                     $languageService->loadSingleTableDescription($excludeArray['table']);
-                    $helpTextArray = $GLOBALS['TCA_DESCR'][$excludeArray['table']]['columns'][$excludeArray['table']] ?? [];
-                    if (!empty($helpTextArray['description'])) {
-                        $helpText['description'] = $helpTextArray['description'];
-                    }
+                    $helpText = (string)($GLOBALS['TCA_DESCR'][$excludeArray['table']]['columns'][$excludeArray['fullField']]['description'] ?? '');
                     // Item configuration:
                     $items[] = [
                         rtrim($excludeArray['origin'] === 'flexForm' ? $excludeArray['fieldLabel'] : $languageService->sL($GLOBALS['TCA'][$excludeArray['table']]['columns'][$excludeArray['fieldName']]['label']), ':') . ' (' . $excludeArray['fieldName'] . ')',
                         $excludeArray['table'] . ':' . $excludeArray['fullField'],
                         'empty-empty',
+                        null,
                         $helpText
                     ];
                 }
@@ -329,7 +340,7 @@ abstract class AbstractItemProvider
                             // Traverse items:
                             foreach ($coValue['items'] as $itemKey => $itemCfg) {
                                 $icon = 'empty-empty';
-                                $helpText = [];
+                                $helpText = '';
                                 if (!empty($itemCfg[1])) {
                                     if ($iconRegistry->isRegistered($itemCfg[1])) {
                                         // Use icon identifier when registered
@@ -337,12 +348,13 @@ abstract class AbstractItemProvider
                                     }
                                 }
                                 if (!empty($itemCfg[2])) {
-                                    $helpText['description'] = $languageService->sL($itemCfg[2]);
+                                    $helpText = $languageService->sL($itemCfg[2]);
                                 }
                                 $items[] = [
                                     $languageService->sL($itemCfg[0]),
                                     $coKey . ':' . preg_replace('/[:|,]/', '', $itemKey),
                                     $icon,
+                                    null,
                                     $helpText
                                 ];
                             }
@@ -383,7 +395,7 @@ abstract class AbstractItemProvider
                         $label .= $languageService->sL($moduleLabels['title']);
 
                         // Item configuration
-                        $items[] = [$label, $theMod, $icon, $helpText];
+                        $items[] = [$label, $theMod, $icon, null, $helpText];
                     }
                 }
                 break;
@@ -435,7 +447,7 @@ abstract class AbstractItemProvider
             $recursionLevels = isset($result['processedTca']['columns'][$fieldName]['config']['fileFolder_recursions'])
                 ? MathUtility::forceIntegerInRange($result['processedTca']['columns'][$fieldName]['config']['fileFolder_recursions'], 0, 99)
                 : 99;
-            $fileArray = GeneralUtility::getAllFilesAndFoldersInPath([], $fileFolder, $fileExtensionList, 0, $recursionLevels);
+            $fileArray = GeneralUtility::getAllFilesAndFoldersInPath([], $fileFolder, $fileExtensionList, false, $recursionLevels);
             $fileArray = GeneralUtility::removePrefixPathFromList($fileArray, $fileFolder);
             foreach ($fileArray as $fileReference) {
                 $fileInformation = pathinfo($fileReference);
@@ -516,10 +528,14 @@ abstract class AbstractItemProvider
         }
 
         $fileRepository = GeneralUtility::makeInstance(FileRepository::class);
+        $iconFactory = GeneralUtility::makeInstance(IconFactory::class);
 
         while ($foreignRow = $queryResult->fetch()) {
             BackendUtility::workspaceOL($foreignTable, $foreignRow);
-            if (is_array($foreignRow)) {
+            // Only proceed in case the row was not unset and we don't deal with a delete placeholder
+            if (is_array($foreignRow)
+                && !VersionState::cast($foreignRow['t3ver_state'] ?? 0)->equals(VersionState::DELETE_PLACEHOLDER)
+            ) {
                 // If the foreign table sets selicon_field, this field can contain an image
                 // that represents this specific row.
                 $iconFieldName = '';
@@ -540,6 +556,9 @@ abstract class AbstractItemProvider
                         $icon = reset($references);
                         $icon = $icon->getPublicUrl();
                     }
+                } else {
+                    // Else, determine icon based on record type, or a generic fallback
+                    $icon = $iconFactory->mapRecordTypeToIconIdentifier($foreignTable, $foreignRow);
                 }
                 // Add the item
                 $items[] = [
@@ -728,7 +747,7 @@ abstract class AbstractItemProvider
         }
 
         $allowedStorageIds = array_map(
-            function (\TYPO3\CMS\Core\Resource\ResourceStorage $storage) {
+            function (ResourceStorage $storage) {
                 return $storage->getUid();
             },
             $this->getBackendUser()->getFileStorages()
@@ -762,6 +781,7 @@ abstract class AbstractItemProvider
         foreach ($GLOBALS['TCA'] as $table => $conf) {
             $tableToTranslation[$table] = $languageService->sL($conf['ctrl']['title']);
         }
+        /** @var array<string, string> $tableToTranslation */
         // Sort by translations
         asort($tableToTranslation);
         foreach ($tableToTranslation as $table => $translatedTable) {
@@ -773,7 +793,10 @@ abstract class AbstractItemProvider
                 && (empty($GLOBALS['TCA'][$table]['ctrl']['rootLevel']) || !empty($GLOBALS['TCA'][$table]['ctrl']['security']['ignoreRootLevelRestriction']))
             ) {
                 foreach ($GLOBALS['TCA'][$table]['columns'] as $field => $_) {
-                    if (isset($GLOBALS['TCA'][$table]['columns'][$field]['exclude']) && (bool)$GLOBALS['TCA'][$table]['columns'][$field]['exclude']) {
+                    $isExcludeField = (bool)($GLOBALS['TCA'][$table]['columns'][$field]['exclude'] ?? false);
+                    $isOnlyVisibleForAdmins = ($GLOBALS['TCA'][$table]['columns'][$field]['displayCond'] ?? '') === 'HIDE_FOR_NON_ADMINS';
+                    // Only show fields that can be excluded for editors, or are hidden for non-admins
+                    if ($isExcludeField && !$isOnlyVisibleForAdmins) {
                         // Get human readable names of fields
                         $translatedField = $languageService->sL($GLOBALS['TCA'][$table]['columns'][$field]['label']);
                         // Add entry, key 'labels' needed for sorting
@@ -874,6 +897,7 @@ abstract class AbstractItemProvider
             if (!empty($fieldConf['config']['type']) && !empty($fieldConf['config']['ds']) && $fieldConf['config']['type'] === 'flex') {
                 $flexForms[$tableField] = [];
                 foreach (array_keys($fieldConf['config']['ds']) as $flexFormKey) {
+                    $flexFormKey = (string)$flexFormKey;
                     // Get extension identifier (uses second value if it's not empty, "list" or "*", else first one)
                     $identFields = GeneralUtility::trimExplode(',', $flexFormKey);
                     $extIdent = $identFields[0];
@@ -988,7 +1012,8 @@ abstract class AbstractItemProvider
 
         $queryBuilder->getRestrictions()
             ->removeAll()
-            ->add(GeneralUtility::makeInstance(DeletedRestriction::class));
+            ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
+            ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, $this->getBackendUser()->workspace));
 
         $queryBuilder
             ->select(...GeneralUtility::trimExplode(',', $fieldList, true))
@@ -1058,6 +1083,17 @@ abstract class AbstractItemProvider
             }
         }
 
+        // @todo what about PID restriction?
+        if ($this->getBackendUser()->workspace !== 0 && BackendUtility::isTableWorkspaceEnabled($foreignTableName)) {
+            $queryBuilder
+                ->andWhere(
+                    $queryBuilder->expr()->neq(
+                        $foreignTableName . '.t3ver_state',
+                        $queryBuilder->createNamedParameter(VersionState::MOVE_PLACEHOLDER, \PDO::PARAM_INT)
+                    )
+                );
+        }
+
         return $queryBuilder;
     }
 
@@ -1101,8 +1137,10 @@ abstract class AbstractItemProvider
                         $rowFieldValue = $result[$databaseRowKey][$whereClauseSubParts[0]] ?? '';
                         if (is_array($rowFieldValue)) {
                             // If a select or group field is used here, it may have been processed already and
-                            // is now an array. Use first selected value in this case.
-                            $rowFieldValue = $rowFieldValue[0];
+                            // is now an array containing uid + table + title + row.
+                            // See TcaGroup data provider for details.
+                            // Pick the first one (always on 0), and use uid only.
+                            $rowFieldValue = $rowFieldValue[0]['uid'] ?? $rowFieldValue[0];
                         }
                         if (substr($whereClauseParts[0], -1) === '\'' && $whereClauseSubParts[1][0] === '\'') {
                             $whereClauseParts[0] = substr($whereClauseParts[0], 0, -1);
@@ -1201,13 +1239,13 @@ abstract class AbstractItemProvider
         }
         // Find ORDER BY
         $reg = [];
-        if (preg_match('/^(.*)[[:space:]]+ORDER[[:space:]]+BY[[:space:]]+([[:alnum:][:space:],._]+)$/is', $foreignTableClause, $reg)) {
+        if (preg_match('/^(.*)[[:space:]]+ORDER[[:space:]]+BY[[:space:]]+([[:alnum:][:space:],._()"]+)$/is', $foreignTableClause, $reg)) {
             $foreignTableClauseArray['ORDERBY'] = QueryHelper::parseOrderBy(trim($reg[2]));
             $foreignTableClause = $reg[1];
         }
         // Find GROUP BY
         $reg = [];
-        if (preg_match('/^(.*)[[:space:]]+GROUP[[:space:]]+BY[[:space:]]+([[:alnum:][:space:],._]+)$/is', $foreignTableClause, $reg)) {
+        if (preg_match('/^(.*)[[:space:]]+GROUP[[:space:]]+BY[[:space:]]+([[:alnum:][:space:],._()"]+)$/is', $foreignTableClause, $reg)) {
             $foreignTableClauseArray['GROUPBY'] = QueryHelper::parseGroupBy(trim($reg[2]));
             $foreignTableClause = $reg[1];
         }
@@ -1324,18 +1362,20 @@ abstract class AbstractItemProvider
             }
             $value = strlen((string)$item[1]) > 0 ? $item[1] : '';
             $icon = !empty($item[2]) ? $item[2] : null;
+            $groupId = $item[3] ?? null;
             $helpText = null;
-            if (!empty($item[3])) {
-                if (\is_string($item[3])) {
-                    $helpText = $languageService->sL($item[3]);
+            if (!empty($item[4])) {
+                if (\is_string($item[4])) {
+                    $helpText = $languageService->sL($item[4]);
                 } else {
-                    $helpText = $item[3];
+                    $helpText = $item[4];
                 }
             }
             $itemArray[$key] = [
                 $label,
                 $value,
                 $icon,
+                $groupId,
                 $helpText
             ];
         }
@@ -1343,6 +1383,29 @@ abstract class AbstractItemProvider
         return $itemArray;
     }
 
+    /**
+     * Add alternative icon using "altIcons" TSconfig
+     *
+     * @param array $result
+     * @param array $items
+     * @param string $table
+     * @param string $fieldName
+     *
+     * @return array
+     */
+    public function addIconFromAltIcons(array $result, array $items, string $table, string $fieldName): array
+    {
+        foreach ($items as &$item) {
+            if (isset($result['pageTsConfig']['TCEFORM.'][$table . '.'][$fieldName . '.']['altIcons.'][$item[1]])
+                && !empty($result['pageTsConfig']['TCEFORM.'][$table . '.'][$fieldName . '.']['altIcons.'][$item[1]])
+            ) {
+                $item[2] = $result['pageTsConfig']['TCEFORM.'][$table . '.'][$fieldName . '.']['altIcons.'][$item[1]];
+            }
+        }
+
+        return $items;
+    }
+
     /**
      * Sanitize incoming item array
      *
