@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\FormDataProvider;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Form\FormDataProvider;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\FormDataProvider;
+
 use TYPO3\CMS\Backend\Form\FormDataProviderInterface;
 
 /**
@@ -37,6 +38,19 @@ class TcaColumnsOverrides implements FormDataProviderInterface
                 $result['processedTca']['columns'],
                 $result['processedTca']['types'][$type]['columnsOverrides']
             );
+            if ($result['command'] === 'new') {
+                $tableNameWithDot = $result['tableName'] . '.';
+                foreach ($result['processedTca']['types'][$type]['columnsOverrides'] as $field => $columnsOverrideConfig) {
+                    $overridenDefault = $columnsOverrideConfig['config']['default'] ?? '';
+                    if ($overridenDefault !== ''
+                        && !isset($result['userTsConfig']['TCAdefaults.'][$tableNameWithDot][$field])
+                        && !isset($result['pageTsConfig']['TCAdefaults.'][$tableNameWithDot][$field])
+                        && ($result['databaseRow'][$field] ?? '') !== $overridenDefault
+                    ) {
+                        $result['databaseRow'][$field] = $overridenDefault;
+                    }
+                }
+            }
             unset($result['processedTca']['types'][$type]['columnsOverrides']);
         }
         return $result;
