@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\FormDataProvider;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Form\FormDataProvider;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\FormDataProvider;
+
 use TYPO3\CMS\Backend\Form\Exception\DatabaseRecordException;
 use TYPO3\CMS\Backend\Form\FormDataCompiler;
 use TYPO3\CMS\Backend\Form\FormDataGroup\OnTheFly;
@@ -102,7 +103,7 @@ class TcaInline extends AbstractDatabaseRecordProvider implements FormDataProvid
                 $liveVersionId = BackendUtility::getLiveVersionIdOfRecord('pages', $row['uid']);
                 $pid = $liveVersionId ?? $row['uid'];
             } elseif (($row['pid'] ?? 0) < 0) {
-                $prevRec = BackendUtility::getRecord($table, abs($row['pid']));
+                $prevRec = BackendUtility::getRecord($table, (int)abs($row['pid']));
                 $pid = $prevRec['pid'];
             } else {
                 $pid = $row['pid'] ?? 0;
@@ -197,7 +198,7 @@ class TcaInline extends AbstractDatabaseRecordProvider implements FormDataProvid
                             $e->getMessage(),
                             [
                                 'table' => $childTableName,
-                                'uid' => $localizedUid,
+                                'uid' => $defaultLanguageUid,
                                 'exception' => $e
                             ]
                         );
@@ -239,8 +240,12 @@ class TcaInline extends AbstractDatabaseRecordProvider implements FormDataProvid
 
         if ($result['inlineCompileExistingChildren']) {
             foreach ($connectedUidsOfDefaultLanguageRecord as $uid) {
-                $compiledChild = $this->compileChild($result, $fieldName, $uid);
-                $result['processedTca']['columns'][$fieldName]['children'][] = $compiledChild;
+                try {
+                    $compiledChild = $this->compileChild($result, $fieldName, $uid);
+                    $result['processedTca']['columns'][$fieldName]['children'][] = $compiledChild;
+                } catch (DatabaseRecordException $e) {
+                    // Nothing to do here, missing child is just not being rendered.
+                }
             }
         }
         return $result;
@@ -444,7 +449,7 @@ class TcaInline extends AbstractDatabaseRecordProvider implements FormDataProvid
      *
      * @param array $parentConfig TCA config section of parent
      * @param string $parentTableName Name of parent table
-     * @param string $parentUid Uid of parent record
+     * @param int $parentUid Uid of parent record
      * @param string $parentFieldValue Database value of parent record of this inline field
      * @return array Array with connected uids
      * @todo: Cover with unit tests
