@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Form\FormDataProvider;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Form\FormDataProvider;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Form\FormDataProvider;
+
 use TYPO3\CMS\Backend\Form\FormDataProviderInterface;
 use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Imaging\IconFactory;
@@ -127,8 +128,10 @@ class TcaSelectTreeItems extends AbstractItemProvider implements FormDataProvide
                         // itemsProcFunc must not be used anymore
                         unset($fieldConfig['config']['itemsProcFunc']);
                     }
-                    // And translate any labels from the static list
+                    // translate any labels
                     $staticItems = $this->translateLabels($result, $staticItems, $table, $fieldName);
+                    // and add icons from the static list
+                    $staticItems = $this->addIconFromAltIcons($result, $staticItems, $table, $fieldName);
                     // Now compile the target items using the same array structure as the "dynamic" list below
                     foreach ($staticItems as $item) {
                         if ($item[1] === '--div--') {
