@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\LoginProvider;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,9 @@ namespace TYPO3\CMS\Backend\LoginProvider;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\LoginProvider;
+
+use TYPO3\CMS\Backend\Authentication\PasswordReset;
 use TYPO3\CMS\Backend\Controller\LoginController;
 use TYPO3\CMS\Core\Page\PageRenderer;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
@@ -40,5 +42,7 @@ class UsernamePasswordLoginProvider implements LoginProviderInterface
             $view->assign('presetUsername', GeneralUtility::_GP('u'));
             $view->assign('presetPassword', GeneralUtility::_GP('p'));
         }
+
+        $view->assign('enablePasswordReset', GeneralUtility::makeInstance(PasswordReset::class)->isEnabled());
     }
 }
