@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Module;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,12 +13,15 @@ namespace TYPO3\CMS\Backend\Module;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Module;
+
 use TYPO3\CMS\Backend\Domain\Model\Module\BackendModule;
+use TYPO3\CMS\Core\SingletonInterface;
 
 /**
  * Model for the module storage
  */
-class ModuleStorage implements \TYPO3\CMS\Core\SingletonInterface
+class ModuleStorage implements SingletonInterface
 {
     /**
      * @var \SplObjectStorage
@@ -38,7 +40,6 @@ class ModuleStorage implements \TYPO3\CMS\Core\SingletonInterface
      * Set Entries
      *
      * @param \SplObjectStorage $entries
-     * @return void
      */
     public function setEntries($entries)
     {
@@ -59,7 +60,6 @@ class ModuleStorage implements \TYPO3\CMS\Core\SingletonInterface
      * Attach Entry
      *
      * @param BackendModule $entry
-     * @return void
      */
     public function attachEntry(BackendModule $entry)
     {
