@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Backend\Preview;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,12 +15,13 @@ namespace TYPO3\CMS\Backend\Preview;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Preview;
+
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Backend\View\BackendLayout\Grid\GridColumnItem;
-use TYPO3\CMS\Backend\View\Drawing\DrawingConfiguration;
 use TYPO3\CMS\Backend\View\PageLayoutView;
 use TYPO3\CMS\Backend\View\PageLayoutViewDrawFooterHookInterface;
 use TYPO3\CMS\Backend\View\PageLayoutViewDrawItemHookInterface;
@@ -50,10 +51,29 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
 {
     use LoggerAwareTrait;
 
+    /**
+     * Menu content types defined by TYPO3
+     *
+     * @var string[]
+     */
+    private const MENU_CONTENT_TYPES = [
+        'menu_abstract',
+        'menu_categorized_content',
+        'menu_categorized_pages',
+        'menu_pages',
+        'menu_recently_updated',
+        'menu_related_pages',
+        'menu_section',
+        'menu_section_pages',
+        'menu_sitemap',
+        'menu_sitemap_pages',
+        'menu_subpages',
+    ];
+
     public function renderPageModulePreviewHeader(GridColumnItem $item): string
     {
         $record = $item->getRecord();
-        $itemLabels = $item->getBackendLayout()->getDrawingConfiguration()->getItemLabels();
+        $itemLabels = $item->getContext()->getItemLabels();
 
         $outHeader = '';
 
@@ -63,7 +83,7 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
             $hiddenHeaderNote = '';
             // If header layout is set to 'hidden', display an accordant note:
             if ($record['header_layout'] == 100) {
-                $hiddenHeaderNote = ' <em>[' . htmlspecialchars($this->getLanguageService()->sL('LLL:EXT:lang/Resources/Private/Language/locallang_core.xlf:labels.hidden')) . ']</em>';
+                $hiddenHeaderNote = ' <em>[' . htmlspecialchars($this->getLanguageService()->sL('LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:header_layout.I.6')) . ']</em>';
             }
             $outHeader = $record['date']
                 ? htmlspecialchars($itemLabels['date'] . ' ' . BackendUtility::date($record['date'])) . '<br />'
@@ -80,16 +100,34 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
         $out = '';
         $record = $item->getRecord();
 
-        $contentTypeLabels = $item->getBackendLayout()->getDrawingConfiguration()->getContentTypeLabels();
+        $contentTypeLabels = $item->getContext()->getContentTypeLabels();
         $languageService = $this->getLanguageService();
 
+        $drawItem = true;
+        $hookPreviewContent = '';
+        // Hook: Render an own preview of a record
+        if (!empty($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['cms/layout/class.tx_cms_layout.php']['tt_content_drawItem'])) {
+            $pageLayoutView = PageLayoutView::createFromPageLayoutContext($item->getContext());
+            foreach ($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['cms/layout/class.tx_cms_layout.php']['tt_content_drawItem'] ?? [] as $className) {
+                $hookObject = GeneralUtility::makeInstance($className);
+                if (!$hookObject instanceof PageLayoutViewDrawItemHookInterface) {
+                    throw new \UnexpectedValueException($className . ' must implement interface ' . PageLayoutViewDrawItemHookInterface::class, 1582574553);
+                }
+                $hookObject->preProcess($pageLayoutView, $drawItem, $previewHeader, $hookPreviewContent, $record);
+            }
+            $item->setRecord($record);
+        }
+
+        if (!$drawItem) {
+            return $hookPreviewContent;
+        }
         // Check if a Fluid-based preview template was defined for this CType
         // and render it via Fluid. Possible option:
         // mod.web_layout.tt_content.preview.media = EXT:site_mysite/Resources/Private/Templates/Preview/Media.html
         $infoArr = [];
         $this->getProcessedValue($item, 'header_position,header_layout,header_link', $infoArr);
         $tsConfig = BackendUtility::getPagesTSconfig($record['pid'])['mod.']['web_layout.']['tt_content.']['preview.'] ?? [];
-        if (!empty($tsConfig[$record['CType']])) {
+        if (!empty($tsConfig[$record['CType']]) || !empty($tsConfig[$record['CType'] . '.'])) {
             $fluidPreview = $this->renderContentElementPreviewFromFluidTemplate($record);
             if ($fluidPreview !== null) {
                 return $fluidPreview;
@@ -108,20 +146,6 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
                     $out .= $this->linkEditContent($this->getThumbCodeUnlinked($record, 'tt_content', 'media'), $record) . '<br />';
                 }
                 break;
-            case 'menu':
-                $contentType = $contentTypeLabels[$record['CType']];
-                $out .= $this->linkEditContent('<strong>' . htmlspecialchars($contentType) . '</strong>', $record) . '<br />';
-                // Add Menu Type
-                $menuTypeLabel = $languageService->sL(
-                    BackendUtility::getLabelFromItemListMerged($record['pid'], 'tt_content', 'menu_type', $record['menu_type'])
-                );
-                $menuTypeLabel = $menuTypeLabel ?: 'invalid menu type';
-                $out .= $this->linkEditContent($menuTypeLabel, $record);
-                if ($record['menu_type'] !== '2' && ($record['pages'] || $record['selected_categories'])) {
-                    // Show pages if menu type is not "Sitemap"
-                    $out .= ':' . $this->linkEditContent($this->generateListForCTypeMenu($record), $record) . '<br />';
-                }
-                break;
             case 'shortcut':
                 if (!empty($record['records'])) {
                     $shortcutContent = [];
@@ -136,7 +160,7 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
                                 $icon,
                                 $tableName,
                                 $shortcutRecord['uid'],
-                                1,
+                                '1',
                                 '',
                                 '+copy,info,edit,view'
                             );
@@ -150,7 +174,7 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
             case 'list':
                 $hookOut = '';
                 if (!empty($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['cms/layout/class.tx_cms_layout.php']['list_type_Info'])) {
-                    $pageLayoutView = $this->createEmulatedPageLayoutViewFromDrawingConfiguration($item->getBackendLayout()->getDrawingConfiguration());
+                    $pageLayoutView = PageLayoutView::createFromPageLayoutContext($item->getContext());
                     $_params = ['pObj' => &$pageLayoutView, 'row' => $record];
                     foreach (
                         $GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['cms/layout/class.tx_cms_layout.php']['list_type_Info'][$record['list_type']] ??
@@ -168,7 +192,7 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
                     if (!empty($label)) {
                         $out .= $this->linkEditContent('<strong>' . htmlspecialchars($languageService->sL($label)) . '</strong>', $record) . '<br />';
                     } else {
-                        $message = sprintf($languageService->sL('LLL:EXT:lang/locallang_core.xlf:labels.noMatchingValue'), $record['list_type']);
+                        $message = sprintf($languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:labels.noMatchingValue'), $record['list_type']);
                         $out .= '<span class="label label-warning">' . htmlspecialchars($message) . '</span>';
                     }
                 } elseif (!empty($record['select_key'])) {
@@ -180,22 +204,30 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
                 $out .= htmlspecialchars($languageService->sL(BackendUtility::getLabelFromItemlist('tt_content', 'pages', $record['pages']))) . '<br />';
                 break;
             default:
-                $contentType = $contentTypeLabels[$record['CType']];
-
-                if (isset($contentType)) {
-                    $out .= $this->linkEditContent('<strong>' . htmlspecialchars($contentType) . '</strong>', $record) . '<br />';
-                    if ($record['bodytext']) {
-                        $out .= $this->linkEditContent($this->renderText($record['bodytext']), $record) . '<br />';
-                    }
-                    if ($record['image']) {
-                        $out .= $this->linkEditContent($this->getThumbCodeUnlinked($record, 'tt_content', 'image'), $record) . '<br />';
-                    }
-                } else {
+                $contentTypeLabel = (string)($contentTypeLabels[$record['CType']] ?? '');
+                if ($contentTypeLabel === '') {
                     $message = sprintf(
-                        $languageService->sL('LLL:EXT:lang/locallang_core.xlf:labels.noMatchingValue'),
+                        $languageService->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:labels.noMatchingValue'),
                         $record['CType']
                     );
                     $out .= '<span class="label label-warning">' . htmlspecialchars($message) . '</span>';
+                    break;
+                }
+                // Handle menu content types
+                if (in_array($record['CType'], self::MENU_CONTENT_TYPES, true)) {
+                    $out .= $this->linkEditContent('<strong>' . htmlspecialchars($contentTypeLabel) . '</strong>', $record);
+                    if ($record['CType'] !== 'menu_sitemap' && (($record['pages'] ?? false) || ($record['selected_categories'] ?? false))) {
+                        // Show pages/categories if menu type is not "Sitemap"
+                        $out .= ':' . $this->linkEditContent($this->generateListForMenuContentTypes($record), $record) . '<br />';
+                    }
+                    break;
+                }
+                $out .= $this->linkEditContent('<strong>' . htmlspecialchars($contentTypeLabel) . '</strong>', $record) . '<br />';
+                if ($record['bodytext']) {
+                    $out .= $this->linkEditContent($this->renderText($record['bodytext']), $record) . '<br />';
+                }
+                if ($record['image']) {
+                    $out .= $this->linkEditContent($this->getThumbCodeUnlinked($record, 'tt_content', 'image'), $record) . '<br />';
                 }
         }
 
@@ -215,13 +247,13 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
         $record = $item->getRecord();
         $this->getProcessedValue($item, 'starttime,endtime,fe_group,space_before_class,space_after_class', $info);
 
-        if (!empty($GLOBALS['TCA']['tt_content']['ctrl']['descriptionColumn']) && !empty($this->record[$GLOBALS['TCA']['tt_content']['ctrl']['descriptionColumn']])) {
-            $info[] = $this->record[$GLOBALS['TCA']['tt_content']['ctrl']['descriptionColumn']];
+        if (!empty($GLOBALS['TCA']['tt_content']['ctrl']['descriptionColumn']) && !empty($record[$GLOBALS['TCA']['tt_content']['ctrl']['descriptionColumn']])) {
+            $info[] = htmlspecialchars($record[$GLOBALS['TCA']['tt_content']['ctrl']['descriptionColumn']]);
         }
 
         // Call drawFooter hooks
         if (!empty($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['cms/layout/class.tx_cms_layout.php']['tt_content_drawFooter'])) {
-            $pageLayoutView = $this->createEmulatedPageLayoutViewFromDrawingConfiguration($item->getBackendLayout()->getDrawingConfiguration());
+            $pageLayoutView = PageLayoutView::createFromPageLayoutContext($item->getContext());
             foreach ($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['cms/layout/class.tx_cms_layout.php']['tt_content_drawFooter'] ?? [] as $className) {
                 $hookObject = GeneralUtility::makeInstance($className);
                 if (!$hookObject instanceof PageLayoutViewDrawFooterHookInterface) {
@@ -229,6 +261,7 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
                 }
                 $hookObject->preProcess($pageLayoutView, $info, $record);
             }
+            $item->setRecord($record);
         }
 
         if (!empty($info)) {
@@ -244,46 +277,22 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
 
     public function wrapPageModulePreview(string $previewHeader, string $previewContent, GridColumnItem $item): string
     {
-        $drawItem = true;
-        $record = $item->getRecord();
-        $hookPreviewContent = '';
-
-        // Hook: Render an own preview of a record
-        if (!empty($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['cms/layout/class.tx_cms_layout.php']['tt_content_drawItem'])) {
-            $pageLayoutView = $this->createEmulatedPageLayoutViewFromDrawingConfiguration($item->getBackendLayout()->getDrawingConfiguration());
-            foreach ($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['cms/layout/class.tx_cms_layout.php']['tt_content_drawItem'] ?? [] as $className) {
-                $hookObject = GeneralUtility::makeInstance($className);
-                if (!$hookObject instanceof PageLayoutViewDrawItemHookInterface) {
-                    throw new \UnexpectedValueException($className . ' must implement interface ' . PageLayoutViewDrawItemHookInterface::class, 1582574553);
-                }
-                $hookObject->preProcess($pageLayoutView, $drawItem, $previewHeader, $hookPreviewContent, $record);
-            }
-        }
-
-        $content = $previewHeader;
-
-        $content .= $hookPreviewContent;
-        if ($drawItem) {
-            $content .= $previewContent;
-        }
-
-        $out = '<span class="exampleContent">' . $content . '</span>';
-
+        $content = '<span class="exampleContent">' . $previewHeader . $previewContent . '</span>';
         if ($item->isDisabled()) {
-            return '<span class="text-muted">' . $out . '</span>';
+            return '<span class="text-muted">' . $content . '</span>';
         }
-        return $out;
+        return $content;
     }
 
     protected function getProcessedValue(GridColumnItem $item, string $fieldList, array &$info): void
     {
-        $itemLabels = $item->getBackendLayout()->getDrawingConfiguration()->getItemLabels();
+        $itemLabels = $item->getContext()->getItemLabels();
         $record = $item->getRecord();
         $fieldArr = explode(',', $fieldList);
         foreach ($fieldArr as $field) {
             if ($record[$field]) {
-                $info[] = '<strong>' . htmlspecialchars($itemLabels[$field]) . '</strong> '
-                    . htmlspecialchars(BackendUtility::getProcessedValue('tt_content', $field, $record[$field]));
+                $info[] = '<strong>' . htmlspecialchars((string)($itemLabels[$field] ?? '')) . '</strong> '
+                    . htmlspecialchars(BackendUtility::getProcessedValue('tt_content', $field, $record[$field]) ?? '');
             }
         }
     }
@@ -363,17 +372,17 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
     }
 
     /**
-     * Generates a list of selected pages or categories for the CType menu
+     * Generates a list of selected pages or categories for the menu content types
      *
      * @param array $record row from pages
      * @return string
      */
-    protected function generateListForCTypeMenu(array $record): string
+    protected function generateListForMenuContentTypes(array $record): string
     {
         $table = 'pages';
         $field = 'pages';
         // get categories instead of pages
-        if (strpos($record['menu_type'], 'categorized_') !== false) {
+        if (strpos($record['CType'], 'menu_categorized') !== false) {
             $table = 'sys_category';
             $field = 'selected_categories';
         }
@@ -385,7 +394,9 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
         foreach ($uidList as $uid) {
             $uid = (int)$uid;
             $pageRecord = BackendUtility::getRecord($table, $uid, 'title');
-            $content .= '<br>' . $pageRecord['title'] . ' (' . $uid . ')';
+            if ($pageRecord) {
+                $content .= '<br>' . htmlspecialchars($pageRecord['title']) . ' (' . $uid . ')';
+            }
         }
         return $content;
     }
@@ -400,7 +411,8 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
      */
     protected function linkEditContent(string $linkText, $row): string
     {
-        if ($this->getBackendUser()->recordEditAccessInternals('tt_content', $row)) {
+        $backendUser = $this->getBackendUser();
+        if ($backendUser->check('tables_modify', 'tt_content') && $backendUser->recordEditAccessInternals('tt_content', $row)) {
             $urlParameters = [
                 'edit' => [
                     'tt_content' => [
@@ -416,25 +428,6 @@ class StandardContentPreviewRenderer implements PreviewRendererInterface, Logger
         return $linkText;
     }
 
-    protected function createEmulatedPageLayoutViewFromDrawingConfiguration(DrawingConfiguration $drawingConfiguration): PageLayoutView
-    {
-        $pageLayoutView = GeneralUtility::makeInstance(PageLayoutView::class);
-        $pageLayoutView->id = $drawingConfiguration->getPageId();
-        $pageLayoutView->pageRecord = $drawingConfiguration->getPageRecord();
-        $pageLayoutView->option_newWizard = $drawingConfiguration->getShowNewContentWizard();
-        $pageLayoutView->defLangBinding = $drawingConfiguration->getDefaultLanguageBinding();
-        $pageLayoutView->tt_contentConfig['cols'] = implode(',', $drawingConfiguration->getActiveColumns());
-        $pageLayoutView->tt_contentConfig['activeCols'] = implode(',', $drawingConfiguration->getActiveColumns());
-        $pageLayoutView->tt_contentConfig['showHidden'] = $drawingConfiguration->getShowHidden();
-        $pageLayoutView->tt_contentConfig['sys_language_uid'] = $drawingConfiguration->getLanguageColumnsPointer();
-        if ($drawingConfiguration->getLanguageMode()) {
-            $pageLayoutView->tt_contentConfig['languageMode'] = 1;
-            $pageLayoutView->tt_contentConfig['languageCols'] = $drawingConfiguration->getLanguageColumns();
-            $pageLayoutView->tt_contentConfig['languageColsPointer'] = $drawingConfiguration->getLanguageColumnsPointer();
-        }
-        return $pageLayoutView;
-    }
-
     protected function getBackendUser(): BackendUserAuthentication
     {
         return $GLOBALS['BE_USER'];
