@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Template;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Backend\Template;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Template;
+
 use TYPO3\CMS\Backend\Backend\Shortcut\ShortcutRepository;
 use TYPO3\CMS\Backend\Template\Components\DocHeaderComponent;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
@@ -23,6 +24,7 @@ use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Imaging\IconFactory;
 use TYPO3\CMS\Core\Localization\LanguageService;
 use TYPO3\CMS\Core\Messaging\AbstractMessage;
+use TYPO3\CMS\Core\Messaging\FlashMessage;
 use TYPO3\CMS\Core\Messaging\FlashMessageQueue;
 use TYPO3\CMS\Core\Messaging\FlashMessageService;
 use TYPO3\CMS\Core\Page\PageRenderer;
@@ -244,6 +246,9 @@ class ModuleTemplate
         $this->iconFactory = $iconFactory;
         $this->flashMessageService = $flashMessageService;
         $this->docHeaderComponent = GeneralUtility::makeInstance(DocHeaderComponent::class);
+        $this->setupPage();
+        $this->loadJavaScripts();
+        $this->loadStylesheets();
     }
 
     /**
@@ -252,8 +257,14 @@ class ModuleTemplate
     protected function loadJavaScripts()
     {
         $this->pageRenderer->loadRequireJsModule('bootstrap');
-        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/ContextHelp');
-        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/DocumentHeader');
+
+        if ($this->getBackendUserAuthentication() && !empty($this->getBackendUserAuthentication()->user)) {
+            $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/ContextHelp');
+            $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/DocumentHeader');
+        }
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/GlobalEventHandler');
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/ActionDispatcher');
+        $this->pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/Element/ImmediateActionElement');
     }
 
     /**
@@ -355,11 +366,8 @@ class ModuleTemplate
      */
     public function renderContent()
     {
-        $this->setupPage();
-        $this->pageRenderer->setTitle($this->title);
-        $this->loadJavaScripts();
         $this->setJavaScriptCodeArray();
-        $this->loadStylesheets();
+        $this->pageRenderer->setTitle($this->title);
 
         $this->view->assign('docHeader', $this->docHeaderComponent->docHeaderContent());
         if ($this->moduleId) {
@@ -429,7 +437,7 @@ class ModuleTemplate
     /**
      * Generates the Menu for things like Web->Info
      *
-     * @param $moduleMenuIdentifier
+     * @param string $moduleMenuIdentifier
      * @return self
      */
     public function registerModuleMenu($moduleMenuIdentifier): self
@@ -496,7 +504,6 @@ class ModuleTemplate
      * Do not use these methods within own extensions if possible or
      * be prepared to change this later again.
      *******************************************/
-
     /**
      * Returns a linked shortcut-icon which will call the shortcut frame and set a
      * shortcut there back to the calling page/module
@@ -537,7 +544,7 @@ class ModuleTemplate
         }
         if ((int)$motherModName === 1) {
             $motherModule = 'top.currentModuleLoaded';
-        } elseif ($motherModName) {
+        } elseif (is_string($motherModName) && $motherModName !== '') {
             $motherModule = GeneralUtility::quoteJSvalue($motherModName);
         } else {
             $motherModule = '\'\'';
@@ -581,7 +588,7 @@ class ModuleTemplate
         $getParams = GeneralUtility::_GET();
         $storeArray = array_merge(
             GeneralUtility::compileSelectedGetVarsFromArray($gvList, $getParams),
-            ['SET' => GeneralUtility::compileSelectedGetVarsFromArray($setList, (array)$GLOBALS['SOBE']->MOD_SETTINGS)]
+            ['SET' => GeneralUtility::compileSelectedGetVarsFromArray($setList, (array)($GLOBALS['SOBE']->MOD_SETTINGS ?? []))]
         );
         return HttpUtility::buildQueryString($storeArray, '&');
     }
@@ -707,7 +714,7 @@ class ModuleTemplate
         }
         /* @var \TYPO3\CMS\Core\Messaging\FlashMessage $flashMessage */
         $flashMessage = GeneralUtility::makeInstance(
-            \TYPO3\CMS\Core\Messaging\FlashMessage::class,
+            FlashMessage::class,
             $messageBody,
             $messageTitle,
             $severity,
