@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Tree\Renderer;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,10 +13,16 @@ namespace TYPO3\CMS\Backend\Tree\Renderer;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Tree\Renderer;
+
+use TYPO3\CMS\Backend\Tree\AbstractTree;
+use TYPO3\CMS\Backend\Tree\TreeNodeCollection;
+use TYPO3\CMS\Backend\Tree\TreeRepresentationNode;
+
 /**
  * Renderer for unordered lists
  */
-class UnorderedListTreeRenderer extends \TYPO3\CMS\Backend\Tree\Renderer\AbstractTreeRenderer
+class UnorderedListTreeRenderer extends AbstractTreeRenderer
 {
     /**
      * recursion level
@@ -33,7 +38,7 @@ class UnorderedListTreeRenderer extends \TYPO3\CMS\Backend\Tree\Renderer\Abstrac
      * @param bool $recursive
      * @return string
      */
-    public function renderNode(\TYPO3\CMS\Backend\Tree\TreeRepresentationNode $node, $recursive = true)
+    public function renderNode(TreeRepresentationNode $node, $recursive = true)
     {
         $code = '<li><span class="' . htmlspecialchars($node->getIcon()) . '">&nbsp;</span>' . htmlspecialchars($node->getLabel());
         if ($recursive && $node->getChildNodes() !== null) {
@@ -52,7 +57,7 @@ class UnorderedListTreeRenderer extends \TYPO3\CMS\Backend\Tree\Renderer\Abstrac
      * @param bool $recursive
      * @return string
      */
-    public function renderTree(\TYPO3\CMS\Backend\Tree\AbstractTree $tree, $recursive = true)
+    public function renderTree(AbstractTree $tree, $recursive = true)
     {
         $this->recursionLevel = 0;
         $code = '<ul class="level' . $this->recursionLevel . '" style="margin-left:10px">';
@@ -68,7 +73,7 @@ class UnorderedListTreeRenderer extends \TYPO3\CMS\Backend\Tree\Renderer\Abstrac
      * @param bool $recursive
      * @return string
      */
-    public function renderNodeCollection(\TYPO3\CMS\Backend\Tree\TreeNodeCollection $collection, $recursive = true)
+    public function renderNodeCollection(TreeNodeCollection $collection, $recursive = true)
     {
         $code = '<ul class="level' . $this->recursionLevel . '" style="margin-left:10px">';
         foreach ($collection as $node) {
