@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Backend\Tree;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,11 @@ namespace TYPO3\CMS\Backend\Tree;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Backend\Tree;
+
+use TYPO3\CMS\Core\Exception;
+use TYPO3\CMS\Core\Utility\GeneralUtility;
+
 /**
  * Tree Node Collection
  */
@@ -52,7 +56,7 @@ class TreeNodeCollection extends \ArrayObject
      * @param TreeNode $otherNode
      * @return int
      */
-    public function nodeCompare(\TYPO3\CMS\Backend\Tree\TreeNode $node, \TYPO3\CMS\Backend\Tree\TreeNode $otherNode)
+    public function nodeCompare(TreeNode $node, TreeNode $otherNode)
     {
         return $node->compareTo($otherNode);
     }
@@ -77,7 +81,7 @@ class TreeNodeCollection extends \ArrayObject
     {
         $arrayRepresentation = unserialize($serializedString);
         if ($arrayRepresentation['serializeClassName'] !== static::class) {
-            throw new \TYPO3\CMS\Core\Exception('Deserialized object type is not identical!', 1294586647);
+            throw new Exception('Deserialized object type is not identical!', 1294586647);
         }
         $this->dataFromArray($arrayRepresentation);
     }
@@ -109,7 +113,7 @@ class TreeNodeCollection extends \ArrayObject
     {
         unset($data['serializeClassName']);
         foreach ($data as $index => $nodeArray) {
-            $node = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance($nodeArray['serializeClassName'], $nodeArray);
+            $node = GeneralUtility::makeInstance($nodeArray['serializeClassName'], $nodeArray);
             $this->offsetSet($index, $node);
         }
     }
