@@ -95,6 +95,12 @@ return [
         'target' => Controller\Page\TreeController::class . '::fetchDataAction'
     ],
 
+    // Get data for page tree
+    'page_tree_filter' => [
+        'path' => '/page/tree/filterData',
+        'target' => Controller\Page\TreeController::class . '::filterDataAction'
+    ],
+
     // Get page tree configuration
     'page_tree_configuration' => [
         'path' => '/page/tree/fetchConfiguration',
@@ -170,6 +176,13 @@ return [
         'access' => 'public'
     ],
 
+    // Preflight check for login form
+    'login_preflight' => [
+        'path' => '/login/preflight',
+        'target' => \TYPO3\CMS\Backend\Controller\AjaxLoginController::class . '::preflightAction',
+        'access' => 'public'
+    ],
+
     // Refresh login of backend
     'login_refresh' => [
         'path' => '/login/refresh',
