@@ -10,4 +10,4 @@
  *
  * The TYPO3 project - inspiring people to share!
  */
-define(["require","exports"],(function(e,t){"use strict";Object.defineProperty(t,"__esModule",{value:!0});t.Tabbable=class{static enable(t){t.classList.contains("t3js-enable-tab")&&e(["taboverride"],e=>{e.set(t)})}}}));
\ No newline at end of file
+define(["require","exports"],(function(e,t){"use strict";Object.defineProperty(t,"__esModule",{value:!0}),t.Tabbable=void 0;t.Tabbable=class{static enable(t){t.classList.contains("t3js-enable-tab")&&e(["taboverride"],e=>{e.set(t)})}}}));
\ No newline at end of file
