@@ -32,12 +32,14 @@ define(['jquery',
      */
     var PageTree = function() {
       SvgTree.call(this);
+      this.originalNodes = [];
       this.settings.defaultProperties = {
         hasChildren: false,
         nameSourceField: 'title',
         prefix: '',
         suffix: '',
         locked: false,
+        loaded: false,
         overlayIcon: '',
         selectable: true,
         expanded: false,
@@ -48,9 +50,11 @@ define(['jquery',
         readableRootline: '',
         isMountPoint: false,
       };
+      this.searchQuery = '';
     };
 
     PageTree.prototype = Object.create(SvgTree.prototype);
+
     var _super_ = SvgTree.prototype;
 
     /**
@@ -66,7 +70,7 @@ define(['jquery',
         return false;
       }
 
-      _this.settings.isDragAnDrop = true;
+      _this.settings.isDragAnDrop = settings.allowDragMove;
       _this.dispatch.on('nodeSelectedAfter.pageTree', _this.nodeSelectedAfter);
       _this.dispatch.on('nodeRightClick.pageTree', _this.nodeRightClick);
       _this.dispatch.on('contextmenu.pageTree', _this.contextmenu);
@@ -192,7 +196,7 @@ define(['jquery',
               _this.update();
               _this.nodesRemovePlaceholder();
             } else {
-              _this.loadData();
+              _this.refreshOrFilterTree();
             }
           } else {
             _this.errorNotification();
@@ -204,6 +208,26 @@ define(['jquery',
       return this.nodes[0];
     };
 
+    /**
+     * Finds node by its stateIdentifier (e.g. "0_360")
+     * @return {Node}
+     */
+    PageTree.prototype.getNodeByIdentifier = function(identifier) {
+      return this.nodes.find(function (node) {
+        return node.stateIdentifier === identifier;
+      });
+    };
+
+    PageTree.prototype.getNodeLabel = function(node) {
+      var _this = this;
+      var label = _super_.getNodeLabel(node);
+      if (_this.searchQuery) {
+        var regexp = new RegExp(_this.searchQuery, 'gi');
+        label = label.replace(regexp, '<tspan class="node-highlight-text">$&</tspan>');
+      }
+      return label;
+    }
+
     /**
      * Observer for the selectedNode event
      *
@@ -282,10 +306,63 @@ define(['jquery',
     };
 
     PageTree.prototype.showChildren = function(node) {
+      this.loadChildrenOfNode(node);
       _super_.showChildren(node);
       Persistent.set('BackendComponents.States.Pagetree.stateHash.' + node.stateIdentifier, 1);
     };
 
+    /**
+     * Loads child nodes via Ajax (used when expanding a collapesed node)
+     *
+     * @param parentNode
+     * @return {boolean}
+     */
+    PageTree.prototype.loadChildrenOfNode = function(parentNode) {
+      if (parentNode.loaded) {
+        return;
+      }
+      var _this = this;
+      _this.nodesAddPlaceholder();
+      d3.json(_this.settings.dataUrl + '&pid=' + parentNode.identifier + '&mount=' + parentNode.mountPoint + '&pidDepth=' + parentNode.depth, function(error, json) {
+          if (error) {
+            var title = TYPO3.lang.pagetree_networkErrorTitle;
+            var desc = TYPO3.lang.pagetree_networkErrorDesc;
+
+            if (error && error.target && (error.target.status || error.target.statusText)) {
+              title += ' - ' + (error.target.status || '') + ' ' + (error.target.statusText || '');
+            }
+
+            Notification.error(
+              title,
+              desc);
+
+            _this.nodesRemovePlaceholder();
+            throw error;
+          }
+
+          var nodes = Array.isArray(json) ? json : [];
+          //first element is a parent
+          nodes.shift();
+          var index = _this.nodes.indexOf(parentNode) + 1;
+          //adding fetched node after parent
+          nodes.forEach(function (node, offset) {
+            _this.nodes.splice(index + offset, 0, node);
+          });
+
+          parentNode.loaded = true;
+          _this.setParametersNode();
+          _this.prepareDataForVisibleNodes();
+          _this.update();
+          _this.nodesRemovePlaceholder();
+
+          // Focus node only if it's not currently in edit mode
+          if (!_this.nodeIsEdit) {
+            _this.switchFocusNode(parentNode);
+          }
+        });
+
+    };
+
     PageTree.prototype.updateNodeBgClass = function(nodeBg) {
       return _super_.updateNodeBgClass.call(this, nodeBg).call(this.dragDrop.drag());
     };
@@ -388,6 +465,69 @@ define(['jquery',
         });
     };
 
+    PageTree.prototype.filterTree = function() {
+      var _this = this;
+      _this.nodesAddPlaceholder();
+
+      d3.json(_this.settings.filterUrl + '&q=' + _this.searchQuery, function(error, json) {
+        if (error) {
+          var title = TYPO3.lang.pagetree_networkErrorTitle;
+          var desc = TYPO3.lang.pagetree_networkErrorDesc;
+
+          if (error && error.target && (error.target.status || error.target.statusText)) {
+            title += ' - ' + (error.target.status || '') + ' ' + (error.target.statusText || '');
+          }
+
+          Notification.error(
+            title,
+            desc);
+
+          _this.nodesRemovePlaceholder();
+          throw error;
+        }
+
+        var nodes = Array.isArray(json) ? json : [];
+        if (nodes.length > 0) {
+          if (_this.originalNodes.length === 0) {
+            _this.originalNodes = JSON.stringify(_this.nodes);
+          }
+          _this.replaceData(nodes);
+        }
+        _this.nodesRemovePlaceholder();
+      });
+    };
+
+    PageTree.prototype.refreshOrFilterTree = function() {
+      if (this.searchQuery !== '') {
+        this.filterTree();
+      } else {
+        this.refreshTree();
+      }
+    }
+
+    PageTree.prototype.resetFilter = function() {
+      this.searchQuery = '';
+      if (this.originalNodes.length > 0) {
+        var currentlySelected = this.getSelectedNodes()[0];
+        if (typeof currentlySelected === 'undefined') {
+          this.refreshTree();
+          return;
+        }
+
+        this.nodes = JSON.parse(this.originalNodes);
+        this.originalNodes = '';
+        var currentlySelectedNode = this.getNodeByIdentifier(currentlySelected.stateIdentifier);
+
+        if (currentlySelectedNode) {
+          this.selectNode(currentlySelectedNode);
+        } else {
+          this.refreshTree();
+        }
+      } else {
+        this.refreshTree();
+      }
+    };
+
     PageTree.prototype.setTemporaryMountPoint = function(pid) {
       var params = 'pid=' + pid;
       var _this = this;
@@ -418,7 +558,7 @@ define(['jquery',
               _this.update();
             } else {
               _this.addMountPoint(response.mountPointPath);
-              _this.loadData();
+              _this.refreshOrFilterTree();
             }
           } else {
             _this.errorNotification();
@@ -465,11 +605,11 @@ define(['jquery',
               }
 
               _this.nodesAddPlaceholder();
-              _this.loadData();
+              _this.refreshOrFilterTree();
             } else {
               node.name = node.newName;
               _this.svg.select('.node-placeholder[data-uid="' + node.stateIdentifier + '"]').remove();
-              _this.loadData();
+              _this.refreshOrFilterTree();
               _this.nodesRemovePlaceholder();
             }
           } else {
@@ -482,6 +622,10 @@ define(['jquery',
     PageTree.prototype.editNodeLabel = function(node) {
       var _this = this;
 
+      if (!node.allowEdit) {
+        return;
+      }
+
       _this.removeEditedText();
       _this.nodeIsEdit = true;
 
