@@ -18,11 +18,12 @@ define(['jquery',
     'TYPO3/CMS/Backend/Icons',
     'd3',
     'TYPO3/CMS/Backend/PageTree/PageTreeDragDrop',
+    'TYPO3/CMS/Core/Event/DebounceEvent',
     'TYPO3/CMS/Backend/Tooltip',
     'TYPO3/CMS/Backend/SvgTree',
     'TYPO3/CMS/Backend/Input/Clearable'
   ],
-  function($, Icons, d3, PageTreeDragDrop) {
+  function($, Icons, d3, PageTreeDragDrop, DebounceEvent) {
     'use strict';
 
     /**
@@ -35,7 +36,8 @@ define(['jquery',
       this.settings = {
         toolbarSelector: 'tree-toolbar',
         searchInput: '.search-input',
-        target: '.svg-toolbar'
+        target: '.svg-toolbar',
+        filterTimeout: 450
       };
 
       /**
@@ -66,13 +68,6 @@ define(['jquery',
        * @type {jQuery}
        */
       this.template = null;
-
-      /**
-       * Nodes stored encoded before tree gets filtered
-       *
-       * @type {string}
-       */
-      this.originalNodes = '';
     };
 
     /**
@@ -108,9 +103,11 @@ define(['jquery',
       var $template = $(
         '<div class="' + _this.settings.toolbarSelector + '">' +
         '<div class="svg-toolbar__menu">' +
+        '<div class="btn-group">' +
         '<div class="x-btn btn btn-default btn-sm x-btn-noicon" data-tree-show-submenu="filter">' +
         '<button class="svg-toolbar__btn" data-tree-icon="actions-filter" title="' + TYPO3.lang['tree.buttonFilter'] + '"></button>' +
         '</div>' +
+        '</div>' +
         '<div class="x-btn btn btn-default btn-sm x-btn-noicon js-svg-refresh">' +
         '<button class="svg-toolbar__btn" data-tree-icon="actions-refresh" title="' + TYPO3.lang['labels.refresh'] + '"></button>' +
         '</div>' +
@@ -127,7 +124,7 @@ define(['jquery',
 
       if (this.tree.settings.doktypes && this.tree.settings.doktypes.length) {
         var $buttons = $template.find('[data-tree-submenu=page-new]');
-        $template.find('.svg-toolbar__menu').prepend('<div class="x-btn btn btn-default btn-sm x-btn-noicon" data-tree-show-submenu="page-new">' +
+        $template.find('.svg-toolbar__menu .btn-group').prepend('<div class="x-btn btn btn-default btn-sm x-btn-noicon" data-tree-show-submenu="page-new">' +
           '<button class="svg-toolbar__btn" data-tree-icon="actions-page-new" title="' + TYPO3.lang['tree.buttonNewNode'] + '"></button>' +
           '</div>'
         );
@@ -159,6 +156,7 @@ define(['jquery',
 
         Icons.getIcon($this.attr('data-tree-icon'), Icons.sizes.small).then(function(icon) {
           $this.append(icon);
+          _this.tree.setWrapperHeight();
         });
       });
 
@@ -178,8 +176,10 @@ define(['jquery',
           let input = $submenu.find('input').get(0);
           if (input) {
             input.clearable({
-              onClear: function (input) {
-                $(input).trigger('input');
+              onClear: function () {
+                _this.tree.resetFilter();
+                _this.tree.prepareDataForVisibleNodes();
+                _this.tree.update();
               }
             });
           }
@@ -201,9 +201,9 @@ define(['jquery',
         }
       });
 
-      $toolbar.find(this.settings.searchInput).on('input', function() {
-        _this.search.call(_this, this);
-      });
+      new DebounceEvent('input', function (e) {
+        this.search(e.target);
+      }.bind(this), this.settings.filterTimeout).bindTo(document.querySelector(this.settings.searchInput));
 
       $toolbar.find('[data-toggle="tooltip"]').tooltip();
 
@@ -218,7 +218,8 @@ define(['jquery',
      * Refresh tree
      */
     TreeToolbar.prototype.refreshTree = function() {
-      this.tree.refreshTree();
+      const searchInput = document.querySelector(this.settings.target + ' ' + this.settings.searchInput);
+      this.tree.refreshOrFilterTree();
     };
 
     /**
@@ -227,31 +228,8 @@ define(['jquery',
      * @param {HTMLElement} input
      */
     TreeToolbar.prototype.search = function(input) {
-      var _this = this;
-      var name = $(input).val().trim();
-
-      if (name !== '') {
-        if (this.originalNodes.length === 0) {
-          this.originalNodes = JSON.stringify(this.tree.nodes);
-        }
-
-        this.tree.nodes[0].expanded = false;
-        this.tree.nodes.forEach(function (node) {
-          var regex = new RegExp(name, 'i');
-          if (node.identifier.toString() === name || regex.test(node.name) || regex.test(node.alias || '')) {
-            _this.showParents(node);
-            node.expanded = true;
-            node.hidden = false;
-          } else if (node.depth !== 0) {
-            node.hidden = true;
-            node.expanded = false;
-          }
-        });
-      } else {
-        this.tree.nodes = JSON.parse(this.originalNodes);
-        this.originalNodes = '';
-      }
-
+      this.tree.searchQuery =  $(input).val().trim();
+      this.tree.refreshOrFilterTree();
       this.tree.prepareDataForVisibleNodes();
       this.tree.update();
     };
