@@ -24,9 +24,10 @@ define(
     'TYPO3/CMS/Backend/Notification',
     'TYPO3/CMS/Backend/Icons',
     'TYPO3/CMS/Backend/Tooltip',
-    'TYPO3/CMS/Backend/Enum/KeyTypes'
+    'TYPO3/CMS/Backend/Enum/KeyTypes',
+    'TYPO3/CMS/Core/SecurityUtility'
   ],
-  function($, d3, ContextMenu, Modal, Severity, Notification, Icons, Tooltip, KeyTypes) {
+  function($, d3, ContextMenu, Modal, Severity, Notification, Icons, Tooltip, KeyTypes, SecurityUtility) {
     'use strict';
 
     /**
@@ -397,7 +398,7 @@ define(
        * Set svg wrapper height
        */
       setWrapperHeight: function() {
-        var treeWrapperHeight = ($('#typo3-pagetree').height() - $('#svg-toolbar').height());
+        var treeWrapperHeight = ($('body').height() - $('#svg-toolbar').outerHeight() - $('.scaffold-topbar').height());
         $('#typo3-pagetree-tree').height(treeWrapperHeight);
       },
 
@@ -608,11 +609,6 @@ define(
           Icons.getIcon(iconName, Icons.sizes.small, null, null, 'inline').then(function(icon) {
             var result = icon.match(/<svg[\s\S]*<\/svg>/i);
 
-            // Check if the icon is from the Bitmap Icon Provider (see PHP class for the inline rendering)
-            if (!result) {
-              result = icon.match(/<image[\s\S]*\/>/i);
-            }
-
             if (result) {
               _this.data.icons[iconName].icon = result[0];
             }
@@ -691,7 +687,7 @@ define(
           })
           .attr('transform', this.getNodeTransform)
           .select('.node-name')
-          .text(this.getNodeLabel);
+          .html(function(node) { return this.getNodeLabel(node); }.bind(this));
 
         nodes
           .select('.chevron')
@@ -1079,7 +1075,9 @@ define(
        * @returns {String}
        */
       getNodeLabel: function(node) {
-        return (node.prefix || '') + node.name + (node.suffix || '');
+        var label = (node.prefix || '') + node.name + (node.suffix || '');
+        var sec = new SecurityUtility();
+        return sec.encodeHtml(label);
       },
 
       /**
@@ -1387,9 +1385,10 @@ define(
        * @param {Node} node
        */
       setExpandedState: function(node) {
-        document
-          .getElementById('identifier-' + this.getNodeStateIdentifier(node))
-          .setAttribute('aria-expanded', (node.hasChildren ? node.expanded : null));
+        var nodeElement = document.getElementById('identifier-' + this.getNodeStateIdentifier(node));
+        if (nodeElement) {
+          nodeElement.setAttribute('aria-expanded', (node.hasChildren ? node.expanded : null));
+        }
       },
 
       /**
