@@ -10,4 +10,4 @@
  *
  * The TYPO3 project - inspiring people to share!
  */
-define(["require","exports","../Enum/Viewport/ScaffoldIdentifier","jquery"],(function(e,r,t,i){"use strict";return class{registerEvent(e){i(e),i(t.ScaffoldIdentifierEnum.header).on("t3-topbar-update",e)}}}));
\ No newline at end of file
+var __importDefault=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};define(["require","exports","../Enum/Viewport/ScaffoldIdentifier","jquery"],(function(e,t,r,u){"use strict";u=__importDefault(u);return class{registerEvent(e){u.default(e),u.default(r.ScaffoldIdentifierEnum.header).on("t3-topbar-update",e)}}}));
\ No newline at end of file
