@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Belog\Domain\Repository;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,12 +13,17 @@ namespace TYPO3\CMS\Belog\Domain\Repository;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Belog\Domain\Repository;
+
+use TYPO3\CMS\Extbase\Persistence\Generic\QuerySettingsInterface;
+use TYPO3\CMS\Extbase\Persistence\Repository;
+
 /**
  * Repository for workspaces
  * @todo This should be moved to EXT:workspaces if EXT:belog works no matter if workspaces are installed or not
  * @internal This class is a TYPO3 Backend implementation and is not considered part of the Public TYPO3 API.
  */
-class WorkspaceRepository extends \TYPO3\CMS\Extbase\Persistence\Repository
+class WorkspaceRepository extends Repository
 {
     /**
      * Initializes the repository.
@@ -27,7 +31,7 @@ class WorkspaceRepository extends \TYPO3\CMS\Extbase\Persistence\Repository
     public function initializeObject()
     {
         /** @var \TYPO3\CMS\Extbase\Persistence\Generic\QuerySettingsInterface $querySettings */
-        $querySettings = $this->objectManager->get(\TYPO3\CMS\Extbase\Persistence\Generic\QuerySettingsInterface::class);
+        $querySettings = $this->objectManager->get(QuerySettingsInterface::class);
         $querySettings->setRespectStoragePage(false);
         $this->setDefaultQuerySettings($querySettings);
     }
