@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Belog\ViewHelpers\Form;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,11 @@ namespace TYPO3\CMS\Belog\ViewHelpers\Form;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Belog\ViewHelpers\Form;
+
+use TYPO3\CMS\Extbase\Utility\LocalizationUtility;
+use TYPO3\CMS\Fluid\ViewHelpers\Form\SelectViewHelper;
+
 /**
  * Extends the usual select ViewHelper, but additionally translates
  * the select option labels
@@ -24,7 +28,7 @@ namespace TYPO3\CMS\Belog\ViewHelpers\Form;
  * Will lookup number.200 (or whatever optionValue is given) in locallang database
  * @internal
  */
-class TranslateLabelSelectViewHelper extends \TYPO3\CMS\Fluid\ViewHelpers\Form\SelectViewHelper
+class TranslateLabelSelectViewHelper extends SelectViewHelper
 {
     /**
      * Initialize arguments.
@@ -64,7 +68,7 @@ class TranslateLabelSelectViewHelper extends \TYPO3\CMS\Fluid\ViewHelpers\Form\S
             return '';
         }
         $labelKey = $this->hasArgument('optionLabelPrefix') ? $this->arguments['optionLabelPrefix'] . $label : $label;
-        $translatedLabel = \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate($labelKey, $this->renderingContext->getControllerContext()->getRequest()->getControllerExtensionName());
+        $translatedLabel = LocalizationUtility::translate($labelKey, $this->renderingContext->getControllerContext()->getRequest()->getControllerExtensionName());
         return $translatedLabel ?: $label;
     }
 }
