@@ -1,7 +1,5 @@
 <?php
 
-namespace TYPO3\CMS\Beuser\Controller;
-
 /*
  * This file is part of the TYPO3 CMS project.
  *
@@ -15,18 +13,30 @@ namespace TYPO3\CMS\Beuser\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Beuser\Controller;
+
 use TYPO3\CMS\Backend\Authentication\Event\SwitchUserEvent;
+use TYPO3\CMS\Backend\Authentication\PasswordReset;
+use TYPO3\CMS\Backend\Utility\BackendUtility;
+use TYPO3\CMS\Beuser\Domain\Model\BackendUser;
+use TYPO3\CMS\Beuser\Domain\Model\Demand;
 use TYPO3\CMS\Beuser\Domain\Repository\BackendUserGroupRepository;
 use TYPO3\CMS\Beuser\Domain\Repository\BackendUserRepository;
 use TYPO3\CMS\Beuser\Domain\Repository\BackendUserSessionRepository;
 use TYPO3\CMS\Beuser\Service\ModuleDataStorageService;
 use TYPO3\CMS\Beuser\Service\UserInformationService;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
+use TYPO3\CMS\Core\Context\Context;
+use TYPO3\CMS\Core\Messaging\FlashMessage;
+use TYPO3\CMS\Core\Session\Backend\HashableSessionBackendInterface;
 use TYPO3\CMS\Core\Session\Backend\SessionBackendInterface;
 use TYPO3\CMS\Core\Session\SessionManager;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\HttpUtility;
 use TYPO3\CMS\Extbase\Mvc\Controller\ActionController;
+use TYPO3\CMS\Extbase\Mvc\Exception\StopActionException;
+use TYPO3\CMS\Extbase\Mvc\RequestInterface;
+use TYPO3\CMS\Extbase\Mvc\ResponseInterface;
 use TYPO3\CMS\Extbase\Mvc\View\ViewInterface;
 use TYPO3\CMS\Extbase\Utility\LocalizationUtility;
 
@@ -92,14 +102,14 @@ class BackendUserController extends ActionController
      * @param \TYPO3\CMS\Extbase\Mvc\ResponseInterface $response
      * @throws \TYPO3\CMS\Extbase\Mvc\Exception\StopActionException
      */
-    public function processRequest(\TYPO3\CMS\Extbase\Mvc\RequestInterface $request, \TYPO3\CMS\Extbase\Mvc\ResponseInterface $response)
+    public function processRequest(RequestInterface $request, ResponseInterface $response)
     {
         $this->moduleData = $this->moduleDataStorageService->loadModuleData();
         // We "finally" persist the module data.
         try {
             parent::processRequest($request, $response);
             $this->moduleDataStorageService->persistModuleData($this->moduleData);
-        } catch (\TYPO3\CMS\Extbase\Mvc\Exception\StopActionException $e) {
+        } catch (StopActionException $e) {
             $this->moduleDataStorageService->persistModuleData($this->moduleData);
             throw $e;
         }
@@ -124,7 +134,7 @@ class BackendUserController extends ActionController
      *
      * @param \TYPO3\CMS\Beuser\Domain\Model\Demand $demand
      */
-    public function indexAction(\TYPO3\CMS\Beuser\Domain\Model\Demand $demand = null)
+    public function indexAction(Demand $demand = null)
     {
         if ($demand === null) {
             $demand = $this->moduleData->getDemand();
@@ -163,10 +173,15 @@ class BackendUserController extends ActionController
             ];
         }
 
+        $currentSessionId = $this->getBackendUserAuthentication()->getSessionId();
+        $sessionBackend = $this->getSessionBackend();
+        if ($sessionBackend instanceof HashableSessionBackendInterface) {
+            $currentSessionId = $sessionBackend->hash($currentSessionId);
+        }
         $this->view->assignMultiple([
             'shortcutLabel' => 'onlineUsers',
             'onlineUsersAndSessions' => $onlineUsersAndSessions,
-            'currentSessionId' => $this->getBackendUserAuthentication()->user['ses_id'],
+            'currentSessionId' => $currentSessionId,
         ]);
     }
 
@@ -175,7 +190,7 @@ class BackendUserController extends ActionController
      */
     public function showAction(int $uid = 0): void
     {
-        $data = $this->userInformationService->get($uid);
+        $data = $this->userInformationService->getUserInformation($uid);
         $this->view->assignMultiple([
             'shortcutLabel' => 'showUser',
             'data' => $data
@@ -194,7 +209,9 @@ class BackendUserController extends ActionController
 
         $compareData = [];
         foreach ($compareUserList as $uid) {
-            $compareData[] =  $this->userInformationService->get($uid);
+            if ($compareInformation = $this->userInformationService->getUserInformation($uid)) {
+                $compareData[] = $compareInformation;
+            }
         }
 
         $this->view->assignMultiple([
@@ -204,6 +221,38 @@ class BackendUserController extends ActionController
         ]);
     }
 
+    /**
+     * Starts the password reset process for a selected user.
+     *
+     * @param int $user
+     */
+    public function initiatePasswordResetAction(int $user): void
+    {
+        $context = GeneralUtility::makeInstance(Context::class);
+        /** @var BackendUser $user */
+        $user = $this->backendUserRepository->findByUid($user);
+        if (!$user || !$user->isPasswordResetEnabled() || !$context->getAspect('backend.user')->isAdmin()) {
+            // Add an error message
+            $this->addFlashMessage(
+                LocalizationUtility::translate('LLL:EXT:beuser/Resources/Private/Language/locallang.xlf:flashMessage.resetPassword.error.text', 'beuser') ?? '',
+                LocalizationUtility::translate('LLL:EXT:beuser/Resources/Private/Language/locallang.xlf:flashMessage.resetPassword.error.title', 'beuser') ?? '',
+                FlashMessage::ERROR
+            );
+        } else {
+            GeneralUtility::makeInstance(PasswordReset::class)->initiateReset(
+                $GLOBALS['TYPO3_REQUEST'],
+                $context,
+                $user->getEmail()
+            );
+            $this->addFlashMessage(
+                LocalizationUtility::translate('LLL:EXT:beuser/Resources/Private/Language/locallang.xlf:flashMessage.resetPassword.success.text', 'beuser', [$user->getEmail()]) ?? '',
+                LocalizationUtility::translate('LLL:EXT:beuser/Resources/Private/Language/locallang.xlf:flashMessage.resetPassword.success.title', 'beuser') ?? '',
+                FlashMessage::OK
+            );
+        }
+        $this->forward('index');
+    }
+
     /**
      * Attaches one backend user to the compare list
      *
@@ -220,12 +269,29 @@ class BackendUserController extends ActionController
      * Removes given backend user to the compare list
      *
      * @param int $uid
+     * @param int $redirectToCompare
      */
-    public function removeFromCompareListAction($uid)
+    public function removeFromCompareListAction($uid, int $redirectToCompare = 0)
     {
         $this->moduleData->detachUidCompareUser($uid);
         $this->moduleDataStorageService->persistModuleData($this->moduleData);
-        $this->forward('index');
+        if ($redirectToCompare) {
+            $this->redirect('compare');
+        } else {
+            $this->redirect('index');
+        }
+    }
+
+    /**
+     * Removes all backend users from the compare list
+     */
+    public function removeAllFromCompareListAction(): void
+    {
+        foreach ($this->moduleData->getCompareUserList() as $user) {
+            $this->moduleData->detachUidCompareUser($user);
+        }
+        $this->moduleDataStorageService->persistModuleData($this->moduleData);
+        $this->redirect('index');
     }
 
     /**
@@ -235,13 +301,14 @@ class BackendUserController extends ActionController
      * @param \TYPO3\CMS\Beuser\Domain\Model\BackendUser $backendUser
      * @param string $sessionId
      */
-    protected function terminateBackendUserSessionAction(\TYPO3\CMS\Beuser\Domain\Model\BackendUser $backendUser, $sessionId)
+    protected function terminateBackendUserSessionAction(BackendUser $backendUser, $sessionId)
     {
+        // terminating value of persisted session ID (probably hashed value)
         $sessionBackend = $this->getSessionBackend();
         $success = $sessionBackend->remove($sessionId);
 
         if ($success) {
-            $this->addFlashMessage(LocalizationUtility::translate('LLL:EXT:beuser/Resources/Private/Language/locallang.xlf:terminateSessionSuccess', 'beuser'));
+            $this->addFlashMessage(LocalizationUtility::translate('LLL:EXT:beuser/Resources/Private/Language/locallang.xlf:terminateSessionSuccess', 'beuser') ?? '');
         }
         $this->forward('online');
     }
@@ -249,11 +316,11 @@ class BackendUserController extends ActionController
     /**
      * Switches to a given user (SU-mode) and then redirects to the start page of the backend to refresh the navigation etc.
      *
-     * @param string $switchUser BE-user record that will be switched to
+     * @param int $switchUser BE-user record that will be switched to
      */
     protected function switchUser($switchUser)
     {
-        $targetUser = \TYPO3\CMS\Backend\Utility\BackendUtility::getRecord('be_users', $switchUser);
+        $targetUser = BackendUtility::getRecord('be_users', $switchUser);
         if (is_array($targetUser) && $this->getBackendUserAuthentication()->isAdmin()) {
             // Set backend user listing module as starting module for switchback
             $this->getBackendUserAuthentication()->uc['startModuleOnFirstLogin'] = 'system_BeuserTxBeuser';
@@ -274,8 +341,7 @@ class BackendUserController extends ActionController
                 ]
             );
 
-            $sessionBackend = $this->getSessionBackend();
-            $sessionBackend->update(
+            $this->getSessionBackend()->update(
                 $this->getBackendUserAuthentication()->getSessionId(),
                 [
                     'ses_userid' => (int)$targetUser['uid'],
@@ -286,7 +352,7 @@ class BackendUserController extends ActionController
             $event = new SwitchUserEvent(
                 $this->getBackendUserAuthentication()->getSessionId(),
                 $targetUser,
-                $this->getBackendUserAuthentication()->user
+                (array)$this->getBackendUserAuthentication()->user
             );
             $this->eventDispatcher->dispatch($event);
 
