@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Beuser\Hook;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,10 +13,15 @@ namespace TYPO3\CMS\Beuser\Hook;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Beuser\Hook;
+
+use TYPO3\CMS\Backend\Routing\UriBuilder;
+use TYPO3\CMS\Beuser\Domain\Repository\BackendUserSessionRepository;
 use TYPO3\CMS\Core\Authentication\AbstractUserAuthentication;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\HttpUtility;
+use TYPO3\CMS\Extbase\Object\ObjectManager;
 
 /**
  * Backend user switchback, for logoff_pre_processing hook within
@@ -36,11 +40,11 @@ class SwitchBackUserHook
     public function switchBack($params, AbstractUserAuthentication $authentication)
     {
         if ($this->isAHandledBackendSession($authentication)) {
-            $objectManager = GeneralUtility::makeInstance(\TYPO3\CMS\Extbase\Object\ObjectManager::class);
-            $backendUserSessionRepository = $objectManager->get(\TYPO3\CMS\Beuser\Domain\Repository\BackendUserSessionRepository::class);
+            $objectManager = GeneralUtility::makeInstance(ObjectManager::class);
+            $backendUserSessionRepository = $objectManager->get(BackendUserSessionRepository::class);
             $backendUserSessionRepository->switchBackToOriginalUser($authentication);
             /** @var \TYPO3\CMS\Backend\Routing\UriBuilder $uriBuilder */
-            $uriBuilder = GeneralUtility::makeInstance(\TYPO3\CMS\Backend\Routing\UriBuilder::class);
+            $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
             HttpUtility::redirect((string)$uriBuilder->buildUriFromRoute('main'));
         }
     }
