@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Authentication;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Authentication;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Authentication;
+
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
 use Symfony\Component\HttpFoundation\Cookie;
@@ -31,6 +32,7 @@ use TYPO3\CMS\Core\Database\Query\Restriction\StartTimeRestriction;
 use TYPO3\CMS\Core\Exception;
 use TYPO3\CMS\Core\Http\CookieHeaderTrait;
 use TYPO3\CMS\Core\Session\Backend\Exception\SessionNotFoundException;
+use TYPO3\CMS\Core\Session\Backend\HashableSessionBackendInterface;
 use TYPO3\CMS\Core\Session\Backend\SessionBackendInterface;
 use TYPO3\CMS\Core\Session\SessionManager;
 use TYPO3\CMS\Core\SysLog\Action\Login as SystemLogLoginAction;
@@ -371,8 +373,8 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
         // Load user session, check to see if anyone has submitted login-information and if so authenticate
         // the user with the session. $this->user[uid] may be used to write log...
         $this->checkAuthentication();
-        // Setting cookies
-        if (!$this->dontSetCookie) {
+        // Set cookie if generally enabled or if the current session is a non-session cookie (FE permalogin)
+        if (!$this->dontSetCookie || $this->isRefreshTimeBasedCookie()) {
             $this->setSessionCookie();
         }
         // Hook for alternative ways of filling the $this->user array (is used by the "timtaw" extension)
@@ -421,7 +423,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
         $cacheControlHeader = 'no-cache, must-revalidate';
         $pragmaHeader = 'no-cache';
         // Prevent error message in IE when using a https connection
-        // see http://forge.typo3.org/issues/24125
+        // see https://forge.typo3.org/issues/24125
         if (strpos(GeneralUtility::getIndpEnv('HTTP_USER_AGENT'), 'MSIE') !== false
             && GeneralUtility::getIndpEnv('TYPO3_SSL')) {
             // Some IEs can not handle no-cache
@@ -482,7 +484,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
             }
             $this->logger->debug(
                 ($isRefreshTimeBasedCookie ? 'Updated Cookie: ' : 'Set Cookie: ')
-                . $this->id . ($cookieDomain ? ', ' . $cookieDomain : '')
+                . sha1($this->id) . ($cookieDomain ? ', ' . $cookieDomain : '')
             );
         }
     }
@@ -573,14 +575,14 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
         $authInfo = $this->getAuthInfoArray();
         // Get Login/Logout data submitted by a form or params
         $loginData = $this->getLoginFormData();
-        $this->logger->debug('Login data', $loginData);
+        $this->logger->debug('Login data', $this->removeSensitiveLoginDataForLoggingInfo($loginData));
         // Active logout (eg. with "logout" button)
         if ($loginData['status'] === LoginType::LOGOUT) {
             if ($this->writeStdLog) {
                 // $type,$action,$error,$details_nr,$details,$data,$tablename,$recuid,$recpid
                 $this->writelog(SystemLogType::LOGIN, SystemLogLoginAction::LOGOUT, SystemLogErrorClassification::MESSAGE, 2, 'User %s logged out', [$this->user['username']], '', 0, 0);
             }
-            $this->logger->info('User logged out. Id: ' . $this->id);
+            $this->logger->info('User logged out. Id: ' . sha1($this->id));
             $this->logoff();
         }
         // Determine whether we need to skip session update.
@@ -685,7 +687,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
                 // Use 'auth' service to authenticate the user
                 // If one service returns FALSE then authentication failed
                 // a service might return 100 which means there's no reason to stop but the user can't be authenticated by that service
-                $this->logger->debug('Auth user', $tempuser);
+                $this->logger->debug('Auth user', $this->removeSensitiveLoginDataForLoggingInfo($tempuser, true));
                 $subType = 'authUser' . $this->loginType;
 
                 /** @var AuthenticationService $serviceObj */
@@ -742,6 +744,17 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
                     ]);
                 }
             } elseif ($haveSession) {
+                // Validate the session ID and promote it
+                // This check can be removed in TYPO3 v11
+                if ($this->getSessionBackend() instanceof HashableSessionBackendInterface && !empty($authInfo['userSession']['ses_id'] ?? '')) {
+                    // The session is stored in plaintext, promote it
+                    if ($authInfo['userSession']['ses_id'] === $this->id) {
+                        $authInfo['userSession'] = $this->getSessionBackend()->update(
+                            $this->id,
+                            ['ses_data' => $authInfo['userSession']['ses_data']]
+                        );
+                    }
+                }
                 // if we come here the current session is for sure not anonymous as this is a pre-condition for $authenticated = true
                 $this->user = $authInfo['userSession'];
             }
@@ -771,7 +784,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
                 $this->loginFailure = true;
                 if (empty($tempuserArr) && $activeLogin) {
                     $logData = [
-                        'loginData' => $loginData
+                        'loginData' => $this->removeSensitiveLoginDataForLoggingInfo($loginData)
                     ];
                     $this->logger->debug('Login failed', $logData);
                 }
@@ -884,7 +897,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
      */
     public function createUserSession($tempuser)
     {
-        $this->logger->debug('Create session ses_id = ' . $this->id);
+        $this->logger->debug('Create session ses_id = ' . sha1($this->id));
         // Delete any session entry first
         $this->getSessionBackend()->remove($this->id);
         // Re-create session entry
@@ -940,7 +953,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
      */
     public function fetchUserSession($skipSessionUpdate = false)
     {
-        $this->logger->debug('Fetch session ses_id = ' . $this->id);
+        $this->logger->debug('Fetch session ses_id = ' . sha1($this->id));
         try {
             $sessionRecord = $this->getSessionBackend()->get($this->id);
         } catch (SessionNotFoundException $e) {
@@ -1003,7 +1016,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
      */
     public function logoff()
     {
-        $this->logger->debug('logoff: ses_id = ' . $this->id);
+        $this->logger->debug('logoff: ses_id = ' . sha1($this->id));
 
         $_params = [];
         foreach ($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['t3lib/class.t3lib_userauth.php']['logoff_pre_processing'] ?? [] as $_funcRef) {
@@ -1032,6 +1045,9 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
         }
         $this->sessionData = [];
         $this->user = null;
+        if ($this->isCookieSet()) {
+            $this->removeCookie($this->name);
+        }
     }
 
     /**
@@ -1044,7 +1060,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
         $cookieDomain = $this->getCookieDomain();
         // If no cookie domain is set, use the base path
         $cookiePath = $cookieDomain ? '/' : GeneralUtility::getIndpEnv('TYPO3_SITE_PATH');
-        setcookie($cookieName, null, -1, $cookiePath, $cookieDomain);
+        setcookie($cookieName, '', -1, $cookiePath, $cookieDomain);
     }
 
     /**
@@ -1160,7 +1176,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
     public function unpack_uc($theUC = '')
     {
         if (!$theUC && isset($this->user['uc'])) {
-            $theUC = unserialize($this->user['uc']);
+            $theUC = unserialize($this->user['uc'], ['allowed_classes' => false]);
         }
         if (is_array($theUC)) {
             $this->uc = $theUC;
@@ -1178,8 +1194,12 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
      */
     public function pushModuleData($module, $data, $noSave = 0)
     {
+        $sessionHash = GeneralUtility::hmac(
+            $this->id,
+            'core-session-hash'
+        );
         $this->uc['moduleData'][$module] = $data;
-        $this->uc['moduleSessionID'][$module] = $this->id;
+        $this->uc['moduleSessionID'][$module] = $sessionHash;
         if (!$noSave) {
             $this->writeUC();
         }
@@ -1194,8 +1214,18 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
      */
     public function getModuleData($module, $type = '')
     {
-        if ($type !== 'ses' || (isset($this->uc['moduleSessionID'][$module]) && $this->uc['moduleSessionID'][$module] == $this->id)) {
-            return $this->uc['moduleData'][$module];
+        $sessionHash = GeneralUtility::hmac(
+            $this->id,
+            'core-session-hash'
+        );
+        $sessionData = $this->uc['moduleData'][$module] ?? null;
+        $moduleSessionIdHash = $this->uc['moduleSessionID'][$module] ?? null;
+        if ($type !== 'ses'
+            || $sessionData !== null && $moduleSessionIdHash === $sessionHash
+            // @todo Fallback for non-hashed values in `moduleSessionID`, remove for TYPO3 v11.5 LTS
+            || $sessionData !== null && $moduleSessionIdHash === $this->id
+        ) {
+            return $sessionData;
         }
         return null;
     }
@@ -1238,7 +1268,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
     {
         $this->sessionData[$key] = $data;
         $this->user['ses_data'] = serialize($this->sessionData);
-        $this->logger->debug('setAndSaveSessionData: ses_id = ' . $this->id);
+        $this->logger->debug('setAndSaveSessionData: ses_id = ' . sha1($this->id));
         $updatedSession = $this->getSessionBackend()->update(
             $this->id,
             ['ses_data' => $this->user['ses_data']]
@@ -1268,7 +1298,6 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
         if ($loginData['status'] === LoginType::LOGIN) {
             $loginData = $this->processLoginData($loginData);
         }
-        $loginData = array_map('trim', $loginData);
         return $loginData;
     }
 
@@ -1285,7 +1314,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
     {
         $loginSecurityLevel = trim($GLOBALS['TYPO3_CONF_VARS'][$this->loginType]['loginSecurityLevel']) ?: 'normal';
         $passwordTransmissionStrategy = $passwordTransmissionStrategy ?: $loginSecurityLevel;
-        $this->logger->debug('Login data before processing', $loginData);
+        $this->logger->debug('Login data before processing', $this->removeSensitiveLoginDataForLoggingInfo($loginData));
         $subType = 'processLoginData' . $this->loginType;
         $authInfo = $this->getAuthInfoArray();
         $isLoginDataProcessed = false;
@@ -1303,11 +1332,39 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
         }
         if ($isLoginDataProcessed) {
             $loginData = $processedLoginData;
-            $this->logger->debug('Processed login data', $processedLoginData);
+            $this->logger->debug('Processed login data', $this->removeSensitiveLoginDataForLoggingInfo($processedLoginData));
         }
         return $loginData;
     }
 
+    /**
+     * Removes any sensitive data from the incoming data (either from loginData, processedLogin data
+     * or the user record from the DB).
+     *
+     * No type hinting is added because it might be possible that the incoming data is of any other type.
+     *
+     * @param mixed|array $data
+     * @param bool $isUserRecord
+     * @return mixed
+     */
+    protected function removeSensitiveLoginDataForLoggingInfo($data, bool $isUserRecord = false)
+    {
+        if ($isUserRecord && is_array($data)) {
+            $fieldNames = ['uid', 'pid', 'tstamp', 'crdate', 'cruser_id', 'deleted', 'disabled', 'starttime', 'endtime', 'username', 'admin', 'usergroup', 'db_mountpoints', 'file_mountpoints', 'file_permissions', 'workspace_perms', 'lastlogin', 'workspace_id', 'category_perms'];
+            $data = array_intersect_key($data, array_combine($fieldNames, $fieldNames));
+        }
+        if (isset($data['uident'])) {
+            $data['uident'] = '********';
+        }
+        if (isset($data['uident_text'])) {
+            $data['uident_text'] = '********';
+        }
+        if (isset($data['password'])) {
+            $data['password'] = '********';
+        }
+        return $data;
+    }
+
     /**
      * Returns an info array which provides additional information for auth services
      *
@@ -1339,7 +1396,7 @@ abstract class AbstractUserAuthentication implements LoggerAwareInterface
             $authInfo['db_user']['checkPidList'] = $this->checkPid_value;
             $authInfo['db_user']['check_pid_clause'] = $expressionBuilder->in(
                 'pid',
-                GeneralUtility::intExplode(',', $this->checkPid_value)
+                GeneralUtility::intExplode(',', (string)$this->checkPid_value)
             );
         } else {
             $authInfo['db_user']['checkPidList'] = '';
