@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Authentication;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Authentication;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Authentication;
+
 use TYPO3\CMS\Core\Crypto\PasswordHashing\InvalidPasswordHashException;
 use TYPO3\CMS\Core\Crypto\PasswordHashing\PasswordHashFactory;
 use TYPO3\CMS\Core\Database\Connection;
@@ -42,6 +43,7 @@ class AuthenticationService extends AbstractAuthenticationService
     {
         $isProcessed = false;
         if ($passwordTransmissionStrategy === 'normal') {
+            $loginData = array_map('trim', $loginData);
             $loginData['uident_text'] = $loginData['uident'];
             $isProcessed = true;
         }
@@ -123,7 +125,7 @@ class AuthenticationService extends AbstractAuthenticationService
         // Get a hashed password instance for the hash stored in db of this user
         $invalidPasswordHashException = null;
         try {
-            $hashInstance = $saltFactory->get($passwordHashInDatabase, TYPO3_MODE);
+            $hashInstance = $saltFactory->get($passwordHashInDatabase, $this->pObj->loginType);
         } catch (InvalidPasswordHashException $invalidPasswordHashException) {
             // Could not find a responsible hash algorithm for given password. This is unusual since other
             // authentication services would usually be called before this one with higher priority. We thus log
@@ -131,14 +133,13 @@ class AuthenticationService extends AbstractAuthenticationService
             $message = 'Login-attempt from ###IP###, username \'%s\', no suitable hash method found!';
             $this->writeLogMessage($message, $submittedUsername);
             $this->writelog(SystemLogType::LOGIN, SystemLogLoginAction::ATTEMPT, SystemLogErrorClassification::SECURITY_NOTICE, 1, $message, [$submittedUsername]);
-            $this->logger->info(sprintf($message, $submittedUsername));
             // Not responsible, check other services
             return 100;
         }
 
         // An instance of the currently configured salted password mechanism
         // Don't catch InvalidPasswordHashException here: Only install tool should handle those configuration failures
-        $defaultHashInstance = $saltFactory->getDefaultHashInstance(TYPO3_MODE);
+        $defaultHashInstance = $saltFactory->getDefaultHashInstance($this->pObj->loginType);
 
         // We found a hash class that can handle this type of hash
         $isValidPassword = $hashInstance->checkPassword($submittedPassword, $passwordHashInDatabase);
@@ -161,10 +162,9 @@ class AuthenticationService extends AbstractAuthenticationService
 
         if (!$isValidPassword) {
             // Failed login attempt - wrong password
-            $this->writeLogMessage(TYPO3_MODE . ' Authentication failed - wrong password for username \'%s\'', $submittedUsername);
             $message = 'Login-attempt from ###IP###, username \'%s\', password not accepted!';
+            $this->writeLogMessage($message, $submittedUsername);
             $this->writelog(SystemLogType::LOGIN, SystemLogLoginAction::ATTEMPT, SystemLogErrorClassification::SECURITY_NOTICE, 1, $message, [$submittedUsername]);
-            $this->logger->info(sprintf($message, $submittedUsername));
             // Responsible, authentication failed, do NOT check other services
             return 0;
         }
@@ -189,7 +189,7 @@ class AuthenticationService extends AbstractAuthenticationService
         }
 
         // Responsible, authentication ok, domain lock ok. Log successful login and return 'auth ok, do NOT check other services'
-        $this->writeLogMessage(TYPO3_MODE . ' Authentication successful for username \'%s\'', $submittedUsername);
+        $this->writeLogMessage($this->pObj->loginType . ' Authentication successful for username \'%s\'', $submittedUsername);
         return 200;
     }
 
@@ -318,7 +318,7 @@ class AuthenticationService extends AbstractAuthenticationService
             // Get row:
             $row = $groupRows[$uid];
             // Must be an array and $uid should not be in the idList, because then it is somewhere previously in the grouplist
-            if (is_array($row) && !GeneralUtility::inList($idList, $uid) && trim($row['subgroup'])) {
+            if (is_array($row) && !GeneralUtility::inList($idList, (string)$uid) && trim($row['subgroup'])) {
                 // Make integer list
                 $theList = implode(',', GeneralUtility::intExplode(',', $row['subgroup']));
                 // Call recursively, pass along list of already processed groups so they are not processed again.
@@ -350,16 +350,18 @@ class AuthenticationService extends AbstractAuthenticationService
      *
      * This function accepts variable number of arguments and can format
      * parameters. The syntax is the same as for sprintf()
+     * If a marker ###IP### is present in the message, it is automatically replaced with the REMOTE_ADDR
      *
      * @param string $message Message to output
-     * @param array|mixed[] $params
+     * @param array<int,mixed> $params
      */
     protected function writeLogMessage(string $message, ...$params): void
     {
         if (!empty($params)) {
             $message = vsprintf($message, $params);
         }
-        if (TYPO3_MODE === 'FE') {
+        $message = str_replace('###IP###', (string)GeneralUtility::getIndpEnv('REMOTE_ADDR'), $message);
+        if ($this->pObj->loginType === 'FE') {
             $timeTracker = GeneralUtility::makeInstance(TimeTracker::class);
             $timeTracker->setTSlogMessage($message);
         }
