@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Cache\Backend;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Cache\Backend;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Cache\Backend;
+
 use Doctrine\DBAL\FetchMode;
 use TYPO3\CMS\Core\Cache\Exception;
 use TYPO3\CMS\Core\Cache\Exception\InvalidDataException;
@@ -481,7 +482,7 @@ class Typo3DatabaseBackend extends AbstractBackend implements TaggableBackendInt
      * If compression is enabled and this is not set,
      * gzcompress default level will be used
      *
-     * @param int -1 to 9: Compression level
+     * @param int $compressionLevel -1 to 9: Compression level
      */
     public function setCompressionLevel($compressionLevel)
     {
@@ -524,12 +525,12 @@ class Typo3DatabaseBackend extends AbstractBackend implements TaggableBackendInt
      */
     public function getTableDefinitions()
     {
-        $cacheTableSql = file_get_contents(
+        $cacheTableSql = (string)file_get_contents(
             ExtensionManagementUtility::extPath('core') .
             'Resources/Private/Sql/Cache/Backend/Typo3DatabaseBackendCache.sql'
         );
         $requiredTableStructures = str_replace('###CACHE_TABLE###', $this->cacheTable, $cacheTableSql) . LF . LF;
-        $tagsTableSql = file_get_contents(
+        $tagsTableSql = (string)file_get_contents(
             ExtensionManagementUtility::extPath('core') .
             'Resources/Private/Sql/Cache/Backend/Typo3DatabaseBackendTags.sql'
         );
