@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Configuration\FlexForm;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Core\Configuration\FlexForm;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Configuration\FlexForm;
+
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Configuration\FlexForm\Exception\InvalidCombinedPointerFieldException;
 use TYPO3\CMS\Core\Configuration\FlexForm\Exception\InvalidIdentifierException;
@@ -688,7 +690,7 @@ class FlexFormTools
                         1478105826
                     );
                 }
-                $dataStructure = file_get_contents($file);
+                $dataStructure = (string)file_get_contents($file);
             }
 
             // Parse main structure
@@ -727,7 +729,7 @@ class FlexFormTools
                         $file = GeneralUtility::getFileAbsFileName(trim($sheetStructure));
                     }
                     if ($file && @is_file($file)) {
-                        $sheetStructure = GeneralUtility::xml2array(file_get_contents($file));
+                        $sheetStructure = GeneralUtility::xml2array((string)file_get_contents($file));
                     }
                 }
                 $dataStructure['sheets'][$sheetName] = $sheetStructure;
