@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Configuration\TypoScript\Exception;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,11 +13,15 @@ namespace TYPO3\CMS\Core\Configuration\TypoScript\Exception;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Configuration\TypoScript\Exception;
+
+use TYPO3\CMS\Core\Exception;
+
 /**
  * A "Your TypoScript condition is invalid" exception
  * used when a TypoScript condition is called but not extending
  * from the AbstractCondition class.
  */
-class InvalidTypoScriptConditionException extends \TYPO3\CMS\Core\Exception
+class InvalidTypoScriptConditionException extends Exception
 {
 }
