@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Console;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Core\Console;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Console;
+
 use Psr\Container\ContainerInterface;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\CommandLoader\CommandLoaderInterface;
@@ -156,9 +158,9 @@ class CommandRegistry implements CommandLoaderInterface, \IteratorAggregate, Sin
      * @param string $identifier
      * @throws CommandNameAlreadyInUseException
      * @throws UnknownCommandException
-     * @return Command
+     * @return Command|null
      */
-    public function getCommandByIdentifier(string $identifier): Command
+    public function getCommandByIdentifier(string $identifier): ?Command
     {
         $this->populateCommandsFromPackages();
 
