@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Core;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,9 @@ namespace TYPO3\CMS\Core\Core;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Core;
+
+use TYPO3\CMS\Core\Resource\Security\FileNameValidator;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\PathUtility;
 
@@ -49,21 +51,6 @@ class SystemEnvironmentBuilder
     /** @internal */
     const REQUESTTYPE_INSTALL = 16;
 
-    /**
-     * A list of supported CGI server APIs
-     * NOTICE: This is a duplicate of the SAME array in GeneralUtility!
-     *         It is duplicated here as this information is needed early in bootstrap
-     *         and GeneralUtility is not available yet.
-     * @var array
-     */
-    protected static $supportedCgiServerApis = [
-        'fpm-fcgi',
-        'cgi',
-        'isapi',
-        'cgi-fcgi',
-        'srv', // HHVM with fastcgi
-    ];
-
     /**
      * Run base setup.
      * This entry method is used in all scopes (FE, BE, Install Tool and CLI)
@@ -86,9 +73,17 @@ class SystemEnvironmentBuilder
         self::initializeEnvironment($requestType, $scriptPath, $rootPath);
     }
 
+    /**
+     * Some notes:
+     *
+     * HTTP_TYPO3_CONTEXT -> used with Apache suexec support
+     * REDIRECT_TYPO3_CONTEXT -> used under some circumstances when value is set in the webserver and proxying the values to FPM
+     * @return ApplicationContext
+     * @throws \TYPO3\CMS\Core\Exception
+     */
     protected static function createApplicationContext(): ApplicationContext
     {
-        $applicationContext = getenv('TYPO3_CONTEXT') ?: (getenv('REDIRECT_TYPO3_CONTEXT') ?: 'Production');
+        $applicationContext = getenv('TYPO3_CONTEXT') ?: (getenv('REDIRECT_TYPO3_CONTEXT') ?: (getenv('HTTP_TYPO3_CONTEXT') ?: 'Production'));
         return new ApplicationContext($applicationContext);
     }
 
@@ -99,6 +94,7 @@ class SystemEnvironmentBuilder
     {
         // Check one of the constants and return early if already defined,
         // needed if multiple requests are handled in one process, for instance in functional testing.
+        // This check can be removed in TYPO3 v11.0.
         if (defined('FILE_DENY_PATTERN_DEFAULT')) {
             return;
         }
@@ -108,16 +104,25 @@ class SystemEnvironmentBuilder
         defined('CR') ?: define('CR', chr(13));
         defined('CRLF') ?: define('CRLF', CR . LF);
 
-        // Security related constant: Default value of fileDenyPattern
-        define('FILE_DENY_PATTERN_DEFAULT', '\\.(php[3-8]?|phpsh|phtml|pht|phar|shtml|cgi)(\\..*)?$|\\.pl$|^\\.htaccess$');
-        // Security related constant: List of file extensions that should be registered as php script file extensions
-        define('PHP_EXTENSIONS_DEFAULT', 'php,php3,php4,php5,php6,php7,php8,phpsh,inc,phtml,pht,phar');
+        // A generic constant to state we are in TYPO3 scope. This is especially used in script files
+        // like ext_localconf.php that run in global scope without class encapsulation: "defined('TYPO3') or die();"
+        // This is a security measure to prevent script output if those files are located within document root and
+        // called directly without bootstrap and error handling setup.
+        defined('TYPO3') ?: define('TYPO3', true);
 
         // Relative path from document root to typo3/ directory, hardcoded to "typo3/"
         if (!defined('TYPO3_mainDir')) {
             define('TYPO3_mainDir', 'typo3/');
         }
 
+        /**
+         * @deprecated use FileNameAccess class to retrieve this information, will be removed in TYPO3 v11.0
+         */
+        define('FILE_DENY_PATTERN_DEFAULT', FileNameValidator::DEFAULT_FILE_DENY_PATTERN);
+        /**
+         * @deprecated use FILE_DENY_PATTERN and FileNameAccess class to retrieve this information, will be removed in TYPO3 v11.0
+         */
+        define('PHP_EXTENSIONS_DEFAULT', 'php,php3,php4,php5,php6,php7,php8,phpsh,inc,phtml,pht,phar');
         /**
          * @deprecated use Typo3Information class to retrieve this information, will be removed in TYPO3 v11.0
          */
@@ -129,7 +134,7 @@ class SystemEnvironmentBuilder
         /**
          * @deprecated use Typo3Information class to retrieve this information, will be removed in TYPO3 v11.0
          */
-        define('TYPO3_URL_LICENSE', 'https://typo3.org/typo3-cms/overview/licenses/');
+        define('TYPO3_URL_LICENSE', 'https://typo3.org/project/licenses/');
         /**
          * @deprecated use Typo3Information class to retrieve this information, will be removed in TYPO3 v11.0
          */
@@ -141,7 +146,7 @@ class SystemEnvironmentBuilder
         /**
          * @deprecated use Typo3Information class to retrieve this information, will be removed in TYPO3 v11.0
          */
-        define('TYPO3_URL_WIKI_OPCODECACHE', 'https://wiki.typo3.org/Opcode_Cache');
+        define('TYPO3_URL_WIKI_OPCODECACHE', 'https://docs.typo3.org/m/typo3/guide-installation/master/en-us/Troubleshooting/Index.html#opcode-cache-messages');
     }
 
     /**
@@ -173,18 +178,21 @@ class SystemEnvironmentBuilder
                 // or has the real path
                 $scriptName = ltrim(substr($scriptPath, strlen($rootPath)), '/');
             }
-            $rootPath = rtrim(GeneralUtility::fixWindowsFilePath(getenv('TYPO3_PATH_ROOT')), '/');
+            $rootPath = rtrim(GeneralUtility::fixWindowsFilePath((string)getenv('TYPO3_PATH_ROOT')), '/');
             $scriptPath = $rootPath . '/' . $scriptName;
         }
         return $scriptPath;
     }
 
     /**
-     * Absolute path to the root of the typo3 instance. This is often identical to the web document root path (eg. .../public),
-     * but may be different. For instance helhum/typo3-secure-web uses this: Then, rootPath TYPO3_PATH_ROOT is the absolute path to
-     * the private directory where code and runtime files are located (currently typo3/ext, typo3/sysext, fileadmin, typo3temp),
-     * while TYPO3_PATH_WEB is the public/ web document folder that gets assets like fileadmin and Resources/Public folders
-     * from extensions linked in.
+     * Absolute path to the "classic" site root of the TYPO3 application.
+     * This semantically refers to the directory where executable server-side code, configuration
+     * and runtime files are located (e.g. typo3conf/ext, typo3/sysext, typo3temp/var).
+     * In practice this is always identical to the public web document root path which contains
+     * files that are served by the webserver directly (fileadmin/ and public resources).
+     *
+     * This is not to be confused with the app-path that is used in composer-mode installations (by default).
+     * Resources in app-path are located outside the document root.
      *
      * @param int $entryPointLevel Number of subdirectories where the entry script is located under the document root
      * @param int $requestType
@@ -194,7 +202,7 @@ class SystemEnvironmentBuilder
     {
         // Check if the root path has been set in the environment (e.g. by the composer installer)
         if (getenv('TYPO3_PATH_ROOT')) {
-            return rtrim(GeneralUtility::fixWindowsFilePath(getenv('TYPO3_PATH_ROOT')), '/');
+            return rtrim(GeneralUtility::fixWindowsFilePath((string)getenv('TYPO3_PATH_ROOT')), '/');
         }
         $isCli = self::isCliRequestType($requestType);
         // Absolute path of the entry script that was called
@@ -238,7 +246,7 @@ class SystemEnvironmentBuilder
     protected static function initializeEnvironment(int $requestType, string $scriptPath, string $sitePath)
     {
         if (getenv('TYPO3_PATH_ROOT')) {
-            $rootPathFromEnvironment = rtrim(GeneralUtility::fixWindowsFilePath(getenv('TYPO3_PATH_ROOT')), '/');
+            $rootPathFromEnvironment = rtrim(GeneralUtility::fixWindowsFilePath((string)getenv('TYPO3_PATH_ROOT')), '/');
             if ($sitePath !== $rootPathFromEnvironment) {
                 // This means, that we re-initialized the environment during a single request
                 // This currently only happens in custom code or during functional testing
@@ -248,7 +256,7 @@ class SystemEnvironmentBuilder
             }
         }
 
-        $projectRootPath = GeneralUtility::fixWindowsFilePath(getenv('TYPO3_PATH_APP'));
+        $projectRootPath = GeneralUtility::fixWindowsFilePath((string)getenv('TYPO3_PATH_APP'));
         $isDifferentRootPath = ($projectRootPath && $projectRootPath !== $sitePath);
         Environment::initialize(
             static::createApplicationContext(),
@@ -306,7 +314,7 @@ class SystemEnvironmentBuilder
     protected static function getPathThisScriptNonCli()
     {
         $cgiPath = $_SERVER['ORIG_PATH_TRANSLATED'] ?? $_SERVER['PATH_TRANSLATED'] ?? '';
-        if ($cgiPath && in_array(PHP_SAPI, self::$supportedCgiServerApis, true)) {
+        if ($cgiPath && Environment::isRunningOnCgiServer()) {
             return $cgiPath;
         }
         return $_SERVER['ORIG_SCRIPT_FILENAME'] ?? $_SERVER['SCRIPT_FILENAME'];
@@ -411,7 +419,7 @@ class SystemEnvironmentBuilder
     /**
      * Define constants and variables
      *
-     * @param string
+     * @param string $mode
      */
     protected static function defineLegacyConstants(string $mode)
     {
