@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Crypto\PasswordHashing;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,9 +15,13 @@ namespace TYPO3\CMS\Core\Crypto\PasswordHashing;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Crypto\PasswordHashing;
+
+use TYPO3\CMS\Core\Exception;
+
 /**
  * InvalidPasswordHashException thrown if salting went wrong.
  */
-class InvalidPasswordHashException extends \TYPO3\CMS\Core\Exception
+class InvalidPasswordHashException extends Exception
 {
 }
