@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Crypto\PasswordHashing;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Core\Crypto\PasswordHashing;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Crypto\PasswordHashing;
+
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
 /**
@@ -69,7 +71,7 @@ class PasswordHashFactory
         // Do not add the hash to the exception to prevent information disclosure
         throw new InvalidPasswordHashException(
             'No implementation found to handle given hash. This happens if the stored hash uses a'
-            . ' mechanism not supported by current server. Follow the wiki link to fix this issue.',
+            . ' mechanism not supported by current server. Follow the documentation link to fix this issue.',
             1533818591
         );
     }
@@ -120,7 +122,7 @@ class PasswordHashFactory
             throw new InvalidPasswordHashException(
                 'Configured default hash method ' . $defaultHashClassName . ' is not available. If'
                 . ' the instance has just been upgraded, please log in to the standalone install tool'
-                . ' at typo3/install.php to fix this. Follow the wiki link for more details.',
+                . ' at typo3/install.php to fix this. Follow the documentation link for more details.',
                 1533822084
             );
         }
