@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\DataHandling\Localization;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,14 +13,17 @@ namespace TYPO3\CMS\Core\DataHandling\Localization;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\DataHandling\Localization;
+
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Database\Connection;
 use TYPO3\CMS\Core\Database\ConnectionPool;
-use TYPO3\CMS\Core\Database\Query\Restriction\BackendWorkspaceRestriction;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
+use TYPO3\CMS\Core\Database\Query\Restriction\WorkspaceRestriction;
 use TYPO3\CMS\Core\Database\RelationHandler;
 use TYPO3\CMS\Core\DataHandling\DataHandler;
+use TYPO3\CMS\Core\DataHandling\ReferenceIndexUpdater;
 use TYPO3\CMS\Core\Localization\LanguageService;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
@@ -43,6 +45,8 @@ use TYPO3\CMS\Core\Utility\StringUtility;
  * Namings in this class:
  * + forTableName, forId always refers to dependencies data is provided *for*
  * + fromTableName, fromId always refers to ancestors data is retrieved *from*
+ *
+ * @internal should only be used by the TYPO3 Core
  */
 class DataMapProcessor
 {
@@ -66,6 +70,11 @@ class DataMapProcessor
      */
     protected $backendUser;
 
+    /**
+     * @var ReferenceIndexUpdater
+     */
+    protected $referenceIndexUpdater;
+
     /**
      * @var DataMapItem[]
      */
@@ -81,26 +90,39 @@ class DataMapProcessor
      *
      * @param array $dataMap The submitted data-map to be worked on
      * @param BackendUserAuthentication $backendUser Forwarded backend-user scope
+     * @param ReferenceIndexUpdater|null $referenceIndexUpdater Forward reference index updater to sub DataHandler instances
      * @return DataMapProcessor
      */
-    public static function instance(array $dataMap, BackendUserAuthentication $backendUser)
-    {
+    public static function instance(
+        array $dataMap,
+        BackendUserAuthentication $backendUser,
+        ReferenceIndexUpdater $referenceIndexUpdater = null
+    ) {
         return GeneralUtility::makeInstance(
             static::class,
             $dataMap,
-            $backendUser
+            $backendUser,
+            $referenceIndexUpdater
         );
     }
 
     /**
      * @param array $dataMap The submitted data-map to be worked on
      * @param BackendUserAuthentication $backendUser Forwarded backend-user scope
+     * @param ReferenceIndexUpdater|null $referenceIndexUpdater Forward reference index updater to sub DataHandler instances
      */
-    public function __construct(array $dataMap, BackendUserAuthentication $backendUser)
-    {
+    public function __construct(
+        array $dataMap,
+        BackendUserAuthentication $backendUser,
+        ReferenceIndexUpdater $referenceIndexUpdater = null
+    ) {
         $this->allDataMap = $dataMap;
         $this->modifiedDataMap = $dataMap;
         $this->backendUser = $backendUser;
+        if ($referenceIndexUpdater === null) {
+            $referenceIndexUpdater = GeneralUtility::makeInstance(ReferenceIndexUpdater::class);
+        }
+        $this->referenceIndexUpdater = $referenceIndexUpdater;
     }
 
     /**
@@ -613,7 +635,7 @@ class DataMapProcessor
         }
         // execute copy, localize and delete actions on persisted child records
         if (!empty($localCommandMap)) {
-            $localDataHandler = GeneralUtility::makeInstance(DataHandler::class);
+            $localDataHandler = GeneralUtility::makeInstance(DataHandler::class, $this->referenceIndexUpdater);
             $localDataHandler->start([], $localCommandMap, $this->backendUser);
             $localDataHandler->process_cmdmap();
             // update copied or localized ids
@@ -859,7 +881,7 @@ class DataMapProcessor
         $queryBuilder->getRestrictions()
             ->removeAll()
             ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
-            ->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class, $this->backendUser->workspace, false));
+            ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, $this->backendUser->workspace));
         $statement = $queryBuilder
             ->select(...array_values($fieldNames))
             ->from($tableName)
@@ -1029,7 +1051,7 @@ class DataMapProcessor
                 continue;
             }
             // only keep ancestors that were initially requested before expanding
-            if (in_array($ancestorId, $ids)) {
+            if (in_array($ancestorId, $ids, true)) {
                 $dependentIdMap[$ancestorId] = $dependentId;
             } elseif (!empty($ancestorIdMap[$ancestorId])) {
                 // resolve from previously expanded search criteria
@@ -1068,7 +1090,7 @@ class DataMapProcessor
         $queryBuilder->getRestrictions()
             ->removeAll()
             ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
-            ->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class, $this->backendUser->workspace, false));
+            ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, $this->backendUser->workspace));
 
         $zeroParameter = $queryBuilder->createNamedParameter(0, \PDO::PARAM_INT);
         $ids = $this->filterNumericIds($ids);
@@ -1152,16 +1174,17 @@ class DataMapProcessor
      * Return only ids that are integer - so no "NEW..." values
      *
      * @param string[]|int[] $ids
-     * @return int[]|string[]
+     * @return int[]
      */
     protected function filterNumericIds(array $ids)
     {
-        return array_filter(
+        $ids = array_filter(
             $ids,
             function ($id) {
                 return MathUtility::canBeInterpretedAsInteger($id);
             }
         );
+        return array_map('intval', $ids);
     }
 
     /**
@@ -1198,22 +1221,21 @@ class DataMapProcessor
     }
 
     /**
-     * @param array $fieldNames
-     * @param array $element
-     * @return int|null
+     * @param array<string, string> $fieldNames
+     * @param array<string, mixed> $element
+     * @return int|null either a (non-empty) ancestor uid, or `null` if unresolved
      */
     protected function resolveAncestorId(array $fieldNames, array $element)
     {
-        // implicit: having source value different to parent value, use source pointer
-        if (
-            !empty($fieldNames['source'])
-            && $element[$fieldNames['source']] !== $element[$fieldNames['parent']]
-        ) {
-            return (int)$fieldNames['source'];
+        $sourceName = $fieldNames['source'] ?? null;
+        if ($sourceName !== null && !empty($element[$sourceName])) {
+            // implicit: use source pointer if given (not empty)
+            return (int)$element[$sourceName];
         }
-        if (!empty($fieldNames['parent'])) {
-            // implicit: use parent pointer if defined
-            return (int)$element[$fieldNames['parent']];
+        $parentName = $fieldNames['parent'] ?? null;
+        if ($parentName !== null && !empty($element[$parentName])) {
+            // implicit: use parent pointer if given (not empty)
+            return (int)$element[$parentName];
         }
         return null;
     }
@@ -1317,7 +1339,7 @@ class DataMapProcessor
      * Prefixes language title if applicable for the accordant field name in raw data-map item.
      *
      * @param string $tableName
-     * @param $fromId
+     * @param string|int $fromId
      * @param int $language
      * @param array $data
      * @return array
