@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Database;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,14 +15,19 @@ namespace TYPO3\CMS\Core\Database;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Database;
+
 use Doctrine\Common\EventManager;
 use Doctrine\DBAL\Configuration;
 use Doctrine\DBAL\Driver;
+use Doctrine\DBAL\Driver\ServerInfoAwareConnection;
 use Doctrine\DBAL\Driver\Statement;
 use Doctrine\DBAL\Platforms\PostgreSqlPlatform;
 use Doctrine\DBAL\Platforms\SQLServer2012Platform;
+use Doctrine\DBAL\VersionAwarePlatformDriver;
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
+use TYPO3\CMS\Core\Database\Query\BulkInsertQuery;
 use TYPO3\CMS\Core\Database\Query\Expression\ExpressionBuilder;
 use TYPO3\CMS\Core\Database\Query\QueryBuilder;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
@@ -61,6 +66,9 @@ class Connection extends \Doctrine\DBAL\Connection implements LoggerAwareInterfa
      */
     const PARAM_BOOL = \PDO::PARAM_BOOL; // 5
 
+    /** @var ExpressionBuilder */
+    protected $_expr;
+
     /**
      * @var array
      */
@@ -215,7 +223,7 @@ class Connection extends \Doctrine\DBAL\Connection implements LoggerAwareInterfa
      */
     public function bulkInsert(string $tableName, array $data, array $columns = [], array $types = []): int
     {
-        $query = GeneralUtility::makeInstance(Query\BulkInsertQuery::class, $this, $tableName, $columns);
+        $query = GeneralUtility::makeInstance(BulkInsertQuery::class, $this, $tableName, $columns);
         foreach ($data as $values) {
             $query->addValues($values, $types);
         }
@@ -237,7 +245,7 @@ class Connection extends \Doctrine\DBAL\Connection implements LoggerAwareInterfa
      * @param int $limit The maximum number of rows to return.
      * @param int $offset The first result row to select (when used with limit)
      *
-     * @return Statement The executed statement.
+     * @return Statement|\Doctrine\DBAL\ForwardCompatibility\Result|\Doctrine\DBAL\Driver\ResultStatement  The executed statement.
      */
     public function select(
         array $columns,
@@ -247,7 +255,7 @@ class Connection extends \Doctrine\DBAL\Connection implements LoggerAwareInterfa
         array $orderBy = [],
         int $limit = 0,
         int $offset = 0
-    ): Statement {
+    ) {
         $query = $this->createQueryBuilder();
         $query->select(...$columns)
             ->from($tableName);
@@ -392,11 +400,11 @@ class Connection extends \Doctrine\DBAL\Connection implements LoggerAwareInterfa
         }
 
         // Driver does not support version specific platforms.
-        if (!$this->getDriver() instanceof \Doctrine\DBAL\VersionAwarePlatformDriver) {
+        if (!$this->getDriver() instanceof VersionAwarePlatformDriver) {
             return $version;
         }
 
-        if ($this->getWrappedConnection() instanceof \Doctrine\DBAL\Driver\ServerInfoAwareConnection
+        if ($this->getWrappedConnection() instanceof ServerInfoAwareConnection
             && !$this->getWrappedConnection()->requiresQueryForServerVersion()
         ) {
             $version .= ' ' . $this->getWrappedConnection()->getServerVersion();
@@ -452,4 +460,14 @@ class Connection extends \Doctrine\DBAL\Connection implements LoggerAwareInterfa
 
         return (string)parent::lastInsertId($tableName);
     }
+
+    /**
+     * Gets the ExpressionBuilder for the connection.
+     *
+     * @return ExpressionBuilder
+     */
+    public function getExpressionBuilder()
+    {
+        return $this->_expr;
+    }
 }
