@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Database\Query;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,12 +15,21 @@ namespace TYPO3\CMS\Core\Database\Query;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Database\Query;
+
+use Doctrine\DBAL\Driver\Statement;
+use Doctrine\DBAL\Platforms\MySqlPlatform;
+use Doctrine\DBAL\Platforms\OraclePlatform;
+use Doctrine\DBAL\Platforms\PostgreSqlPlatform;
+use Doctrine\DBAL\Platforms\SqlitePlatform;
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Query\Expression\CompositeExpression;
 use TYPO3\CMS\Core\Database\Connection;
 use TYPO3\CMS\Core\Database\Query\Expression\ExpressionBuilder;
 use TYPO3\CMS\Core\Database\Query\Restriction\DefaultRestrictionContainer;
+use TYPO3\CMS\Core\Database\Query\Restriction\LimitToTablesRestrictionContainer;
 use TYPO3\CMS\Core\Database\Query\Restriction\QueryRestrictionContainerInterface;
+use TYPO3\CMS\Core\Database\Query\Restriction\QueryRestrictionInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
 /**
@@ -63,13 +72,24 @@ class QueryBuilder
      */
     protected $additionalRestrictions;
 
+    /**
+     * List of table aliases which are completely ignored
+     * when generating the table restrictions in the where-clause.
+     *
+     * Aliases added here are part of a LEFT/RIGHT JOIN, having
+     * their restrictions applied in the JOIN's ON condition already.
+     *
+     * @var string[]
+     */
+    private $restrictionsAppliedInJoinCondition = [];
+
     /**
      * Initializes a new QueryBuilder.
      *
      * @param Connection $connection The DBAL Connection.
-     * @param QueryRestrictionContainerInterface $restrictionContainer
-     * @param \Doctrine\DBAL\Query\QueryBuilder $concreteQueryBuilder
-     * @param array $additionalRestrictions
+     * @param QueryRestrictionContainerInterface|null $restrictionContainer
+     * @param \Doctrine\DBAL\Query\QueryBuilder|null $concreteQueryBuilder
+     * @param array|null $additionalRestrictions
      */
     public function __construct(
         Connection $connection,
@@ -98,6 +118,7 @@ class QueryBuilder
     {
         foreach ($this->additionalRestrictions as $restrictionClass => $options) {
             if (empty($options['disabled'])) {
+                /** @var QueryRestrictionInterface $restriction */
                 $restriction = GeneralUtility::makeInstance($restrictionClass);
                 $restrictionContainer->add($restriction);
             }
@@ -105,6 +126,16 @@ class QueryBuilder
         $this->restrictionContainer = $restrictionContainer;
     }
 
+    /**
+     * Limits ALL currently active restrictions of the restriction container to the table aliases given
+     *
+     * @param array $tableAliases
+     */
+    public function limitRestrictionsToTables(array $tableAliases): void
+    {
+        $this->restrictionContainer = GeneralUtility::makeInstance(LimitToTablesRestrictionContainer::class)->addForTables($this->restrictionContainer, $tableAliases);
+    }
+
     /**
      * Re-apply default restrictions
      */
@@ -173,7 +204,7 @@ class QueryBuilder
     /**
      * Executes this query using the bound parameters and their types.
      *
-     * @return \Doctrine\DBAL\Driver\Statement|int
+     * @return Statement|\Doctrine\DBAL\ForwardCompatibility\Result|\Doctrine\DBAL\Driver\ResultStatement|int
      */
     public function execute()
     {
@@ -384,7 +415,7 @@ class QueryBuilder
      * Specifies items that are to be returned in the query result.
      * Replaces any previously specified selections, if any.
      *
-     * @param string[] $selects
+     * @param string ...$selects
      * @return QueryBuilder This QueryBuilder instance.
      */
     public function select(string ...$selects): QueryBuilder
@@ -397,8 +428,7 @@ class QueryBuilder
     /**
      * Adds an item that is to be returned in the query result.
      *
-     * @param string[] $selects The selection expression.
-     *
+     * @param string ...$selects
      * @return QueryBuilder This QueryBuilder instance.
      */
     public function addSelect(string ...$selects): QueryBuilder
@@ -414,7 +444,7 @@ class QueryBuilder
      * This should only be used for literal SQL expressions as no
      * quoting/escaping of any kind will be performed on the items.
      *
-     * @param string[] $selects Literal SQL expressions to be selected. Warning: No quoting will be done!
+     * @param string ...$selects Literal SQL expressions to be selected. Warning: No quoting will be done!
      * @return QueryBuilder This QueryBuilder instance.
      */
     public function selectLiteral(string ...$selects): QueryBuilder
@@ -429,7 +459,7 @@ class QueryBuilder
      * only be used for literal SQL expressions as no quoting/escaping of
      * any kind will be performed on the items.
      *
-     * @param string[] $selects Literal SQL expressions to be selected.
+     * @param string ...$selects Literal SQL expressions to be selected.
      * @return QueryBuilder This QueryBuilder instance.
      */
     public function addSelectLiteral(string ...$selects): QueryBuilder
@@ -445,7 +475,7 @@ class QueryBuilder
      *
      * @param string $delete The table whose rows are subject to the deletion.
      *                       Will be quoted according to database platform automatically.
-     * @param string $alias The table alias used in the constructed query.
+     * @param string|null $alias The table alias used in the constructed query.
      *                      Will be quoted according to database platform automatically.
      *
      * @return QueryBuilder This QueryBuilder instance.
@@ -465,7 +495,7 @@ class QueryBuilder
      * a certain table
      *
      * @param string $update The table whose rows are subject to the update.
-     * @param string $alias The table alias used in the constructed query.
+     * @param string|null $alias The table alias used in the constructed query.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -499,7 +529,7 @@ class QueryBuilder
      * given alias, forming a cartesian product with any existing query roots.
      *
      * @param string $from The table. Will be quoted according to database platform automatically.
-     * @param string $alias The alias of the table. Will be quoted according to database platform automatically.
+     * @param string|null $alias The alias of the table. Will be quoted according to database platform automatically.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -519,7 +549,7 @@ class QueryBuilder
      * @param string $fromAlias The alias that points to a from clause.
      * @param string $join The table name to join.
      * @param string $alias The alias of the join table.
-     * @param string $condition The condition for the join.
+     * @param string|null $condition The condition for the join.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -541,7 +571,7 @@ class QueryBuilder
      * @param string $fromAlias The alias that points to a from clause.
      * @param string $join The table name to join.
      * @param string $alias The alias of the join table.
-     * @param string $condition The condition for the join.
+     * @param string|null $condition The condition for the join.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -563,12 +593,18 @@ class QueryBuilder
      * @param string $fromAlias The alias that points to a from clause.
      * @param string $join The table name to join.
      * @param string $alias The alias of the join table.
-     * @param string $condition The condition for the join.
+     * @param string|null $condition The condition for the join.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
     public function leftJoin(string $fromAlias, string $join, string $alias, string $condition = null): QueryBuilder
     {
+        $condition = $this->expr()->andX(
+            $condition,
+            $this->restrictionContainer->buildExpression([$alias ?? $join => $join], $this->expr())
+        );
+        $this->restrictionsAppliedInJoinCondition[] = $alias ?? $join;
+
         $this->concreteQueryBuilder->leftJoin(
             $this->quoteIdentifier($fromAlias),
             $this->quoteIdentifier($join),
@@ -585,12 +621,27 @@ class QueryBuilder
      * @param string $fromAlias The alias that points to a from clause.
      * @param string $join The table name to join.
      * @param string $alias The alias of the join table.
-     * @param string $condition The condition for the join.
+     * @param string|null $condition The condition for the join.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
     public function rightJoin(string $fromAlias, string $join, string $alias, string $condition = null): QueryBuilder
     {
+        $fromTable = $fromAlias;
+        // find the table belonging to the $fromAlias, if it's an alias at all
+        foreach ($this->getQueryPart('from') ?: [] as $from) {
+            if (isset($from['alias']) && $this->unquoteSingleIdentifier($from['alias']) === $fromAlias) {
+                $fromTable = $this->unquoteSingleIdentifier($from['table']);
+                break;
+            }
+        }
+
+        $condition = $this->expr()->andX(
+            $condition,
+            $this->restrictionContainer->buildExpression([$fromAlias => $fromTable], $this->expr())
+        );
+        $this->restrictionsAppliedInJoinCondition[] = $fromAlias;
+
         $this->concreteQueryBuilder->rightJoin(
             $this->quoteIdentifier($fromAlias),
             $this->quoteIdentifier($join),
@@ -625,7 +676,7 @@ class QueryBuilder
      * Specifies one or more restrictions to the query result.
      * Replaces any previously specified restrictions, if any.
      *
-     * @param mixed $predicates
+     * @param array<int,mixed> $predicates
      * @return QueryBuilder This QueryBuilder instance.
      */
     public function where(...$predicates): QueryBuilder
@@ -639,7 +690,7 @@ class QueryBuilder
      * Adds one or more restrictions to the query results, forming a logical
      * conjunction with any previously specified restrictions.
      *
-     * @param mixed $where The query restrictions.
+     * @param array<int,string> $where The query restrictions.
      *
      * @return QueryBuilder This QueryBuilder instance.
      *
@@ -656,7 +707,7 @@ class QueryBuilder
      * Adds one or more restrictions to the query results, forming a logical
      * disjunction with any previously specified restrictions.
      *
-     * @param mixed $where The WHERE statement.
+     * @param array<int,string> $where The WHERE statement.
      *
      * @return QueryBuilder This QueryBuilder instance.
      *
@@ -673,7 +724,7 @@ class QueryBuilder
      * Specifies a grouping over the results of the query.
      * Replaces any previously specified groupings, if any.
      *
-     * @param mixed $groupBy The grouping expression.
+     * @param array<int,string> $groupBy The grouping expression.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -687,7 +738,7 @@ class QueryBuilder
     /**
      * Adds a grouping expression to the query.
      *
-     * @param mixed $groupBy The grouping expression.
+     * @param array<int,string> $groupBy The grouping expression.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -743,7 +794,7 @@ class QueryBuilder
      * Specifies a restriction over the groups of the query.
      * Replaces any previous having restrictions, if any.
      *
-     * @param mixed $having The restriction over the groups.
+     * @param array<int,string> $having The restriction over the groups.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -757,7 +808,7 @@ class QueryBuilder
      * Adds a restriction over the groups of the query, forming a logical
      * conjunction with any existing having restrictions.
      *
-     * @param mixed $having The restriction to append.
+     * @param array<int,string> $having The restriction to append.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -772,7 +823,7 @@ class QueryBuilder
      * Adds a restriction over the groups of the query, forming a logical
      * disjunction with any existing having restrictions.
      *
-     * @param mixed $having The restriction to add.
+     * @param array<int,string> $having The restriction to add.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -788,7 +839,7 @@ class QueryBuilder
      * Replaces any previously specified orderings, if any.
      *
      * @param string $fieldName The fieldName to order by. Will be quoted according to database platform automatically.
-     * @param string $order The ordering direction. No automatic quoting/escaping.
+     * @param string|null $order The ordering direction. No automatic quoting/escaping.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -803,7 +854,7 @@ class QueryBuilder
      * Adds an ordering to the query results.
      *
      * @param string $fieldName The fieldName to order by. Will be quoted according to database platform automatically.
-     * @param string $order The ordering direction.
+     * @param string|null $order The ordering direction.
      *
      * @return QueryBuilder This QueryBuilder instance.
      */
@@ -888,7 +939,7 @@ class QueryBuilder
      *
      * @param mixed $value
      * @param int $type
-     * @param string $placeHolder The name to bind with. The string must start with a colon ':'.
+     * @param string|null $placeHolder The name to bind with. The string must start with a colon ':'.
      *
      * @return string the placeholder name used.
      */
@@ -1034,6 +1085,46 @@ class QueryBuilder
         return $this->getConnection()->quoteColumnValuePairs($input);
     }
 
+    /**
+     * Creates a cast of the $fieldName to a text datatype depending on the database management system.
+     *
+     * @param string $fieldName The fieldname will be quoted and casted according to database platform automatically
+     * @return string
+     */
+    public function castFieldToTextType(string $fieldName): string
+    {
+        $databasePlatform = $this->connection->getDatabasePlatform();
+        // https://dev.mysql.com/doc/refman/5.7/en/cast-functions.html#function_convert
+        if ($databasePlatform instanceof MySqlPlatform) {
+            return sprintf('CONVERT(%s, CHAR)', $this->connection->quoteIdentifier($fieldName));
+        }
+        // https://www.postgresql.org/docs/current/sql-createcast.html
+        if ($databasePlatform instanceof PostgreSqlPlatform) {
+            return sprintf('%s::text', $this->connection->quoteIdentifier($fieldName));
+        }
+        // https://www.sqlite.org/lang_expr.html#castexpr
+        if ($databasePlatform instanceof SqlitePlatform) {
+            return sprintf('CAST(%s as TEXT)', $this->connection->quoteIdentifier($fieldName));
+        }
+        // https://docs.microsoft.com/en-us/sql/t-sql/functions/cast-and-convert-transact-sql?view=sql-server-ver15#implicit-conversions
+        if ($databasePlatform instanceof SQLServerPlatform) {
+            return sprintf('CAST(%s as VARCHAR)', $this->connection->quoteIdentifier($fieldName));
+        }
+        // https://docs.oracle.com/javadb/10.8.3.0/ref/rrefsqlj33562.html
+        if ($databasePlatform instanceof OraclePlatform) {
+            return sprintf('CAST(%s as VARCHAR)', $this->connection->quoteIdentifier($fieldName));
+        }
+
+        throw new \RuntimeException(
+            sprintf(
+                '%s is not implemented for the used database platform "%s", yet!',
+                __METHOD__,
+                get_class($this->connection->getDatabasePlatform())
+            ),
+            1584637096
+        );
+    }
+
     /**
      * Unquote a single identifier (no dot expansion). Used to unquote the table names
      * from the expressionBuilder so that the table can be found in the TCA definition.
@@ -1073,7 +1164,9 @@ class QueryBuilder
         foreach ($this->getQueryPart('from') as $from) {
             $tableName = $this->unquoteSingleIdentifier($from['table']);
             $tableAlias = isset($from['alias']) ? $this->unquoteSingleIdentifier($from['alias']) : $tableName;
-            $queriedTables[$tableAlias] = $tableName;
+            if (!in_array($tableAlias, $this->restrictionsAppliedInJoinCondition, true)) {
+                $queriedTables[$tableAlias] = $tableName;
+            }
         }
 
         // Loop through all JOIN tables
@@ -1081,7 +1174,9 @@ class QueryBuilder
             foreach ($joins as $join) {
                 $tableName = $this->unquoteSingleIdentifier($join['joinTable']);
                 $tableAlias = isset($join['joinAlias']) ? $this->unquoteSingleIdentifier($join['joinAlias']) : $tableName;
-                $queriedTables[$tableAlias] = $tableName;
+                if (!in_array($tableAlias, $this->restrictionsAppliedInJoinCondition, true)) {
+                    $queriedTables[$tableAlias] = $tableName;
+                }
             }
         }
 
