@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Database;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Database;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Database;
+
 use Doctrine\DBAL\DBALException;
 use Psr\EventDispatcher\EventDispatcherInterface;
 use Psr\Log\LoggerAwareInterface;
@@ -28,6 +29,7 @@ use TYPO3\CMS\Core\DataHandling\DataHandler;
 use TYPO3\CMS\Core\DataHandling\Event\IsTableExcludedFromReferenceIndexEvent;
 use TYPO3\CMS\Core\Registry;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Core\Versioning\VersionState;
 
 /**
  * Reference index processing and relation extraction
@@ -259,6 +261,10 @@ class ReferenceIndex implements LoggerAwareInterface
                     if (!is_array($relation)) {
                         continue;
                     }
+                    // Exclude any relations TO a specific table
+                    if (($relation['ref_table'] ?? '') && $this->shouldExcludeTableFromReferenceIndex($relation['ref_table'])) {
+                        continue;
+                    }
                     $relation['hash'] = md5(implode('///', $relation) . '///' . $this->hashVersion);
                     // First, check if already indexed and if so, unset that row (so in the end we know which rows to remove!)
                     if (isset($currentRelationHashes[$relation['hash']])) {
@@ -376,9 +382,17 @@ class ReferenceIndex implements LoggerAwareInterface
     protected function generateDataUsingRecord(string $tableName, array $record): array
     {
         $this->relations = [];
-        $deleteField = $GLOBALS['TCA'][$tableName]['ctrl']['delete'];
+
+        if (BackendUtility::isTableWorkspaceEnabled($tableName)) {
+            // Never write relations for t3ver_state = 1 and t3ver_state = 3 placeholder records
+            $versionState = VersionState::cast($record['t3ver_state']);
+            if ($versionState->equals(VersionState::NEW_PLACEHOLDER) || $versionState->equals(VersionState::MOVE_PLACEHOLDER)) {
+                return [];
+            }
+        }
 
         // Is the record deleted?
+        $deleteField = $GLOBALS['TCA'][$tableName]['ctrl']['delete'];
         $deleted = $deleteField && $record[$deleteField] ? 1 : 0;
 
         // Get all relations from record:
@@ -440,7 +454,7 @@ class ReferenceIndex implements LoggerAwareInterface
         }
         return $this->createEntryDataUsingRecord(
             (string)$table,
-            $this->getRecordRawCached($table, $uid),
+            $this->getRecordRawCached($table, $uid) ?: [],
             (string)$field,
             (string)$flexPointer,
             $deleted ? (int)$deleted : 0,
@@ -513,7 +527,7 @@ class ReferenceIndex implements LoggerAwareInterface
         }
         $this->createEntryDataForDatabaseRelationsUsingRecord(
             (string)$table,
-            $this->getRecordRawCached($table, $uid),
+            $this->getRecordRawCached($table, $uid) ?: [],
             (string)$fieldName,
             (string)$flexPointer,
             $deleted ? (int)$deleted : 0,
@@ -556,7 +570,7 @@ class ReferenceIndex implements LoggerAwareInterface
         }
         $this->createEntryDataForSoftReferencesUsingRecord(
             (string)$table,
-            $this->getRecordRawCached($table, $uid),
+            $this->getRecordRawCached($table, $uid) ?: [],
             (string)$fieldName,
             (string)$flexPointer,
             $deleted ? (int)$deleted : 0,
@@ -755,6 +769,7 @@ class ReferenceIndex implements LoggerAwareInterface
         if ($conf['type'] === 'inline' && !empty($conf['foreign_table']) && empty($conf['MM'])) {
             $dbAnalysis = GeneralUtility::makeInstance(RelationHandler::class);
             $dbAnalysis->setUseLiveReferenceIds(false);
+            $dbAnalysis->setWorkspaceId($this->getWorkspaceId());
             $dbAnalysis->start($value, $conf['foreign_table'], '', $uid, $table, $conf);
             return $dbAnalysis->itemArray;
             // DB record lists:
@@ -1062,7 +1077,7 @@ class ReferenceIndex implements LoggerAwareInterface
      * Updating Index (External API)
      *
      * @param bool $testOnly If set, only a test
-     * @param bool $cli_echo If set, output CLI status - but can now be of type ProgressListenerInterface, which should be used instead.
+     * @param bool|ProgressListenerInterface|null $cli_echo If set, output CLI status - but can now be of type ProgressListenerInterface, which should be used instead.
      * @return array Header and body status content
      */
     public function updateIndex($testOnly, $cli_echo = null)
@@ -1073,7 +1088,7 @@ class ReferenceIndex implements LoggerAwareInterface
             $cli_echo = null;
         }
         if ($cli_echo !== null) {
-            trigger_error('The second argument of ReferenceIndex->updateIndex() will not work in TYPO3 v11 anymore. Use the ProgressListener to show detailled results', E_USER_DEPRECATED);
+            trigger_error('The second argument of ReferenceIndex->updateIndex() will not work in TYPO3 v11 anymore. Use the ProgressListener to show detailed results', E_USER_DEPRECATED);
         } else {
             // default value for now
             $cli_echo = false;
@@ -1110,6 +1125,7 @@ class ReferenceIndex implements LoggerAwareInterface
                 $queryResult = $queryBuilder
                     ->select(...$fields)
                     ->from($tableName)
+                    ->orderBy('uid')
                     ->execute();
             } catch (DBALException $e) {
                 // Table exists in TCA but does not exist in the database
@@ -1325,7 +1341,7 @@ class ReferenceIndex implements LoggerAwareInterface
                     $selectFields .= ',' . $deleteField;
                 }
                 if (BackendUtility::isTableWorkspaceEnabled($tableName)) {
-                    $selectFields .= ',t3ver_wsid';
+                    $selectFields .= ',t3ver_wsid,t3ver_state';
                 }
             }
 
