@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Database;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,12 +13,15 @@ namespace TYPO3\CMS\Core\Database;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Database;
+
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Database\Platform\PlatformInformation;
 use TYPO3\CMS\Core\Database\Query\QueryHelper;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
 use TYPO3\CMS\Core\Database\Query\Restriction\WorkspaceRestriction;
 use TYPO3\CMS\Core\DataHandling\PlainDataResolver;
+use TYPO3\CMS\Core\DataHandling\ReferenceIndexUpdater;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
 use TYPO3\CMS\Core\Versioning\VersionState;
@@ -56,7 +58,7 @@ class RelationHandler
     /**
      * Contains items in a numeric array (table/id for each). Tablenames here might be "_NO_TABLE"
      *
-     * @var array
+     * @var array<int, array<string, mixed>>
      */
     public $itemArray = [];
 
@@ -181,10 +183,17 @@ class RelationHandler
     protected $MM_oppositeUsage;
 
     /**
+     * If false, reference index is not updated.
+     *
      * @var bool
      */
     protected $updateReferenceIndex = true;
 
+    /**
+     * @var ReferenceIndexUpdater|null
+     */
+    protected $referenceIndexUpdater;
+
     /**
      * @var bool
      */
@@ -196,7 +205,7 @@ class RelationHandler
     protected $useLiveReferenceIds = true;
 
     /**
-     * @var int
+     * @var int|null
      */
     protected $workspaceId;
 
@@ -217,7 +226,7 @@ class RelationHandler
      *
      * @return int
      */
-    public function getWorkspaceId()
+    public function getWorkspaceId(): int
     {
         if (!isset($this->workspaceId)) {
             $this->workspaceId = (int)$GLOBALS['BE_USER']->workspace;
@@ -230,11 +239,22 @@ class RelationHandler
      *
      * @param int $workspaceId
      */
-    public function setWorkspaceId($workspaceId)
+    public function setWorkspaceId($workspaceId): void
     {
         $this->workspaceId = (int)$workspaceId;
     }
 
+    /**
+     * Setter to carry the 'deferred' reference index updater registry around.
+     *
+     * @param ReferenceIndexUpdater $updater
+     * @internal Used internally within DataHandler only
+     */
+    public function setReferenceIndexUpdater(ReferenceIndexUpdater $updater): void
+    {
+        $this->referenceIndexUpdater = $updater;
+    }
+
     /**
      * Whether item array has been purged in this instance.
      *
@@ -352,6 +372,7 @@ class RelationHandler
      * Sets whether the reference index shall be updated.
      *
      * @param bool $updateReferenceIndex Whether the reference index shall be updated
+     * @todo: Unused in core, should be removed, use ReferenceIndexUpdater instead
      */
     public function setUpdateReferenceIndex($updateReferenceIndex)
     {
@@ -389,7 +410,7 @@ class RelationHandler
             foreach ($tempItemArray as $key => $val) {
                 // Will be set to "true" if the entry was a real table/id
                 $isSet = false;
-                // Extract table name and id. This is un the formular [tablename]_[id]
+                // Extract table name and id. This is in the formula [tablename]_[id]
                 // where table name MIGHT contain "_", hence the reversion of the string!
                 $val = strrev($val);
                 $parts = explode('_', $val, 2);
@@ -473,7 +494,7 @@ class RelationHandler
             );
         } elseif (count($this->tableArray) === 1) {
             reset($this->tableArray);
-            $table = key($this->tableArray);
+            $table = (string)key($this->tableArray);
             $connection = $this->getConnectionForTableName($table);
             $maxBindParameters = PlatformInformation::getMaxBindParameters($connection->getDatabasePlatform());
 
@@ -557,7 +578,7 @@ class RelationHandler
         }
         if ($this->MM_table_where) {
             $queryBuilder->andWhere(
-                QueryHelper::stripLogicalOperatorPrefix(str_replace('###THIS_UID###', (int)$uid, $this->MM_table_where))
+                QueryHelper::stripLogicalOperatorPrefix(str_replace('###THIS_UID###', (string)$uid, $this->MM_table_where))
             );
         }
         foreach ($this->MM_match_fields as $field => $value) {
@@ -572,6 +593,7 @@ class RelationHandler
             )
         );
         $queryBuilder->orderBy($sorting_field);
+        $queryBuilder->addOrderBy($uidForeign_field);
         $statement = $queryBuilder->execute();
         while ($row = $statement->fetch()) {
             // Default
@@ -633,7 +655,7 @@ class RelationHandler
             if ($this->MM_table_where) {
                 $additionalWhere->add(
                     QueryHelper::stripLogicalOperatorPrefix(
-                        str_replace('###THIS_UID###', (int)$uid, $this->MM_table_where)
+                        str_replace('###THIS_UID###', (string)$uid, $this->MM_table_where)
                     )
                 );
             }
@@ -875,7 +897,7 @@ class RelationHandler
             // Add WHERE clause if configured
             if ($this->MM_table_where) {
                 $queryBuilder->andWhere(
-                    QueryHelper::stripLogicalOperatorPrefix(str_replace('###THIS_UID###', (int)$uid, $this->MM_table_where))
+                    QueryHelper::stripLogicalOperatorPrefix(str_replace('###THIS_UID###', (string)$uid, $this->MM_table_where))
                 );
             }
             // Select, update or delete only those relations that match the configured fields
@@ -1009,7 +1031,7 @@ class RelationHandler
         $rows = [];
         $result = $queryBuilder->execute();
         while ($row = $result->fetch()) {
-            $rows[$row['uid']] = $row;
+            $rows[(int)$row['uid']] = $row;
         }
         if (!empty($rows)) {
             // Retrieve the parsed and prepared ORDER BY configuration for the resolver
@@ -1077,7 +1099,7 @@ class RelationHandler
                 }
                 $isOnSymmetricSide = false;
                 if ($symmetric_field) {
-                    $isOnSymmetricSide = self::isOnSymmetricSide($parentUid, $conf, $row);
+                    $isOnSymmetricSide = self::isOnSymmetricSide((string)$parentUid, $conf, $row);
                 }
                 $updateValues = $foreign_match_fields;
                 // No update to the uid is requested, so this is the normal behaviour
@@ -1285,25 +1307,32 @@ class RelationHandler
     }
 
     /**
-     * Update Reference Index (sys_refindex) for a record
+     * Update Reference Index (sys_refindex) for a record.
      * Should be called any almost any update to a record which could affect references inside the record.
-     * (copied from DataHandler)
+     * If used from within DataHandler, only registers a row for update for later processing.
      *
      * @param string $table Table name
-     * @param int $id Record UID
-     * @return array Information concerning modifications delivered by \TYPO3\CMS\Core\Database\ReferenceIndex::updateRefIndexTable()
+     * @param int $uid Record uid
+     * @return array Result from ReferenceIndex->updateRefIndexTable() updated directly, else empty array
+     * @internal Should be protected
      */
-    public function updateRefIndex($table, $id)
+    public function updateRefIndex($table, $uid): array
     {
-        $statisticsArray = [];
-        if ($this->updateReferenceIndex) {
-            /** @var \TYPO3\CMS\Core\Database\ReferenceIndex $refIndexObj */
-            $refIndexObj = GeneralUtility::makeInstance(\TYPO3\CMS\Core\Database\ReferenceIndex::class);
+        if (!$this->updateReferenceIndex) {
+            return [];
+        }
+        if ($this->referenceIndexUpdater) {
+            // Add to update registry if given
+            $this->referenceIndexUpdater->registerForUpdate((string)$table, (int)$uid, $this->getWorkspaceId());
+            $statisticsArray = [];
+        } else {
+            // Update reference index directly if enabled
+            $referenceIndex = GeneralUtility::makeInstance(ReferenceIndex::class);
             if (BackendUtility::isTableWorkspaceEnabled($table)) {
-                $refIndexObj->setWorkspaceId($this->getWorkspaceId());
+                $referenceIndex->setWorkspaceId($this->getWorkspaceId());
             }
-            $refIndexObj->enableRuntimeCache();
-            $statisticsArray = $refIndexObj->updateRefIndexTable($table, $id);
+            $referenceIndex->enableRuntimeCache();
+            $statisticsArray = $referenceIndex->updateRefIndexTable($table, $uid);
         }
         return $statisticsArray;
     }
@@ -1402,7 +1431,7 @@ class RelationHandler
     /**
      * Handles a purge callback on $this->itemArray
      *
-     * @param callable $purgeCallback
+     * @param string $purgeCallback
      * @return bool Whether items have been purged
      */
     protected function purgeItemArrayHandler($purgeCallback)
@@ -1414,7 +1443,12 @@ class RelationHandler
                 continue;
             }
 
-            $purgedItemIds = call_user_func([$this, $purgeCallback], $itemTableName, $itemIds);
+            $purgedItemIds = [];
+            $callable =[$this, $purgeCallback];
+            if (is_callable($callable)) {
+                $purgedItemIds = call_user_func($callable, $itemTableName, $itemIds);
+            }
+
             $removedItemIds = array_diff($itemIds, $purgedItemIds);
             foreach ($removedItemIds as $removedItemId) {
                 $this->removeFromItemArray($itemTableName, $removedItemId);
@@ -1438,7 +1472,7 @@ class RelationHandler
     protected function purgeVersionedIds($tableName, array $ids)
     {
         $ids = $this->sanitizeIds($ids);
-        $ids = array_combine($ids, $ids);
+        $ids = (array)array_combine($ids, $ids);
         $connection = $this->getConnectionForTableName($tableName);
         $maxBindParameters = PlatformInformation::getMaxBindParameters($connection->getDatabasePlatform());
 
@@ -1481,7 +1515,7 @@ class RelationHandler
     protected function purgeLiveVersionedIds($tableName, array $ids)
     {
         $ids = $this->sanitizeIds($ids);
-        $ids = array_combine($ids, $ids);
+        $ids = (array)array_combine($ids, $ids);
         $connection = $this->getConnectionForTableName($tableName);
         $maxBindParameters = PlatformInformation::getMaxBindParameters($connection->getDatabasePlatform());
 
@@ -1525,7 +1559,7 @@ class RelationHandler
     protected function purgeDeletePlaceholder($tableName, array $ids)
     {
         $ids = $this->sanitizeIds($ids);
-        $ids = array_combine($ids, $ids);
+        $ids = array_combine($ids, $ids) ?: [];
         $connection = $this->getConnectionForTableName($tableName);
         $maxBindParameters = PlatformInformation::getMaxBindParameters($connection->getDatabasePlatform());
 
