@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Database\Schema;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,10 +15,13 @@ namespace TYPO3\CMS\Core\Database\Schema;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Database\Schema;
+
 use Doctrine\DBAL\DBALException;
 use Doctrine\DBAL\Platforms\MySqlPlatform;
 use Doctrine\DBAL\Platforms\PostgreSqlPlatform;
 use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\DBAL\Platforms\SQLServer2012Platform as SQLServerPlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
@@ -162,7 +165,7 @@ class ConnectionMigrator
                     $indexColumns = array_map(
                         function ($columnName) {
                             // Strip MySQL prefix length information to get real column names
-                            $columnName = preg_replace('/\(\d+\)$/', '', $columnName);
+                            $columnName = preg_replace('/\(\d+\)$/', '', $columnName) ?? '';
                             // Strip mssql '[' and ']' from column names
                             $columnName = ltrim($columnName, '[');
                             $columnName = rtrim($columnName, ']');
@@ -250,6 +253,7 @@ class ConnectionMigrator
 
         // Collect the table names that have been mapped to this connection.
         $connectionName = $this->connectionName;
+        /** @var string[] $tablesForConnection */
         $tablesForConnection = array_keys(
             array_filter(
                 $GLOBALS['TYPO3_CONF_VARS']['DB']['TableMapping'],
@@ -361,11 +365,11 @@ class ConnectionMigrator
             if (count($changedTable->addedColumns) !== 0) {
                 // Treat each added column with a new diff to get a dedicated suggestions
                 // just for this single column.
-                foreach ($changedTable->addedColumns as $addedColumn) {
+                foreach ($changedTable->addedColumns as $columnName => $addedColumn) {
                     $changedTables[$index . ':tbl_' . $addedColumn->getName()] = GeneralUtility::makeInstance(
                         TableDiff::class,
                         $changedTable->name,
-                        [$addedColumn],
+                        [$columnName => $addedColumn],
                         [],
                         [],
                         [],
@@ -379,14 +383,14 @@ class ConnectionMigrator
             if (count($changedTable->addedIndexes) !== 0) {
                 // Treat each added index with a new diff to get a dedicated suggestions
                 // just for this index.
-                foreach ($changedTable->addedIndexes as $addedIndex) {
+                foreach ($changedTable->addedIndexes as $indexName => $addedIndex) {
                     $changedTables[$index . ':idx_' . $addedIndex->getName()] = GeneralUtility::makeInstance(
                         TableDiff::class,
                         $changedTable->name,
                         [],
                         [],
                         [],
-                        [$this->buildQuotedIndex($addedIndex)],
+                        [$indexName => $this->buildQuotedIndex($addedIndex)],
                         [],
                         [],
                         $fromTable
@@ -497,7 +501,7 @@ class ConnectionMigrator
             // Treat each changed index with a new diff to get a dedicated suggestions
             // just for this index.
             if (count($changedTable->changedIndexes) !== 0) {
-                foreach ($changedTable->changedIndexes as $key => $changedIndex) {
+                foreach ($changedTable->changedIndexes as $indexName => $changedIndex) {
                     $indexDiff = GeneralUtility::makeInstance(
                         TableDiff::class,
                         $changedTable->name,
@@ -505,7 +509,7 @@ class ConnectionMigrator
                         [],
                         [],
                         [],
-                        [$changedIndex],
+                        [$indexName => $changedIndex],
                         [],
                         $schemaDiff->fromSchema->getTable($changedTable->name)
                     );
@@ -567,13 +571,15 @@ class ConnectionMigrator
                 // just for this single column.
                 $fromTable = $this->buildQuotedTable($schemaDiff->fromSchema->getTable($changedTable->name));
 
-                foreach ($changedTable->changedColumns as $changedColumn) {
+                foreach ($changedTable->changedColumns as $columnName => $changedColumn) {
                     // Field has been renamed and will be handled separately
                     if ($changedColumn->getOldColumnName()->getName() !== $changedColumn->column->getName()) {
                         continue;
                     }
 
-                    $changedColumn->fromColumn = $this->buildQuotedColumn($changedColumn->fromColumn);
+                    if ($changedColumn->fromColumn !== null) {
+                        $changedColumn->fromColumn = $this->buildQuotedColumn($changedColumn->fromColumn);
+                    }
 
                     // Get the current SQL declaration for the column
                     $currentColumn = $fromTable->getColumn($changedColumn->getOldColumnName()->getName());
@@ -587,7 +593,7 @@ class ConnectionMigrator
                         TableDiff::class,
                         $changedTable->name,
                         [],
-                        [$changedColumn],
+                        [$columnName => $changedColumn],
                         [],
                         [],
                         [],
@@ -711,25 +717,35 @@ class ConnectionMigrator
                 continue;
             }
 
+            $databasePlatform = $this->getDatabasePlatform($index);
+
             // Treat each changed column with a new diff to get a dedicated suggestions
             // just for this single column.
-            foreach ($changedTable->changedColumns as $changedColumn) {
+            foreach ($changedTable->changedColumns as $oldFieldName => $changedColumn) {
                 // Field has not been renamed
                 if ($changedColumn->getOldColumnName()->getName() === $changedColumn->column->getName()) {
                     continue;
                 }
 
-                $changedTables[$index . ':' . $changedColumn->column->getName()] = GeneralUtility::makeInstance(
+                $renameColumnTableDiff = GeneralUtility::makeInstance(
                     TableDiff::class,
                     $changedTable->name,
                     [],
-                    [$changedColumn],
+                    [$oldFieldName => $changedColumn],
                     [],
                     [],
                     [],
                     [],
                     $this->buildQuotedTable($schemaDiff->fromSchema->getTable($changedTable->name))
                 );
+                if ($databasePlatform === 'postgresql') {
+                    $renameColumnTableDiff->renamedColumns[$oldFieldName] = $changedColumn->column;
+                }
+                $changedTables[$index . ':' . $changedColumn->column->getName()] = $renameColumnTableDiff;
+
+                if ($databasePlatform === 'sqlite') {
+                    break;
+                }
             }
         }
 
@@ -765,28 +781,35 @@ class ConnectionMigrator
         foreach ($schemaDiff->changedTables as $index => $changedTable) {
             $fromTable = $this->buildQuotedTable($schemaDiff->fromSchema->getTable($changedTable->name));
 
+            $isSqlite = $this->getDatabasePlatform($index) === 'sqlite';
+            $addMoreOperations = true;
+
             if (count($changedTable->removedColumns) !== 0) {
                 // Treat each changed column with a new diff to get a dedicated suggestions
                 // just for this single column.
-                foreach ($changedTable->removedColumns as $removedColumn) {
+                foreach ($changedTable->removedColumns as $columnName => $removedColumn) {
                     $changedTables[$index . ':tbl_' . $removedColumn->getName()] = GeneralUtility::makeInstance(
                         TableDiff::class,
                         $changedTable->name,
                         [],
                         [],
-                        [$this->buildQuotedColumn($removedColumn)],
+                        [$columnName => $this->buildQuotedColumn($removedColumn)],
                         [],
                         [],
                         [],
                         $fromTable
                     );
+                    if ($isSqlite) {
+                        $addMoreOperations = false;
+                        break;
+                    }
                 }
             }
 
-            if (count($changedTable->removedIndexes) !== 0) {
+            if ($addMoreOperations && count($changedTable->removedIndexes) !== 0) {
                 // Treat each removed index with a new diff to get a dedicated suggestions
                 // just for this index.
-                foreach ($changedTable->removedIndexes as $removedIndex) {
+                foreach ($changedTable->removedIndexes as $indexName => $removedIndex) {
                     $changedTables[$index . ':idx_' . $removedIndex->getName()] = GeneralUtility::makeInstance(
                         TableDiff::class,
                         $changedTable->name,
@@ -795,16 +818,23 @@ class ConnectionMigrator
                         [],
                         [],
                         [],
-                        [$this->buildQuotedIndex($removedIndex)],
+                        [$indexName => $this->buildQuotedIndex($removedIndex)],
                         $fromTable
                     );
+                    if ($isSqlite) {
+                        $addMoreOperations = false;
+                        break;
+                    }
                 }
             }
 
-            if (count($changedTable->removedForeignKeys) !== 0) {
+            if ($addMoreOperations && count($changedTable->removedForeignKeys) !== 0) {
                 // Treat each removed foreign key with a new diff to get a dedicated suggestions
                 // just for this foreign key.
                 foreach ($changedTable->removedForeignKeys as $removedForeignKey) {
+                    if (is_string($removedForeignKey)) {
+                        continue;
+                    }
                     $fkIndex = $index . ':fk_' . $removedForeignKey->getName();
                     $changedTables[$fkIndex] = GeneralUtility::makeInstance(
                         TableDiff::class,
@@ -818,6 +848,9 @@ class ConnectionMigrator
                         $fromTable
                     );
                     $changedTables[$fkIndex]->removedForeignKeys = [$this->buildQuotedForeignKey($removedForeignKey)];
+                    if ($isSqlite) {
+                        break;
+                    }
                 }
             }
         }
@@ -1060,9 +1093,9 @@ class ConnectionMigrator
     /**
      * Helper for buildSchemaDiff to filter an array of TableDiffs against a list of valid table names.
      *
-     * @param TableDiff[]|Table[] $tableDiffs
+     * @param \Doctrine\DBAL\Schema\TableDiff[]|Table[] $tableDiffs
      * @param string[] $validTableNames
-     * @return TableDiff[]
+     * @return \Doctrine\DBAL\Schema\TableDiff[]
      * @throws \InvalidArgumentException
      */
     protected function removeUnrelatedTables(array $tableDiffs, array $validTableNames): array
@@ -1302,4 +1335,20 @@ class ConnectionMigrator
             $index->getOptions()
         );
     }
+
+    protected function getDatabasePlatform(string $tableName): string
+    {
+        $databasePlatform = GeneralUtility::makeInstance(ConnectionPool::class)->getConnectionForTable($tableName)->getDatabasePlatform();
+        if ($databasePlatform instanceof PostgreSqlPlatform) {
+            return 'postgresql';
+        }
+        if ($databasePlatform instanceof SQLServerPlatform) {
+            return 'mssql';
+        }
+        if ($databasePlatform instanceof SqlitePlatform) {
+            return 'sqlite';
+        }
+
+        return 'mysql';
+    }
 }
