@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Html;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,13 +13,18 @@ namespace TYPO3\CMS\Core\Html;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Html;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
+use TYPO3\CMS\Core\Configuration\Features;
 use TYPO3\CMS\Core\Html\Event\BrokenLinkAnalysisEvent;
 use TYPO3\CMS\Core\LinkHandling\Exception\UnknownLinkHandlerException;
 use TYPO3\CMS\Core\LinkHandling\LinkService;
+use TYPO3\CMS\Core\Resource\Exception\InsufficientFolderAccessPermissionsException;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\HtmlSanitizer\Builder\BuilderInterface;
 
 /**
  * Class for parsing HTML for the Rich Text Editor. (also called transformations)
@@ -247,7 +251,7 @@ class RteHtmlParser extends HtmlParser implements LoggerAwareInterface
                         // Transform empty paragraphs into spacing paragraphs
                         $value = str_replace('<p></p>', '<p>&nbsp;</p>', $value);
                         // Double any trailing spacing paragraph so that it does not get removed by divideIntoLines()
-                        $value = preg_replace('/<p>&nbsp;<\/p>$/', '<p>&nbsp;</p><p>&nbsp;</p>', $value);
+                        $value = preg_replace('/<p>&nbsp;<\/p>$/', '<p>&nbsp;</p><p>&nbsp;</p>', $value) ?? $value;
                         $value = $this->TS_transform_db($value);
                         break;
                     default:
@@ -255,6 +259,8 @@ class RteHtmlParser extends HtmlParser implements LoggerAwareInterface
                 }
             }
         }
+        // process markup with HTML Sanitizer
+        $value = $this->htmlSanitize($value, $this->procOptions['HTMLparser_db.'] ?? []);
         // If an exit HTML cleaner was configured, pass the content through the HTMLcleaner
         $value = $this->runHtmlParserIfConfigured($value, 'exitHTMLparser_db');
         // Final clean up of linebreaks
@@ -373,10 +379,9 @@ class RteHtmlParser extends HtmlParser implements LoggerAwareInterface
                     continue;
                 }
                 $linkService = GeneralUtility::makeInstance(LinkService::class);
-                $linkInformation = $linkService->resolve($tagAttributes['href'] ?? '');
-
                 // Store the link as <a> tag as default by TYPO3, with the link service syntax
                 try {
+                    $linkInformation = $linkService->resolve($tagAttributes['href'] ?? '');
                     $tagAttributes['href'] = $linkService->asString($linkInformation);
                 } catch (UnknownLinkHandlerException $e) {
                     $tagAttributes['href'] = $linkInformation['href'] ?? $tagAttributes['href'];
@@ -449,6 +454,13 @@ class RteHtmlParser extends HtmlParser implements LoggerAwareInterface
                     $blockSplit[$k] = preg_replace('/<(hr)(\\s[^>\\/]*)?[[:space:]]*\\/?>[' . LF . ']+/', '<$1$2/>', $blockSplit[$k]);
                     // Replace other linebreaks with space
                     $blockSplit[$k] = preg_replace('/[' . LF . ']+/', ' ', $blockSplit[$k]);
+                    // process allowed/removed tags
+                    $blockSplit[$k] = $this->HTMLcleaner(
+                        (string)$blockSplit[$k],
+                        $this->getKeepTags('db'),
+                        $this->procOptions['HTMLparser_db.']['keepNonMatchedTags'] ?? '',
+                        (int)($this->procOptions['HTMLparser_db.']['htmlSpecialChars'] ?? 0)
+                    );
                     $blockSplit[$k] = $this->divideIntoLines($blockSplit[$k]);
                 } else {
                     unset($blockSplit[$k]);
@@ -756,9 +768,9 @@ class RteHtmlParser extends HtmlParser implements LoggerAwareInterface
      */
     protected function sanitizeLineBreaksForContentOnly(string $content)
     {
-        $content = preg_replace('/<(hr)(\\s[^>\\/]*)?[[:space:]]*\\/?>/i', LF . '<$1$2/>' . LF, $content);
+        $content = preg_replace('/<(hr)(\\s[^>\\/]*)?[[:space:]]*\\/?>/i', LF . '<$1$2/>' . LF, $content) ?? $content;
         $content = str_replace(LF . LF, LF, $content);
-        $content = preg_replace('/(^' . LF . ')|(' . LF . '$)/i', '', $content);
+        $content = preg_replace('/(^' . LF . ')|(' . LF . '$)/i', '', $content) ?? $content;
         return $content;
     }
 
@@ -815,12 +827,19 @@ class RteHtmlParser extends HtmlParser implements LoggerAwareInterface
             if (empty($attributes['href'])) {
                 continue;
             }
-            $hrefInformation = $linkService->resolve($attributes['href']);
 
-            $brokenLinkAnalysis = new BrokenLinkAnalysisEvent($hrefInformation['type'], $hrefInformation);
-            $this->eventDispatcher->dispatch($brokenLinkAnalysis);
-            if ($brokenLinkAnalysis->isBrokenLink()) {
-                $attributes['data-rte-error'] = $brokenLinkAnalysis->getReason();
+            try {
+                $hrefInformation = $linkService->resolve($attributes['href']);
+
+                $brokenLinkAnalysis = new BrokenLinkAnalysisEvent($hrefInformation['type'], $hrefInformation);
+                $this->eventDispatcher->dispatch($brokenLinkAnalysis);
+                if ($brokenLinkAnalysis->isBrokenLink()) {
+                    $attributes['data-rte-error'] = $brokenLinkAnalysis->getReason();
+                }
+            } catch (InsufficientFolderAccessPermissionsException $e) {
+                // do nothing if user doesn't have access to the file/folder
+            } catch (UnknownLinkHandlerException $e) {
+                $attributes['data-rte-error'] = $e->getMessage();
             }
 
             // Always rewrite the block to allow the nested calling even if a page is found
@@ -866,4 +885,27 @@ class RteHtmlParser extends HtmlParser implements LoggerAwareInterface
         }
         return implode('', $blocks);
     }
+
+    protected function htmlSanitize(string $content, array $configuration): string
+    {
+        $features = GeneralUtility::makeInstance(Features::class);
+        // either `htmlSanitize = null` or `htmlSanitize = false`
+        // or feature flag `security.backend.htmlSanitizeRte` is disabled
+        if (array_key_exists('htmlSanitize', $configuration) && empty($configuration['htmlSanitize'])
+            || !$features->isFeatureEnabled('security.backend.htmlSanitizeRte')
+        ) {
+            return $content;
+        }
+
+        $build = $configuration['htmlSanitize.']['build'] ?? 'default';
+        if (class_exists($build) && is_a($build, BuilderInterface::class, true)) {
+            $builder = GeneralUtility::makeInstance($build);
+        } else {
+            $factory = GeneralUtility::makeInstance(SanitizerBuilderFactory::class);
+            $builder = $factory->build($build);
+        }
+        $sanitizer = $builder->build();
+        $initiator = GeneralUtility::makeInstance(SanitizerInitiator::class, get_class($this));
+        return $sanitizer->sanitize($content, $initiator);
+    }
 }
