@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Http;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Core\Http;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Http;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use Psr\Http\Server\RequestHandlerInterface;
@@ -92,7 +94,7 @@ abstract class AbstractApplication implements ApplicationInterface
     {
         try {
             $response = $this->handle(
-                \TYPO3\CMS\Core\Http\ServerRequestFactory::fromGlobals()
+                ServerRequestFactory::fromGlobals()
             );
             if ($execute !== null) {
                 call_user_func($execute);
