@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Imaging\IconProvider;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Imaging\IconProvider;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Imaging\IconProvider;
+
 use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Imaging\IconProviderInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
@@ -80,7 +81,11 @@ class BitmapIconProvider implements IconProviderInterface
             return '';
         }
 
-        return '<image width="' . $icon->getDimension()->getWidth() . '" height="'
-            . $icon->getDimension()->getHeight() . '" xlink:href="' . PathUtility::getAbsoluteWebPath($source) . '"/>';
+        return sprintf(
+            '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 %1$d %2$d" width="%1$d" height="%2$d"><image width="%1$d" height="%1$d" xlink:href="%3$s"/></svg>',
+            $icon->getDimension()->getWidth(),
+            $icon->getDimension()->getHeight(),
+            PathUtility::getAbsoluteWebPath($source)
+        );
     }
 }
