@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Localization;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +13,11 @@ namespace TYPO3\CMS\Core\Localization;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Localization;
+
 use TYPO3\CMS\Core\Authentication\AbstractUserAuthentication;
+use TYPO3\CMS\Core\Compatibility\PublicMethodDeprecationTrait;
+use TYPO3\CMS\Core\Compatibility\PublicPropertyDeprecationTrait;
 use TYPO3\CMS\Core\Site\Entity\SiteLanguage;
 use TYPO3\CMS\Core\Utility\ArrayUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
@@ -40,6 +43,19 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  */
 class LanguageService
 {
+    use PublicPropertyDeprecationTrait;
+    use PublicMethodDeprecationTrait;
+
+    protected $deprecatedPublicProperties = [
+        'LL_files_cache' => 'The runtime cache variable is only used for internal purposes, and should never be accessed from the outside. Accessing this property will stop working in TYPO3 v11.0.',
+        'LL_labels_cache' => 'The runtime cache variable is only used for internal purposes, and should never be accessed from the outside. Accessing this property will stop working in TYPO3 v11.0.'
+    ];
+
+    protected $deprecatedPublicMethods = [
+        'debugLL' => 'Should never be called directly. use the "debugKey" to actually access the method.',
+        'getLLL' => 'Use "getLL()" or "sL()" instead as API methods.',
+    ];
+
     /**
      * This is set to the language that is currently running for the user
      *
@@ -59,14 +75,14 @@ class LanguageService
      *
      * @var array
      */
-    public $LL_files_cache = [];
+    protected $LL_files_cache = [];
 
     /**
      * Internal cache for ll-labels (filled as labels are requested)
      *
      * @var array
      */
-    public $LL_labels_cache = [];
+    protected $LL_labels_cache = [];
 
     /**
      * List of language dependencies for actual language. This is used for local variants of a language
@@ -89,10 +105,22 @@ class LanguageService
     protected $labels = [];
 
     /**
-     * LanguageService constructor.
+     * @var Locales
      */
-    public function __construct()
+    protected $locales;
+
+    /**
+     * @var LocalizationFactory
+     */
+    protected $localizationFactory;
+
+    /**
+     * @internal use one of the factory methods instead
+     */
+    public function __construct(Locales $locales, LocalizationFactory $localizationFactory)
     {
+        $this->locales = $locales;
+        $this->localizationFactory = $localizationFactory;
         $this->debugKey = (bool)$GLOBALS['TYPO3_CONF_VARS']['BE']['languageDebug'];
     }
 
@@ -103,17 +131,17 @@ class LanguageService
      *
      * @throws \RuntimeException
      * @param string $languageKey The language key (two character string from backend users profile)
+     * @internal use one of the factory methods instead
      */
     public function init($languageKey)
     {
         // Find the requested language in this list based on the $languageKey
-        $locales = GeneralUtility::makeInstance(Locales::class);
         // Language is found. Configure it:
-        if (in_array($languageKey, $locales->getLocales(), true)) {
+        if (in_array($languageKey, $this->locales->getLocales(), true)) {
             // The current language key
             $this->lang = $languageKey;
             $this->languageDependencies[] = $languageKey;
-            foreach ($locales->getLocaleDependencies($languageKey) as $language) {
+            foreach ($this->locales->getLocaleDependencies($languageKey) as $language) {
                 $this->languageDependencies[] = $language;
             }
         }
@@ -125,7 +153,7 @@ class LanguageService
      * @param string $value value to debug
      * @return string
      */
-    public function debugLL($value)
+    protected function debugLL($value)
     {
         return $this->debugKey ? '[' . $value . ']' : '';
     }
@@ -149,7 +177,7 @@ class LanguageService
      * @param array $localLanguage $LOCAL_LANG array to get label key from
      * @return string
      */
-    public function getLLL($index, $localLanguage)
+    protected function getLLL($index, $localLanguage)
     {
         // Get Local Language. Special handling for all extensions that
         // read PHP LL files and pass arrays here directly.
@@ -183,15 +211,15 @@ class LanguageService
         if (isset($this->LL_labels_cache[$this->lang][$identifier])) {
             return $this->LL_labels_cache[$this->lang][$identifier];
         }
-        if (strpos($input, 'LLL:') === 0) {
-            $restStr = trim(substr($input, 4));
+        if (strpos(trim($input), 'LLL:') === 0) {
+            $restStr = substr(trim($input), 4);
             $extPrfx = '';
             // ll-file referred to is found in an extension.
-            if (strpos($restStr, 'EXT:') === 0) {
-                $restStr = trim(substr($restStr, 4));
+            if (strpos(trim($restStr), 'EXT:') === 0) {
+                $restStr = substr(trim($restStr), 4);
                 $extPrfx = 'EXT:';
             }
-            $parts = explode(':', $restStr);
+            $parts = explode(':', trim($restStr));
             $parts[0] = $extPrfx . $parts[0];
             // Getting data if not cached
             if (!isset($this->LL_files_cache[$parts[0]])) {
@@ -213,6 +241,7 @@ class LanguageService
      * $TCA_DESCR is a global var
      *
      * @param string $table Table name found as key in global array $TCA_DESCR
+     * @internal
      */
     public function loadSingleTableDescription($table)
     {
@@ -276,7 +305,7 @@ class LanguageService
      *
      * @param string $fileRef $fileRef is a file-reference
      * @param bool $setGlobal Setting in global variable $LOCAL_LANG (or returning the variable), do not set this, will be dropped in TYPO3 v11.0
-     * @param bool $mergeLocalOntoDefault, do not set this, will be dropped in TYPO3 v11.0
+     * @param bool $mergeLocalOntoDefault do not set this, will be dropped in TYPO3 v11.0
      * @return array returns the loaded label file
      */
     public function includeLLFile($fileRef, $setGlobal = null, $mergeLocalOntoDefault = null)
@@ -353,9 +382,6 @@ class LanguageService
             return $this->languageFileCache[$fileRef . $this->lang];
         }
 
-        /** @var LocalizationFactory $languageFactory */
-        $languageFactory = GeneralUtility::makeInstance(LocalizationFactory::class);
-
         if ($this->lang !== 'default') {
             $languages = array_reverse($this->languageDependencies);
         } else {
@@ -363,7 +389,7 @@ class LanguageService
         }
         $localLanguage = [];
         foreach ($languages as $language) {
-            $tempLL = $languageFactory->getParsedData($fileRef, $language);
+            $tempLL = $this->localizationFactory->getParsedData($fileRef, $language);
             $localLanguage['default'] = $tempLL['default'];
             if (!isset($localLanguage[$this->lang])) {
                 $localLanguage[$this->lang] = $localLanguage['default'];
@@ -386,10 +412,11 @@ class LanguageService
      * @param string $prefix Prefix to select the correct labels
      * @param string $strip Sub-prefix to be removed from label names in the result
      * @return array Processed labels
-     * @todo: deprecate
+     * @deprecated will be removed in TYPO3 v11.0
      */
     public function getLabelsWithPrefix($prefix, $strip = '')
     {
+        trigger_error('LanguageService->getLabelsWithPrefix() will be removed in TYPO3 v11.0. Prefixing labels was used for various Backend-related JavaScript calls, which is not supported anymore. Prefixes should be applied to the label keys / ids directly instead.', E_USER_DEPRECATED);
         $extraction = [];
         if (!empty($GLOBALS['LOCAL_LANG']['default'])) {
             $labels = array_merge((array)$GLOBALS['LOCAL_LANG']['default'], (array)$GLOBALS['LOCAL_LANG'][$this->lang]);
@@ -416,9 +443,7 @@ class LanguageService
      */
     public static function create(string $locale): self
     {
-        $obj = GeneralUtility::makeInstance(LanguageService::class);
-        $obj->init($locale);
-        return $obj;
+        return GeneralUtility::makeInstance(LanguageServiceFactory::class)->create($locale);
     }
 
     public static function createFromUserPreferences(?AbstractUserAuthentication $user): self
