@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Localization\Parser;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Localization\Parser;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Localization\Parser;
+
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Localization\Exception\FileNotFoundException;
 use TYPO3\CMS\Core\Localization\Exception\InvalidXmlFileException;
@@ -72,14 +73,25 @@ abstract class AbstractXmlParser implements LocalizationParserInterface
     protected function parseXmlFile()
     {
         $xmlContent = file_get_contents($this->sourcePath);
+        if ($xmlContent === false) {
+            throw new InvalidXmlFileException(
+                'The path provided does not point to an existing and accessible file.',
+                1278155986
+            );
+        }
         // Disables the functionality to allow external entities to be loaded when parsing the XML, must be kept
-        $previousValueOfEntityLoader = libxml_disable_entity_loader(true);
+        $previousValueOfEntityLoader = null;
+        if (PHP_MAJOR_VERSION < 8) {
+            $previousValueOfEntityLoader = libxml_disable_entity_loader(true);
+        }
         $rootXmlNode = simplexml_load_string($xmlContent, \SimpleXMLElement::class, LIBXML_NOWARNING);
-        libxml_disable_entity_loader($previousValueOfEntityLoader);
-        if (!isset($rootXmlNode) || $rootXmlNode === false) {
+        if (PHP_MAJOR_VERSION < 8) {
+            libxml_disable_entity_loader($previousValueOfEntityLoader);
+        }
+        if ($rootXmlNode === false) {
             $xmlError = libxml_get_last_error();
             throw new InvalidXmlFileException(
-                'The path provided does not point to existing and accessible well-formed XML file. Reason: ' . $xmlError->message . ' in ' . $this->sourcePath . ', line ' . $xmlError->line,
+                'The path provided does not point to an existing and accessible well-formed XML file. Reason: ' . $xmlError->message . ' in ' . $this->sourcePath . ', line ' . $xmlError->line,
                 1278155988
             );
         }
@@ -93,7 +105,7 @@ abstract class AbstractXmlParser implements LocalizationParserInterface
      * @param string $fileRef Absolute file reference to locallang file
      * @param string $language Language key
      * @param bool $sameLocation If TRUE, then locallang localization file name will be returned with same directory as $fileRef
-     * @return string|null Absolute path to the language file, or null if error occurred
+     * @return string Absolute path to the language file
      */
     protected function getLocalizedFileName($fileRef, $language, $sameLocation = false)
     {
@@ -132,7 +144,7 @@ abstract class AbstractXmlParser implements LocalizationParserInterface
             // The filename is prefixed with "[language key]." because it prevents the llxmltranslate tool from detecting it.
             return Environment::getLabelsPath() . '/' . $language . '/' . $extensionKey . '/' . ($file_extPath ? $file_extPath . '/' : '') . $language . '.' . $file_fileName;
         }
-        return null;
+        return '';
     }
 
     /**
