@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Locking;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,9 +13,12 @@ namespace TYPO3\CMS\Core\Locking;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Locking;
+
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Locking\Exception\LockAcquireException;
 use TYPO3\CMS\Core\Locking\Exception\LockCreateException;
+use TYPO3\CMS\Core\Security\BlockSerializationTrait;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
 /**
@@ -24,12 +26,13 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  */
 class SemaphoreLockStrategy implements LockingStrategyInterface
 {
-    const FILE_LOCK_FOLDER = 'lock/';
+    use BlockSerializationTrait;
 
+    const FILE_LOCK_FOLDER = 'lock/';
     const DEFAULT_PRIORITY = 25;
 
     /**
-     * @var mixed Identifier used for this lock
+     * @var int Identifier used for this lock
      */
     protected $id;
 
