@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Log;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +13,13 @@ namespace TYPO3\CMS\Core\Log;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Log;
+
+use Psr\Log\InvalidArgumentException;
+use TYPO3\CMS\Core\Log\Exception\InvalidLogProcessorConfigurationException;
+use TYPO3\CMS\Core\Log\Exception\InvalidLogWriterConfigurationException;
 use TYPO3\CMS\Core\SingletonInterface;
+use TYPO3\CMS\Core\Utility\GeneralUtility;
 
 /**
  * Global LogManager that keeps track of global logging information.
@@ -62,7 +67,7 @@ class LogManager implements SingletonInterface, LogManagerInterface
     public function __construct(string $requestId = '')
     {
         $this->requestId = $requestId;
-        $this->rootLogger = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance(Logger::class, '', $requestId);
+        $this->rootLogger = GeneralUtility::makeInstance(Logger::class, '', $requestId);
         $this->loggers[''] = $this->rootLogger;
     }
 
@@ -98,7 +103,7 @@ class LogManager implements SingletonInterface, LogManagerInterface
         } else {
             // Lazy instantiation
             /** @var \TYPO3\CMS\Core\Log\Logger $logger */
-            $logger = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance(Logger::class, $name, $this->requestId);
+            $logger = GeneralUtility::makeInstance(Logger::class, $name, $this->requestId);
             $this->loggers[$name] = $logger;
             $this->setWritersForLogger($logger);
             $this->setProcessorsForLogger($logger);
@@ -136,11 +141,15 @@ class LogManager implements SingletonInterface, LogManagerInterface
         $configuration = $this->getConfigurationForLogger(self::CONFIGURATION_TYPE_WRITER, $logger->getName());
         foreach ($configuration as $severityLevel => $writer) {
             foreach ($writer as $logWriterClassName => $logWriterOptions) {
+                if ($logWriterOptions['disabled'] ?? false) {
+                    continue;
+                }
+                unset($logWriterOptions['disabled']);
                 try {
                     /** @var \TYPO3\CMS\Core\Log\Writer\WriterInterface $logWriter */
-                    $logWriter = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance($logWriterClassName, $logWriterOptions);
+                    $logWriter = GeneralUtility::makeInstance($logWriterClassName, $logWriterOptions);
                     $logger->addWriter($severityLevel, $logWriter);
-                } catch (\Psr\Log\InvalidArgumentException|\TYPO3\CMS\Core\Log\Exception\InvalidLogWriterConfigurationException $e) {
+                } catch (InvalidArgumentException|InvalidLogWriterConfigurationException $e) {
                     $logger->warning('Instantiation of LogWriter "' . $logWriterClassName . '" failed for logger ' . $logger->getName() . ' (' . $e->getMessage() . ')');
                 }
             }
@@ -159,9 +168,9 @@ class LogManager implements SingletonInterface, LogManagerInterface
             foreach ($processor as $logProcessorClassName => $logProcessorOptions) {
                 try {
                     /** @var \TYPO3\CMS\Core\Log\Processor\ProcessorInterface $logProcessor */
-                    $logProcessor = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance($logProcessorClassName, $logProcessorOptions);
+                    $logProcessor = GeneralUtility::makeInstance($logProcessorClassName, $logProcessorOptions);
                     $logger->addProcessor($severityLevel, $logProcessor);
-                } catch (\Psr\Log\InvalidArgumentException|\TYPO3\CMS\Core\Log\Exception\InvalidLogProcessorConfigurationException $e) {
+                } catch (InvalidArgumentException|InvalidLogProcessorConfigurationException $e) {
                     $logger->warning('Instantiation of LogProcessor "' . $logProcessorClassName . '" failed for logger ' . $logger->getName() . ' (' . $e->getMessage() . ')');
                 }
             }
@@ -201,8 +210,8 @@ class LogManager implements SingletonInterface, LogManagerInterface
         foreach ($result as $level => $unused) {
             try {
                 LogLevel::validateLevel(LogLevel::normalizeLevel($level));
-            } catch (\Psr\Log\InvalidArgumentException $e) {
-                throw new \Psr\Log\InvalidArgumentException('The given severity level "' . htmlspecialchars($level) . '" for ' . $configurationKey . ' of logger "' . $loggerName . '" is not valid.', 1326406447);
+            } catch (InvalidArgumentException $e) {
+                throw new InvalidArgumentException('The given severity level "' . htmlspecialchars($level) . '" for ' . $configurationKey . ' of logger "' . $loggerName . '" is not valid.', 1326406447);
             }
         }
         return $result;
