@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Mail;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Mail;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Mail;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use Symfony\Component\Mailer\Envelope;
 use Symfony\Component\Mailer\MailerInterface;
@@ -113,7 +114,7 @@ class Mailer implements MailerInterface
                     if ($address === 0) {
                         $replyTo = new Address($replyTo[$address]);
                     } else {
-                        $replyTo = new Address($address, reset($replyTo));
+                        $replyTo = new Address((string)$address, reset($replyTo));
                     }
                     $message->replyTo($replyTo);
                 }
@@ -140,8 +141,7 @@ class Mailer implements MailerInterface
      * Used options:
      * $TYPO3_CONF_VARS['MAIL']['transport'] = 'smtp' | 'sendmail' | 'null' | 'mbox'
      *
-     * $TYPO3_CONF_VARS['MAIL']['transport_smtp_server'] = 'smtp.example.org';
-     * $TYPO3_CONF_VARS['MAIL']['transport_smtp_port'] = '25';
+     * $TYPO3_CONF_VARS['MAIL']['transport_smtp_server'] = 'smtp.example.org:25';
      * $TYPO3_CONF_VARS['MAIL']['transport_smtp_encrypt'] = FALSE; # requires openssl in PHP
      * $TYPO3_CONF_VARS['MAIL']['transport_smtp_username'] = 'username';
      * $TYPO3_CONF_VARS['MAIL']['transport_smtp_password'] = 'password';
