@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Mail;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,12 +15,15 @@ namespace TYPO3\CMS\Core\Mail;
  * The TYPO3 project - inspiring people to share!
  */
 
-use Psr\Log\LoggerAwareInterface;
-use Psr\Log\LoggerAwareTrait;
+namespace TYPO3\CMS\Core\Mail;
+
+use Psr\Log\LoggerInterface;
 use Symfony\Component\Mailer\Exception\TransportExceptionInterface;
 use Symfony\Component\Mailer\SentMessage;
 use Symfony\Component\Mailer\Transport\AbstractTransport;
 use Symfony\Component\Mailer\Transport\TransportInterface;
+use Symfony\Contracts\EventDispatcher\EventDispatcherInterface;
+use TYPO3\CMS\Core\Security\BlockSerializationTrait;
 use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
@@ -34,14 +37,21 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  *
  * @internal This class is experimental and subject to change!
  */
-class MemorySpool extends AbstractTransport implements SingletonInterface, LoggerAwareInterface, DelayedTransportInterface
+class MemorySpool extends AbstractTransport implements SingletonInterface, DelayedTransportInterface
 {
-    use LoggerAwareTrait;
+    use BlockSerializationTrait;
+
+    /**
+     * The logger instance.
+     *
+     * @var LoggerInterface
+     */
+    protected $logger;
 
     /**
      * @var SentMessage[]
      */
-    protected $queuedMessages;
+    protected $queuedMessages = [];
 
     /**
      * Maximum number of retries when the real transport has failed.
@@ -50,6 +60,23 @@ class MemorySpool extends AbstractTransport implements SingletonInterface, Logge
      */
     protected $retries = 3;
 
+    /**
+     * Create a new MemorySpool
+     *
+     * @param EventDispatcherInterface $dispatcher
+     * @param LoggerInterface $logger
+     */
+    public function __construct(
+        EventDispatcherInterface $dispatcher = null,
+        LoggerInterface $logger = null
+    ) {
+        parent::__construct($dispatcher, $logger);
+
+        $this->logger = $logger;
+
+        $this->setMaxPerSecond(0);
+    }
+
     /**
      * Sends out the messages in the memory
      */
@@ -68,7 +95,7 @@ class MemorySpool extends AbstractTransport implements SingletonInterface, Logge
      */
     public function flushQueue(TransportInterface $transport): int
     {
-        if (!$this->queuedMessages) {
+        if ($this->queuedMessages === []) {
             return 0;
         }
 
@@ -109,10 +136,6 @@ class MemorySpool extends AbstractTransport implements SingletonInterface, Logge
 
     public function __toString(): string
     {
-        $result = '';
-        foreach ($this->queuedMessages as $sentMessage) {
-            $result .= $sentMessage->toString() . "\n";
-        }
-        return $result;
+        return 'MemorySpool';
     }
 }
