@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Package\Exception;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,9 +13,13 @@ namespace TYPO3\CMS\Core\Package\Exception;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Package\Exception;
+
+use TYPO3\CMS\Core\Package\Exception;
+
 /**
  * An "Invalid Package Manifest" exception
  */
-class InvalidPackageManifestException extends \TYPO3\CMS\Core\Package\Exception
+class InvalidPackageManifestException extends Exception
 {
 }
