@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Package;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,14 +13,26 @@ namespace TYPO3\CMS\Core\Package;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Package;
+
 use Symfony\Component\Finder\Finder;
 use Symfony\Component\Finder\SplFileInfo;
 use TYPO3\CMS\Core\Cache\Frontend\FrontendInterface;
 use TYPO3\CMS\Core\Core\ClassLoadingInformation;
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Information\Typo3Version;
-use TYPO3\CMS\Core\Package\Event\BeforePackageActivationEvent;
 use TYPO3\CMS\Core\Package\Event\PackagesMayHaveChangedEvent;
+use TYPO3\CMS\Core\Package\Exception\InvalidPackageKeyException;
+use TYPO3\CMS\Core\Package\Exception\InvalidPackageManifestException;
+use TYPO3\CMS\Core\Package\Exception\InvalidPackagePathException;
+use TYPO3\CMS\Core\Package\Exception\InvalidPackageStateException;
+use TYPO3\CMS\Core\Package\Exception\MissingPackageManifestException;
+use TYPO3\CMS\Core\Package\Exception\PackageManagerCacheUnavailableException;
+use TYPO3\CMS\Core\Package\Exception\PackageStatesFileNotWritableException;
+use TYPO3\CMS\Core\Package\Exception\PackageStatesUnavailableException;
+use TYPO3\CMS\Core\Package\Exception\ProtectedPackageKeyException;
+use TYPO3\CMS\Core\Package\Exception\UnknownPackageException;
+use TYPO3\CMS\Core\Package\MetaData\PackageConstraint;
 use TYPO3\CMS\Core\Service\DependencyOrderingService;
 use TYPO3\CMS\Core\Service\OpcodeCacheService;
 use TYPO3\CMS\Core\SingletonInterface;
@@ -131,7 +142,7 @@ class PackageManager implements SingletonInterface
     {
         try {
             $this->loadPackageManagerStatesFromCache();
-        } catch (Exception\PackageManagerCacheUnavailableException $exception) {
+        } catch (PackageManagerCacheUnavailableException $exception) {
             $this->loadPackageStates();
             $this->initializePackageObjects();
             $this->saveToPackageCache();
@@ -140,7 +151,7 @@ class PackageManager implements SingletonInterface
 
     /**
      * @internal
-     * @return string | null
+     * @return string|null
      */
     public function getCacheIdentifier()
     {
@@ -194,11 +205,11 @@ class PackageManager implements SingletonInterface
     {
         $cacheEntryIdentifier = $this->getCacheEntryIdentifier();
         if ($cacheEntryIdentifier === null || ($packageCache = $this->coreCache->require($cacheEntryIdentifier)) === false) {
-            throw new Exception\PackageManagerCacheUnavailableException('The package state cache could not be loaded.', 1393883342);
+            throw new PackageManagerCacheUnavailableException('The package state cache could not be loaded.', 1393883342);
         }
         $this->packageStatesConfiguration = $packageCache['packageStatesConfiguration'];
         if ($this->packageStatesConfiguration['version'] < 5) {
-            throw new Exception\PackageManagerCacheUnavailableException('The package state cache could not be loaded.', 1393883341);
+            throw new PackageManagerCacheUnavailableException('The package state cache could not be loaded.', 1393883341);
         }
         $this->packageAliasMap = $packageCache['packageAliasMap'];
         $this->composerNameToPackageKeyMap = $packageCache['composerNameToPackageKeyMap'];
@@ -206,7 +217,7 @@ class PackageManager implements SingletonInterface
             'allowed_classes' => [
                 Package::class,
                 MetaData::class,
-                MetaData\PackageConstraint::class,
+                PackageConstraint::class,
                 \stdClass::class,
             ]
         ]);
@@ -222,7 +233,7 @@ class PackageManager implements SingletonInterface
     {
         $this->packageStatesConfiguration = @include $this->packageStatesPathAndFilename ?: [];
         if (!isset($this->packageStatesConfiguration['version']) || $this->packageStatesConfiguration['version'] < 5) {
-            throw new Exception\PackageStatesUnavailableException('The PackageStates.php file is either corrupt or unavailable.', 1381507733);
+            throw new PackageStatesUnavailableException('The PackageStates.php file is either corrupt or unavailable.', 1381507733);
         }
         $this->registerPackagesFromConfiguration($this->packageStatesConfiguration['packages'], false);
     }
@@ -280,11 +291,11 @@ class PackageManager implements SingletonInterface
                 $packageKey = $this->getPackageKeyFromManifest($composerManifest, $packagePath);
                 $this->composerNameToPackageKeyMap[strtolower($composerManifest->name)] = $packageKey;
                 $packages[$packageKey] = ['packagePath' => str_replace($this->packagesBasePath, '', $packagePath)];
-            } catch (Exception\MissingPackageManifestException $exception) {
+            } catch (MissingPackageManifestException $exception) {
                 if (!$this->isPackageKeyValid($packageKey)) {
                     continue;
                 }
-            } catch (Exception\InvalidPackageKeyException $exception) {
+            } catch (InvalidPackageKeyException $exception) {
                 continue;
             }
         }
@@ -304,18 +315,12 @@ class PackageManager implements SingletonInterface
         $this->scanAvailablePackages();
     }
 
-    public function beforeInstallationEventListener(BeforePackageActivationEvent $event): void
-    {
-        if (TYPO3_REQUESTTYPE & TYPO3_REQUESTTYPE_BE) {
-            $this->scanAvailablePackages();
-        }
-    }
-
     /**
      * Scans all directories for a certain package.
      *
      * @param string $packageKey
      * @return PackageInterface
+     * @deprecated will be removed in TYPO3 v11.0
      */
     protected function registerPackageDuringRuntime($packageKey)
     {
@@ -390,7 +395,7 @@ class PackageManager implements SingletonInterface
             try {
                 $packagePath = PathUtility::sanitizeTrailingSeparator($this->packagesBasePath . $stateConfiguration['packagePath']);
                 $package = new Package($this, $packageKey, $packagePath);
-            } catch (Exception\InvalidPackagePathException|Exception\InvalidPackageKeyException|Exception\InvalidPackageManifestException $exception) {
+            } catch (InvalidPackagePathException|InvalidPackageKeyException|InvalidPackageManifestException $exception) {
                 $this->unregisterPackageByPackageKey($packageKey);
                 $packageStatesHasChanged = true;
                 continue;
@@ -415,7 +420,7 @@ class PackageManager implements SingletonInterface
     {
         $packageKey = $package->getPackageKey();
         if ($this->isPackageRegistered($packageKey)) {
-            throw new Exception\InvalidPackageStateException('Package "' . $packageKey . '" is already registered.', 1338996122);
+            throw new InvalidPackageStateException('Package "' . $packageKey . '" is already registered.', 1338996122);
         }
 
         $this->packages[$packageKey] = $package;
@@ -442,7 +447,7 @@ class PackageManager implements SingletonInterface
                     unset($this->packageAliasMap[strtolower($packageToReplace)]);
                 }
             }
-        } catch (Exception\UnknownPackageException $e) {
+        } catch (UnknownPackageException $e) {
         }
         unset($this->packages[$packageKey]);
         unset($this->packageStatesConfiguration['packages'][$packageKey]);
@@ -478,7 +483,7 @@ class PackageManager implements SingletonInterface
     public function getPackage($packageKey)
     {
         if (!$this->isPackageRegistered($packageKey) && !$this->isPackageAvailable($packageKey)) {
-            throw new Exception\UnknownPackageException('Package "' . $packageKey . '" is not available. Please check if the package exists and that the package key is correct (package keys are case sensitive).', 1166546734);
+            throw new UnknownPackageException('Package "' . $packageKey . '" is not available. Please check if the package exists and that the package key is correct (package keys are case sensitive).', 1166546734);
         }
         return $this->packages[$packageKey];
     }
@@ -546,7 +551,7 @@ class PackageManager implements SingletonInterface
 
         $package = $this->getPackage($packageKey);
         if ($package->isProtected()) {
-            throw new Exception\ProtectedPackageKeyException('The package "' . $packageKey . '" is protected and cannot be deactivated.', 1308662891);
+            throw new ProtectedPackageKeyException('The package "' . $packageKey . '" is protected and cannot be deactivated.', 1308662891);
         }
 
         $this->activePackages = [];
@@ -575,6 +580,7 @@ class PackageManager implements SingletonInterface
      * Enables packages during runtime, but no class aliases will be available
      *
      * @param string $packageKey
+     * @deprecated will be removed in TYPO3 v11.0
      */
     public function activatePackageDuringRuntime($packageKey)
     {
@@ -607,12 +613,12 @@ class PackageManager implements SingletonInterface
     public function deletePackage($packageKey)
     {
         if (!$this->isPackageAvailable($packageKey)) {
-            throw new Exception\UnknownPackageException('Package "' . $packageKey . '" is not available and cannot be removed.', 1166543253);
+            throw new UnknownPackageException('Package "' . $packageKey . '" is not available and cannot be removed.', 1166543253);
         }
 
         $package = $this->getPackage($packageKey);
         if ($package->isProtected()) {
-            throw new Exception\ProtectedPackageKeyException('The package "' . $packageKey . '" is protected and cannot be removed.', 1220722120);
+            throw new ProtectedPackageKeyException('The package "' . $packageKey . '" is protected and cannot be removed.', 1220722120);
         }
 
         if ($this->isPackageActive($packageKey)) {
@@ -689,7 +695,7 @@ class PackageManager implements SingletonInterface
      * resolved direct or indirect dependencies of each package will put into the package
      * states configuration array.
      *
-     * @param $packageConfig
+     * @param array $packageConfig
      * @return array
      */
     protected function resolvePackageDependencies($packageConfig)
@@ -716,7 +722,7 @@ class PackageManager implements SingletonInterface
         $suggestedPackageKeys = [];
         $suggestedPackageConstraints = $this->packages[$packageKey]->getPackageMetaData()->getConstraintsByType(MetaData::CONSTRAINT_TYPE_SUGGESTS);
         foreach ($suggestedPackageConstraints as $constraint) {
-            if ($constraint instanceof MetaData\PackageConstraint) {
+            if ($constraint instanceof PackageConstraint) {
                 $suggestedPackageKey = $constraint->getValue();
                 if (isset($this->packages[$suggestedPackageKey])) {
                     $suggestedPackageKeys[] = $suggestedPackageKey;
@@ -746,7 +752,7 @@ class PackageManager implements SingletonInterface
             // If file does not exist, try to create it
             $fileHandle = @fopen($this->packageStatesPathAndFilename, 'x');
             if (!$fileHandle) {
-                throw new Exception\PackageStatesFileNotWritableException(
+                throw new PackageStatesFileNotWritableException(
                     sprintf('We could not update the list of installed packages because the file %s is not writable. Please, check the file system permissions for this file and make sure that the web server can update it.', $this->packageStatesPathAndFilename),
                     1382449759
                 );
@@ -755,6 +761,8 @@ class PackageManager implements SingletonInterface
         }
         $packageStatesCode = "<?php\n$fileDescription\nreturn " . ArrayUtility::arrayExport($this->packageStatesConfiguration) . ";\n";
         GeneralUtility::writeFile($this->packageStatesPathAndFilename, $packageStatesCode, true);
+        // Cache identifier depends on package states file, therefore we invalidate the identifier
+        $this->cacheIdentifier = null;
 
         GeneralUtility::makeInstance(OpcodeCacheService::class)->clearAllActive($this->packageStatesPathAndFilename);
     }
@@ -808,7 +816,7 @@ class PackageManager implements SingletonInterface
     {
         $packageKey = $package->getPackageKey();
         if (!$this->isPackageRegistered($packageKey)) {
-            throw new Exception\InvalidPackageStateException('Package "' . $packageKey . '" is not registered.', 1338996142);
+            throw new InvalidPackageStateException('Package "' . $packageKey . '" is not registered.', 1338996142);
         }
         $this->unregisterPackageByPackageKey($packageKey);
     }
@@ -823,7 +831,7 @@ class PackageManager implements SingletonInterface
     public function reloadPackageInformation($packageKey)
     {
         if (!$this->isPackageRegistered($packageKey)) {
-            throw new Exception\InvalidPackageStateException('Package "' . $packageKey . '" is not registered.', 1436201329);
+            throw new InvalidPackageStateException('Package "' . $packageKey . '" is not registered.', 1436201329);
         }
 
         /** @var PackageInterface $package */
@@ -847,9 +855,11 @@ class PackageManager implements SingletonInterface
         $composerManifest = null;
         if (file_exists($manifestPath . 'composer.json')) {
             $json = file_get_contents($manifestPath . 'composer.json');
-            $composerManifest = json_decode($json);
+            if ($json !== false) {
+                $composerManifest = json_decode($json);
+            }
             if (!$composerManifest instanceof \stdClass) {
-                throw new Exception\InvalidPackageManifestException('The composer.json found for extension "' . PathUtility::basename($manifestPath) . '" is invalid!', 1439555561);
+                throw new InvalidPackageManifestException('The composer.json found for extension "' . PathUtility::basename($manifestPath) . '" is invalid!', 1439555561);
             }
         }
 
@@ -883,7 +893,7 @@ class PackageManager implements SingletonInterface
                 return $EM_CONF[$_EXTKEY];
             }
         }
-        throw new Exception\InvalidPackageManifestException('No valid ext_emconf.php file found for package "' . $packageKey . '".', 1360403545);
+        throw new InvalidPackageManifestException('No valid ext_emconf.php file found for package "' . $packageKey . '".', 1360403545);
     }
 
     /**
@@ -914,7 +924,7 @@ class PackageManager implements SingletonInterface
                         $composerManifest->require->{$requiredPackageKey} = $requiredPackageVersion;
                     }
                 } else {
-                    throw new Exception\InvalidPackageManifestException(sprintf('The extension "%s" has invalid version constraints in depends section. Extension key is missing!', $packageKey), 1439552058);
+                    throw new InvalidPackageManifestException(sprintf('The extension "%s" has invalid version constraints in depends section. Extension key is missing!', $packageKey), 1439552058);
                 }
             }
         }
@@ -924,7 +934,7 @@ class PackageManager implements SingletonInterface
                 if (!empty($conflictingPackageKey)) {
                     $composerManifest->conflict->$conflictingPackageKey = $conflictingPackageVersion;
                 } else {
-                    throw new Exception\InvalidPackageManifestException(sprintf('The extension "%s" has invalid version constraints in conflicts section. Extension key is missing!', $packageKey), 1439552059);
+                    throw new InvalidPackageManifestException(sprintf('The extension "%s" has invalid version constraints in conflicts section. Extension key is missing!', $packageKey), 1439552059);
                 }
             }
         }
@@ -934,17 +944,23 @@ class PackageManager implements SingletonInterface
                 if (!empty($suggestedPackageKey)) {
                     $composerManifest->suggest->$suggestedPackageKey = $suggestedPackageVersion;
                 } else {
-                    throw new Exception\InvalidPackageManifestException(sprintf('The extension "%s" has invalid version constraints in suggests section. Extension key is missing!', $packageKey), 1439552060);
+                    throw new InvalidPackageManifestException(sprintf('The extension "%s" has invalid version constraints in suggests section. Extension key is missing!', $packageKey), 1439552060);
                 }
             }
         }
         if (isset($extensionManagerConfiguration['autoload'])) {
-            $composerManifest->autoload = json_decode(json_encode($extensionManagerConfiguration['autoload']));
+            $autoload = json_encode($extensionManagerConfiguration['autoload']);
+            if ($autoload !== false) {
+                $composerManifest->autoload = json_decode($autoload);
+            }
         }
         // composer.json autoload-dev information must be discarded, as it may contain information only available after a composer install
         unset($composerManifest->{'autoload-dev'});
         if (isset($extensionManagerConfiguration['autoload-dev'])) {
-            $composerManifest->{'autoload-dev'} = json_decode(json_encode($extensionManagerConfiguration['autoload-dev']));
+            $autoloadDev = json_encode($extensionManagerConfiguration['autoload-dev']);
+            if ($autoloadDev !== false) {
+                $composerManifest->{'autoload-dev'} = json_decode($autoloadDev);
+            }
         }
 
         return $composerManifest;
@@ -987,7 +1003,7 @@ class PackageManager implements SingletonInterface
         $trace[] = $packageKey;
         $dependentPackageConstraints = $this->packages[$packageKey]->getPackageMetaData()->getConstraintsByType(MetaData::CONSTRAINT_TYPE_DEPENDS);
         foreach ($dependentPackageConstraints as $constraint) {
-            if ($constraint instanceof MetaData\PackageConstraint) {
+            if ($constraint instanceof PackageConstraint) {
                 $dependentPackageKey = $constraint->getValue();
                 if (in_array($dependentPackageKey, $dependentPackageKeys, true) === false && in_array($dependentPackageKey, $trace, true) === false) {
                     $dependentPackageKeys[] = $dependentPackageKey;
@@ -1016,7 +1032,7 @@ class PackageManager implements SingletonInterface
     protected function getPackageKeyFromManifest($manifest, $packagePath)
     {
         if (!is_object($manifest)) {
-            throw new Exception\InvalidPackageManifestException('Invalid composer manifest in package path: ' . $packagePath, 1348146451);
+            throw new InvalidPackageManifestException('Invalid composer manifest in package path: ' . $packagePath, 1348146451);
         }
         if (isset($manifest->type) && strpos($manifest->type, 'typo3-cms-') === 0) {
             $packageKey = PathUtility::basename($packagePath);
