@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Page;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,18 +13,24 @@ namespace TYPO3\CMS\Core\Page;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Page;
+
 use TYPO3\CMS\Backend\Routing\Router;
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Core\Cache\CacheManager;
 use TYPO3\CMS\Core\Cache\Frontend\FrontendInterface;
 use TYPO3\CMS\Core\Core\Environment;
+use TYPO3\CMS\Core\Information\Typo3Version;
 use TYPO3\CMS\Core\Localization\Locales;
 use TYPO3\CMS\Core\Localization\LocalizationFactory;
 use TYPO3\CMS\Core\MetaTag\MetaTagManagerRegistry;
+use TYPO3\CMS\Core\Package\PackageInterface;
 use TYPO3\CMS\Core\Package\PackageManager;
+use TYPO3\CMS\Core\Resource\RelativeCssPathFixer;
 use TYPO3\CMS\Core\Resource\ResourceCompressor;
 use TYPO3\CMS\Core\Service\MarkerBasedTemplateService;
 use TYPO3\CMS\Core\SingletonInterface;
+use TYPO3\CMS\Core\Utility\ArrayUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\PathUtility;
 
@@ -101,7 +106,7 @@ class PageRenderer implements SingletonInterface
 
     // Arrays containing associative array for the included files
     /**
-     * @var array
+     * @var array<string, array>
      */
     protected $jsFiles = [];
 
@@ -121,12 +126,12 @@ class PageRenderer implements SingletonInterface
     protected $jsFooterLibs = [];
 
     /**
-     * @var array
+     * @var array<string, array>
      */
     protected $cssFiles = [];
 
     /**
-     * @var array
+     * @var array<string, array>
      */
     protected $cssLibs = [];
 
@@ -222,7 +227,7 @@ class PageRenderer implements SingletonInterface
 
     // Static inline code blocks
     /**
-     * @var array
+     * @var array<string, array>
      */
     protected $jsInline = [];
 
@@ -232,7 +237,7 @@ class PageRenderer implements SingletonInterface
     protected $jsFooterInline = [];
 
     /**
-     * @var array
+     * @var array<string, array>
      */
     protected $cssInline = [];
 
@@ -297,12 +302,18 @@ class PageRenderer implements SingletonInterface
     /**
      * @var array
      */
-    protected $inlineJavascriptWrap = [];
+    protected $inlineJavascriptWrap = [
+        '<script type="text/javascript">' . LF . '/*<![CDATA[*/' . LF,
+        '/*]]>*/' . LF . '</script>' . LF
+    ];
 
     /**
      * @var array
      */
-    protected $inlineCssWrap = [];
+    protected $inlineCssWrap = [
+        '<style type="text/css">' . LF . '/*<![CDATA[*/' . LF . '<!-- ' . LF,
+        '-->' . LF . '/*]]>*/' . LF . '</style>' . LF
+    ];
 
     /**
      * Saves error messages generated during compression
@@ -338,26 +349,51 @@ class PageRenderer implements SingletonInterface
         if ($templateFile !== '') {
             $this->templateFile = $templateFile;
         }
-        $this->inlineJavascriptWrap = [
-            '<script type="text/javascript">' . LF . '/*<![CDATA[*/' . LF,
-            '/*]]>*/' . LF . '</script>' . LF
-        ];
-        $this->inlineCssWrap = [
-            '<style type="text/css">' . LF . '/*<![CDATA[*/' . LF . '<!-- ' . LF,
-            '-->' . LF . '/*]]>*/' . LF . '</style>' . LF
-        ];
 
         $this->metaTagRegistry = GeneralUtility::makeInstance(MetaTagManagerRegistry::class);
         $this->setMetaTag('name', 'generator', 'TYPO3 CMS');
     }
 
     /**
-     * Set restored meta tag managers as singletons
-     * so that uncached plugins can use them to add or remove meta tags
+     * @param array $newState
+     * @internal
      */
-    public function __wakeup()
+    public function updateState(array $newState): void
     {
-        GeneralUtility::setSingletonInstance(get_class($this->metaTagRegistry), $this->metaTagRegistry);
+        foreach ($newState as $var => $value) {
+            switch ($var) {
+            case 'locales':
+                break;
+            case 'metaTagRegistry':
+                $this->metaTagRegistry->updateState($value);
+                break;
+            default:
+                $this->{$var} = $value;
+                break;
+            }
+        }
+    }
+
+    /**
+     * @return array
+     * @internal
+     */
+    public function getState(): array
+    {
+        $state = [];
+        foreach (get_object_vars($this) as $var => $value) {
+            switch ($var) {
+            case 'locales':
+                break;
+            case 'metaTagRegistry':
+                $state[$var] = $this->metaTagRegistry->getState();
+                break;
+            default:
+                $state[$var] = $value;
+                break;
+            }
+        }
+        return $state;
     }
 
     /**
@@ -411,6 +447,13 @@ class PageRenderer implements SingletonInterface
     public function setRenderXhtml($enable)
     {
         $this->renderXhtml = $enable;
+
+        // Whenever XHTML gets disabled, remove the "text/javascript" type from the wrap
+        // since this is not needed and may lead to validation errors in the future.
+        $this->inlineJavascriptWrap = [
+            '<script' . ($enable ? ' type="text/javascript" ' : '') . '>' . LF . '/*<![CDATA[*/' . LF,
+            '/*]]>*/' . LF . '</script>' . LF
+        ];
     }
 
     /**
@@ -1291,7 +1334,7 @@ class PageRenderer implements SingletonInterface
 
         $packages = GeneralUtility::makeInstance(PackageManager::class)->getActivePackages();
         $isDevelopment = Environment::getContext()->isDevelopment();
-        $cacheIdentifier = 'requireJS_' . md5(implode(',', array_keys($packages)) . ($isDevelopment ? ':dev' : '') . GeneralUtility::getIndpEnv('TYPO3_REQUEST_SCRIPT'));
+        $cacheIdentifier = 'requireJS_' . sha1((string)(new Typo3Version()) . Environment::getProjectPath() . implode(',', array_keys($packages)) . ($isDevelopment ? ':dev' : '') . GeneralUtility::getIndpEnv('TYPO3_REQUEST_SCRIPT'));
         /** @var FrontendInterface $cache */
         $cache = static::$cache ?? GeneralUtility::makeInstance(CacheManager::class)->getCache('assets');
         $requireJsConfig = $cache->get($cacheIdentifier);
@@ -1312,7 +1355,7 @@ class PageRenderer implements SingletonInterface
      * resource folders plus some additional generic configuration.
      *
      * @param bool $isDevelopment
-     * @param array $packages
+     * @param array<string, PackageInterface> $packages
      * @return array The RequireJS configuration
      */
     protected function computeRequireJsConfig($isDevelopment, array $packages)
@@ -1328,9 +1371,8 @@ class PageRenderer implements SingletonInterface
         $corePath = PathUtility::getAbsoluteWebPath($corePath);
         // first, load all paths for the namespaces, and configure contrib libs.
         $requireJsConfig['public']['paths'] = [
-            'jquery' => $corePath . '/jquery/jquery',
+            'jquery' => $corePath . 'jquery/jquery',
             'jquery-ui' => $corePath . 'jquery-ui',
-            'datatables' => $corePath . 'jquery.dataTables',
             'nprogress' => $corePath . 'nprogress',
             'moment' => $corePath . 'moment',
             'cropper' => $corePath . 'cropper.min',
@@ -1339,11 +1381,17 @@ class PageRenderer implements SingletonInterface
             'twbs/bootstrap-datetimepicker' => $corePath . 'bootstrap-datetimepicker',
             'autosize' => $corePath . 'autosize',
             'taboverride' => $corePath . 'taboverride.min',
-            'twbs/bootstrap-slider' => $corePath . 'bootstrap-slider.min',
             'jquery/autocomplete' => $corePath . 'jquery.autocomplete',
+            'jquery/minicolors' => $corePath . 'jquery.minicolors',
             'd3' => $corePath . 'd3/d3',
             'Sortable' => $corePath . 'Sortable.min',
-            'broadcastchannel' => $corePath . '/broadcastchannel-polyfill',
+            'sortablejs' => $corePath . 'Sortable.min',
+            'tablesort' => $corePath . 'tablesort',
+            'tablesort.dotsep' => $corePath . 'tablesort.dotsep',
+            'broadcastchannel' => $corePath . 'broadcastchannel-polyfill',
+        ];
+        $requireJsConfig['public']['shim'] = [
+            'tablesort.dotsep' => ['deps' => ['tablesort']],
         ];
         $requireJsConfig['public']['waitSeconds'] = 30;
         $requireJsConfig['public']['typo3BaseUrl'] = false;
@@ -1411,7 +1459,7 @@ class PageRenderer implements SingletonInterface
             // Load RequireJS in backend context at first. Doing this in FE could break the output
             $this->loadRequireJs();
         }
-        \TYPO3\CMS\Core\Utility\ArrayUtility::mergeRecursiveWithOverrule($this->requireJsConfig, $configuration);
+        $this->requireJsConfig = array_merge_recursive($this->requireJsConfig, $configuration);
     }
 
     /**
@@ -1507,7 +1555,7 @@ class PageRenderer implements SingletonInterface
             unset($this->requireJsConfig['paths'][$baseModuleName]);
         }
         // execute the main module, and load a possible callback function
-        $javaScriptCode = 'require(["' . $mainModuleName . '"]';
+        $javaScriptCode = 'require([' . GeneralUtility::quoteJSvalue($mainModuleName) . ']';
         if ($callBackFunction !== null) {
             $inlineCodeKey .= sha1($callBackFunction);
             $javaScriptCode .= ', ' . $callBackFunction;
@@ -1794,6 +1842,7 @@ class PageRenderer implements SingletonInterface
         $jsFiles .= $assetRenderer->renderJavaScript(true);
         $jsFooterFiles .= $assetRenderer->renderJavaScript();
         $cssInline .= $assetRenderer->renderInlineStyleSheets(true);
+        // append inline CSS to footer (as there is no cssFooterInline)
         $jsFooterFiles .= $assetRenderer->renderInlineStyleSheets();
         $cssLibs .= $assetRenderer->renderStyleSheets(true, $this->endingSlash);
         $cssFiles .= $assetRenderer->renderStyleSheets(false, $this->endingSlash);
@@ -1891,7 +1940,7 @@ class PageRenderer implements SingletonInterface
     {
         $templateFile = GeneralUtility::getFileAbsFileName($this->templateFile);
         if (is_file($templateFile)) {
-            $template = file_get_contents($templateFile);
+            $template = (string)file_get_contents($templateFile);
             if ($this->removeLineBreaksFromTemplate) {
                 $template = strtr($template, [LF => '', CR => '']);
             }
@@ -2079,14 +2128,14 @@ class PageRenderer implements SingletonInterface
      */
     private function createCssTag(array $properties, string $file): string
     {
-        if ($properties['inline'] && @is_file($file)) {
+        if (($properties['inline'] ?? false) && @is_file($file)) {
             $tag = $this->createInlineCssTagFromFile($file, $properties);
         } else {
             $href = $this->getStreamlinedFileName($file);
             $tag = '<link rel="' . htmlspecialchars($properties['rel'])
                 . '" type="text/css" href="' . htmlspecialchars($href)
                 . '" media="' . htmlspecialchars($properties['media']) . '"'
-                . ($properties['title'] ? ' title="' . htmlspecialchars($properties['title']) . '"' : '')
+                . (($properties['title'] ?? false) ? ' title="' . htmlspecialchars($properties['title']) . '"' : '')
                 . $this->endingSlash . '>';
         }
         if ($properties['allWrap']) {
@@ -2132,12 +2181,13 @@ class PageRenderer implements SingletonInterface
         if (!empty($this->jsLibs)) {
             foreach ($this->jsLibs as $properties) {
                 $properties['file'] = $this->getStreamlinedFileName($properties['file']);
+                $type = $properties['type'] ? ' type="' . htmlspecialchars($properties['type']) . '"' : '';
                 $async = $properties['async'] ? ' async="async"' : '';
                 $defer = $properties['defer'] ? ' defer="defer"' : '';
                 $nomodule = $properties['nomodule'] ? ' nomodule="nomodule"' : '';
                 $integrity = $properties['integrity'] ? ' integrity="' . htmlspecialchars($properties['integrity']) . '"' : '';
                 $crossorigin = $properties['crossorigin'] ? ' crossorigin="' . htmlspecialchars($properties['crossorigin']) . '"' : '';
-                $tag = '<script src="' . htmlspecialchars($properties['file']) . '" type="' . htmlspecialchars($properties['type']) . '"' . $async . $defer . $integrity . $crossorigin . $nomodule . '></script>';
+                $tag = '<script src="' . htmlspecialchars($properties['file']) . '"' . $type . $async . $defer . $integrity . $crossorigin . $nomodule . '></script>';
                 if ($properties['allWrap']) {
                     $wrapArr = explode($properties['splitChar'] ?: '|', $properties['allWrap'], 2);
                     $tag = $wrapArr[0] . $tag . $wrapArr[1];
@@ -2179,10 +2229,10 @@ class PageRenderer implements SingletonInterface
                 $file = $this->getStreamlinedFileName($file);
                 $type = $properties['type'] ? ' type="' . htmlspecialchars($properties['type']) . '"' : '';
                 $async = $properties['async'] ? ' async="async"' : '';
-                $defer = $properties['defer'] ? ' defer="defer"' : '';
-                $nomodule = $properties['nomodule'] ? ' nomodule="nomodule"' : '';
-                $integrity = $properties['integrity'] ? ' integrity="' . htmlspecialchars($properties['integrity']) . '"' : '';
-                $crossorigin = $properties['crossorigin'] ? ' crossorigin="' . htmlspecialchars($properties['crossorigin']) . '"' : '';
+                $defer = ($properties['defer'] ?? false) ? ' defer="defer"' : '';
+                $nomodule = ($properties['nomodule'] ?? false) ? ' nomodule="nomodule"' : '';
+                $integrity = ($properties['integrity'] ?? false) ? ' integrity="' . htmlspecialchars($properties['integrity']) . '"' : '';
+                $crossorigin = ($properties['crossorigin'] ?? false) ? ' crossorigin="' . htmlspecialchars($properties['crossorigin']) . '"' : '';
                 $tag = '<script src="' . htmlspecialchars($file) . '"' . $type . $async . $defer . $integrity . $crossorigin . $nomodule . '></script>';
                 if ($properties['allWrap']) {
                     $wrapArr = explode($properties['splitChar'] ?: '|', $properties['allWrap'], 2);
@@ -2318,7 +2368,7 @@ class PageRenderer implements SingletonInterface
             if ($this->lang !== 'default' && isset($tempLL[$language])) {
                 // Merge current language labels onto labels from previous language
                 // This way we have a labels with fall back applied
-                \TYPO3\CMS\Core\Utility\ArrayUtility::mergeRecursiveWithOverrule($localLanguage[$this->lang], $tempLL[$language], true, false);
+                ArrayUtility::mergeRecursiveWithOverrule($localLanguage[$this->lang], $tempLL[$language], true, false);
             }
         }
 
@@ -2505,7 +2555,7 @@ class PageRenderer implements SingletonInterface
         if (strpos($file, 'EXT:') === 0) {
             $file = GeneralUtility::getFileAbsFileName($file);
             // as the path is now absolute, make it "relative" to the current script to stay compatible
-            $file = PathUtility::getRelativePathTo($file);
+            $file = PathUtility::getRelativePathTo($file) ?? '';
             $file = rtrim($file, '/');
         } else {
             $file = GeneralUtility::resolveBackPath($file);
@@ -2655,13 +2705,21 @@ class PageRenderer implements SingletonInterface
     protected function createInlineCssTagFromFile(string $file, array $properties): string
     {
         $cssInline = file_get_contents($file);
-
+        if ($cssInline === false) {
+            return '';
+        }
+        $cssInlineFix = $this->getPathFixer()->fixRelativeUrlPaths($cssInline, '/' . PathUtility::dirname($file) . '/');
         return '<style type="text/css"'
             . ' media="' . htmlspecialchars($properties['media']) . '"'
             . ($properties['title'] ? ' title="' . htmlspecialchars($properties['title']) . '"' : '')
             . '>' . LF
             . '/*<![CDATA[*/' . LF . '<!-- ' . LF
-            . $cssInline
+            . $cssInlineFix
             . '-->' . LF . '/*]]>*/' . LF . '</style>' . LF;
     }
+
+    protected function getPathFixer(): RelativeCssPathFixer
+    {
+        return GeneralUtility::makeInstance(RelativeCssPathFixer::class);
+    }
 }
