@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource\Driver;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,12 +13,21 @@ namespace TYPO3\CMS\Core\Resource\Driver;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource\Driver;
+
 use Psr\Http\Message\ResponseInterface;
 use TYPO3\CMS\Core\Charset\CharsetConverter;
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Http\Response;
 use TYPO3\CMS\Core\Http\SelfEmittableLazyOpenStream;
 use TYPO3\CMS\Core\Resource\Exception;
+use TYPO3\CMS\Core\Resource\Exception\ExistingTargetFileNameException;
+use TYPO3\CMS\Core\Resource\Exception\FileOperationErrorException;
+use TYPO3\CMS\Core\Resource\Exception\FolderDoesNotExistException;
+use TYPO3\CMS\Core\Resource\Exception\InvalidConfigurationException;
+use TYPO3\CMS\Core\Resource\Exception\InvalidFileNameException;
+use TYPO3\CMS\Core\Resource\Exception\InvalidPathException;
+use TYPO3\CMS\Core\Resource\Exception\ResourcePermissionsUnavailableException;
 use TYPO3\CMS\Core\Resource\FolderInterface;
 use TYPO3\CMS\Core\Resource\ResourceStorage;
 use TYPO3\CMS\Core\Type\File\FileInfo;
@@ -123,7 +131,9 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
     {
         // only calculate baseURI if the storage does not enforce jumpUrl Script
         if ($this->hasCapability(ResourceStorage::CAPABILITY_PUBLIC)) {
-            if (GeneralUtility::isFirstPartOfStr($this->absoluteBasePath, Environment::getPublicPath())) {
+            if (!empty($this->configuration['baseUri'])) {
+                $this->baseUri = rtrim($this->configuration['baseUri'], '/') . '/';
+            } elseif (GeneralUtility::isFirstPartOfStr($this->absoluteBasePath, Environment::getPublicPath())) {
                 // use site-relative URLs
                 $temporaryBaseUri = rtrim(PathUtility::stripPathSitePrefix($this->absoluteBasePath), '/');
                 if ($temporaryBaseUri !== '') {
@@ -132,8 +142,6 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
                     $temporaryBaseUri = implode('/', $uriParts) . '/';
                 }
                 $this->baseUri = $temporaryBaseUri;
-            } elseif (isset($this->configuration['baseUri']) && GeneralUtility::isValidUrl($this->configuration['baseUri'])) {
-                $this->baseUri = rtrim($this->configuration['baseUri'], '/') . '/';
             }
         }
     }
@@ -149,7 +157,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
     protected function calculateBasePath(array $configuration)
     {
         if (!array_key_exists('basePath', $configuration) || empty($configuration['basePath'])) {
-            throw new Exception\InvalidConfigurationException(
+            throw new InvalidConfigurationException(
                 'Configuration must contain base path.',
                 1346510477
             );
@@ -164,7 +172,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
         $absoluteBasePath = $this->canonicalizeAndCheckFilePath($absoluteBasePath);
         $absoluteBasePath = rtrim($absoluteBasePath, '/') . '/';
         if (!is_dir($absoluteBasePath)) {
-            throw new Exception\InvalidConfigurationException(
+            throw new InvalidConfigurationException(
                 'Base path "' . $absoluteBasePath . '" does not exist or is no directory.',
                 1299233097
             );
@@ -178,7 +186,6 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
      *
      * @param string $identifier
      * @return string|null NULL if file is missing or deleted, the generated url otherwise
-     * @throws \TYPO3\CMS\Core\Resource\Exception
      */
     public function getPublicUrl($identifier)
     {
@@ -280,7 +287,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
         $folderIdentifier = $this->canonicalizeAndCheckFolderIdentifier($folderIdentifier);
 
         if (!$this->folderExists($folderIdentifier)) {
-            throw new Exception\FolderDoesNotExistException(
+            throw new FolderDoesNotExistException(
                 'Folder "' . $folderIdentifier . '" does not exist.',
                 1314516810
             );
@@ -312,16 +319,16 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
         // Handle UTF-8 characters
         if ($GLOBALS['TYPO3_CONF_VARS']['SYS']['UTF8filesystem']) {
             // Allow ".", "-", 0-9, a-z, A-Z and everything beyond U+C0 (latin capital letter a with grave)
-            $cleanFileName = preg_replace('/[' . self::UNSAFE_FILENAME_CHARACTER_EXPRESSION . ']/u', '_', trim($fileName));
+            $cleanFileName = (string)preg_replace('/[' . self::UNSAFE_FILENAME_CHARACTER_EXPRESSION . ']/u', '_', trim($fileName));
         } else {
             $fileName = GeneralUtility::makeInstance(CharsetConverter::class)->specCharsToASCII($charset, $fileName);
             // Replace unwanted characters with underscores
-            $cleanFileName = preg_replace('/[' . self::UNSAFE_FILENAME_CHARACTER_EXPRESSION . '\\xC0-\\xFF]/', '_', trim($fileName));
+            $cleanFileName = (string)preg_replace('/[' . self::UNSAFE_FILENAME_CHARACTER_EXPRESSION . '\\xC0-\\xFF]/', '_', trim($fileName));
         }
         // Strip trailing dots and return
         $cleanFileName = rtrim($cleanFileName, '.');
         if ($cleanFileName === '') {
-            throw new Exception\InvalidFileNameException(
+            throw new InvalidFileNameException(
                 'File name ' . $fileName . ' is invalid.',
                 1320288991
             );
@@ -394,7 +401,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
                     // item here
                     --$c;
                 }
-            } catch (Exception\InvalidPathException $e) {
+            } catch (InvalidPathException $e) {
             }
         }
         return $items;
@@ -552,6 +559,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
                 || ($isFile && !$includeFiles) // skip files if they are excluded
                 || ($isDirectory && !$includeDirs) // skip directories if they are excluded
                 || $entry->getFilename() === '' // skip empty entries
+                || !$entry->isReadable() // skip unreadable entries
             ) {
                 $iterator->next();
                 continue;
@@ -609,10 +617,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
                     $sortingKey = pathinfo($entryArray['name'], PATHINFO_EXTENSION);
                     break;
                 case 'tstamp':
-                    $sortingKey = '0';
-                    if ($entryArray['type'] === 'file') {
-                        $sortingKey = $this->getSpecificFileInformation($fullPath, $dir, 'mtime');
-                    }
+                    $sortingKey = $this->getSpecificFileInformation($fullPath, $dir, 'mtime');
                     // Add a character for a natural order sorting
                     $sortingKey .= 't';
                     break;
@@ -948,7 +953,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
         $sourcePath = $this->getAbsolutePath($fileIdentifier);
         $temporaryPath = $this->getTemporaryPathForFile($fileIdentifier);
         $result = copy($sourcePath, $temporaryPath);
-        touch($temporaryPath, filemtime($sourcePath));
+        touch($temporaryPath, (int)filemtime($sourcePath));
         if ($result === false) {
             throw new \RuntimeException(
                 'Copying file "' . $fileIdentifier . '" to temporary path "' . $temporaryPath . '" failed.',
@@ -970,7 +975,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
     {
         $destinationFile = $recycleDirectory . '/' . PathUtility::basename($filePath);
         if (file_exists($destinationFile)) {
-            $timeStamp = \DateTimeImmutable::createFromFormat('U.u', microtime(true))->format('YmdHisu');
+            $timeStamp = \DateTimeImmutable::createFromFormat('U.u', (string)microtime(true))->format('YmdHisu');
             $destinationFile = $recycleDirectory . '/' . $timeStamp . '_' . PathUtility::basename($filePath);
         }
         $result = rename($filePath, $destinationFile);
@@ -1010,7 +1015,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
                 );
             }
             if (!file_exists($this->getAbsolutePath($newIdentifier))) {
-                throw new Exception\FileOperationErrorException(
+                throw new FileOperationErrorException(
                     sprintf('File "%1$s" was not found (should have been copied/moved from "%2$s").', $newIdentifier, $oldIdentifier),
                     1330119453
                 );
@@ -1087,7 +1092,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
                 if ($result === false) {
                     // rollback
                     GeneralUtility::rmdir($targetFolderIdentifier, true);
-                    throw new Exception\FileOperationErrorException(
+                    throw new FileOperationErrorException(
                         'Copying resource "' . $copySourcePath . '" to "' . $copyTargetPath . '" failed.',
                         1330119452
                     );
@@ -1116,7 +1121,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
         $newIdentifier = $this->canonicalizeAndCheckFileIdentifier($newIdentifier);
         // The target should not exist already
         if ($this->fileExists($newIdentifier)) {
-            throw new Exception\ExistingTargetFileNameException(
+            throw new ExistingTargetFileNameException(
                 'The target file "' . $newIdentifier . '" already exists.',
                 1320291063
             );
@@ -1211,7 +1216,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
             $result = GeneralUtility::rmdir($folderPath, $deleteRecursively);
         }
         if ($result === false) {
-            throw new Exception\FileOperationErrorException(
+            throw new FileOperationErrorException(
                 'Deleting folder "' . $folderIdentifier . '" failed.',
                 1330119451
             );
@@ -1229,6 +1234,9 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
     {
         $path = $this->getAbsolutePath($folderIdentifier);
         $dirHandle = opendir($path);
+        if ($dirHandle === false) {
+            return true;
+        }
         while ($entry = readdir($dirHandle)) {
             if ($entry !== '.' && $entry !== '..') {
                 closedir($dirHandle);
@@ -1269,7 +1277,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
         $path = $this->getAbsolutePath($identifier);
         $permissionBits = fileperms($path);
         if ($permissionBits === false) {
-            throw new Exception\ResourcePermissionsUnavailableException('Error while fetching permissions for ' . $path, 1319455097);
+            throw new ResourcePermissionsUnavailableException('Error while fetching permissions for ' . $path, 1319455097);
         }
         return [
             'r' => (bool)is_readable($path),
@@ -1385,7 +1393,7 @@ class LocalDriver extends AbstractHierarchicalFilesystemDriver implements Stream
      */
     public function dumpFileContents($identifier)
     {
-        readfile($this->getAbsolutePath($this->canonicalizeAndCheckFileIdentifier($identifier)), 0);
+        readfile($this->getAbsolutePath($this->canonicalizeAndCheckFileIdentifier($identifier)), false);
     }
 
     /**
