@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource\Exception;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,10 +13,13 @@ namespace TYPO3\CMS\Core\Resource\Exception;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource\Exception;
+
+use TYPO3\CMS\Core\Resource\Exception;
+
 /**
  * An exception when something is wrong with the file handling
- *
  */
-class InsufficientUserPermissionsException extends \TYPO3\CMS\Core\Resource\Exception
+class InsufficientUserPermissionsException extends Exception
 {
 }
