@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Core\Resource\Exception;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,10 +15,14 @@ namespace TYPO3\CMS\Core\Resource\Exception;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource\Exception;
+
+use TYPO3\CMS\Core\Resource\Exception;
+
 /**
  * An exception when something is wrong with the Hash
  * Is thrown for example when the driver returns an unexpected (non-string) hash value
  */
-class InvalidHashException extends \TYPO3\CMS\Core\Resource\Exception
+class InvalidHashException extends Exception
 {
 }
