@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Resource;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource;
+
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
 /**
@@ -93,7 +94,13 @@ class File extends AbstractFile
      */
     public function getProperties(): array
     {
-        return array_merge(parent::getProperties(), array_diff_key($this->getMetaData()->get(), parent::getProperties()));
+        return array_merge(
+            parent::getProperties(),
+            array_diff_key($this->getMetaData()->get(), parent::getProperties()),
+            [
+                'metadata_uid' => $this->getMetaData()->get()['uid']
+            ]
+        );
     }
 
     /**
@@ -224,7 +231,7 @@ class File extends AbstractFile
     /**
      * Check if a file operation (= action) is allowed for this file
      *
-     * @param 	string	$action, can be read, write, delete
+     * @param string $action can be read, write, delete
      * @return bool
      */
     public function checkActionPermission($action)
@@ -334,15 +341,7 @@ class File extends AbstractFile
     }
 
     /**
-     * @return Index\FileIndexRepository
-     */
-    protected function getFileIndexRepository()
-    {
-        return GeneralUtility::makeInstance(Index\FileIndexRepository::class);
-    }
-
-    /**
-     * @param $key
+     * @param string $key
      * @internal Only for use in Repositories and indexer
      * @return mixed
      */
