@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,10 @@ namespace TYPO3\CMS\Core\Resource;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource;
+
+use TYPO3\CMS\Core\Resource\Exception\InsufficientFolderAccessPermissionsException;
+use TYPO3\CMS\Core\Resource\Exception\ResourcePermissionsUnavailableException;
 use TYPO3\CMS\Core\Resource\Search\FileSearchDemand;
 use TYPO3\CMS\Core\Resource\Search\Result\FileSearchResultInterface;
 use TYPO3\CMS\Core\Utility\PathUtility;
@@ -77,8 +80,8 @@ class Folder implements FolderInterface
      * Initialization of the folder
      *
      * @param ResourceStorage $storage
-     * @param $identifier
-     * @param $name
+     * @param string $identifier
+     * @param string $name
      */
     public function __construct(ResourceStorage $storage, $identifier, $name)
     {
@@ -122,7 +125,7 @@ class Folder implements FolderInterface
         if ($this->identifier !== $rootId) {
             try {
                 $readablePath = $this->getParentFolder()->getReadablePath($rootId);
-            } catch (Exception\InsufficientFolderAccessPermissionsException $e) {
+            } catch (InsufficientFolderAccessPermissionsException $e) {
                 // May no access to parent folder (e.g. because of mount point)
                 $readablePath = '/';
             }
@@ -425,7 +428,7 @@ class Folder implements FolderInterface
     {
         try {
             return $this->getStorage()->checkFolderActionPermission($action, $this);
-        } catch (Exception\ResourcePermissionsUnavailableException $e) {
+        } catch (ResourcePermissionsUnavailableException $e) {
             return false;
         }
     }
@@ -518,7 +521,7 @@ class Folder implements FolderInterface
     /**
      * Returns the role of this folder (if any). See FolderInterface::ROLE_* constants for possible values.
      *
-     * @return int
+     * @return string
      */
     public function getRole()
     {
@@ -532,7 +535,7 @@ class Folder implements FolderInterface
      *
      * The parent folder of the root folder is the root folder.
      *
-     * @return Folder
+     * @return FolderInterface
      */
     public function getParentFolder()
     {
