@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource\Hook;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +13,10 @@ namespace TYPO3\CMS\Core\Resource\Hook;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource\Hook;
+
 use Psr\Http\Message\ResponseInterface;
+use TYPO3\CMS\Core\Resource\ResourceInterface;
 
 /**
  * Interface for FileDumpEID Hook to perform some custom security/access checks
@@ -31,5 +33,5 @@ interface FileDumpEIDHookInterface
      * @param \TYPO3\CMS\Core\Resource\ResourceInterface $file
      * @return ResponseInterface|null
      */
-    public function checkFileAccess(\TYPO3\CMS\Core\Resource\ResourceInterface $file);
+    public function checkFileAccess(ResourceInterface $file);
 }
