@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,10 @@ namespace TYPO3\CMS\Core\Resource;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource;
+
+use TYPO3\CMS\Core\Resource\Exception\InsufficientFolderReadPermissionsException;
+
 /**
  * A representation for an inaccessible folder.
  *
@@ -32,7 +35,7 @@ class InaccessibleFolder extends Folder
      */
     protected function throwInaccessibleException()
     {
-        throw new Exception\InsufficientFolderReadPermissionsException(
+        throw new InsufficientFolderReadPermissionsException(
             'You are trying to use a method on the inaccessible folder "' . $this->getName() . '".',
             1390290029
         );
@@ -62,6 +65,7 @@ class InaccessibleFolder extends Folder
     public function getPublicUrl($relativeToCurrentScript = false)
     {
         $this->throwInaccessibleException();
+        return null;
     }
 
     /**
