@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,9 @@ namespace TYPO3\CMS\Core\Resource;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource;
+
+use TYPO3\CMS\Core\Resource\Processing\TaskTypeRegistry;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
 
@@ -103,6 +105,14 @@ class ProcessedFile extends AbstractFile
      */
     protected $updated = false;
 
+    /**
+     * If this is set, this URL is used as public URL
+     * This MUST be a fully qualified URL including host
+     *
+     * @var string
+     */
+    protected $processingUrl = '';
+
     /**
      * Constructor for a processed file object. Should normally not be used
      * directly, use the corresponding factory methods instead.
@@ -122,7 +132,7 @@ class ProcessedFile extends AbstractFile
         if (is_array($databaseRow)) {
             $this->reconstituteFromDatabaseRecord($databaseRow);
         }
-        $this->taskTypeRegistry = GeneralUtility::makeInstance(Processing\TaskTypeRegistry::class);
+        $this->taskTypeRegistry = GeneralUtility::makeInstance(TaskTypeRegistry::class);
     }
 
     /**
@@ -139,6 +149,7 @@ class ProcessedFile extends AbstractFile
         $this->identifier = $databaseRow['identifier'];
         $this->name = $databaseRow['name'];
         $this->properties = $databaseRow;
+        $this->processingUrl = $databaseRow['processing_url'] ?? '';
 
         if (!empty($databaseRow['storage']) && (int)$this->storage->getUid() !== (int)$databaseRow['storage']) {
             $this->storage = GeneralUtility::makeInstance(ResourceFactory::class)->getStorageObject($databaseRow['storage']);
@@ -182,7 +193,7 @@ class ProcessedFile extends AbstractFile
      */
     public function updateWithLocalFile($filePath)
     {
-        if ($this->identifier === null) {
+        if (empty($this->identifier)) {
             throw new \RuntimeException('Cannot update original file!', 1350582054);
         }
         $processingFolder = $this->originalFile->getStorage()->getProcessingFolder($this->originalFile);
@@ -199,7 +210,7 @@ class ProcessedFile extends AbstractFile
     }
 
     /*****************************************
-     * STORAGE AND MANAGEMENT RELATED METHDOS
+     * STORAGE AND MANAGEMENT RELATED METHODS
      *****************************************/
     /**
      * Returns TRUE if this file is indexed
@@ -348,13 +359,20 @@ class ProcessedFile extends AbstractFile
         if (array_key_exists('uid', $properties) && MathUtility::canBeInterpretedAsInteger($properties['uid'])) {
             $this->properties['uid'] = $properties['uid'];
         }
+        if (isset($properties['processing_url'])) {
+            $this->processingUrl = $properties['processing_url'];
+        }
 
         // @todo we should have a blacklist of properties that might not be updated
         $this->properties = array_merge($this->properties, $properties);
 
         // @todo when should this update be done?
         if (!$this->isUnchanged() && $this->exists()) {
-            $this->properties = array_merge($this->properties, $this->storage->getFileInfo($this));
+            $storage = $this->storage;
+            if ($this->usesOriginalFile()) {
+                $storage = $this->originalFile->getStorage();
+            }
+            $this->properties = array_merge($this->properties, $storage->getFileInfo($this));
         }
     }
 
@@ -368,9 +386,9 @@ class ProcessedFile extends AbstractFile
         if ($this->usesOriginalFile()) {
             $properties = $this->originalFile->getProperties();
             unset($properties['uid']);
-            unset($properties['pid']);
-            unset($properties['identifier']);
-            unset($properties['name']);
+            $properties['identifier'] = '';
+            $properties['name'] = null;
+            $properties['processing_url'] = '';
 
             // Use width + height set in processed file
             $properties['width'] = $this->properties['width'];
@@ -411,15 +429,22 @@ class ProcessedFile extends AbstractFile
         // @todo check if some of these properties can/should be set in a generic update method
         $this->identifier = $this->originalFile->getIdentifier();
         $this->updated = true;
+        $this->processingUrl = '';
         $this->originalFileSha1 = $this->originalFile->getSha1();
     }
 
+    public function updateProcessingUrl(string $url): void
+    {
+        $this->updated = true;
+        $this->processingUrl = $url;
+    }
+
     /**
      * @return bool
      */
     public function usesOriginalFile()
     {
-        return $this->identifier === null || $this->identifier === $this->originalFile->getIdentifier();
+        return empty($this->identifier) || $this->identifier === $this->originalFile->getIdentifier();
     }
 
     /**
@@ -542,9 +567,9 @@ class ProcessedFile extends AbstractFile
      * @return Processing\TaskInterface
      * @throws \RuntimeException
      */
-    public function getTask()
+    public function getTask(): Processing\TaskInterface
     {
-        if ($this->task == null) {
+        if ($this->task === null) {
             $this->task = $this->taskTypeRegistry->getTaskForType($this->taskType, $this, $this->processingConfiguration);
         }
 
@@ -573,6 +598,9 @@ class ProcessedFile extends AbstractFile
      */
     public function getPublicUrl($relativeToCurrentScript = false)
     {
+        if ($this->processingUrl) {
+            return $this->processingUrl;
+        }
         if ($this->deleted) {
             return null;
         }
