@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource\Processing;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,13 +13,14 @@ namespace TYPO3\CMS\Core\Resource\Processing;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource\Processing;
+
 use TYPO3\CMS\Core\Imaging\GraphicalFunctions;
 use TYPO3\CMS\Core\Imaging\ImageMagickFile;
 use TYPO3\CMS\Core\Resource\File;
 use TYPO3\CMS\Core\Utility\CommandUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
-use TYPO3\CMS\Frontend\Imaging\GifBuilder;
 
 /**
  * Helper for creating local image previews using TYPO3s image processing classes.
@@ -48,7 +48,14 @@ class LocalPreviewHelper
         $configuration = array_replace(static::$defaultConfiguration, $configuration);
         $configuration['width'] = MathUtility::forceIntegerInRange($configuration['width'], 1, 1000);
         $configuration['height'] = MathUtility::forceIntegerInRange($configuration['height'], 1, 1000);
-        return $configuration;
+
+        return array_filter(
+            $configuration,
+            function ($value, $name) {
+                return !empty($value) && in_array($name, ['width', 'height'], true);
+            },
+            ARRAY_FILTER_USE_BOTH
+        );
     }
 
     /**
@@ -85,6 +92,19 @@ class LocalPreviewHelper
         return $this->generatePreviewFromFile($sourceFile, $configuration, $this->getTemporaryFilePath($task));
     }
 
+    /**
+     * Does the heavy lifting prescribed in processTask()
+     * except that the processing can be performed on any given local image
+     *
+     * @param TaskInterface $task
+     * @param string $localFile
+     * @return array|null
+     */
+    public function processWithLocalFile(TaskInterface $task, string $localFile): ?array
+    {
+        return $this->generatePreviewFromLocalFile($localFile, $task->getConfiguration(), $this->getTemporaryFilePath($task));
+    }
+
     /**
      * Returns the path to a temporary file for processing
      *
@@ -104,12 +124,10 @@ class LocalPreviewHelper
      * @param string $targetFilePath Output file path
      * @return array
      */
-    protected function generatePreviewFromFile(File $file, array $configuration, $targetFilePath)
+    protected function generatePreviewFromFile(File $file, array $configuration, string $targetFilePath)
     {
         // Check file extension
-        if ($file->getType() !== File::FILETYPE_IMAGE
-            && !GeneralUtility::inList($GLOBALS['TYPO3_CONF_VARS']['GFX']['imagefile_ext'], $file->getExtension())
-        ) {
+        if ($file->getType() !== File::FILETYPE_IMAGE && !$file->isImage()) {
             // Create a default image
             $graphicalFunctions = GeneralUtility::makeInstance(GraphicalFunctions::class);
             $graphicalFunctions->getTemporaryImageWithText(
@@ -123,46 +141,46 @@ class LocalPreviewHelper
             ];
         }
 
-        $originalFileName = $file->getForLocalProcessing(false);
-        if ($file->getExtension() === 'svg') {
-            $gifBuilder = GeneralUtility::makeInstance(GifBuilder::class);
-            $info = $gifBuilder->getImageDimensions($originalFileName);
-            $newInfo = $gifBuilder->getImageScale($info, $configuration['width'], $configuration['height'], []);
-            $result = [
-                'width' => $newInfo[0],
-                'height' => $newInfo[1],
-                'filePath' => '' // no file = use original
-            ];
-        } else {
-            // Create the temporary file
-            if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['processor_enabled']) {
-                $arguments = CommandUtility::escapeShellArguments([
-                    'width' => $configuration['width'],
-                    'height' => $configuration['height'],
-                ]);
-                $parameters = '-sample ' . $arguments['width'] . 'x' . $arguments['height']
-                    . ' ' . ImageMagickFile::fromFilePath($originalFileName, 0)
-                    . ' ' . CommandUtility::escapeShellArgument($targetFilePath);
+        return $this->generatePreviewFromLocalFile($file->getForLocalProcessing(false), $configuration, $targetFilePath);
+    }
 
-                $cmd = CommandUtility::imageMagickCommand('convert', $parameters) . ' 2>&1';
-                CommandUtility::exec($cmd);
+    /**
+     * Generates a preview for a local file
+     *
+     * @param string $originalFileName Optional input file path
+     * @param array $configuration Processing configuration
+     * @param string $targetFilePath Output file path
+     * @return array
+     */
+    protected function generatePreviewFromLocalFile(string $originalFileName, array $configuration, string $targetFilePath)
+    {
+        // Create the temporary file
+        if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['processor_enabled']) {
+            $arguments = CommandUtility::escapeShellArguments([
+                'width' => $configuration['width'],
+                'height' => $configuration['height'],
+            ]);
+            $parameters = '-sample ' . $arguments['width'] . 'x' . $arguments['height']
+                . ' ' . ImageMagickFile::fromFilePath($originalFileName, 0)
+                . ' ' . CommandUtility::escapeShellArgument($targetFilePath);
 
-                if (!file_exists($targetFilePath)) {
-                    // Create an error gif
-                    $graphicalFunctions = GeneralUtility::makeInstance(GraphicalFunctions::class);
-                    $graphicalFunctions->getTemporaryImageWithText(
-                        $targetFilePath,
-                        'No thumb',
-                        'generated!',
-                        $file->getName()
-                    );
-                }
+            $cmd = CommandUtility::imageMagickCommand('convert', $parameters) . ' 2>&1';
+            CommandUtility::exec($cmd);
+
+            if (!file_exists($targetFilePath)) {
+                // Create an error gif
+                $graphicalFunctions = GeneralUtility::makeInstance(GraphicalFunctions::class);
+                $graphicalFunctions->getTemporaryImageWithText(
+                    $targetFilePath,
+                    'No thumb',
+                    'generated!',
+                    ''
+                );
             }
-            $result = [
-                'filePath' => $targetFilePath,
-            ];
         }
 
-        return $result;
+        return [
+            'filePath' => $targetFilePath,
+        ];
     }
 }
