@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Resource;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,14 +13,21 @@ namespace TYPO3\CMS\Core\Resource;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Resource;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
+use TYPO3\CMS\Core\Resource\Collection\FileCollectionRegistry;
+use TYPO3\CMS\Core\Resource\Driver\DriverRegistry;
 use TYPO3\CMS\Core\Resource\Event\AfterResourceStorageInitializationEvent;
 use TYPO3\CMS\Core\Resource\Event\BeforeResourceStorageInitializationEvent;
+use TYPO3\CMS\Core\Resource\Exception\FileDoesNotExistException;
+use TYPO3\CMS\Core\Resource\Exception\ResourceDoesNotExistException;
 use TYPO3\CMS\Core\Resource\Index\FileIndexRepository;
+use TYPO3\CMS\Core\Resource\Index\Indexer;
 use TYPO3\CMS\Core\Service\FlexFormService;
 use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
@@ -68,7 +74,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
     /**
      * A list of the base paths of "local" driver storages. Used to make the detection of base paths easier.
      *
-     * @var array
+     * @var array<int, LocalPath>|null
      */
     protected $localDriverStorageCache;
 
@@ -96,7 +102,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
     public function getDriverObject($driverIdentificationString, array $driverConfiguration)
     {
         /** @var Driver\DriverRegistry $driverRegistry */
-        $driverRegistry = GeneralUtility::makeInstance(Driver\DriverRegistry::class);
+        $driverRegistry = GeneralUtility::makeInstance(DriverRegistry::class);
         $driverClass = $driverRegistry->getDriverClass($driverIdentificationString);
         $driverObject = GeneralUtility::makeInstance($driverClass, $driverConfiguration);
         return $driverObject;
@@ -129,7 +135,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
      * Creates an instance of the storage from given UID. The $recordData can
      * be supplied to increase performance.
      *
-     * @param int $uid The uid of the storage to instantiate.
+     * @param int|null $uid The uid of the storage to instantiate.
      * @param array $recordData The record row from database.
      * @param string $fileIdentifier Identifier for a file. Used for auto-detection of a storage, but only if $uid === 0 (Local default storage) is used
      *
@@ -147,7 +153,6 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
         }
         if (empty($this->storageInstances[$uid])) {
             $storageConfiguration = null;
-            $storageObject = null;
             /** @var BeforeResourceStorageInitializationEvent $event */
             $event = $this->eventDispatcher->dispatch(new BeforeResourceStorageInitializationEvent($uid, $recordData, $fileIdentifier));
             $recordData = $event->getRecord();
@@ -174,15 +179,12 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
                     'basePath' => '/',
                     'pathType' => 'relative'
                 ];
-            } elseif (count($recordData) === 0 || (int)$recordData['uid'] !== $uid) {
+            } elseif ($recordData === [] || (int)$recordData['uid'] !== $uid) {
                 /** @var StorageRepository $storageRepository */
                 $storageRepository = GeneralUtility::makeInstance(StorageRepository::class);
-                /** @var ResourceStorage $storage */
-                $storageObject = $storageRepository->findByUid($uid);
-            }
-            if (!$storageObject instanceof ResourceStorage) {
-                $storageObject = $this->createStorageObject($recordData, $storageConfiguration);
+                $recordData = $storageRepository->fetchRowByUid($uid);
             }
+            $storageObject = $this->createStorageObject($recordData, $storageConfiguration);
             $storageObject = $this->eventDispatcher
                 ->dispatch(new AfterResourceStorageInitializationEvent($storageObject))
                 ->getStorage();
@@ -207,19 +209,39 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
             $this->initializeLocalStorageCache();
         }
 
+        // normalize path information (`//`, `../`)
+        $localPath = PathUtility::getCanonicalPath($localPath);
+        if ($localPath[0] !== '/') {
+            $localPath = '/' . $localPath;
+        }
         $bestMatchStorageUid = 0;
         $bestMatchLength = 0;
         foreach ($this->localDriverStorageCache as $storageUid => $basePath) {
-            $matchLength = strlen(PathUtility::getCommonPrefix([$basePath, $localPath]));
-            $basePathLength = strlen($basePath);
-
-            if ($matchLength >= $basePathLength && $matchLength > $bestMatchLength) {
-                $bestMatchStorageUid = (int)$storageUid;
-                $bestMatchLength = $matchLength;
+            // try to match (resolved) relative base-path
+            if ($basePath->getRelative() !== null
+                && null !== $commonPrefix = PathUtility::getCommonPrefix([$basePath->getRelative(), $localPath])
+            ) {
+                $matchLength = strlen($commonPrefix);
+                $basePathLength = strlen($basePath->getRelative());
+                if ($matchLength >= $basePathLength && $matchLength > $bestMatchLength) {
+                    $bestMatchStorageUid = $storageUid;
+                    $bestMatchLength = $matchLength;
+                }
+            }
+            // try to match (resolved) absolute base-path
+            if (null !== $commonPrefix = PathUtility::getCommonPrefix([$basePath->getAbsolute(), $localPath])) {
+                $matchLength = strlen($commonPrefix);
+                $basePathLength = strlen($basePath->getAbsolute());
+                if ($matchLength >= $basePathLength && $matchLength > $bestMatchLength) {
+                    $bestMatchStorageUid = $storageUid;
+                    $bestMatchLength = $matchLength;
+                }
             }
         }
-        if ($bestMatchStorageUid !== 0) {
-            $localPath = substr($localPath, $bestMatchLength);
+        if ($bestMatchLength > 0) {
+            // $commonPrefix always has trailing slash, which needs to be excluded
+            // (commonPrefix: /some/path/, localPath: /some/path/file.png --> /file.png; keep leading slash)
+            $localPath = substr($localPath, $bestMatchLength - 1);
         }
         return $bestMatchStorageUid;
     }
@@ -234,12 +256,28 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
         /** @var ResourceStorage[] $storageObjects */
         $storageObjects = $storageRepository->findByStorageType('Local');
 
-        $storageCache = [];
+        $this->localDriverStorageCache = [
+            // implicit legacy storage in project's public path
+            0 => new LocalPath('/', LocalPath::TYPE_RELATIVE)
+        ];
         foreach ($storageObjects as $localStorage) {
             $configuration = $localStorage->getConfiguration();
-            $storageCache[$localStorage->getUid()] = $configuration['basePath'];
+            if (!isset($configuration['basePath']) || !isset($configuration['pathType'])) {
+                continue;
+            }
+            if ($configuration['pathType'] === 'relative') {
+                $pathType = LocalPath::TYPE_RELATIVE;
+            } elseif ($configuration['pathType'] === 'absolute') {
+                $pathType = LocalPath::TYPE_ABSOLUTE;
+            } else {
+                continue;
+            }
+            $this->localDriverStorageCache[$localStorage->getUid()] = GeneralUtility::makeInstance(
+                LocalPath::class,
+                $configuration['basePath'],
+                $pathType
+            );
         }
-        $this->localDriverStorageCache = $storageCache;
     }
 
     /**
@@ -306,7 +344,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
     public function createCollectionObject(array $collectionData)
     {
         /** @var Collection\FileCollectionRegistry $registry */
-        $registry = GeneralUtility::makeInstance(Collection\FileCollectionRegistry::class);
+        $registry = GeneralUtility::makeInstance(FileCollectionRegistry::class);
 
         /** @var \TYPO3\CMS\Core\Collection\AbstractRecordCollection $class */
         $class = $registry->getFileCollectionClass($collectionData['type']);
@@ -365,7 +403,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
             if (empty($fileData)) {
                 $fileData = $this->getFileIndexRepository()->findOneByUid($uid);
                 if ($fileData === false) {
-                    throw new Exception\FileDoesNotExistException('No file found for given UID: ' . $uid, 1317178604);
+                    throw new FileDoesNotExistException('No file found for given UID: ' . $uid, 1317178604);
                 }
             }
             $this->fileInstances[$uid] = $this->createFileObject($fileData);
@@ -382,12 +420,12 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
      */
     public function getFileObjectFromCombinedIdentifier($identifier)
     {
-        if (!isset($identifier) || !is_string($identifier) || $identifier === '') {
+        if (!is_string($identifier) || $identifier === '') {
             throw new \InvalidArgumentException('Invalid file identifier given. It must be of type string and not empty. "' . gettype($identifier) . '" given.', 1401732564);
         }
         $parts = GeneralUtility::trimExplode(':', $identifier);
         if (count($parts) === 2) {
-            $storageUid = $parts[0];
+            $storageUid = (int)$parts[0];
             $fileIdentifier = $parts[1];
         } else {
             // We only got a path: Go into backwards compatibility mode and
@@ -418,7 +456,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
             if ($fileData === false) {
                 $fileObject = $this->getIndexer($storage)->createIndexEntry($fileIdentifier);
             } else {
-                $fileObject = $this->getFileObject($fileData['uid'], $fileData);
+                $fileObject = $this->getFileObject($fileData['uid'], (array)$fileData);
             }
         } else {
             $fileObject = $this->getProcessedFileRepository()->findByStorageAndIdentifier($storage, $fileIdentifier);
@@ -458,7 +496,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
             return $this->retrieveFileOrFolderObject($input);
         }
         if (MathUtility::canBeInterpretedAsInteger($input)) {
-            return $this->getFileObject($input);
+            return $this->getFileObject((int)$input);
         }
         if (strpos($input, ':') > 0) {
             [$prefix] = explode(':', $input);
@@ -499,7 +537,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
     {
         $parts = GeneralUtility::trimExplode(':', $identifier);
         if (count($parts) === 2) {
-            $storageUid = $parts[0];
+            $storageUid = (int)$parts[0];
             $folderIdentifier = $parts[1];
         } else {
             // We only got a path: Go into backwards compatibility mode and
@@ -526,7 +564,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
     public function getStorageObjectFromCombinedIdentifier($identifier)
     {
         $parts = GeneralUtility::trimExplode(':', $identifier);
-        $storageUid = count($parts) === 2 ? $parts[0] : null;
+        $storageUid = count($parts) === 2 ? (int)$parts[0] : null;
         return $this->getStorageObject($storageUid);
     }
 
@@ -541,14 +579,14 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
     public function getObjectFromCombinedIdentifier($identifier)
     {
         [$storageId, $objectIdentifier] = GeneralUtility::trimExplode(':', $identifier);
-        $storage = $this->getStorageObject($storageId);
+        $storage = $this->getStorageObject((int)$storageId);
         if ($storage->hasFile($objectIdentifier)) {
             return $storage->getFile($objectIdentifier);
         }
         if ($storage->hasFolder($objectIdentifier)) {
             return $storage->getFolder($objectIdentifier);
         }
-        throw new Exception\ResourceDoesNotExistException('Object with identifier "' . $identifier . '" does not exist in storage', 1329647780);
+        throw new ResourceDoesNotExistException('Object with identifier "' . $identifier . '" does not exist in storage', 1329647780);
     }
 
     /**
@@ -561,7 +599,6 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
      */
     public function createFileObject(array $fileData, ResourceStorage $storage = null)
     {
-        /** @var File $fileObject */
         if (array_key_exists('storage', $fileData) && MathUtility::canBeInterpretedAsInteger($fileData['storage'])) {
             $storageObject = $this->getStorageObject((int)$fileData['storage']);
         } elseif ($storage !== null) {
@@ -570,6 +607,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
         } else {
             throw new \RuntimeException('A file needs to reside in a Storage', 1381570997);
         }
+        /** @var File $fileObject */
         $fileObject = GeneralUtility::makeInstance(File::class, $fileData, $storageObject);
         return $fileObject;
     }
@@ -598,7 +636,7 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
             if (empty($fileReferenceData)) {
                 $fileReferenceData = $this->getFileReferenceData($uid, $raw);
                 if (!is_array($fileReferenceData)) {
-                    throw new Exception\ResourceDoesNotExistException(
+                    throw new ResourceDoesNotExistException(
                         'No file reference (sys_file_reference) was found for given UID: "' . $uid . '"',
                         1317178794
                     );
@@ -682,6 +720,6 @@ class ResourceFactory implements ResourceFactoryInterface, SingletonInterface
      */
     protected function getIndexer(ResourceStorage $storage)
     {
-        return GeneralUtility::makeInstance(Index\Indexer::class, $storage);
+        return GeneralUtility::makeInstance(Indexer::class, $storage);
     }
 }
