@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Core\Routing\Aspect;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,13 +15,20 @@ namespace TYPO3\CMS\Core\Routing\Aspect;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Routing\Aspect;
+
 use Doctrine\DBAL\Connection;
 use TYPO3\CMS\Core\Context\Context;
+use TYPO3\CMS\Core\Context\ContextAwareInterface;
+use TYPO3\CMS\Core\Context\ContextAwareTrait;
 use TYPO3\CMS\Core\Context\LanguageAspectFactory;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\QueryBuilder;
+use TYPO3\CMS\Core\Database\Query\Restriction\FrontendGroupRestriction;
+use TYPO3\CMS\Core\Database\Query\Restriction\FrontendRestrictionContainer;
 use TYPO3\CMS\Core\Domain\Repository\PageRepository;
 use TYPO3\CMS\Core\Routing\Legacy\PersistedAliasMapperLegacyTrait;
+use TYPO3\CMS\Core\Site\SiteAwareInterface;
 use TYPO3\CMS\Core\Site\SiteLanguageAwareInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
@@ -45,9 +51,12 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  *           routeFieldName: 'path_segment'
  *           routeValuePrefix: '/'
  */
-class PersistedAliasMapper implements PersistedMappableAspectInterface, StaticMappableAspectInterface, SiteLanguageAwareInterface
+class PersistedAliasMapper implements PersistedMappableAspectInterface, StaticMappableAspectInterface, ContextAwareInterface, SiteLanguageAwareInterface, SiteAwareInterface
 {
+    use AspectTrait;
     use SiteLanguageAccessorTrait;
+    use SiteAccessorTrait;
+    use ContextAwareTrait;
     use PersistedAliasMapperLegacyTrait;
 
     /**
@@ -85,6 +94,11 @@ class PersistedAliasMapper implements PersistedMappableAspectInterface, StaticMa
      */
     protected $languageParentFieldName;
 
+    /**
+     * @var bool
+     */
+    protected $slugUniqueInSite;
+
     /**
      * @param array $settings
      * @throws \InvalidArgumentException
@@ -121,6 +135,7 @@ class PersistedAliasMapper implements PersistedMappableAspectInterface, StaticMa
         $this->languageFieldName = $GLOBALS['TCA'][$this->tableName]['ctrl']['languageField'] ?? null;
         $this->languageParentFieldName = $GLOBALS['TCA'][$this->tableName]['ctrl']['transOrigPointerField'] ?? null;
         $this->persistenceFieldNames = $this->buildPersistenceFieldNames();
+        $this->slugUniqueInSite = $this->isSlugUniqueInSite($this->tableName, $this->routeFieldName);
     }
 
     /**
@@ -220,6 +235,11 @@ class PersistedAliasMapper implements PersistedMappableAspectInterface, StaticMa
             ->where(...$constraints)
             ->execute()
             ->fetchAll();
+        // limit results to be contained in rootPageId of current Site
+        // (which is defining the route configuration currently being processed)
+        if ($this->slugUniqueInSite) {
+            $results = array_values($this->filterContainedInSite($results));
+        }
         // return first result record in case table is not language aware
         if (!$languageAware) {
             return $results[0] ?? null;
@@ -230,9 +250,16 @@ class PersistedAliasMapper implements PersistedMappableAspectInterface, StaticMa
 
     protected function createQueryBuilder(): QueryBuilder
     {
-        return GeneralUtility::makeInstance(ConnectionPool::class)
+        $queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)
             ->getQueryBuilderForTable($this->tableName)
             ->from($this->tableName);
+        $queryBuilder->setRestrictions(
+            GeneralUtility::makeInstance(FrontendRestrictionContainer::class, $this->context)
+        );
+        // Frontend Groups are not available at this time (initialized via TSFE->determineId)
+        // So this must be excluded to allow access restricted records
+        $queryBuilder->getRestrictions()->removeByType(FrontendGroupRestriction::class);
+        return $queryBuilder;
     }
 
     /**
