@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Core\Routing\Enhancer;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Core\Routing\Enhancer;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Routing\Enhancer;
+
 use TYPO3\CMS\Core\Routing\Route;
 use TYPO3\CMS\Core\Routing\RouteCollection;
 
@@ -147,7 +148,7 @@ class PageTypeDecorator extends AbstractEnhancer implements DecoratingEnhancerIn
         // If the type is > 0 but the value could not be resolved,
         // the type is appended as GET argument, which can be resolved already anyway.
         // This happens when the PageTypeDecorator is used, but hasn't been configured for all available types.
-        if ($value === '' && !empty($type)) {
+        if (!empty($type) && ($value === '' || $value === $this->default)) {
             return;
         }
 
