@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Core\Routing;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Core\Routing;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Routing;
+
 use Psr\Http\Message\ServerRequestInterface;
 use Psr\Http\Message\UriInterface;
 use Symfony\Component\Routing\Exception\MissingMandatoryParametersException;
@@ -89,7 +90,7 @@ class PageRouter implements RouterInterface
     protected $cacheHashCalculator;
 
     /**
-     * @var \TYPO3\CMS\Core\Context\Context|null
+     * @var \TYPO3\CMS\Core\Context\Context
      */
     protected $context;
 
@@ -102,10 +103,10 @@ class PageRouter implements RouterInterface
     public function __construct(Site $site, Context $context = null)
     {
         $this->site = $site;
-        $this->enhancerFactory = GeneralUtility::makeInstance(EnhancerFactory::class);
-        $this->aspectFactory = GeneralUtility::makeInstance(AspectFactory::class);
-        $this->cacheHashCalculator = GeneralUtility::makeInstance(CacheHashCalculator::class);
         $this->context = $context ?? GeneralUtility::makeInstance(Context::class);
+        $this->enhancerFactory = GeneralUtility::makeInstance(EnhancerFactory::class);
+        $this->aspectFactory = GeneralUtility::makeInstance(AspectFactory::class, $this->context);
+        $this->cacheHashCalculator = GeneralUtility::makeInstance(CacheHashCalculator::class);
     }
 
     /**
@@ -129,7 +130,7 @@ class PageRouter implements RouterInterface
         if ($requestId > 0) {
             if (!empty($pageId = $candidateProvider->getRealPageIdForPageIdAsPossibleCandidate($requestId))) {
                 return new PageArguments(
-                    $pageId,
+                    (int)$pageId,
                     (string)($request->getQueryParams()['type'] ?? '0'),
                     [],
                     [],
@@ -146,13 +147,19 @@ class PageRouter implements RouterInterface
             if ($normalizedParams instanceof NormalizedParams) {
                 $scriptName = ltrim($normalizedParams->getScriptName(), '/');
                 if ($scriptName !== '' && strpos($urlPath, $scriptName) !== false) {
-                    $urlPath = str_replace($scriptName, '', $urlPath);
+                    $urlPath = str_replace('/' . $scriptName, '', $urlPath);
                 }
             }
         }
 
         $language = $previousResult->getLanguage();
-        $prefixedUrlPath = '/' . trim($urlPath, '/');
+        // Keep possible existing "/" at the end (no trim, just ltrim), even though the page slug might not
+        // contain a "/" at the end. This way we find page candidates where pages MIGHT have a trailing slash
+        // and pages with slugs that do not have a trailing slash
+        // $pageCandidates will contain more records than expected, which is important here, as the ->match() method
+        // will handle this then.
+        // The prepended slash will ensure that the root page of the site tree will also be fetched
+        $prefixedUrlPath = '/' . ltrim($urlPath, '/');
 
         $pageCandidates = $candidateProvider->getCandidatesForPath($prefixedUrlPath, $language);
 
@@ -185,8 +192,16 @@ class PageRouter implements RouterInterface
                 }
             }
 
-            $pageCollection->addNamePrefix('page_' . $page['uid'] . '_');
+            $collectionPrefix = 'page_' . $page['uid'];
+            // Pages with a MountPoint Parameter means that they have a different context, and should be treated
+            // as a separate instance
+            if (isset($page['MPvar'])) {
+                $collectionPrefix .= '_MP_' . str_replace(',', '', $page['MPvar']);
+            }
+            $pageCollection->addNamePrefix($collectionPrefix . '_');
             $fullCollection->addCollection($pageCollection);
+            // set default route flag after all routes have been processed
+            $defaultRouteForPage->setOption('_isDefault', true);
         }
 
         $matcher = new PageUriMatcher($fullCollection);
@@ -196,7 +211,18 @@ class PageRouter implements RouterInterface
             $matchedRoute = $fullCollection->get($result['_route']);
             return $this->buildPageArguments($matchedRoute, $result, $request->getQueryParams());
         } catch (ResourceNotFoundException $e) {
-            // Do nothing
+            // Second try, look for /my-page even though the request was called via /my-page/ and the slash
+            // was not part of the slug, but let's then check again
+            if (substr($prefixedUrlPath, -1) === '/') {
+                try {
+                    $result = $matcher->match(rtrim($prefixedUrlPath, '/'));
+                    /** @var Route $matchedRoute */
+                    $matchedRoute = $fullCollection->get($result['_route']);
+                    return $this->buildPageArguments($matchedRoute, $result, $request->getQueryParams());
+                } catch (ResourceNotFoundException $e) {
+                    // Do nothing
+                }
+            }
         }
         throw new RouteNotFoundException('No route found for path "' . $urlPath . '"', 1538389998);
     }
@@ -251,7 +277,7 @@ class PageRouter implements RouterInterface
             // with the base of the MountPoint page, this is especially relevant for cross-domain linking
             // Because the language contains the full base, it is retrieved in this case.
             try {
-                [, $mountPointPage] = explode('-', reset($mountPointPairs));
+                [, $mountPointPage] = explode('-', (string)reset($mountPointPairs));
                 $site = GeneralUtility::makeInstance(SiteMatcher::class)
                     ->matchByPageId((int)$mountPointPage);
                 $language = $site->getLanguageById($language->getLanguageId());
@@ -300,8 +326,13 @@ class PageRouter implements RouterInterface
         );
         $generator = new UrlGenerator($collection, $context);
         $generator->injectMappableProcessor($mappableProcessor);
-        $allRoutes = $collection->all();
-        $allRoutes = array_reverse($allRoutes, true);
+        // set default route flag after all routes have been processed
+        $defaultRouteForPage->setOption('_isDefault', true);
+        $allRoutes = GeneralUtility::makeInstance(RouteSorter::class)
+            ->withRoutes($collection->all())
+            ->withOriginalParameters($originalParameters)
+            ->sortRoutesForGeneration()
+            ->getRoutes();
         $matchedRoute = null;
         $pageRouteResult = null;
         $uri = null;
@@ -351,11 +382,11 @@ class PageRouter implements RouterInterface
         if ($matchedRoute && $pageRouteResult && !empty($pageRouteResult->getDynamicArguments())) {
             $cacheHash = $this->generateCacheHash($pageId, $pageRouteResult);
 
+            $queryArguments = $pageRouteResult->getQueryArguments();
             if (!empty($cacheHash)) {
-                $queryArguments = $pageRouteResult->getQueryArguments();
                 $queryArguments['cHash'] = $cacheHash;
-                $uri = $uri->withQuery(http_build_query($queryArguments, '', '&', PHP_QUERY_RFC3986));
             }
+            $uri = $uri->withQuery(http_build_query($queryArguments, '', '&', PHP_QUERY_RFC3986));
         }
         if ($fragment) {
             $uri = $uri->withFragment($fragment);
@@ -443,7 +474,8 @@ class PageRouter implements RouterInterface
             if (!empty($enhancerConfiguration['aspects'] ?? null)) {
                 $aspects = $this->aspectFactory->createAspects(
                     $enhancerConfiguration['aspects'],
-                    $language
+                    $language,
+                    $this->site
                 );
                 $enhancer->setAspects($aspects);
             }
@@ -508,7 +540,8 @@ class PageRouter implements RouterInterface
             return $enhancer->buildResult($route, $results, $remainingQueryParameters);
         }
         $page = $route->getOption('_page');
-        $pageId = (int)($page['l10n_parent'] > 0 ? $page['l10n_parent'] : $page['uid']);
+        $pageId = (int)(isset($page['t3ver_oid']) && $page['t3ver_oid'] > 0 ? $page['t3ver_oid'] : $page['uid']);
+        $pageId = (int)($page['l10n_parent'] > 0 ? $page['l10n_parent'] : $pageId);
         $type = $this->resolveType($route, $remainingQueryParameters);
         // See PageSlugCandidateProvider where this is added.
         if ($page['MPvar'] ?? '') {
