@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Core\Routing;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Core\Routing;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Routing;
+
 use Doctrine\DBAL\Connection;
 use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Database\ConnectionPool;
@@ -185,7 +186,7 @@ class PageSlugCandidateProvider
      *
      * @param array $slugCandidates
      * @param int $languageId
-     * @param string|null $excludeUids when called recursively this is the mountpoint parameter of the original prefix
+     * @param array $excludeUids when called recursively this is the mountpoint parameter of the original prefix
      * @return array[]|array
      * @throws SiteNotFoundException
      */
@@ -201,7 +202,7 @@ class PageSlugCandidateProvider
             ->add(GeneralUtility::makeInstance(FrontendWorkspaceRestriction::class, null, null, $searchLiveRecordsOnly));
 
         $statement = $queryBuilder
-            ->select('uid', 'l10n_parent', 'pid', 'slug', 'mount_pid', 'mount_pid_ol', 't3ver_state', 'doktype')
+            ->select('uid', 'l10n_parent', 'pid', 'slug', 'mount_pid', 'mount_pid_ol', 't3ver_state', 'doktype', 't3ver_wsid', 't3ver_oid')
             ->from('pages')
             ->where(
                 $queryBuilder->expr()->eq(
@@ -218,20 +219,51 @@ class PageSlugCandidateProvider
             )
             // Exact match will be first, that's important
             ->orderBy('slug', 'desc')
+            // Sort pages that are not MountPoint pages before mount points
+            ->addOrderBy('mount_pid_ol', 'asc')
+            ->addOrderBy('mount_pid', 'asc')
             ->execute();
 
         $pages = [];
         $siteFinder = GeneralUtility::makeInstance(SiteFinder::class);
         $pageRepository = GeneralUtility::makeInstance(PageRepository::class, $this->context);
+        $isRecursiveCall = !empty($excludeUids);
 
         while ($row = $statement->fetch()) {
+            $mountPageInformation = null;
+            // This changes the PID value and adds a _ORIG_PID value (only different in move actions)
+            // In live: This fetches everything in a bad way ! as there is no workspace limitation given, fetching all new and moved placeholders here!
+            // In a workspace: Filter out versioned records (t3ver_oid=0), leaving effectively the new/move placeholders in place, where the new placeholder
+            // However, this is checked in $siteFinder->getSiteByPageId() via RootlineUtility where overlays are happening
+            // so the fixVersioningPid() call is probably irrelevant.
             $pageRepository->fixVersioningPid('pages', $row);
             $pageIdInDefaultLanguage = (int)($languageId > 0 ? $row['l10n_parent'] : $row['uid']);
-            // When called previously this mountpoint should be skipped
+            // When this page was added before via recursion, this page should be skipped
             if (in_array($pageIdInDefaultLanguage, $excludeUids, true)) {
                 continue;
             }
+
+            try {
+                $isOnSameSite = $siteFinder->getSiteByPageId($pageIdInDefaultLanguage)->getRootPageId() === $this->site->getRootPageId();
+            } catch (SiteNotFoundException $e) {
+                // Page is not in a site, so it's not considered
+                $isOnSameSite = false;
+            }
+
+            // If a MountPoint is found on the current site, and it hasn't been added yet by some other iteration
+            // (see below "findPageCandidatesOfMountPoint"), then let's resolve the MountPoint information now
+            if (!$isOnSameSite && $isRecursiveCall) {
+                // Not in the same site, and called recursive, should be skipped
+                continue;
+            }
             $mountPageInformation = $pageRepository->getMountPointInfo($pageIdInDefaultLanguage, $row);
+
+            // Mount Point Pages which are not on the same site (when not called on the first level) should be skipped
+            // As they just clutter up the queries.
+            if (!$isOnSameSite && !$isRecursiveCall && $mountPageInformation) {
+                continue;
+            }
+
             $mountedPage = null;
             if ($mountPageInformation) {
                 // Add the MPvar to the row, so it can be used later-on in the PageRouter / PageArguments
@@ -243,14 +275,11 @@ class PageSlugCandidateProvider
                 if (!$mountedPage) {
                     continue;
                 }
-            }
-
-            try {
-                $isOnSameSite = $siteFinder->getSiteByPageId($pageIdInDefaultLanguage)->getRootPageId() === $this->site->getRootPageId();
-                // If the page is a mountpoint which should be overlaid with the contents of the mounted page,
-                // it must never be accessible directly, but only in the mountpoint context. Therefore we change
+                // If the page is a MountPoint which should be overlaid with the contents of the mounted page,
+                // it must never be accessible directly, but only in the MountPoint context. Therefore we change
                 // the current ID and slug.
-                if ($mountedPage && PageRepository::DOKTYPE_MOUNTPOINT === (int)$row['doktype'] && $row['mount_pid_ol']) {
+                // This needs to happen before the regular case, as the $pageToAdd contains the MPvar information
+                if (PageRepository::DOKTYPE_MOUNTPOINT === (int)$row['doktype'] && $row['mount_pid_ol']) {
                     // If the mounted page was already added from above, this should not be added again (to include
                     // the mount point parameter).
                     if (in_array((int)$mountedPage['uid'], $excludeUids, true)) {
@@ -264,16 +293,18 @@ class PageSlugCandidateProvider
                     $excludeUids[] = (int)$pageToAdd['uid'];
                     $excludeUids[] = $pageIdInDefaultLanguage;
                 }
-                if ($isOnSameSite && !in_array($pageIdInDefaultLanguage, $excludeUids, true)) {
-                    $pages[] = $row;
-                    $excludeUids[] = $pageIdInDefaultLanguage;
-                }
-            } catch (SiteNotFoundException $e) {
-                // Page is not in a site, so it's not considered
             }
 
-            // Add possible sub-pages prepended with the mountpoint page slug
+            // This is the regular "non-MountPoint page" case (must happen after the if condition so MountPoint
+            // pages that have been replaced by the Mounted Page will not be added again.
+            if ($isOnSameSite && !in_array($pageIdInDefaultLanguage, $excludeUids, true)) {
+                $pages[] = $row;
+                $excludeUids[] = $pageIdInDefaultLanguage;
+            }
+
+            // Add possible sub-pages prepended with the MountPoint page slug
             if ($mountPageInformation) {
+                /** @var array $mountedPage */
                 $siteOfMountedPage = $siteFinder->getSiteByPageId((int)$mountedPage['uid']);
                 $morePageCandidates = $this->findPageCandidatesOfMountPoint(
                     $row,
@@ -283,7 +314,7 @@ class PageSlugCandidateProvider
                     $slugCandidates
                 );
                 foreach ($morePageCandidates as $candidate) {
-                    // When called previously this mountpoint should be skipped
+                    // When called previously this MountPoint page should be skipped
                     if (in_array((int)$candidate['uid'], $excludeUids, true)) {
                         continue;
                     }
@@ -417,7 +448,7 @@ class PageSlugCandidateProvider
         if (!empty($redecorationPattern) && preg_match('#' . $redecorationPattern . '#', $routePath, $matches)) {
             $decoration = $matches['decoration'];
             $decorationPattern = preg_quote($decoration, '#');
-            $routePath = preg_replace('#' . $decorationPattern . '$#', '', $routePath);
+            $routePath = preg_replace('#' . $decorationPattern . '$#', '', $routePath) ?? '';
         }
 
         $candidatePathParts = [];
