@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Core\Routing;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,9 +15,13 @@ namespace TYPO3\CMS\Core\Routing;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Routing;
+
+use TYPO3\CMS\Core\Exception;
+
 /**
  * Exception thrown when a route does not exist
  */
-class RouteNotFoundException extends \TYPO3\CMS\Core\Exception
+class RouteNotFoundException extends Exception
 {
 }
