@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Service;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,8 +13,11 @@ namespace TYPO3\CMS\Core\Service;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Service;
+
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
+use TYPO3\CMS\Core\Security\BlockSerializationTrait;
 use TYPO3\CMS\Core\TimeTracker\TimeTracker;
 use TYPO3\CMS\Core\Utility\CommandUtility;
 use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;
@@ -26,6 +28,7 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  */
 abstract class AbstractService implements LoggerAwareInterface
 {
+    use BlockSerializationTrait;
     use LoggerAwareTrait;
 
     // General error - something went wrong
@@ -326,7 +329,7 @@ abstract class AbstractService implements LoggerAwareInterface
      *
      * @param string $absFile File name to read from.
      * @param int $length Maximum length to read. If empty the whole file will be read.
-     * @return string|bool $content or FALSE
+     * @return string|bool file content or false
      */
     public function readFile($absFile, $length = 0)
     {
@@ -351,8 +354,12 @@ abstract class AbstractService implements LoggerAwareInterface
     {
         if (!$absFile) {
             $absFile = $this->tempFile($this->prefixId);
+            if ($absFile === false) {
+                return false;
+            }
+            $absFile = (string)$absFile;
         }
-        if ($absFile && GeneralUtility::isAllowedAbsPath($absFile)) {
+        if (GeneralUtility::isAllowedAbsPath($absFile)) {
             if ($fd = @fopen($absFile, 'wb')) {
                 @fwrite($fd, $content);
                 @fclose($fd);
@@ -443,7 +450,7 @@ abstract class AbstractService implements LoggerAwareInterface
      * Get the input content.
      * Will be read from input file if needed. (That is if ->inputContent is empty and ->inputFile is not)
      *
-     * @return mixed
+     * @return string|bool
      */
     public function getInput()
     {
@@ -478,7 +485,7 @@ abstract class AbstractService implements LoggerAwareInterface
     /**
      * Set the output file name.
      *
-     * @param string $absFile File name
+     * @param string|bool $absFile File name
      */
     public function setOutputFile($absFile)
     {
@@ -488,7 +495,7 @@ abstract class AbstractService implements LoggerAwareInterface
     /**
      * Get the output content.
      *
-     * @return mixed
+     * @return string
      */
     public function getOutput()
     {
