@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Service;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,10 +13,12 @@ namespace TYPO3\CMS\Core\Service;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Service;
+
 /**
  * Class with helper functions for clearing the PHP opcache.
  * It auto detects the opcache system and invalidates/resets it.
- * http://forge.typo3.org/issues/55252
+ * https://forge.typo3.org/issues/55252
  * Supported opcaches are: OPcache >= 7.0 (PHP 5.5)
  */
 class OpcodeCacheService
@@ -30,25 +31,19 @@ class OpcodeCacheService
     public function getAllActive()
     {
         $supportedCaches = [
-            // The ZendOpcache aka OPcache since PHP 5.5
-            // http://php.net/manual/de/book.opcache.php
             'OPcache' => [
                 'active' => extension_loaded('Zend OPcache') && ini_get('opcache.enable') === '1',
                 'version' => phpversion('Zend OPcache'),
-                'canReset' => true, // opcache_reset() ... it seems that it doesn't reset for current run.
-                // From documentation this function exists since first version (7.0.0) but from Changelog
-                // this function exists since OPcache 7.0.2
-                // http://pecl.php.net/package-changelog.php?package=ZendOpcache&release=7.0.2
-                // PHP 7.0 onward is delivered minimum OPcache 7.0.6-dev
-                'canInvalidate' => true,
-                'error' => false,
-                'clearCallback' => function ($fileAbsPath) {
-                    if ($fileAbsPath !== null) {
-                        opcache_invalidate($fileAbsPath);
-                    } else {
-                        opcache_reset();
+                'warning' => self::isClearable() ? false : 'Either opcache_invalidate or opcache_reset are disabled in this installation. Clearing will not work.',
+                'clearCallback' => static function ($fileAbsPath) {
+                    if (self::isClearable()) {
+                        if ($fileAbsPath !== null) {
+                            opcache_invalidate($fileAbsPath);
+                        } else {
+                            opcache_reset();
+                        }
                     }
-                }
+                },
             ],
         ];
 
@@ -73,4 +68,13 @@ class OpcodeCacheService
             $callback($fileAbsPath);
         }
     }
+
+    /**
+     * @return bool
+     */
+    protected static function isClearable(): bool
+    {
+        $disabled = explode(',', (string)ini_get('disable_functions'));
+        return !(in_array('opcache_invalidate', $disabled, true) || in_array('opcache_reset', $disabled, true));
+    }
 }
