@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Core\Site;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,10 @@ namespace TYPO3\CMS\Core\Site;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Site;
+
+use TYPO3\CMS\Core\Site\Entity\SiteLanguage;
+
 /**
  * Interface for SiteLanguageAware features of TYPO3
  */
@@ -24,10 +27,10 @@ interface SiteLanguageAwareInterface
     /**
      * @param Entity\SiteLanguage $siteLanguage
      */
-    public function setSiteLanguage(Entity\SiteLanguage $siteLanguage);
+    public function setSiteLanguage(SiteLanguage $siteLanguage);
 
     /**
      * @return Entity\SiteLanguage
      */
-    public function getSiteLanguage(): Entity\SiteLanguage;
+    public function getSiteLanguage(): SiteLanguage;
 }
