@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\TimeTracker;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -13,10 +12,14 @@ namespace TYPO3\CMS\Core\TimeTracker;
  *
  * The TYPO3 project - inspiring people to share!
  */
+
+namespace TYPO3\CMS\Core\TimeTracker;
+
 use TYPO3\CMS\Core\Imaging\Icon;
 use TYPO3\CMS\Core\Imaging\IconFactory;
 use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Core\Utility\MathUtility;
 
 /**
  * Frontend Timetracking functions
@@ -378,7 +381,7 @@ class TimeTracker implements SingletonInterface
             $this->createHierarchyArray($arr, $data['level'], $uniqueId);
         }
         // Parsing the registered content and create icon-html for the tree
-        $this->tsStackLog[$arr['0.'][0]]['content'] = $this->fixContent($arr['0.'], $this->tsStackLog[$arr['0.'][0]]['content'], '', $arr['0.'][0]);
+        $this->tsStackLog[$arr['0.'][0]]['content'] = $this->fixContent($arr['0.'], $this->tsStackLog[$arr['0.'][0]]['content'] ?? '', '', $arr['0.'][0]);
         // Displaying the tree:
         $outputArr = [];
         $outputArr[] = $this->fw('TypoScript Key');
@@ -400,7 +403,7 @@ class TimeTracker implements SingletonInterface
         $flag_tree = $this->printConf['flag_tree'];
         $flag_messages = $this->printConf['flag_messages'];
         $flag_content = $this->printConf['flag_content'];
-        $keyLgd = $this->printConf['keyLgd'];
+        $keyLgd = (int)$this->printConf['keyLgd'];
         $c = 0;
         foreach ($this->tsStackLog as $uniqueId => $data) {
             $logRowClass = '';
@@ -490,31 +493,32 @@ class TimeTracker implements SingletonInterface
      */
     protected function fixContent(&$arr, $content, $depthData = '', $vKey = '')
     {
-        $ac = 0;
+        $entriesCount = 0;
         $c = 0;
         // First, find number of entries
         foreach ($arr as $k => $v) {
-            if (\TYPO3\CMS\Core\Utility\MathUtility::canBeInterpretedAsInteger($k)) {
-                $ac++;
+            //do not count subentries (the one ending with dot, eg. '9.'
+            if (MathUtility::canBeInterpretedAsInteger($k)) {
+                $entriesCount++;
             }
         }
         // Traverse through entries
         $subtime = 0;
         foreach ($arr as $k => $v) {
-            if (\TYPO3\CMS\Core\Utility\MathUtility::canBeInterpretedAsInteger($k)) {
+            if (MathUtility::canBeInterpretedAsInteger($k)) {
                 $c++;
-                $deeper = isset($arr[$k . '.']);
-                $LN = $ac == $c ? 'blank' : 'line';
+                $hasChildren = isset($arr[$k . '.']);
+                $lastEntry = $entriesCount === $c;
 
-                $BTM = $ac == $c ? 'bottom' : '';
-                $PM = $deeper ? '<i class="fa fa-' . ($deeper ? 'minus' : 'plus') . '-square-o"></i>' : '<span class="treeline-icon treeline-icon-join' . ($BTM ? 'bottom' : '') . '"></span>';
+                $PM = '<span class="treeline-icon treeline-icon-join' . ($lastEntry ? 'bottom' : '') . '"></span>';
 
                 $this->tsStackLog[$v]['icons'] = $depthData . $PM;
                 if ($this->tsStackLog[$v]['content'] !== '') {
                     $content = str_replace($this->tsStackLog[$v]['content'], $v, $content);
                 }
-                if ($deeper) {
-                    $this->tsStackLog[$v]['content'] = $this->fixContent($arr[$k . '.'], $this->tsStackLog[$v]['content'], $depthData . '<span class="treeline-icon treeline-icon-' . $LN . '"></span>', $v);
+                if ($hasChildren) {
+                    $lineClass = $lastEntry ? 'treeline-icon-clear' : 'treeline-icon-line';
+                    $this->tsStackLog[$v]['content'] = $this->fixContent($arr[$k . '.'], $this->tsStackLog[$v]['content'], $depthData . '<span class="treeline-icon ' . $lineClass . '"></span>', $v);
                 } else {
                     $this->tsStackLog[$v]['content'] = $this->fixCLen($this->tsStackLog[$v]['content'], $this->tsStackLog[$v]['value']);
                     $this->tsStackLog[$v]['subtime'] = '';
@@ -531,7 +535,7 @@ class TimeTracker implements SingletonInterface
         $content = $this->fixCLen($content, $this->tsStackLog[$vKey]['value']);
         // Traverse array again, this time substitute the unique hash with the red key
         foreach ($arr as $k => $v) {
-            if (\TYPO3\CMS\Core\Utility\MathUtility::canBeInterpretedAsInteger($k)) {
+            if (MathUtility::canBeInterpretedAsInteger($k)) {
                 if ($this->tsStackLog[$v]['content'] !== '') {
                     $content = str_replace($v, '<strong style="color:red;">[' . $this->tsStackLog[$v]['key'] . ']</strong>', $content);
                 }
