@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Tree\TableConfiguration;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,12 +13,17 @@ namespace TYPO3\CMS\Core\Tree\TableConfiguration;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Tree\TableConfiguration;
+
+use TYPO3\CMS\Backend\Tree\AbstractTree;
+use TYPO3\CMS\Backend\Tree\Renderer\AbstractTreeRenderer;
 use TYPO3\CMS\Backend\Tree\TreeNodeCollection;
+use TYPO3\CMS\Backend\Tree\TreeRepresentationNode;
 
 /**
  * Renders a tca tree array for the SelectElementTree
  */
-class ArrayTreeRenderer extends \TYPO3\CMS\Backend\Tree\Renderer\AbstractTreeRenderer
+class ArrayTreeRenderer extends AbstractTreeRenderer
 {
     /**
      * recursion level
@@ -35,7 +39,7 @@ class ArrayTreeRenderer extends \TYPO3\CMS\Backend\Tree\Renderer\AbstractTreeRen
      * @param bool $recursive
      * @return array
      */
-    public function renderNode(\TYPO3\CMS\Backend\Tree\TreeRepresentationNode $node, $recursive = true)
+    public function renderNode(TreeRepresentationNode $node, $recursive = true)
     {
         $nodeArray = [];
         $nodeArray[] = $this->getNodeArray($node);
@@ -56,7 +60,7 @@ class ArrayTreeRenderer extends \TYPO3\CMS\Backend\Tree\Renderer\AbstractTreeRen
      * @param \TYPO3\CMS\Backend\Tree\TreeRepresentationNode|DatabaseTreeNode $node
      * @return array
      */
-    protected function getNodeArray(\TYPO3\CMS\Backend\Tree\TreeRepresentationNode $node)
+    protected function getNodeArray(TreeRepresentationNode $node)
     {
         $overlayIconName = '';
         if (is_object($node->getIcon())) {
@@ -94,7 +98,7 @@ class ArrayTreeRenderer extends \TYPO3\CMS\Backend\Tree\Renderer\AbstractTreeRen
      * @param bool $recursive
      * @return array
      */
-    public function renderTree(\TYPO3\CMS\Backend\Tree\AbstractTree $tree, $recursive = true)
+    public function renderTree(AbstractTree $tree, $recursive = true)
     {
         $this->recursionLevel = 0;
         return $this->renderNode($tree->getRoot(), $recursive);
