@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Utility;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Utility;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Utility;
+
 use TYPO3\CMS\Core\Utility\Exception\MissingArrayPathException;
 
 /**
@@ -262,7 +263,7 @@ class ArrayUtility
      * );
      *
      * @param array $array Input array to manipulate
-     * @param string|array $path Path in array to search for
+     * @param string|array|\ArrayAccess $path Path in array to search for
      * @param mixed $value Value to set at path location in array
      * @param string $delimiter Path delimiter
      * @return array Modified array
@@ -288,9 +289,13 @@ class ArrayUtility
                 throw new \RuntimeException('Invalid path segment specified', 1341406846);
             }
             // Create cell if it doesn't exist
-            if (!array_key_exists($segment, $pointer)) {
+            if (is_array($pointer) && !array_key_exists($segment, $pointer)) {
                 $pointer[$segment] = [];
             }
+            // Make it array if it was something else before
+            if (!is_array($pointer)) {
+                $pointer = [];
+            }
             // Set pointer to new cell
             $pointer = &$pointer[$segment];
         }
@@ -678,7 +683,7 @@ class ArrayUtility
      *
      * @param array $array The initial array to be filtered/reduced
      * @param mixed $keepItems The items which are allowed/kept in the array - accepts array or csv string
-     * @param string $getValueFunc (optional) Callback function used to get the value to keep
+     * @param callable|null $getValueFunc (optional) Callback function used to get the value to keep
      * @return array The filtered/reduced array with the kept items
      */
     public static function keepItemsInArray(array $array, $keepItems, $getValueFunc = null)
@@ -731,7 +736,7 @@ class ArrayUtility
      * @param array $array2 Reduce source array by this array
      * @return array Source array reduced by keys also present in second array
      */
-    public static function arrayDiffAssocRecursive(array $array1, array $array2)
+    public static function arrayDiffKeyRecursive(array $array1, array $array2): array
     {
         $differenceArray = [];
         foreach ($array1 as $key => $value) {
@@ -739,7 +744,38 @@ class ArrayUtility
                 $differenceArray[$key] = $value;
             } elseif (is_array($value)) {
                 if (is_array($array2[$key])) {
-                    $recursiveResult = self::arrayDiffAssocRecursive($value, $array2[$key]);
+                    $recursiveResult = self::arrayDiffKeyRecursive($value, $array2[$key]);
+                    if (!empty($recursiveResult)) {
+                        $differenceArray[$key] = $recursiveResult;
+                    }
+                }
+            }
+        }
+        return $differenceArray;
+    }
+
+    /**
+     * Filters values off from first array that also exist in second array. Comparison is done by keys.
+     * This method is a recursive version of php array_diff_assoc()
+     *
+     * @param array $array1 Source array
+     * @param array $array2 Reduce source array by this array
+     * @param bool $useArrayDiffAssocBehavior If false, the old array_diff_key() behavior is kept
+     * @return array Source array reduced by values also present in second array, indexed by key
+     */
+    public static function arrayDiffAssocRecursive(array $array1, array $array2, bool $useArrayDiffAssocBehavior = false): array
+    {
+        if (!$useArrayDiffAssocBehavior) {
+            return self::arrayDiffKeyRecursive($array1, $array2);
+        }
+
+        $differenceArray = [];
+        foreach ($array1 as $key => $value) {
+            if (!array_key_exists($key, $array2) || (!is_array($value) && $value !== $array2[$key])) {
+                $differenceArray[$key] = $value;
+            } elseif (is_array($value)) {
+                if (is_array($array2[$key])) {
+                    $recursiveResult = self::arrayDiffAssocRecursive($value, $array2[$key], $useArrayDiffAssocBehavior);
                     if (!empty($recursiveResult)) {
                         $differenceArray[$key] = $recursiveResult;
                     }
@@ -836,7 +872,7 @@ class ArrayUtility
             if (is_array($value)) {
                 $result[$key] = self::stripTagsFromValuesRecursive($value);
             } elseif (is_string($value) || (is_object($value) && method_exists($value, '__toString'))) {
-                $result[$key] = strip_tags($value);
+                $result[$key] = strip_tags((string)$value);
             }
         }
         return $result;
