@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Utility;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Utility;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Utility;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use Symfony\Component\Finder\Finder;
 use TYPO3\CMS\Backend\Routing\Route;
@@ -27,8 +28,10 @@ use TYPO3\CMS\Core\Imaging\IconRegistry;
 use TYPO3\CMS\Core\Information\Typo3Version;
 use TYPO3\CMS\Core\Log\LogManager;
 use TYPO3\CMS\Core\Migrations\TcaMigration;
+use TYPO3\CMS\Core\Package\Exception;
 use TYPO3\CMS\Core\Package\PackageManager;
 use TYPO3\CMS\Core\Preparations\TcaPreparation;
+use TYPO3\CMS\Core\Resource\Filter\FileExtensionFilter;
 
 /**
  * Extension Management functions
@@ -165,7 +168,7 @@ class ExtensionManagementUtility
         }
         $version = static::$packageManager->getPackage($key)->getPackageMetaData()->getVersion();
         if (empty($version)) {
-            throw new \TYPO3\CMS\Core\Package\Exception('Version number in composer manifest of package "' . $key . '" is missing or invalid', 1395614959);
+            throw new Exception('Version number in composer manifest of package "' . $key . '" is missing or invalid', 1395614959);
         }
         return $version;
     }
@@ -478,6 +481,66 @@ class ExtensionManagementUtility
         }
     }
 
+    /**
+     * Adds an item group to a TCA select field, allows to add a group so addTcaSelectItem() can add a groupId
+     * with a label and its position within other groups.
+     *
+     * @param string $table the table name in TCA - e.g. tt_content
+     * @param string $field the field name in TCA - e.g. CType
+     * @param string $groupId the unique identifier for a group, where all items from addTcaSelectItem() with a group ID are connected
+     * @param string $groupLabel the label e.g. LLL:EXT:my_extension/Resources/Private/Language/locallang_tca.xlf:group.mygroupId
+     * @param string|null $position e.g. "before:special", "after:default" (where the part after the colon is an existing groupId) or "top" or "bottom"
+     */
+    public static function addTcaSelectItemGroup(string $table, string $field, string $groupId, string $groupLabel, ?string $position = 'bottom'): void
+    {
+        if (!is_array($GLOBALS['TCA'][$table]['columns'][$field]['config'] ?? null)) {
+            throw new \RuntimeException('Given select field item list was not found.', 1586728563);
+        }
+        $itemGroups = $GLOBALS['TCA'][$table]['columns'][$field]['config']['itemGroups'] ?? [];
+        // Group has been defined already, nothing to do
+        if (isset($itemGroups[$groupId])) {
+            return;
+        }
+        $position = (string)$position;
+        $positionGroupId = '';
+        if (strpos($position, ':') !== false) {
+            [$position, $positionGroupId] = explode(':', $position, 2);
+        }
+        // Referenced group was not not found, just append to the bottom
+        if (!isset($itemGroups[$positionGroupId])) {
+            $position = 'bottom';
+        }
+        switch ($position) {
+            case 'after':
+                $newItemGroups = [];
+                foreach ($itemGroups as $existingGroupId => $existingGroupLabel) {
+                    $newItemGroups[$existingGroupId] = $existingGroupLabel;
+                    if ($positionGroupId === $existingGroupId) {
+                        $newItemGroups[$groupId] = $groupLabel;
+                    }
+                }
+                $itemGroups = $newItemGroups;
+                break;
+            case 'before':
+                $newItemGroups = [];
+                foreach ($itemGroups as $existingGroupId => $existingGroupLabel) {
+                    if ($positionGroupId === $existingGroupId) {
+                        $newItemGroups[$groupId] = $groupLabel;
+                    }
+                    $newItemGroups[$existingGroupId] = $existingGroupLabel;
+                }
+                $itemGroups = $newItemGroups;
+                break;
+            case 'top':
+                $itemGroups = array_merge([$groupId => $groupLabel], $itemGroups);
+                break;
+            case 'bottom':
+            default:
+                $itemGroups[$groupId] = $groupLabel;
+        }
+        $GLOBALS['TCA'][$table]['columns'][$field]['config']['itemGroups'] = $itemGroups;
+    }
+
     /**
      * Gets the TCA configuration for a field handling (FAL) files.
      *
@@ -515,7 +578,7 @@ class ExtensionManagementUtility
             ],
             'filter' => [
                 [
-                    'userFunc' => \TYPO3\CMS\Core\Resource\Filter\FileExtensionFilter::class . '->filterInlineChildren',
+                    'userFunc' => FileExtensionFilter::class . '->filterInlineChildren',
                     'parameters' => [
                         'allowedFileExtensions' => $allowedFileExtensions,
                         'disallowedFileExtensions' => $disallowedFileExtensions
@@ -526,8 +589,7 @@ class ExtensionManagementUtility
                 'useSortable' => true,
                 'headerThumbnail' => [
                     'field' => 'uid_local',
-                    'width' => '45',
-                    'height' => '45c',
+                    'height' => '45m',
                 ],
 
                 'enabledControls' => [
@@ -761,6 +823,9 @@ class ExtensionManagementUtility
      */
     public static function addModule($main, $sub = '', $position = '', $path = null, $moduleConfiguration = [])
     {
+        if (!isset($GLOBALS['TBE_MODULES'])) {
+            $GLOBALS['TBE_MODULES'] = [];
+        }
         // If there is already a main module by this name:
         // Adding the submodule to the correct position:
         if (isset($GLOBALS['TBE_MODULES'][$main]) && $sub) {
@@ -788,6 +853,48 @@ class ExtensionManagementUtility
             }
             // Re-inserting the submodule list:
             $GLOBALS['TBE_MODULES'][$main] = trim($modules, ',');
+        } elseif (!isset($GLOBALS['TBE_MODULES'][$main]) && empty($sub)) {
+            // Create a new main module, respecting the order, which is only possible when the module does not exist yet
+            $conf = $GLOBALS['TBE_MODULES']['_configuration'] ?? [];
+            unset($GLOBALS['TBE_MODULES']['_configuration']);
+            $navigationComponents = $GLOBALS['TBE_MODULES']['_navigationComponents'] ?? [];
+            unset($GLOBALS['TBE_MODULES']['_navigationComponents']);
+
+            $modules = array_keys($GLOBALS['TBE_MODULES']);
+            [$place, $moduleReference] = array_pad(GeneralUtility::trimExplode(':', $position, true), 2, null);
+            if ($place === null || ($moduleReference !== null && !in_array($moduleReference, $modules, true))) {
+                $place = 'bottom';
+            }
+            $newModules = [];
+            switch (strtolower($place)) {
+                case 'after':
+                    foreach ($modules as $existingMainModule) {
+                        $newModules[$existingMainModule] = $GLOBALS['TBE_MODULES'][$existingMainModule];
+                        if ($moduleReference === $existingMainModule) {
+                            $newModules[$main] = '';
+                        }
+                    }
+                    break;
+                case 'before':
+                    foreach ($modules as $existingMainModule) {
+                        if ($moduleReference === $existingMainModule) {
+                            $newModules[$main] = '';
+                        }
+                        $newModules[$existingMainModule] = $GLOBALS['TBE_MODULES'][$existingMainModule];
+                    }
+                    break;
+                case 'top':
+                    $newModules[$main] = '';
+                    $newModules += $GLOBALS['TBE_MODULES'];
+                    break;
+                case 'bottom':
+                default:
+                    $newModules = $GLOBALS['TBE_MODULES'];
+                    $newModules[$main] = '';
+            }
+            $GLOBALS['TBE_MODULES'] = $newModules;
+            $GLOBALS['TBE_MODULES']['_configuration'] = $conf;
+            $GLOBALS['TBE_MODULES']['_navigationComponents'] = $navigationComponents;
         } else {
             // Create new main modules with only one submodule, $sub (or none if $sub is blank)
             $GLOBALS['TBE_MODULES'][$main] = $sub;
@@ -796,6 +903,13 @@ class ExtensionManagementUtility
         // add additional configuration
         $fullModuleSignature = $main . ($sub ? '_' . $sub : '');
         if (is_array($moduleConfiguration) && !empty($moduleConfiguration)) {
+            // remove default icon if an icon identifier is available
+            if (!empty($moduleConfiguration['iconIdentifier'])
+                && !empty($moduleConfiguration['icon'])
+                && $moduleConfiguration['icon'] === 'EXT:extbase/Resources/Public/Icons/Extension.png'
+            ) {
+                unset($moduleConfiguration['icon']);
+            }
             if (!empty($moduleConfiguration['icon'])) {
                 $iconRegistry = GeneralUtility::makeInstance(IconRegistry::class);
                 $iconIdentifier = 'module-' . $fullModuleSignature;
@@ -1127,7 +1241,7 @@ class ExtensionManagementUtility
      *
      * FOR USE IN files in Configuration/TCA/Overrides/*.php Use in ext_tables.php FILES may break the frontend.
      *
-     * @param array $itemArray Numerical array: [0] => Plugin label, [1] => Plugin identifier / plugin key, ideally prefixed with a extension-specific name (e.g. "events2_list"), [2] => Path to plugin icon relative to TYPO3_mainDir
+     * @param array $itemArray Numerical array: [0] => Plugin label, [1] => Plugin identifier / plugin key, ideally prefixed with an extension-specific name (e.g. "events2_list"), [2] => Path to plugin icon, [3] => an optional "group" ID, falls back to "default"
      * @param string $type Type (eg. "list_type") - basically a field from "tt_content" table
      * @param string $extensionKey The extension key
      * @throws \RuntimeException
@@ -1148,6 +1262,9 @@ class ExtensionManagementUtility
             // @todo do we really set $itemArray[2], even if we cannot find an icon? (as that means it's set to 'EXT:foobar/')
             $itemArray[2] = 'EXT:' . $extensionKey . '/' . static::getExtensionIcon(static::$packageManager->getPackage($extensionKey)->getPackagePath());
         }
+        if (!isset($itemArray[3])) {
+            $itemArray[3] = 'default';
+        }
         if (is_array($GLOBALS['TCA']['tt_content']['columns']) && is_array($GLOBALS['TCA']['tt_content']['columns'][$type]['config']['items'])) {
             foreach ($GLOBALS['TCA']['tt_content']['columns'][$type]['config']['items'] as $k => $v) {
                 if ((string)$v[1] === (string)$itemArray[1]) {
@@ -1352,7 +1469,7 @@ tt_content.' . $key . $suffix . ' {
      * @param string $key Is the extension key (informative only).
      * @param string $type Is either "setup" or "constants" and obviously determines which kind of TypoScript code we are adding.
      * @param string $content Is the TS content, will be prefixed with a [GLOBAL] line and a comment-header.
-     * @param int|string string pointing to the "key" of a static_file template ([reduced extension_key]/[local path]). The points is that the TypoScript you add is included only IF that static template is included (and in that case, right after). So effectively the TypoScript you set can specifically overrule settings from those static templates.
+     * @param int|string $afterStaticUid string pointing to the "key" of a static_file template ([reduced extension_key]/[local path]). The points is that the TypoScript you add is included only IF that static template is included (and in that case, right after). So effectively the TypoScript you set can specifically overrule settings from those static templates.
      * @throws \InvalidArgumentException
      */
     public static function addTypoScript(string $key, string $type, string $content, $afterStaticUid = 0)
@@ -1488,7 +1605,7 @@ tt_content.' . $key . $suffix . ' {
                 $phpCodeToCache[] = ' */';
                 $phpCodeToCache[] = '';
                 // Add ext_localconf.php content of extension
-                $phpCodeToCache[] = trim(file_get_contents($extLocalconfPath));
+                $phpCodeToCache[] = trim((string)file_get_contents($extLocalconfPath));
                 $phpCodeToCache[] = '';
                 $phpCodeToCache[] = '';
             }
@@ -1712,7 +1829,7 @@ tt_content.' . $key . $suffix . ' {
                 $phpCodeToCache[] = ' */';
                 $phpCodeToCache[] = '';
                 // Add ext_tables.php content of extension
-                $phpCodeToCache[] = trim(file_get_contents($extTablesPath));
+                $phpCodeToCache[] = trim((string)file_get_contents($extTablesPath));
                 $phpCodeToCache[] = '';
             }
         }
