@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Utility\File;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,9 +13,12 @@ namespace TYPO3\CMS\Core\Utility\File;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Utility\File;
+
 use TYPO3\CMS\Core\Charset\CharsetConverter;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\PathUtility;
+use TYPO3\CMS\Core\Utility\StringUtility;
 
 /**
  * Contains class with basic file management functions
@@ -94,7 +96,7 @@ class BasicFileUtility
      * @param string $theFile The input filename to check
      * @param string $theDest The directory for which to return a unique filename for $theFile. $theDest MUST be a valid directory. Should be absolute.
      * @param bool $dontCheckForUnique If set the filename is returned with the path prepended without checking whether it already existed!
-     * @return string The destination absolute filepath (not just the name!) of a unique filename/foldername in that path.
+     * @return string|null The destination absolute filepath (not just the name!) of a unique filename/foldername in that path.
      * @internal May be removed without further notice. Method has been marked as deprecated for various versions but is still used in core.
      * @todo: should go into the LocalDriver in a protected way (not important to the outside world)
      */
@@ -123,7 +125,7 @@ class BasicFileUtility
                     $insert = '_' . sprintf('%02d', $a);
                 } else {
                     // .. then we try unique-strings...
-                    $insert = '_' . substr(md5(uniqid('', true)), 0, $this->uniquePrecision);
+                    $insert = '_' . substr(md5(StringUtility::getUniqueId()), 0, $this->uniquePrecision);
                 }
                 $theTestFile = $theTempFileBody . $insert . $theOrigExt;
                 $theDestFile = $theDest . '/' . $theTestFile;
@@ -134,6 +136,8 @@ class BasicFileUtility
                 }
             }
         }
+
+        return null;
     }
 
     /*********************
@@ -155,11 +159,11 @@ class BasicFileUtility
         // Handle UTF-8 characters
         if ($GLOBALS['TYPO3_CONF_VARS']['SYS']['UTF8filesystem']) {
             // allow ".", "-", 0-9, a-z, A-Z and everything beyond U+C0 (latin capital letter a with grave)
-            $cleanFileName = preg_replace('/[' . self::UNSAFE_FILENAME_CHARACTER_EXPRESSION . ']/u', '_', trim($fileName));
+            $cleanFileName = preg_replace('/[' . self::UNSAFE_FILENAME_CHARACTER_EXPRESSION . ']/u', '_', trim($fileName)) ?? '';
         } else {
             $fileName = GeneralUtility::makeInstance(CharsetConverter::class)->utf8_char_mapping($fileName);
             // Replace unwanted characters by underscores
-            $cleanFileName = preg_replace('/[' . self::UNSAFE_FILENAME_CHARACTER_EXPRESSION . '\\xC0-\\xFF]/', '_', trim($fileName));
+            $cleanFileName = preg_replace('/[' . self::UNSAFE_FILENAME_CHARACTER_EXPRESSION . '\\xC0-\\xFF]/', '_', trim($fileName)) ?? '';
         }
         // Strip trailing dots and return
         return rtrim($cleanFileName, '.');
