@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Core\Utility;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Core\Utility;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Core\Utility;
+
 use TYPO3\CMS\Core\Core\Environment;
 
 /**
@@ -108,12 +109,12 @@ class PathUtility
      */
     public static function getCommonPrefix(array $paths)
     {
-        $paths = array_map([\TYPO3\CMS\Core\Utility\GeneralUtility::class, 'fixWindowsFilePath'], $paths);
+        $paths = array_map([GeneralUtility::class, 'fixWindowsFilePath'], $paths);
         $commonPath = null;
         if (count($paths) === 1) {
             $commonPath = array_shift($paths);
         } elseif (count($paths) > 1) {
-            $parts = explode('/', array_shift($paths));
+            $parts = explode('/', (string)array_shift($paths));
             $comparePath = '';
             $break = false;
             foreach ($parts as $part) {
@@ -163,7 +164,7 @@ class PathUtility
      */
     public static function basename($path)
     {
-        $currentLocale = setlocale(LC_CTYPE, 0);
+        $currentLocale = (string)setlocale(LC_CTYPE, '0');
         setlocale(LC_CTYPE, $GLOBALS['TYPO3_CONF_VARS']['SYS']['systemLocale']);
         $basename = basename($path);
         setlocale(LC_CTYPE, $currentLocale);
@@ -184,7 +185,7 @@ class PathUtility
      */
     public static function dirname($path)
     {
-        $currentLocale = setlocale(LC_CTYPE, 0);
+        $currentLocale = (string)setlocale(LC_CTYPE, '0');
         setlocale(LC_CTYPE, $GLOBALS['TYPO3_CONF_VARS']['SYS']['systemLocale']);
         $dirname = dirname($path);
         setlocale(LC_CTYPE, $currentLocale);
@@ -202,11 +203,11 @@ class PathUtility
      * @param string $path
      * @param int $options
      *
-     * @return string|array
+     * @return string|string[]
      */
     public static function pathinfo($path, $options = null)
     {
-        $currentLocale = setlocale(LC_CTYPE, 0);
+        $currentLocale = (string)setlocale(LC_CTYPE, '0');
         setlocale(LC_CTYPE, $GLOBALS['TYPO3_CONF_VARS']['SYS']['systemLocale']);
         $pathinfo = $options == null ? pathinfo($path) : pathinfo($path, $options);
         setlocale(LC_CTYPE, $currentLocale);
