@@ -72,13 +72,17 @@ return [
         'fileCreateMask' => '0664',
         'folderCreateMask' => '2775',
         'features' => [
-            'fluidBasedPageModule' => true,
+            'fluidBasedPageModule' => false,
             'form.legacyUploadMimeTypes' => true,
             'redirects.hitCount' => false,
             'unifiedPageTranslationHandling' => false,
             'security.frontend.keepSessionDataOnLogout' => false,
+            'security.frontend.htmlSanitizeParseFuncDefault' => true,
+            'security.backend.htmlSanitizeRte' => false,
+            'security.backend.enforceReferrer' => true,
             'rearrangedRedirectMiddlewares' => false,
             'felogin.extbase' => false,
+            'yamlImportsFollowDeclarationOrder' => false
         ],
         'createGroup' => '',
         'sitename' => 'TYPO3',
@@ -246,6 +250,9 @@ return [
                 ],
             ],
         ],
+        'htmlSanitizer' => [
+            'default' => \TYPO3\CMS\Core\Html\DefaultSanitizerBuilder::class,
+        ],
         'defaultCategorizedTables' => '',
         'displayErrors' => -1,
         'productionExceptionHandler' => \TYPO3\CMS\Core\Error\ProductionExceptionHandler::class,
@@ -274,6 +281,21 @@ return [
                 ]
             ],
             'processors' => [
+                'SvgImageProcessor' => [
+                    'className' => \TYPO3\CMS\Core\Resource\Processing\SvgImageProcessor::class,
+                    'before' => [
+                        'LocalImageProcessor',
+                    ],
+                ],
+                'OnlineMediaPreviewProcessor' => [
+                    'className' => \TYPO3\CMS\Core\Resource\OnlineMedia\Processing\PreviewProcessing::class,
+                    'after' => [
+                        'SvgImageProcessor',
+                    ],
+                    'before' => [
+                        'LocalImageProcessor',
+                    ],
+                ],
                 'LocalImageProcessor' => [
                     'className' => \TYPO3\CMS\Core\Resource\Processing\LocalImageProcessor::class,
                 ],
@@ -567,6 +589,12 @@ return [
                             \TYPO3\CMS\Backend\Form\FormDataProvider\TcaRadioItems::class
                         ],
                     ],
+                    \TYPO3\CMS\Backend\Form\FormDataProvider\TcaSlug::class => [
+                        'depends' => [
+                            \TYPO3\CMS\Backend\Form\FormDataProvider\DatabaseRecordOverrideValues::class,
+                            \TYPO3\CMS\Backend\Form\FormDataProvider\TcaTypesShowitem::class,
+                        ],
+                    ],
                     \TYPO3\CMS\Backend\Form\FormDataProvider\TcaGroup::class => [
                         'depends' => [
                             \TYPO3\CMS\Backend\Form\FormDataProvider\DatabaseRecordOverrideValues::class,
@@ -757,6 +785,11 @@ return [
                             \TYPO3\CMS\Backend\Form\FormDataProvider\DatabaseRowDefaultValues::class,
                         ],
                     ],
+                    \TYPO3\CMS\Backend\Form\FormDataProvider\DatabasePageRootline::class => [
+                        'depends' => [
+                            \TYPO3\CMS\Backend\Form\FormDataProvider\DatabaseEffectivePid::class,
+                        ],
+                    ],
                     \TYPO3\CMS\Backend\Form\FormDataProvider\TcaCheckboxItems::class => [
                         'depends' => [
                             \TYPO3\CMS\Backend\Form\FormDataProvider\DatabaseRowDefaultValues::class,
@@ -1113,6 +1146,8 @@ return [
         'userUploadDir' => '',
         'warning_email_addr' => '',
         'warning_mode' => 0,
+        'passwordReset' => true,
+        'passwordResetForAdmins' => true,
         'lockIP' => 0,
         'lockIPv6' => 0,
         'sessionTimeout' => 28800,  // a backend user logged in for 8 hours
@@ -1270,7 +1305,6 @@ return [
         'defaultPermissions' => [],
         'defaultUC' => [],
         'customPermOptions' => [], // Array with sets of custom permission options. Syntax is; 'key' => array('header' => 'header string, language split', 'items' => array('key' => array('label, language split','icon reference', 'Description text, language split'))). Keys cannot contain ":|," characters.
-        'fileDenyPattern' => FILE_DENY_PATTERN_DEFAULT,
         'interfaces' => 'backend',
         'explicitADmode' => 'explicitDeny',
         'flexformForceCDATA' => 0,
@@ -1348,7 +1382,7 @@ return [
     'MAIL' => [ // Mail configurations to tune how \TYPO3\CMS\Core\Mail\ classes will send their mails.
         'transport' => 'sendmail',
         'transport_smtp_server' => 'localhost:25',
-        'transport_smtp_encrypt' => '',
+        'transport_smtp_encrypt' => false,
         'transport_smtp_username' => '',
         'transport_smtp_password' => '',
         'transport_sendmail_command' => '',
@@ -1414,7 +1448,8 @@ return [
                     'writerConfiguration' => [
                         \TYPO3\CMS\Core\Log\LogLevel::NOTICE => [
                             \TYPO3\CMS\Core\Log\Writer\FileWriter::class => [
-                                'logFileInfix' => 'deprecations'
+                                'logFileInfix' => 'deprecations',
+                                'disabled' => true,
                             ],
                         ]
                     ]
