@@ -17,6 +17,9 @@ return [
             ],
         ],
     ],
+    'FE' => [
+        'disableNoCacheParameter' => true,
+    ],
     'SYS' => [
         'sitename' => 'New TYPO3 site',
         'features' => [
@@ -24,6 +27,7 @@ return [
             'unifiedPageTranslationHandling' => true,
             'rearrangedRedirectMiddlewares' => true,
             'felogin.extbase' => true,
+            'yamlImportsFollowDeclarationOrder' => true
         ],
     ],
 ];
