@@ -1,4 +1,5 @@
 <?php
+
 return [
     'ctrl' => [
         'label' => 'username',
@@ -172,6 +173,7 @@ return [
         'disable' => [
             'exclude' => 1,
             'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.enabled',
+            'displayCond' => 'USER:' . \TYPO3\CMS\Core\Hooks\TcaDisplayConditions::class . '->isRecordCurrentUser:false',
             'config' => [
                 'type' => 'check',
                 'renderType' => 'checkboxToggle',
@@ -187,6 +189,7 @@ return [
         ],
         'disableIPlock' => [
             'exclude' => 1,
+            'displayCond' => 'USER:TYPO3\CMS\Core\Hooks\TcaDisplayConditions->isIPLockEnabled:backend',
             'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_tca.xlf:be_users.IPlockState',
             'config' => [
                 'type' => 'check',
@@ -265,6 +268,7 @@ return [
         ],
         'workspace_perms' => [
             'exclude' => 1,
+            'displayCond' => 'USER:TYPO3\CMS\Core\Hooks\TcaDisplayConditions->isExtensionInstalled:workspaces',
             'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_tca.xlf:workspace_perms',
             'config' => [
                 'type' => 'check',
