@@ -1,4 +1,5 @@
 <?php
+
 return [
     'ctrl' => [
         'title' => 'LLL:EXT:core/Resources/Private/Language/locallang_tca.xlf:sys_file',
@@ -21,12 +22,12 @@ return [
             'ignoreWebMountRestriction' => true,
             'ignoreRootLevelRestriction' => true,
         ],
-        'searchFields' => 'name, type, mime_type, sha1'
+        'searchFields' => 'name, type, mime_type'
     ],
     'columns' => [
         'fileinfo' => [
             'config' => [
-                'type' => 'user',
+                'type' => 'none',
                 'renderType' => 'fileInfo',
             ]
         ],
