@@ -1,13 +1,14 @@
 <?php
+
 return [
     // Get the content of a widget
-    'ext-dashboard-get-widget-content' => [
-        'path' => '/ext/dashboard/widget/content',
+    'dashboard_get_widget_content' => [
+        'path' => '/dashboard/widget/content',
         'target' => TYPO3\CMS\Dashboard\Controller\WidgetAjaxController::class . '::getContent'
     ],
     // Save positions of the widgets
-    'ext-dashboard-save-widget-positions' => [
-        'path' => '/ext/dashboard/widget/positions/save',
+    'dashboard_save_widget_positions' => [
+        'path' => '/dashboard/widget/positions/save',
         'target' => TYPO3\CMS\Dashboard\Controller\WidgetAjaxController::class . '::savePositions'
     ],
 ];
