@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Domain\Model;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,13 +13,26 @@ namespace TYPO3\CMS\Extbase\Domain\Model;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Domain\Model;
+
 use TYPO3\CMS\Extbase\Annotation as Extbase;
+use TYPO3\CMS\Extbase\DomainObject\AbstractEntity;
 
 /**
  * This model represents a file mount.
+ *
+ * @deprecated since TYPO3 10.4, will be removed in version 11.0
  */
-class FileMount extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity
+class FileMount extends AbstractEntity
 {
+    public function __construct()
+    {
+        trigger_error(
+            __CLASS__ . ' is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+            E_USER_DEPRECATED
+        );
+    }
+
     /**
      * Title of the file mount.
      *
