@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Extbase\Error;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Extbase\Error;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Error;
+
 /**
  * Result object for operations dealing with objects, such as the Property Mapper or the Validators.
  */
@@ -154,9 +155,9 @@ class Result
     /**
      * Get the first error object of the current Result object (non-recursive)
      *
-     * @return Error
+     * @return bool|Error
      */
-    public function getFirstError(): Error
+    public function getFirstError()
     {
         reset($this->errors);
         return current($this->errors);
@@ -165,9 +166,9 @@ class Result
     /**
      * Get the first warning object of the current Result object (non-recursive)
      *
-     * @return Warning
+     * @return bool|Warning
      */
-    public function getFirstWarning(): Warning
+    public function getFirstWarning()
     {
         reset($this->warnings);
         return current($this->warnings);
@@ -176,9 +177,9 @@ class Result
     /**
      * Get the first notice object of the current Result object (non-recursive)
      *
-     * @return Notice
+     * @return bool|Notice
      */
-    public function getFirstNotice(): Notice
+    public function getFirstNotice()
     {
         reset($this->notices);
         return current($this->notices);
