@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Mvc\Controller;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,9 +13,13 @@ namespace TYPO3\CMS\Extbase\Mvc\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Mvc\Controller;
+
 use TYPO3\CMS\Extbase\Error\Result;
 use TYPO3\CMS\Extbase\Property\Exception\TargetNotFoundException;
+use TYPO3\CMS\Extbase\Property\PropertyMapper;
 use TYPO3\CMS\Extbase\Utility\TypeHandlingUtility;
+use TYPO3\CMS\Extbase\Validation\Validator\ValidatorInterface;
 
 /**
  * A controller argument
@@ -64,7 +67,7 @@ class Argument
     /**
      * Actual value of this argument
      *
-     * @var mixed
+     * @var mixed|null
      */
     protected $value;
 
@@ -97,7 +100,7 @@ class Argument
     /**
      * @param \TYPO3\CMS\Extbase\Property\PropertyMapper $propertyMapper
      */
-    public function injectPropertyMapper(\TYPO3\CMS\Extbase\Property\PropertyMapper $propertyMapper)
+    public function injectPropertyMapper(PropertyMapper $propertyMapper)
     {
         $this->propertyMapper = $propertyMapper;
     }
@@ -227,7 +230,7 @@ class Argument
      * @param \TYPO3\CMS\Extbase\Validation\Validator\ValidatorInterface $validator The actual validator object
      * @return \TYPO3\CMS\Extbase\Mvc\Controller\Argument Returns $this (used for fluent interface)
      */
-    public function setValidator(\TYPO3\CMS\Extbase\Validation\Validator\ValidatorInterface $validator)
+    public function setValidator(ValidatorInterface $validator)
     {
         $this->validator = $validator;
         return $this;
@@ -317,7 +320,7 @@ class Argument
     /**
      * @return \TYPO3\CMS\Extbase\Error\Result
      */
-    public function validate(): \TYPO3\CMS\Extbase\Error\Result
+    public function validate(): Result
     {
         if ($this->hasBeenValidated) {
             return $this->validationResults;
