@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Mvc\Controller;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,14 @@ namespace TYPO3\CMS\Extbase\Mvc\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Mvc\Controller;
+
+use TYPO3\CMS\Core\Messaging\FlashMessageService;
+use TYPO3\CMS\Extbase\Mvc\Request;
+use TYPO3\CMS\Extbase\Mvc\Response;
+use TYPO3\CMS\Extbase\Mvc\Web\Routing\UriBuilder;
+use TYPO3\CMS\Extbase\Service\ExtensionService;
+
 /**
  * The controller context contains information from the controller
  */
@@ -57,7 +64,7 @@ class ControllerContext
     /**
      * @param \TYPO3\CMS\Core\Messaging\FlashMessageService $flashMessageService
      */
-    public function injectFlashMessageService(\TYPO3\CMS\Core\Messaging\FlashMessageService $flashMessageService)
+    public function injectFlashMessageService(FlashMessageService $flashMessageService)
     {
         $this->flashMessageService = $flashMessageService;
     }
@@ -65,7 +72,7 @@ class ControllerContext
     /**
      * @param \TYPO3\CMS\Extbase\Service\ExtensionService $extensionService
      */
-    public function injectExtensionService(\TYPO3\CMS\Extbase\Service\ExtensionService $extensionService)
+    public function injectExtensionService(ExtensionService $extensionService)
     {
         $this->extensionService = $extensionService;
     }
@@ -75,7 +82,7 @@ class ControllerContext
      *
      * @param \TYPO3\CMS\Extbase\Mvc\Request $request
      */
-    public function setRequest(\TYPO3\CMS\Extbase\Mvc\Request $request)
+    public function setRequest(Request $request)
     {
         $this->request = $request;
     }
@@ -95,7 +102,7 @@ class ControllerContext
      *
      * @param \TYPO3\CMS\Extbase\Mvc\Response $response
      */
-    public function setResponse(\TYPO3\CMS\Extbase\Mvc\Response $response)
+    public function setResponse(Response $response)
     {
         $this->response = $response;
     }
@@ -115,7 +122,7 @@ class ControllerContext
      *
      * @param \TYPO3\CMS\Extbase\Mvc\Controller\Arguments $arguments
      */
-    public function setArguments(\TYPO3\CMS\Extbase\Mvc\Controller\Arguments $arguments)
+    public function setArguments(Arguments $arguments)
     {
         $this->arguments = $arguments;
     }
@@ -133,7 +140,7 @@ class ControllerContext
     /**
      * @param \TYPO3\CMS\Extbase\Mvc\Web\Routing\UriBuilder $uriBuilder
      */
-    public function setUriBuilder(\TYPO3\CMS\Extbase\Mvc\Web\Routing\UriBuilder $uriBuilder)
+    public function setUriBuilder(UriBuilder $uriBuilder)
     {
         $this->uriBuilder = $uriBuilder;
     }
