@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Mvc;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Extbase\Mvc;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Mvc;
+
 use TYPO3\CMS\Core\Page\PageRenderer;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController;
@@ -21,7 +22,7 @@ use TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController;
 /**
  * A generic and very basic response implementation
  */
-class Response implements \TYPO3\CMS\Extbase\Mvc\ResponseInterface
+class Response implements ResponseInterface
 {
     /**
      * @var string The response content
@@ -321,7 +322,7 @@ class Response implements \TYPO3\CMS\Extbase\Mvc\ResponseInterface
     public function addAdditionalHeaderData($additionalHeaderData)
     {
         if (!is_string($additionalHeaderData)) {
-            throw new \InvalidArgumentException('The additiona header data must be of type String, ' . gettype($additionalHeaderData) . ' given.', 1237370877);
+            throw new \InvalidArgumentException('The additional header data must be of type String, ' . gettype($additionalHeaderData) . ' given.', 1237370877);
         }
         if ($this->request->isCached()) {
             /** @var PageRenderer $pageRenderer */
@@ -346,7 +347,7 @@ class Response implements \TYPO3\CMS\Extbase\Mvc\ResponseInterface
      * @param \TYPO3\CMS\Extbase\Mvc\Request $request
      * @internal only to be used within Extbase, not part of TYPO3 Core API.
      */
-    public function setRequest(\TYPO3\CMS\Extbase\Mvc\Request $request)
+    public function setRequest(Request $request)
     {
         $this->request = $request;
     }
