@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Persistence\Generic\Mapper;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,15 +13,35 @@ namespace TYPO3\CMS\Extbase\Persistence\Generic\Mapper;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Persistence\Generic\Mapper;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
+use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Database\Query\QueryHelper;
+use TYPO3\CMS\Core\Database\RelationHandler;
+use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Extbase\DomainObject\DomainObjectInterface;
 use TYPO3\CMS\Extbase\Event\Persistence\AfterObjectThawedEvent;
 use TYPO3\CMS\Extbase\Object\Exception\CannotReconstituteObjectException;
+use TYPO3\CMS\Extbase\Object\ObjectManagerInterface;
 use TYPO3\CMS\Extbase\Persistence;
+use TYPO3\CMS\Extbase\Persistence\Generic\Exception;
 use TYPO3\CMS\Extbase\Persistence\Generic\Exception\UnexpectedTypeException;
+use TYPO3\CMS\Extbase\Persistence\Generic\LazyLoadingProxy;
+use TYPO3\CMS\Extbase\Persistence\Generic\LazyObjectStorage;
+use TYPO3\CMS\Extbase\Persistence\Generic\LoadingStrategyInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Mapper\Exception\NonExistentPropertyException;
+use TYPO3\CMS\Extbase\Persistence\Generic\Mapper\Exception\UnknownPropertyTypeException;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\QueryObjectModelFactory;
+use TYPO3\CMS\Extbase\Persistence\Generic\Query;
+use TYPO3\CMS\Extbase\Persistence\Generic\QueryFactoryInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Session;
+use TYPO3\CMS\Extbase\Persistence\ObjectStorage;
 use TYPO3\CMS\Extbase\Persistence\QueryInterface;
+use TYPO3\CMS\Extbase\Persistence\QueryResultInterface;
+use TYPO3\CMS\Extbase\Reflection\ClassSchema;
 use TYPO3\CMS\Extbase\Reflection\ClassSchema\Exception\NoSuchPropertyException;
+use TYPO3\CMS\Extbase\Reflection\ReflectionService;
 use TYPO3\CMS\Extbase\Utility\TypeHandlingUtility;
 
 /**
@@ -67,7 +86,7 @@ class DataMapper
     protected $eventDispatcher;
 
     /**
-     * @var ?QueryInterface
+     * @var QueryInterface|null
      */
     protected $query;
 
@@ -83,12 +102,12 @@ class DataMapper
      * @param QueryInterface|null $query
      */
     public function __construct(
-        \TYPO3\CMS\Extbase\Reflection\ReflectionService $reflectionService,
-        \TYPO3\CMS\Extbase\Persistence\Generic\Qom\QueryObjectModelFactory $qomFactory,
-        \TYPO3\CMS\Extbase\Persistence\Generic\Session $persistenceSession,
-        \TYPO3\CMS\Extbase\Persistence\Generic\Mapper\DataMapFactory $dataMapFactory,
-        \TYPO3\CMS\Extbase\Persistence\Generic\QueryFactoryInterface $queryFactory,
-        \TYPO3\CMS\Extbase\Object\ObjectManagerInterface $objectManager,
+        ReflectionService $reflectionService,
+        QueryObjectModelFactory $qomFactory,
+        Session $persistenceSession,
+        DataMapFactory $dataMapFactory,
+        QueryFactoryInterface $queryFactory,
+        ObjectManagerInterface $objectManager,
         EventDispatcherInterface $eventDispatcher,
         ?QueryInterface $query = null
     ) {
@@ -191,7 +210,7 @@ class DataMapper
     {
         // Note: The class_implements() function also invokes autoload to assure that the interfaces
         // and the class are loaded. Would end up with __PHP_Incomplete_Class without it.
-        if (!in_array(\TYPO3\CMS\Extbase\DomainObject\DomainObjectInterface::class, class_implements($className))) {
+        if (!in_array(DomainObjectInterface::class, class_implements($className))) {
             throw new CannotReconstituteObjectException('Cannot create empty instance of the class "' . $className
                 . '" because it does not implement the TYPO3\\CMS\\Extbase\\DomainObject\\DomainObjectInterface.', 1234386924);
         }
@@ -204,6 +223,8 @@ class DataMapper
      *
      * @param DomainObjectInterface $object The object to set properties on
      * @param array $row
+     * @throws NonExistentPropertyException
+     * @throws UnknownPropertyTypeException
      */
     protected function thawProperties(DomainObjectInterface $object, array $row)
     {
@@ -230,7 +251,28 @@ class DataMapper
             }
             $columnMap = $dataMap->getColumnMap($propertyName);
             $columnName = $columnMap->getColumnName();
-            $propertyType = $classSchema->getProperty($propertyName)->getType();
+
+            try {
+                $property = $classSchema->getProperty($propertyName);
+            } catch (NoSuchPropertyException $e) {
+                throw new NonExistentPropertyException(
+                    'The type of property ' . $className . '::' . $propertyName . ' could not be identified, ' .
+                    'as property ' . $propertyName . ' is unknown to the ' . ClassSchema::class . ' instance of class ' .
+                    $className . '. Please make sure said property exists and that you cleared all caches to trigger ' .
+                    'a new build of said ' . ClassSchema::class . ' instance.',
+                    1580056272
+                );
+            }
+
+            $propertyType = $property->getType();
+            if ($propertyType === null) {
+                throw new UnknownPropertyTypeException(
+                    'The type of property ' . $className . '::' . $propertyName . ' could not be identified, therefore the desired value (' .
+                    var_export($propertyValue, true) . ') cannot be mapped onto it. The type of a class property is usually defined via php doc blocks. ' .
+                    'Make sure the property has a valid @var tag set which defines the type.',
+                    1579965021
+                );
+            }
             $propertyValue = null;
             if (isset($row[$columnName])) {
                 switch ($propertyType) {
@@ -252,22 +294,21 @@ class DataMapper
                         // $propertyValue = $this->mapArray($row[$columnName]); // Not supported, yet!
                         break;
                     case \SplObjectStorage::class:
-                    case Persistence\ObjectStorage::class:
+                    case ObjectStorage::class:
                         $propertyValue = $this->mapResultToPropertyValue(
                             $object,
                             $propertyName,
                             $this->fetchRelated($object, $propertyName, $row[$columnName])
                         );
                         break;
-                    case is_subclass_of($propertyType, \DateTimeInterface::class):
+                    default:
+                        if (is_subclass_of($propertyType, \DateTimeInterface::class)) {
                             $propertyValue = $this->mapDateTime(
                                 $row[$columnName],
                                 $columnMap->getDateTimeStorageFormat(),
                                 $propertyType
                             );
-                        break;
-                    default:
-                        if (TypeHandlingUtility::isCoreType($propertyType)) {
+                        } elseif (TypeHandlingUtility::isCoreType($propertyType)) {
                             $propertyValue = $this->mapCoreType($propertyType, $row[$columnName]);
                         } else {
                             $propertyValue = $this->mapObjectToClassProperty(
@@ -303,7 +344,7 @@ class DataMapper
      *
      * @param int|string $value Unix timestamp or date/datetime/time value
      * @param string|null $storageFormat Storage format for native date/datetime/time fields
-     * @param string|null $targetType The object class name to be created
+     * @param string $targetType The object class name to be created
      * @return \DateTimeInterface
      */
     protected function mapDateTime($value, $storageFormat = null, $targetType = \DateTime::class)
@@ -317,12 +358,12 @@ class DataMapper
         if (in_array($storageFormat, $dateTimeTypes, true)) {
             // native date/datetime/time values are stored in UTC
             $utcTimeZone = new \DateTimeZone('UTC');
-            $utcDateTime = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance($targetType, $value, $utcTimeZone);
+            $utcDateTime = GeneralUtility::makeInstance($targetType, $value, $utcTimeZone);
             $currentTimeZone = new \DateTimeZone(date_default_timezone_get());
             return $utcDateTime->setTimezone($currentTimeZone);
         }
         // integer timestamps are local server time
-        return \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance($targetType, date('c', (int)$value));
+        return GeneralUtility::makeInstance($targetType, date('c', (int)$value));
     }
 
     /**
@@ -338,13 +379,13 @@ class DataMapper
     {
         $property = $this->reflectionService->getClassSchema(get_class($parentObject))->getProperty($propertyName);
         if ($enableLazyLoading === true && $property->isLazy()) {
-            if ($property->getType() === Persistence\ObjectStorage::class) {
-                $result = $this->objectManager->get(\TYPO3\CMS\Extbase\Persistence\Generic\LazyObjectStorage::class, $parentObject, $propertyName, $fieldValue, $this);
+            if ($property->getType() === ObjectStorage::class) {
+                $result = $this->objectManager->get(LazyObjectStorage::class, $parentObject, $propertyName, $fieldValue, $this);
             } else {
                 if (empty($fieldValue)) {
                     $result = null;
                 } else {
-                    $result = $this->objectManager->get(\TYPO3\CMS\Extbase\Persistence\Generic\LazyLoadingProxy::class, $parentObject, $propertyName, $fieldValue, $this);
+                    $result = $this->objectManager->get(LazyLoadingProxy::class, $parentObject, $propertyName, $fieldValue, $this);
                 }
             }
         } else {
@@ -404,7 +445,7 @@ class DataMapper
         $columnMap = $dataMap->getColumnMap($propertyName);
         $type = $this->getType(get_class($parentObject), $propertyName);
         $query = $this->queryFactory->create($type);
-        if ($this->query && $query instanceof Persistence\Generic\Query) {
+        if ($this->query && $query instanceof Query) {
             $query->setParentQuery($this->query);
         }
         $query->getQuerySettings()->setRespectStoragePage(false);
@@ -426,15 +467,15 @@ class DataMapper
 
         if ($columnMap->getTypeOfRelation() === ColumnMap::RELATION_HAS_MANY) {
             if ($columnMap->getChildSortByFieldName() !== null) {
-                $query->setOrderings([$columnMap->getChildSortByFieldName() => Persistence\QueryInterface::ORDER_ASCENDING]);
+                $query->setOrderings([$columnMap->getChildSortByFieldName() => QueryInterface::ORDER_ASCENDING]);
             }
         } elseif ($columnMap->getTypeOfRelation() === ColumnMap::RELATION_HAS_AND_BELONGS_TO_MANY) {
             $query->setSource($this->getSource($parentObject, $propertyName));
             if ($columnMap->getChildSortByFieldName() !== null) {
-                $query->setOrderings([$columnMap->getChildSortByFieldName() => Persistence\QueryInterface::ORDER_ASCENDING]);
+                $query->setOrderings([$columnMap->getChildSortByFieldName() => QueryInterface::ORDER_ASCENDING]);
             }
         }
-        $query->matching($this->getConstraint($query, $parentObject, $propertyName, $fieldValue, $columnMap->getRelationTableMatchFields()));
+        $query->matching($this->getConstraint($query, $parentObject, $propertyName, $fieldValue, (array)$columnMap->getRelationTableMatchFields()));
         return $query;
     }
 
@@ -448,19 +489,55 @@ class DataMapper
      * @param array $relationTableMatchFields
      * @return \TYPO3\CMS\Extbase\Persistence\Generic\Qom\ConstraintInterface $constraint
      */
-    protected function getConstraint(Persistence\QueryInterface $query, DomainObjectInterface $parentObject, $propertyName, $fieldValue = '', $relationTableMatchFields = [])
+    protected function getConstraint(QueryInterface $query, DomainObjectInterface $parentObject, $propertyName, $fieldValue = '', $relationTableMatchFields = [])
     {
-        $columnMap = $this->getDataMap(get_class($parentObject))->getColumnMap($propertyName);
-        if ($columnMap->getParentKeyFieldName() !== null) {
-            $constraint = $query->equals($columnMap->getParentKeyFieldName(), $parentObject);
+        $dataMap = $this->getDataMap(get_class($parentObject));
+        $columnMap = $dataMap->getColumnMap($propertyName);
+        $workspaceId = GeneralUtility::makeInstance(Context::class)->getPropertyFromAspect('workspace', 'id');
+        if ($columnMap && $workspaceId > 0) {
+            $resolvedRelationIds = $this->resolveRelationValuesOfField($dataMap, $columnMap, $parentObject, $fieldValue, $workspaceId);
+        } else {
+            $resolvedRelationIds = [];
+        }
+        // Work with the UIDs directly in a workspace
+        if (!empty($resolvedRelationIds)) {
+            if ($query->getSource() instanceof Persistence\Generic\Qom\JoinInterface) {
+                $constraint = $query->in($query->getSource()->getJoinCondition()->getProperty1Name(), $resolvedRelationIds);
+                // When querying MM relations directly, Typo3DbQueryParser uses enableFields and thus, filters
+                // out versioned records by default. However, we directly query versioned UIDs here, so we want
+                // to include the versioned records explicitly.
+                if ($columnMap->getTypeOfRelation() === ColumnMap::RELATION_HAS_AND_BELONGS_TO_MANY) {
+                    $query->getQuerySettings()->setEnableFieldsToBeIgnored(['pid']);
+                    $query->getQuerySettings()->setIgnoreEnableFields(true);
+                }
+            } else {
+                $constraint = $query->in('uid', $resolvedRelationIds);
+            }
             if ($columnMap->getParentTableFieldName() !== null) {
                 $constraint = $query->logicalAnd(
                     $constraint,
-                    $query->equals($columnMap->getParentTableFieldName(), $this->getDataMap(get_class($parentObject))->getTableName())
+                    $query->equals($columnMap->getParentTableFieldName(), $dataMap->getTableName())
+                );
+            }
+        } elseif ($columnMap->getParentKeyFieldName() !== null) {
+            $value = $parentObject;
+            // If this a MM relation, and MM relations do not know about workspaces, the MM relations always point to the
+            // versioned record, so this must be taken into account here and the versioned record's UID must be used.
+            if ($columnMap->getTypeOfRelation() === ColumnMap::RELATION_HAS_AND_BELONGS_TO_MANY) {
+                // The versioned UID is used ideally the version ID of a translated record, so this takes precedence over the localized UID
+                if ($value->_hasProperty('_versionedUid') && $value->_getProperty('_versionedUid') > 0 && $value->_getProperty('_versionedUid') !== $value->getUid()) {
+                    $value = (int)$value->_getProperty('_versionedUid');
+                }
+            }
+            $constraint = $query->equals($columnMap->getParentKeyFieldName(), $value);
+            if ($columnMap->getParentTableFieldName() !== null) {
+                $constraint = $query->logicalAnd(
+                    $constraint,
+                    $query->equals($columnMap->getParentTableFieldName(), $dataMap->getTableName())
                 );
             }
         } else {
-            $constraint = $query->in('uid', \TYPO3\CMS\Core\Utility\GeneralUtility::intExplode(',', $fieldValue));
+            $constraint = $query->in('uid', GeneralUtility::intExplode(',', $fieldValue));
         }
         if (!empty($relationTableMatchFields)) {
             foreach ($relationTableMatchFields as $relationTableMatchFieldName => $relationTableMatchFieldValue) {
@@ -470,6 +547,58 @@ class DataMapper
         return $constraint;
     }
 
+    /**
+     * This resolves relations via RelationHandler and returns their UIDs respectively, and works for MM/ForeignField/CSV in IRRE + Select + Group.
+     *
+     * Note: This only happens for resolving properties for models. When limiting a parentQuery, the Typo3DbQueryParser is taking care of it.
+     *
+     * By using the RelationHandler, the localized, deleted and moved records turn out to be properly resolved
+     * without having to build intermediate queries.
+     *
+     * This is currently only used in workspaces' context, as it is 1 additional DB query needed.
+     *
+     * @param DataMap $dataMap
+     * @param ColumnMap $columnMap
+     * @param DomainObjectInterface $parentObject
+     * @param string $fieldValue
+     * @param int $workspaceId
+     * @return array|false|mixed
+     */
+    protected function resolveRelationValuesOfField(DataMap $dataMap, ColumnMap $columnMap, DomainObjectInterface $parentObject, $fieldValue, int $workspaceId)
+    {
+        $parentId = $parentObject->getUid();
+        // versionedUid in a multi-language setup is the overlaid versioned AND translated ID
+        if ($parentObject->_hasProperty('_versionedUid') && $parentObject->_getProperty('_versionedUid') > 0 && $parentObject->_getProperty('_versionedUid') !== $parentId) {
+            $parentId = $parentObject->_getProperty('_versionedUid');
+        } elseif ($parentObject->_hasProperty('_languageUid') && $parentObject->_getProperty('_languageUid') > 0) {
+            $parentId = $parentObject->_getProperty('_localizedUid');
+        }
+        $relationHandler = GeneralUtility::makeInstance(RelationHandler::class);
+        $relationHandler->setWorkspaceId($workspaceId);
+        $relationHandler->setUseLiveReferenceIds(true);
+        $relationHandler->setUseLiveParentIds(true);
+        $tableName = $dataMap->getTableName();
+        $fieldName = $columnMap->getColumnName();
+        $fieldConfiguration = $GLOBALS['TCA'][$tableName]['columns'][$fieldName]['config'] ?? null;
+        if (!is_array($fieldConfiguration)) {
+            return [];
+        }
+        $relationHandler->start(
+            $fieldValue,
+            $fieldConfiguration['allowed'] ?? $fieldConfiguration['foreign_table'] ?? '',
+            $fieldConfiguration['MM'] ?? '',
+            $parentId,
+            $tableName,
+            $fieldConfiguration
+        );
+        $relationHandler->processDeletePlaceholder();
+        $relatedUids = [];
+        if (!empty($relationHandler->tableArray)) {
+            $relatedUids = reset($relationHandler->tableArray);
+        }
+        return $relatedUids;
+    }
+
     /**
      * Builds and returns the source to build a join for a m:n relation.
      *
@@ -484,7 +613,7 @@ class DataMapper
         $childClassName = $this->getType(get_class($parentObject), $propertyName);
         $right = $this->qomFactory->selector($childClassName, $columnMap->getChildTableName());
         $joinCondition = $this->qomFactory->equiJoinCondition($columnMap->getRelationTableName(), $columnMap->getChildKeyFieldName(), $columnMap->getChildTableName(), 'uid');
-        $source = $this->qomFactory->join($left, $right, Persistence\Generic\Query::JCR_JOIN_TYPE_INNER, $joinCondition);
+        $source = $this->qomFactory->join($left, $right, Query::JCR_JOIN_TYPE_INNER, $joinCondition);
         return $source;
     }
 
@@ -549,19 +678,19 @@ class DataMapper
     public function mapResultToPropertyValue(DomainObjectInterface $parentObject, $propertyName, $result)
     {
         $propertyValue = null;
-        if ($result instanceof Persistence\Generic\LoadingStrategyInterface) {
+        if ($result instanceof LoadingStrategyInterface) {
             $propertyValue = $result;
         } else {
             $property = $this->reflectionService->getClassSchema(get_class($parentObject))->getProperty($propertyName);
-            if (in_array($property->getType(), ['array', \ArrayObject::class, \SplObjectStorage::class, Persistence\ObjectStorage::class], true)) {
+            if (in_array($property->getType(), ['array', \ArrayObject::class, \SplObjectStorage::class, ObjectStorage::class], true)) {
                 $objects = [];
                 foreach ($result as $value) {
                     $objects[] = $value;
                 }
                 if ($property->getType() === \ArrayObject::class) {
                     $propertyValue = new \ArrayObject($objects);
-                } elseif ($property->getType() === Persistence\ObjectStorage::class) {
-                    $propertyValue = new Persistence\ObjectStorage();
+                } elseif ($property->getType() === ObjectStorage::class) {
+                    $propertyValue = new ObjectStorage();
                     foreach ($objects as $object) {
                         $propertyValue->attach($object);
                     }
@@ -569,9 +698,9 @@ class DataMapper
                 } else {
                     $propertyValue = $objects;
                 }
-            } elseif (strpbrk($property->getType(), '_\\') !== false) {
+            } elseif (strpbrk((string)$property->getType(), '_\\') !== false) {
                 // @todo: check the strpbrk function call. Seems to be a check for Tx_Foo_Bar style class names
-                if (is_object($result) && $result instanceof Persistence\QueryResultInterface) {
+                if (is_object($result) && $result instanceof QueryResultInterface) {
                     $propertyValue = $result->getFirst();
                 } else {
                     $propertyValue = $result;
@@ -619,7 +748,7 @@ class DataMapper
     public function getDataMap($className)
     {
         if (!is_string($className) || $className === '') {
-            throw new Persistence\Generic\Exception('No class name was given to retrieve the Data Map for.', 1251315965);
+            throw new Exception('No class name was given to retrieve the Data Map for.', 1251315965);
         }
         return $this->dataMapFactory->buildDataMap($className);
     }
@@ -653,7 +782,7 @@ class DataMapper
                 }
             }
         }
-        return \TYPO3\CMS\Core\Utility\GeneralUtility::camelCaseToLowerCaseUnderscored($propertyName);
+        return GeneralUtility::camelCaseToLowerCaseUnderscored($propertyName);
     }
 
     /**
@@ -697,7 +826,7 @@ class DataMapper
         if ($input === null) {
             return 'NULL';
         }
-        if ($input instanceof Persistence\Generic\LazyLoadingProxy) {
+        if ($input instanceof LazyLoadingProxy) {
             $input = $input->_loadRealInstance();
         }
 
