@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Extbase\Persistence\Generic\Storage;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Extbase\Persistence\Generic\Storage;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Persistence\Generic\Storage;
+
 use Doctrine\DBAL\DBALException;
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
@@ -28,11 +29,16 @@ use TYPO3\CMS\Core\Domain\Repository\PageRepository;
 use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
+use TYPO3\CMS\Core\Versioning\VersionState;
 use TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface;
 use TYPO3\CMS\Extbase\DomainObject\AbstractValueObject;
 use TYPO3\CMS\Extbase\Object\ObjectManagerInterface;
 use TYPO3\CMS\Extbase\Persistence\Generic\Mapper\DataMapper;
 use TYPO3\CMS\Extbase\Persistence\Generic\Qom;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\JoinInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\SelectorInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\SourceInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\Statement;
 use TYPO3\CMS\Extbase\Persistence\Generic\Query;
 use TYPO3\CMS\Extbase\Persistence\Generic\Storage\Exception\BadConstraintException;
 use TYPO3\CMS\Extbase\Persistence\Generic\Storage\Exception\SqlErrorException;
@@ -339,14 +345,14 @@ class Typo3DbBackend implements BackendInterface, SingletonInterface
     {
         $statement = $query->getStatement();
         // todo: remove instanceof checks as soon as getStatement() strictly returns Qom\Statement only
-        if ($statement instanceof Qom\Statement
+        if ($statement instanceof Statement
             && !$statement->getStatement() instanceof QueryBuilder
         ) {
             $rows = $this->getObjectDataByRawQuery($statement);
         } else {
             /** @var Typo3DbQueryParser $queryParser */
             $queryParser = $this->objectManager->get(Typo3DbQueryParser::class);
-            if ($statement instanceof Qom\Statement
+            if ($statement instanceof Statement
                 && $statement->getStatement() instanceof QueryBuilder
             ) {
                 $queryBuilder = $statement->getStatement();
@@ -385,7 +391,7 @@ class Typo3DbBackend implements BackendInterface, SingletonInterface
      * @return array
      * @throws SqlErrorException when the raw SQL statement fails in the database
      */
-    protected function getObjectDataByRawQuery(Qom\Statement $statement): array
+    protected function getObjectDataByRawQuery(Statement $statement): array
     {
         $realStatement = $statement->getStatement();
         $parameters = $statement->getBoundVariables();
@@ -433,12 +439,12 @@ class Typo3DbBackend implements BackendInterface, SingletonInterface
      */
     public function getObjectCountByQuery(QueryInterface $query): int
     {
-        if ($query->getConstraint() instanceof Qom\Statement) {
+        if ($query->getConstraint() instanceof Statement) {
             throw new BadConstraintException('Could not execute count on queries with a constraint of type TYPO3\\CMS\\Extbase\\Persistence\\Generic\\Qom\\Statement', 1256661045);
         }
 
         $statement = $query->getStatement();
-        if ($statement instanceof Qom\Statement
+        if ($statement instanceof Statement
             && !$statement->getStatement() instanceof QueryBuilder
         ) {
             $rows = $this->getObjectDataByQuery($query);
@@ -538,85 +544,47 @@ class Typo3DbBackend implements BackendInterface, SingletonInterface
      * @return array
      * @throws \TYPO3\CMS\Core\Context\Exception\AspectNotFoundException
      */
-    protected function overlayLanguageAndWorkspace(Qom\SourceInterface $source, array $rows, QueryInterface $query, int $workspaceUid = null): array
+    protected function overlayLanguageAndWorkspace(SourceInterface $source, array $rows, QueryInterface $query, int $workspaceUid = null): array
     {
-        if ($source instanceof Qom\SelectorInterface) {
-            $tableName = $source->getSelectorName();
-        } elseif ($source instanceof Qom\JoinInterface) {
-            $tableName = $source->getRight()->getSelectorName();
-        } else {
-            // No proper source, so we do not have a table name here
-            // we cannot do an overlay and return the original rows instead.
-            return $rows;
-        }
-
-        /** @var Context $context */
-        $context = $this->objectManager->get(Context::class);
+        $context = GeneralUtility::makeInstance(Context::class);
         if ($workspaceUid === null) {
             $workspaceUid = (int)$context->getPropertyFromAspect('workspace', 'id');
         } else {
             // A custom query is needed, so a custom context is cloned
             $context = clone $context;
-            $context->setAspect('workspace', $this->objectManager->get(WorkspaceAspect::class, $workspaceUid));
+            $context->setAspect('workspace', GeneralUtility::makeInstance(WorkspaceAspect::class, $workspaceUid));
         }
-        /** @var PageRepository $pageRepository */
-        $pageRepository = $this->objectManager->get(PageRepository::class, $context);
 
-        // Fetches the move-placeholder in case it is supported
-        // by the table and if there's only one row in the result set
-        // (applying this to all rows does not work, since the sorting
-        // order would be destroyed and possible limits not met anymore)
-        if (!empty($workspaceUid)
-            && BackendUtility::isTableWorkspaceEnabled($tableName)
-            && count($rows) === 1
-        ) {
-            $versionId = $workspaceUid;
-            $queryBuilder = $this->connectionPool->getQueryBuilderForTable($tableName);
-            $queryBuilder->getRestrictions()->removeAll();
-            $movePlaceholder = $queryBuilder
-                ->select($tableName . '.*')
-                ->from($tableName)
-                ->where(
-                    $queryBuilder->expr()->eq('t3ver_state', $queryBuilder->createNamedParameter(3, \PDO::PARAM_INT)),
-                    $queryBuilder->expr()->eq('t3ver_wsid', $queryBuilder->createNamedParameter($versionId, \PDO::PARAM_INT)),
-                    $queryBuilder->expr()->eq('t3ver_move_id', $queryBuilder->createNamedParameter($rows[0]['uid'], \PDO::PARAM_INT))
-                )
-                ->setMaxResults(1)
-                ->execute()
-                ->fetchAll();
-            if (!empty($movePlaceholder)) {
-                $rows = $movePlaceholder;
-            }
+        $pageRepository = GeneralUtility::makeInstance(PageRepository::class, $context);
+        if ($source instanceof SelectorInterface) {
+            $tableName = $source->getSelectorName();
+            $rows = $this->resolveMovedRecordsInWorkspace($tableName, $rows, $workspaceUid);
+            return $this->overlayLanguageAndWorkspaceForSelect($tableName, $rows, $pageRepository, $query);
         }
+        if ($source instanceof JoinInterface) {
+            $tableName = $source->getRight()->getSelectorName();
+            // Special handling of joined select is only needed when doing workspace overlays, which does not happen
+            // in live workspace
+            if ($workspaceUid === 0) {
+                return $this->overlayLanguageAndWorkspaceForSelect($tableName, $rows, $pageRepository, $query);
+            }
+            return $this->overlayLanguageAndWorkspaceForJoinedSelect($tableName, $rows, $pageRepository, $query);
+        }
+        // No proper source, so we do not have a table name here
+        // we cannot do an overlay and return the original rows instead.
+        return $rows;
+    }
+
+    /**
+     * If the result is a plain SELECT (no JOIN) then the regular overlay process works for tables
+     *  - overlay workspace
+     *  - overlay language of versioned record again
+     */
+    protected function overlayLanguageAndWorkspaceForSelect(string $tableName, array $rows, PageRepository $pageRepository, QueryInterface $query): array
+    {
         $overlaidRows = [];
         foreach ($rows as $row) {
-            $pageRepository->versionOL($tableName, $row, true);
-            $querySettings = $query->getQuerySettings();
-            if (is_array($row) && $querySettings->getLanguageOverlayMode()) {
-                if ($tableName === 'pages') {
-                    $row = $pageRepository->getPageOverlay($row, $querySettings->getLanguageUid());
-                } else {
-                    // todo: remove type cast once getLanguageUid strictly returns an int
-                    $languageUid = (int)$querySettings->getLanguageUid();
-                    if (!$querySettings->getRespectSysLanguage()
-                        && isset($row[$GLOBALS['TCA'][$tableName]['ctrl']['languageField']])
-                        && $row[$GLOBALS['TCA'][$tableName]['ctrl']['languageField']] > 0
-                        && (!$query instanceof Query || !$query->getParentQuery())
-                    ) {
-                        //no parent query means we're processing the aggregate root.
-                        //respectSysLanguage is false which means that records returned by the query
-                        //might be from different languages (which is desired).
-                        //So we need to force language used for overlay to the language of the current record.
-                        $languageUid = $row[$GLOBALS['TCA'][$tableName]['ctrl']['languageField']];
-                    }
-                    if (isset($GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField']) && $row[$GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField']] > 0) {
-                        //force overlay by faking default language record, as getRecordOverlay can only handle default language records
-                        $row['uid'] = $row[$GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField']];
-                        $row[$GLOBALS['TCA'][$tableName]['ctrl']['languageField']] = 0;
-                    }
-                    $row = $pageRepository->getRecordOverlay($tableName, $row, $languageUid, (string)$querySettings->getLanguageOverlayMode());
-                }
-            }
+            $row = $this->overlayLanguageAndWorkspaceForSingleRecord($tableName, $row, $pageRepository, $query);
             if ($row !== null && is_array($row)) {
                 $overlaidRows[] = $row;
             }
@@ -624,6 +592,132 @@ class Typo3DbBackend implements BackendInterface, SingletonInterface
         return $overlaidRows;
     }
 
+    /**
+     * If the result consists of a JOIN (usually happens if a property is a relation with a MM table) then it is necessary
+     * to only do overlays for the fields that are contained in the main database table, otherwise a SQL error is thrown.
+     * In order to make this happen, a single SQL query is made to fetch all possible field names (= array keys) of
+     * a record (TCA[$tableName][columns] does not contain all needed information), which is then used to compute
+     * a separate subset of the row which can be overlaid properly.
+     */
+    protected function overlayLanguageAndWorkspaceForJoinedSelect(string $tableName, array $rows, PageRepository $pageRepository, QueryInterface $query): array
+    {
+        // No valid rows, so this is skipped
+        if (!isset($rows[0]['uid'])) {
+            return $rows;
+        }
+        // First, find out the fields that belong to the "main" selected table which is defined by TCA, and take the first
+        // record to find out all possible fields in this database table
+        $fieldsOfMainTable = $pageRepository->getRawRecord($tableName, $rows[0]['uid']);
+        $overlaidRows = [];
+        foreach ($rows as $row) {
+            $mainRow = array_intersect_key($row, $fieldsOfMainTable);
+            $joinRow = array_diff_key($row, $mainRow);
+            $mainRow = $this->overlayLanguageAndWorkspaceForSingleRecord($tableName, $mainRow, $pageRepository, $query);
+            if ($mainRow !== null && is_array($mainRow)) {
+                $overlaidRows[] = array_replace($joinRow, $mainRow);
+            }
+        }
+        return $overlaidRows;
+    }
+
+    /**
+     * Takes one specific row, as defined in TCA and does all overlays.
+     *
+     * @param string $tableName
+     * @param array $row
+     * @param PageRepository $pageRepository
+     * @param QueryInterface $query
+     * @return array|int|mixed|null the overlaid row or false or null if overlay failed.
+     */
+    protected function overlayLanguageAndWorkspaceForSingleRecord(string $tableName, array $row, PageRepository $pageRepository, QueryInterface $query)
+    {
+        $querySettings = $query->getQuerySettings();
+        // If current row is a translation select its parent
+        $languageOfCurrentRecord = 0;
+        if ($GLOBALS['TCA'][$tableName]['ctrl']['languageField'] ?? null
+            && $row[$GLOBALS['TCA'][$tableName]['ctrl']['languageField']] ?? 0
+        ) {
+            $languageOfCurrentRecord = $row[$GLOBALS['TCA'][$tableName]['ctrl']['languageField']];
+        }
+        if ($querySettings->getLanguageOverlayMode()
+            && $languageOfCurrentRecord > 0
+            && isset($GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField'])
+            && $row[$GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField']] > 0
+        ) {
+            $row = $pageRepository->getRawRecord(
+                $tableName,
+                (int)$row[$GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField']]
+            );
+        }
+        // Handle workspace overlays
+        $pageRepository->versionOL($tableName, $row, true);
+        if (is_array($row) && $querySettings->getLanguageOverlayMode()) {
+            if ($tableName === 'pages') {
+                $row = $pageRepository->getPageOverlay($row, $querySettings->getLanguageUid());
+            } else {
+                // todo: remove type cast once getLanguageUid strictly returns an int
+                $languageUid = (int)$querySettings->getLanguageUid();
+                if (!$querySettings->getRespectSysLanguage()
+                    && $languageOfCurrentRecord > 0
+                    && (!$query instanceof Query || !$query->getParentQuery())
+                ) {
+                    // No parent query means we're processing the aggregate root.
+                    // respectSysLanguage is false which means that records returned by the query
+                    // might be from different languages (which is desired).
+                    // So we must set the language used for overlay to the language of the current record
+                    $languageUid = $languageOfCurrentRecord;
+                }
+                if (isset($GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField'])
+                    && $row[$GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField']] > 0
+                    && $languageOfCurrentRecord > 0
+                ) {
+                    // Force overlay by faking default language record, as getRecordOverlay can only handle default language records
+                    $row['uid'] = $row[$GLOBALS['TCA'][$tableName]['ctrl']['transOrigPointerField']];
+                    $row[$GLOBALS['TCA'][$tableName]['ctrl']['languageField']] = 0;
+                }
+                $row = $pageRepository->getRecordOverlay($tableName, $row, $languageUid, (string)$querySettings->getLanguageOverlayMode());
+            }
+        }
+        return $row;
+    }
+
+    /**
+     * Fetches the moved record in case it is supported
+     * by the table and if there's only one row in the result set
+     * (applying this to all rows does not work, since the sorting
+     * order would be destroyed and possible limits are not met anymore)
+     * The move pointers are later unset (see versionOL() last argument)
+     */
+    protected function resolveMovedRecordsInWorkspace(string $tableName, array $rows, int $workspaceUid): array
+    {
+        if ($workspaceUid === 0) {
+            return $rows;
+        }
+        if (!BackendUtility::isTableWorkspaceEnabled($tableName)) {
+            return $rows;
+        }
+        if (count($rows) !== 1) {
+            return $rows;
+        }
+        $queryBuilder = $this->connectionPool->getQueryBuilderForTable($tableName);
+        $queryBuilder->getRestrictions()->removeAll();
+        $movePlaceholder = $queryBuilder
+            ->select('*')
+            ->from($tableName)
+            ->where(
+                $queryBuilder->expr()->eq('t3ver_state', $queryBuilder->createNamedParameter(VersionState::MOVE_PLACEHOLDER, \PDO::PARAM_INT)),
+                $queryBuilder->expr()->eq('t3ver_wsid', $queryBuilder->createNamedParameter($workspaceUid, \PDO::PARAM_INT)),
+                $queryBuilder->expr()->eq('t3ver_move_id', $queryBuilder->createNamedParameter($rows[0]['uid'], \PDO::PARAM_INT))
+            )
+            ->setMaxResults(1)
+            ->execute()
+            ->fetchAll();
+        if (!empty($movePlaceholder)) {
+            $rows = $movePlaceholder;
+        }
+        return $rows;
+    }
+
     /**
      * Clear the TYPO3 page cache for the given record.
      * If the record lies on a page, then we clear the cache of this page.
