@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Persistence\Generic\Storage;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +13,10 @@ namespace TYPO3\CMS\Extbase\Persistence\Generic\Storage;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Persistence\Generic\Storage;
+
 use TYPO3\CMS\Backend\Utility\BackendUtility;
+use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Database\Connection;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\Expression\CompositeExpression;
@@ -34,6 +36,19 @@ use TYPO3\CMS\Extbase\Persistence\Generic\Exception\UnsupportedOrderException;
 use TYPO3\CMS\Extbase\Persistence\Generic\Mapper\ColumnMap;
 use TYPO3\CMS\Extbase\Persistence\Generic\Mapper\DataMapper;
 use TYPO3\CMS\Extbase\Persistence\Generic\Qom;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\AndInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\ComparisonInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\ConstraintInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\DynamicOperandInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\EquiJoinCondition;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\JoinInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\LowerCaseInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\NotInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\OrInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\PropertyValueInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\SelectorInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\SourceInterface;
+use TYPO3\CMS\Extbase\Persistence\Generic\Qom\UpperCaseInterface;
 use TYPO3\CMS\Extbase\Persistence\Generic\QuerySettingsInterface;
 use TYPO3\CMS\Extbase\Persistence\Generic\Storage\Exception\BadConstraintException;
 use TYPO3\CMS\Extbase\Persistence\QueryInterface;
@@ -88,7 +103,7 @@ class Typo3DbQueryParser
      * Maps tablenames to their aliases to be used in where clauses etc.
      * Mainly used for joins on the same table etc.
      *
-     * @var array
+     * @var array<string, string>
      */
     protected $tableAliasMap = [];
 
@@ -181,7 +196,7 @@ class Typo3DbQueryParser
         $this->initializeQueryBuilder($source);
 
         $constraint = $query->getConstraint();
-        if ($constraint instanceof Qom\ConstraintInterface) {
+        if ($constraint instanceof ConstraintInterface) {
             $wherePredicates = $this->parseConstraint($constraint, $source);
             if (!empty($wherePredicates)) {
                 $this->queryBuilder->andWhere($wherePredicates);
@@ -199,9 +214,9 @@ class Typo3DbQueryParser
      *
      * @param Qom\SourceInterface $source The source
      */
-    protected function initializeQueryBuilder(Qom\SourceInterface $source)
+    protected function initializeQueryBuilder(SourceInterface $source)
     {
-        if ($source instanceof Qom\SelectorInterface) {
+        if ($source instanceof SelectorInterface) {
             $className = $source->getNodeTypeName();
             $tableName = $this->dataMapper->getDataMap($className)->getTableName();
             $this->tableName = $tableName;
@@ -220,7 +235,7 @@ class Typo3DbQueryParser
                 ->from($tableName, $tableAlias);
 
             $this->addRecordTypeConstraint($className);
-        } elseif ($source instanceof Qom\JoinInterface) {
+        } elseif ($source instanceof JoinInterface) {
             $leftSource = $source->getLeft();
             $leftTableName = $leftSource->getSelectorName();
 
@@ -242,38 +257,24 @@ class Typo3DbQueryParser
      * @return CompositeExpression|string
      * @throws \RuntimeException
      */
-    protected function parseConstraint(Qom\ConstraintInterface $constraint, Qom\SourceInterface $source)
+    protected function parseConstraint(ConstraintInterface $constraint, SourceInterface $source)
     {
-        if ($constraint instanceof Qom\AndInterface) {
-            $constraint1 = $constraint->getConstraint1();
-            $constraint2 = $constraint->getConstraint2();
-            if (($constraint1 instanceof Qom\ConstraintInterface)
-                && ($constraint2 instanceof Qom\ConstraintInterface)
-            ) {
-                return $this->queryBuilder->expr()->andX(
-                    $this->parseConstraint($constraint1, $source),
-                    $this->parseConstraint($constraint2, $source)
-                );
-            }
-            return '';
+        if ($constraint instanceof AndInterface) {
+            return $this->queryBuilder->expr()->andX(
+                $this->parseConstraint($constraint->getConstraint1(), $source),
+                $this->parseConstraint($constraint->getConstraint2(), $source)
+            );
         }
-        if ($constraint instanceof Qom\OrInterface) {
-            $constraint1 = $constraint->getConstraint1();
-            $constraint2 = $constraint->getConstraint2();
-            if (($constraint1 instanceof Qom\ConstraintInterface)
-                && ($constraint2 instanceof Qom\ConstraintInterface)
-            ) {
-                return $this->queryBuilder->expr()->orX(
-                    $this->parseConstraint($constraint->getConstraint1(), $source),
-                    $this->parseConstraint($constraint->getConstraint2(), $source)
-                );
-            }
-            return '';
+        if ($constraint instanceof OrInterface) {
+            return $this->queryBuilder->expr()->orX(
+                $this->parseConstraint($constraint->getConstraint1(), $source),
+                $this->parseConstraint($constraint->getConstraint2(), $source)
+            );
         }
-        if ($constraint instanceof Qom\NotInterface) {
+        if ($constraint instanceof NotInterface) {
             return ' NOT(' . $this->parseConstraint($constraint->getConstraint(), $source) . ')';
         }
-        if ($constraint instanceof Qom\ComparisonInterface) {
+        if ($constraint instanceof ComparisonInterface) {
             return $this->parseComparison($constraint, $source);
         }
         throw new \RuntimeException('not implemented', 1476199898);
@@ -286,7 +287,7 @@ class Typo3DbQueryParser
      * @param Qom\SourceInterface $source The source
      * @throws UnsupportedOrderException
      */
-    protected function parseOrderings(array $orderings, Qom\SourceInterface $source)
+    protected function parseOrderings(array $orderings, SourceInterface $source)
     {
         foreach ($orderings as $propertyName => $order) {
             if ($order !== QueryInterface::ORDER_ASCENDING && $order !== QueryInterface::ORDER_DESCENDING) {
@@ -294,14 +295,14 @@ class Typo3DbQueryParser
             }
             $className = null;
             $tableName = '';
-            if ($source instanceof Qom\SelectorInterface) {
+            if ($source instanceof SelectorInterface) {
                 $className = $source->getNodeTypeName();
                 $tableName = $this->dataMapper->convertClassNameToTableName($className);
                 $fullPropertyPath = '';
                 while (strpos($propertyName, '.') !== false) {
                     $this->addUnionStatement($className, $tableName, $propertyName, $fullPropertyPath);
                 }
-            } elseif ($source instanceof Qom\JoinInterface) {
+            } elseif ($source instanceof JoinInterface) {
                 $tableName = $source->getLeft()->getSelectorName();
             }
             $columnName = $this->dataMapper->convertPropertyNameToColumnName($propertyName, $className);
@@ -359,14 +360,14 @@ class Typo3DbQueryParser
      * @throws RepositoryException
      * @throws BadConstraintException
      */
-    protected function parseComparison(Qom\ComparisonInterface $comparison, Qom\SourceInterface $source)
+    protected function parseComparison(ComparisonInterface $comparison, SourceInterface $source)
     {
         if ($comparison->getOperator() === QueryInterface::OPERATOR_CONTAINS) {
             if ($comparison->getOperand2() === null) {
                 throw new BadConstraintException('The value for the CONTAINS operator must not be null.', 1484828468);
             }
             $value = $this->dataMapper->getPlainValue($comparison->getOperand2());
-            if (!$source instanceof Qom\SelectorInterface) {
+            if (!$source instanceof SelectorInterface) {
                 throw new \RuntimeException('Source is not of type "SelectorInterface"', 1395362539);
             }
             $className = $source->getNodeTypeName();
@@ -382,7 +383,8 @@ class Typo3DbQueryParser
             $columnMap = $dataMap->getColumnMap($propertyName);
             $typeOfRelation = $columnMap instanceof ColumnMap ? $columnMap->getTypeOfRelation() : null;
             if ($typeOfRelation === ColumnMap::RELATION_HAS_AND_BELONGS_TO_MANY) {
-                $relationTableName = $columnMap->getRelationTableName();
+                /** @var ColumnMap $columnMap */
+                $relationTableName = (string)$columnMap->getRelationTableName();
                 $queryBuilderForSubselect = $this->queryBuilder->getConnection()->createQueryBuilder();
                 $queryBuilderForSubselect
                         ->select($columnMap->getParentKeyFieldName())
@@ -446,7 +448,7 @@ class Typo3DbQueryParser
      * @throws Exception
      * @throws BadConstraintException
      */
-    protected function parseDynamicOperand(Qom\ComparisonInterface $comparison, Qom\SourceInterface $source)
+    protected function parseDynamicOperand(ComparisonInterface $comparison, SourceInterface $source)
     {
         $value = $comparison->getOperand2();
         $fieldName = $this->parseOperand($comparison->getOperand1(), $source);
@@ -579,24 +581,24 @@ class Typo3DbQueryParser
      * @return string
      * @throws \InvalidArgumentException
      */
-    protected function parseOperand(Qom\DynamicOperandInterface $operand, Qom\SourceInterface $source)
+    protected function parseOperand(DynamicOperandInterface $operand, SourceInterface $source)
     {
         $tableName = null;
-        if ($operand instanceof Qom\LowerCaseInterface) {
+        if ($operand instanceof LowerCaseInterface) {
             $constraintSQL = 'LOWER(' . $this->parseOperand($operand->getOperand(), $source) . ')';
-        } elseif ($operand instanceof Qom\UpperCaseInterface) {
+        } elseif ($operand instanceof UpperCaseInterface) {
             $constraintSQL = 'UPPER(' . $this->parseOperand($operand->getOperand(), $source) . ')';
-        } elseif ($operand instanceof Qom\PropertyValueInterface) {
+        } elseif ($operand instanceof PropertyValueInterface) {
             $propertyName = $operand->getPropertyName();
             $className = '';
-            if ($source instanceof Qom\SelectorInterface) {
+            if ($source instanceof SelectorInterface) {
                 $className = $source->getNodeTypeName();
                 $tableName = $this->dataMapper->convertClassNameToTableName($className);
                 $fullPropertyPath = '';
                 while (strpos($propertyName, '.') !== false) {
                     $this->addUnionStatement($className, $tableName, $propertyName, $fullPropertyPath);
                 }
-            } elseif ($source instanceof Qom\JoinInterface) {
+            } elseif ($source instanceof JoinInterface) {
                 $tableName = $source->getJoinCondition()->getSelector1Name();
             }
             $columnName = $this->dataMapper->convertPropertyNameToColumnName($propertyName, $className);
@@ -688,6 +690,9 @@ class Typo3DbQueryParser
      */
     protected function getAdditionalWhereClause(QuerySettingsInterface $querySettings, $tableName, $tableAlias = null)
     {
+        $tableAlias = (string)$tableAlias;
+        // todo: $tableAlias must not be null
+
         $whereClause = [];
         if ($querySettings->getRespectSysLanguage()) {
             $systemLanguageStatement = $this->getLanguageStatement($tableName, $tableAlias, $querySettings);
@@ -701,6 +706,9 @@ class Typo3DbQueryParser
             if (!empty($pageIdStatement)) {
                 $whereClause[] = $pageIdStatement;
             }
+        } elseif (!empty($GLOBALS['TCA'][$tableName]['ctrl']['versioningWS'])) {
+            // Always prevent workspace records from being returned
+            $whereClause[] = $this->queryBuilder->expr()->eq($tableAlias . '.t3ver_oid', 0);
         }
 
         return $whereClause;
@@ -751,7 +759,7 @@ class Typo3DbQueryParser
         if ($ignoreEnableFields && !$includeDeleted) {
             if (!empty($enableFieldsToBeIgnored)) {
                 // array_combine() is necessary because of the way \TYPO3\CMS\Core\Domain\Repository\PageRepository::enableFields() is implemented
-                $statement .= $this->getPageRepository()->enableFields($tableName, -1, array_combine($enableFieldsToBeIgnored, $enableFieldsToBeIgnored));
+                $statement .= $this->getPageRepository()->enableFields($tableName, -1, array_combine($enableFieldsToBeIgnored, $enableFieldsToBeIgnored), true);
             } elseif (!empty($GLOBALS['TCA'][$tableName]['ctrl']['delete'])) {
                 $statement .= ' AND ' . $tableName . '.' . $GLOBALS['TCA'][$tableName]['ctrl']['delete'] . '=0';
             }
@@ -774,7 +782,9 @@ class Typo3DbQueryParser
     protected function getBackendConstraintStatement($tableName, $ignoreEnableFields, $includeDeleted)
     {
         $statement = '';
-        if (!$ignoreEnableFields) {
+        // In case of versioning-preview, enableFields are ignored (checked in Typo3DbBackend::doLanguageAndWorkspaceOverlay)
+        $isUserInWorkspace = GeneralUtility::makeInstance(Context::class)->getPropertyFromAspect('workspace', 'isOffline');
+        if (!$ignoreEnableFields && !$isUserInWorkspace) {
             $statement .= BackendUtility::BEenableFields($tableName);
         }
         if (!$includeDeleted && !empty($GLOBALS['TCA'][$tableName]['ctrl']['delete'])) {
@@ -921,13 +931,13 @@ class Typo3DbQueryParser
      * @param Qom\JoinInterface $join The join
      * @param string $leftTableAlias The alias from the table to main
      */
-    protected function parseJoin(Qom\JoinInterface $join, $leftTableAlias)
+    protected function parseJoin(JoinInterface $join, $leftTableAlias)
     {
         $leftSource = $join->getLeft();
         $leftClassName = $leftSource->getNodeTypeName();
         $this->addRecordTypeConstraint($leftClassName);
         $rightSource = $join->getRight();
-        if ($rightSource instanceof Qom\JoinInterface) {
+        if ($rightSource instanceof JoinInterface) {
             $left = $rightSource->getLeft();
             $rightClassName = $left->getNodeTypeName();
             $rightTableName = $left->getSelectorName();
@@ -940,8 +950,7 @@ class Typo3DbQueryParser
         $rightTableAlias = $this->getUniqueAlias($rightTableName);
         $joinCondition = $join->getJoinCondition();
         $joinConditionExpression = null;
-        $this->unionTableAliasCache[] = $rightTableAlias;
-        if ($joinCondition instanceof Qom\EquiJoinCondition) {
+        if ($joinCondition instanceof EquiJoinCondition) {
             $column1Name = $this->dataMapper->convertPropertyNameToColumnName($joinCondition->getProperty1Name(), $leftClassName);
             $column2Name = $this->dataMapper->convertPropertyNameToColumnName($joinCondition->getProperty2Name(), $rightClassName);
 
@@ -951,7 +960,7 @@ class Typo3DbQueryParser
             );
         }
         $this->queryBuilder->leftJoin($leftTableAlias, $rightTableName, $rightTableAlias, $joinConditionExpression);
-        if ($rightSource instanceof Qom\JoinInterface) {
+        if ($rightSource instanceof JoinInterface) {
             $this->parseJoin($rightSource, $rightTableAlias);
         }
     }
@@ -1068,7 +1077,7 @@ class Typo3DbQueryParser
             );
             $this->suggestDistinctQuery = true;
         } elseif ($columnMap->getTypeOfRelation() === ColumnMap::RELATION_HAS_AND_BELONGS_TO_MANY) {
-            $relationTableName = $columnMap->getRelationTableName();
+            $relationTableName = (string)$columnMap->getRelationTableName();
             $relationTableAlias = $this->getUniqueAlias($relationTableName, $fullPropertyPath . '_mm');
 
             $joinConditionExpression = $this->queryBuilder->expr()->andX(
