@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Persistence;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,12 +13,19 @@ namespace TYPO3\CMS\Extbase\Persistence;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Persistence;
+
+use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\ClassNamingUtility;
+use TYPO3\CMS\Extbase\Object\ObjectManagerInterface;
+use TYPO3\CMS\Extbase\Persistence\Exception\IllegalObjectTypeException;
+use TYPO3\CMS\Extbase\Persistence\Generic\Exception\UnsupportedMethodException;
+use TYPO3\CMS\Extbase\Persistence\Generic\QuerySettingsInterface;
 
 /**
  * The base repository - will usually be extended by a more concrete repository.
  */
-class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterface
+class Repository implements RepositoryInterface, SingletonInterface
 {
     /**
      * @var \TYPO3\CMS\Extbase\Persistence\PersistenceManagerInterface
@@ -42,6 +48,9 @@ class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterf
     protected $defaultOrderings = [];
 
     /**
+     * Override query settings created by extbase natively.
+     * Be careful if using this, see the comment on setDefaultQuerySettings() for more insights.
+     *
      * @var \TYPO3\CMS\Extbase\Persistence\Generic\QuerySettingsInterface
      */
     protected $defaultQuerySettings;
@@ -49,7 +58,7 @@ class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterf
     /**
      * @param \TYPO3\CMS\Extbase\Persistence\PersistenceManagerInterface $persistenceManager
      */
-    public function injectPersistenceManager(\TYPO3\CMS\Extbase\Persistence\PersistenceManagerInterface $persistenceManager)
+    public function injectPersistenceManager(PersistenceManagerInterface $persistenceManager)
     {
         $this->persistenceManager = $persistenceManager;
     }
@@ -59,7 +68,7 @@ class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterf
      *
      * @param \TYPO3\CMS\Extbase\Object\ObjectManagerInterface $objectManager
      */
-    public function __construct(\TYPO3\CMS\Extbase\Object\ObjectManagerInterface $objectManager)
+    public function __construct(ObjectManagerInterface $objectManager)
     {
         $this->objectManager = $objectManager;
         $this->objectType = ClassNamingUtility::translateRepositoryNameToModelName($this->getRepositoryClassName());
@@ -74,7 +83,7 @@ class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterf
     public function add($object)
     {
         if (!$object instanceof $this->objectType) {
-            throw new \TYPO3\CMS\Extbase\Persistence\Exception\IllegalObjectTypeException('The object given to add() was not of the type (' . $this->objectType . ') this repository manages.', 1248363335);
+            throw new IllegalObjectTypeException('The object given to add() was not of the type (' . $this->objectType . ') this repository manages.', 1248363335);
         }
         $this->persistenceManager->add($object);
     }
@@ -88,7 +97,7 @@ class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterf
     public function remove($object)
     {
         if (!$object instanceof $this->objectType) {
-            throw new \TYPO3\CMS\Extbase\Persistence\Exception\IllegalObjectTypeException('The object given to remove() was not of the type (' . $this->objectType . ') this repository manages.', 1248363336);
+            throw new IllegalObjectTypeException('The object given to remove() was not of the type (' . $this->objectType . ') this repository manages.', 1248363336);
         }
         $this->persistenceManager->remove($object);
     }
@@ -103,7 +112,7 @@ class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterf
     public function update($modifiedObject)
     {
         if (!$modifiedObject instanceof $this->objectType) {
-            throw new \TYPO3\CMS\Extbase\Persistence\Exception\IllegalObjectTypeException('The modified object given to update() was not of the type (' . $this->objectType . ') this repository manages.', 1249479625);
+            throw new IllegalObjectTypeException('The modified object given to update() was not of the type (' . $this->objectType . ') this repository manages.', 1249479625);
         }
         $this->persistenceManager->update($modifiedObject);
     }
@@ -177,11 +186,17 @@ class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterf
     }
 
     /**
-     * Sets the default query settings to be used in this repository
+     * Sets the default query settings to be used in this repository.
      *
-     * @param \TYPO3\CMS\Extbase\Persistence\Generic\QuerySettingsInterface $defaultQuerySettings The query settings to be used by default
+     * A typical use case is an initializeObject() method that creates a QuerySettingsInterface
+     * object, configures it and sets it to be used for all queries created by the repository.
+     *
+     * Warning: Using this setter *fully overrides* native query settings created by
+     * QueryFactory->create(). This especially means that storagePid settings from
+     * configuration are not applied anymore, if not explicitly set. Make sure to apply these
+     * to your own QuerySettingsInterface object if needed, when using this method.
      */
-    public function setDefaultQuerySettings(\TYPO3\CMS\Extbase\Persistence\Generic\QuerySettingsInterface $defaultQuerySettings)
+    public function setDefaultQuerySettings(QuerySettingsInterface $defaultQuerySettings)
     {
         $this->defaultQuerySettings = $defaultQuerySettings;
     }
@@ -236,7 +251,7 @@ class Repository implements RepositoryInterface, \TYPO3\CMS\Core\SingletonInterf
             $result = $query->matching($query->equals($propertyName, $arguments[0]))->execute()->count();
             return $result;
         }
-        throw new \TYPO3\CMS\Extbase\Persistence\Generic\Exception\UnsupportedMethodException('The method "' . $methodName . '" is not supported by the repository.', 1233180480);
+        throw new UnsupportedMethodException('The method "' . $methodName . '" is not supported by the repository.', 1233180480);
     }
 
     /**
