@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Extbase\Reflection;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Extbase\Reflection;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Reflection;
+
 use Doctrine\Common\Annotations\AnnotationReader;
 use phpDocumentor\Reflection\DocBlock\Tags\Param;
 use phpDocumentor\Reflection\DocBlockFactory;
@@ -120,6 +121,7 @@ class ClassSchema
      */
     public function __construct(string $className)
     {
+        /** @var class-string $className */
         $this->className = $className;
         $this->bitSet = new BitSet();
 
@@ -354,10 +356,12 @@ class ClassSchema
                     return $annotation instanceof IgnoreValidation && $annotation->argumentName === $parameterName;
                 });
 
+                $reflectionType = $reflectionParameter->getType();
+
                 $this->methods[$methodName]['params'][$parameterName] = [];
                 $this->methods[$methodName]['params'][$parameterName]['position'] = $parameterPosition; // compat
                 $this->methods[$methodName]['params'][$parameterName]['byReference'] = $reflectionParameter->isPassedByReference(); // compat
-                $this->methods[$methodName]['params'][$parameterName]['array'] = $reflectionParameter->isArray(); // compat
+                $this->methods[$methodName]['params'][$parameterName]['array'] = false; // compat
                 $this->methods[$methodName]['params'][$parameterName]['optional'] = $reflectionParameter->isOptional();
                 $this->methods[$methodName]['params'][$parameterName]['allowsNull'] = $reflectionParameter->allowsNull();
                 $this->methods[$methodName]['params'][$parameterName]['class'] = null; // compat
@@ -372,14 +376,30 @@ class ClassSchema
                     $this->methods[$methodName]['params'][$parameterName]['defaultValue'] = $reflectionParameter->getDefaultValue();
                 }
 
-                if (($reflectionType = $reflectionParameter->getType()) instanceof \ReflectionNamedType) {
-                    $this->methods[$methodName]['params'][$parameterName]['type'] = $reflectionType->getName();
+                // A ReflectionNamedType means "there is a type specified, and it's not a union type."
+                // (Union types are not handled, currently.)
+                if ($reflectionType instanceof \ReflectionNamedType) {
                     $this->methods[$methodName]['params'][$parameterName]['allowsNull'] = $reflectionType->allowsNull();
-                }
-
-                if (($parameterClass = $reflectionParameter->getClass()) instanceof \ReflectionClass) {
-                    $this->methods[$methodName]['params'][$parameterName]['class'] = $parameterClass->getName();
-                    $this->methods[$methodName]['params'][$parameterName]['type'] = ltrim($parameterClass->getName(), '\\');
+                    // A built-in type effectively means "not a class".
+                    if ($reflectionType->isBuiltin()) {
+                        $this->methods[$methodName]['params'][$parameterName]['array'] = $reflectionType->getName() === 'array'; // compat
+                        $this->methods[$methodName]['params'][$parameterName]['type'] = ltrim($reflectionType->getName(), '\\');
+                    } elseif ($reflectionType->getName() === 'self') {
+                        // In addition, self cannot be resolved by "new \ReflectionClass('self')",
+                        // so treat this as a reference to the current class
+                        $this->methods[$methodName]['params'][$parameterName]['class'] = $reflectionClass->getName();
+                        $this->methods[$methodName]['params'][$parameterName]['type'] = ltrim($reflectionClass->getName(), '\\');
+                    } else {
+                        // This is mainly to confirm that the class exists. If it doesn't, a ReflectionException
+                        // will be thrown. It's not the ideal way of doing so, but it maintains the existing API
+                        // so that the exception can get caught and recast to a TYPO3-specific exception.
+                        /** @var class-string<mixed> $classname */
+                        $classname = $reflectionType->getName();
+                        $reflection = new \ReflectionClass($classname);
+                        // There's a single type declaration that is a class.
+                        $this->methods[$methodName]['params'][$parameterName]['class'] = $reflectionType->getName();
+                        $this->methods[$methodName]['params'][$parameterName]['type'] = $reflectionType->getName();
+                    }
                 }
 
                 if ($docComment !== '' && $this->methods[$methodName]['params'][$parameterName]['type'] === null) {
@@ -406,10 +426,10 @@ class ClassSchema
                 }
 
                 // Extbase DI
-                if ($reflectionParameter->getClass() instanceof \ReflectionClass
+                if ($reflectionType instanceof \ReflectionNamedType && !$reflectionType->isBuiltin()
                     && ($reflectionMethod->isConstructor() || $this->hasInjectMethodName($reflectionMethod))
                 ) {
-                    $this->methods[$methodName]['params'][$parameterName]['dependency'] = $reflectionParameter->getClass()->getName();
+                    $this->methods[$methodName]['params'][$parameterName]['dependency'] = $reflectionType->getName();
                 }
 
                 // Extbase Validation
