@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Extbase\Service;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,12 +15,21 @@ namespace TYPO3\CMS\Extbase\Service;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Service;
+
+use TYPO3\CMS\Core\SingletonInterface;
+
 /**
  * Service for determining environment params
  * @internal only to be used within Extbase, not part of TYPO3 Core API.
  */
-class EnvironmentService implements \TYPO3\CMS\Core\SingletonInterface
+class EnvironmentService implements SingletonInterface
 {
+    /**
+     * @var bool|null
+     */
+    protected $isFrontendMode;
+
     /**
      * Detects if TYPO3_MODE is defined and its value is "FE"
      *
@@ -29,6 +37,10 @@ class EnvironmentService implements \TYPO3\CMS\Core\SingletonInterface
      */
     public function isEnvironmentInFrontendMode(): bool
     {
+        $this->initialize();
+        if ($this->isFrontendMode !== null) {
+            return $this->isFrontendMode;
+        }
         return (defined('TYPO3_MODE') && TYPO3_MODE === 'FE') ?: false;
     }
 
@@ -39,14 +51,27 @@ class EnvironmentService implements \TYPO3\CMS\Core\SingletonInterface
      */
     public function isEnvironmentInBackendMode(): bool
     {
-        return (defined('TYPO3_MODE') && TYPO3_MODE === 'BE') ?: false;
+        return !$this->isEnvironmentInFrontendMode();
+    }
+
+    protected function initialize(): void
+    {
+        if ($this->isFrontendMode !== null) {
+            return;
+        }
+        if (defined('TYPO3_MODE')) {
+            $this->isFrontendMode = TYPO3_MODE === 'FE';
+        }
     }
 
     /**
-     * @return string
+     * A helper method for tests to simulate TYPO3_MODE behavior, should only be used within TYPO3 Core
+     *
+     * @param bool $isFrontendMode
+     * @internal only used for testing purposes and can be removed at any time.
      */
-    public function getServerRequestMethod(): string
+    public function setFrontendMode(bool $isFrontendMode): void
     {
-        return isset($_SERVER['REQUEST_METHOD']) && is_string($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : 'GET';
+        $this->isFrontendMode = $isFrontendMode;
     }
 }
