@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Validation\Validator;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,11 @@ namespace TYPO3\CMS\Extbase\Validation\Validator;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Validation\Validator;
+
+use TYPO3\CMS\Extbase\Error\Result;
+use TYPO3\CMS\Extbase\Utility\LocalizationUtility;
+use TYPO3\CMS\Extbase\Validation\Error;
 use TYPO3\CMS\Extbase\Validation\Exception\InvalidValidationOptionsException;
 
 /**
@@ -94,7 +98,7 @@ abstract class AbstractValidator implements ValidatorInterface
      */
     public function validate($value)
     {
-        $this->result = new \TYPO3\CMS\Extbase\Error\Result();
+        $this->result = new Result();
         if ($this->acceptsEmptyValues === false || $this->isEmpty($value) === false) {
             $this->isValid($value);
         }
@@ -110,7 +114,7 @@ abstract class AbstractValidator implements ValidatorInterface
     abstract protected function isValid($value);
 
     /**
-     * Creates a new validation error object and adds it to $this->results
+     * Creates a new validation error object and adds it to $this->result
      *
      * @param string $message The error message
      * @param int $code The error code (a unix timestamp)
@@ -119,7 +123,7 @@ abstract class AbstractValidator implements ValidatorInterface
      */
     protected function addError($message, $code, array $arguments = [], $title = '')
     {
-        $this->result->addError(new \TYPO3\CMS\Extbase\Validation\Error((string)$message, (int)$code, $arguments, (string)$title));
+        $this->result->addError(new Error((string)$message, (int)$code, $arguments, (string)$title));
     }
 
     /**
@@ -152,7 +156,7 @@ abstract class AbstractValidator implements ValidatorInterface
      */
     protected function translateErrorMessage($translateKey, $extensionName, $arguments = [])
     {
-        return \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate(
+        return LocalizationUtility::translate(
             $translateKey,
             $extensionName,
             $arguments
