@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extbase\Validation\Validator;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Extbase\Validation\Validator;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extbase\Validation\Validator;
+
 /**
  * Validator for alphanumeric strings
  */
@@ -27,7 +28,7 @@ class AlphanumericValidator extends AbstractValidator
     public function isValid($value)
     {
         if (!is_string($value) || preg_match('/^[\pL\d]*$/u', $value) !== 1) {
-            $this->addError($this->translateErrorMessage('validator.alphanumeric.notvalid', 'extbase'), 1221551320);
+            $this->addError($this->translateErrorMessage('validator.alphanumeric.notvalid', 'extbase') ?? '', 1221551320);
         }
     }
 }
