@@ -1,4 +1,5 @@
 <?php
+
 defined('TYPO3_MODE') or die();
 
 if (!isset($GLOBALS['TCA']['fe_users']['ctrl']['type'])) {
@@ -8,7 +9,7 @@ if (!isset($GLOBALS['TCA']['fe_users']['ctrl']['type'])) {
         ],
         'columns' => [
             'tx_extbase_type' => [
-                'exclude' => 1,
+                'exclude' => true,
                 'label' => 'LLL:EXT:extbase/Resources/Private/Language/locallang_db.xlf:fe_users.tx_extbase_type',
                 'config' => [
                     'type' => 'select',
@@ -19,7 +20,7 @@ if (!isset($GLOBALS['TCA']['fe_users']['ctrl']['type'])) {
                     ],
                     'size' => 1,
                     'maxitems' => 1,
-                    'default' => '0'
+                    'default' => 0
                 ]
             ]
         ],
