@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extensionmanager\Utility;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Extensionmanager\Utility;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extensionmanager\Utility;
+
 use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
@@ -22,6 +23,11 @@ use TYPO3\CMS\Extensionmanager\Domain\Model\Dependency;
 use TYPO3\CMS\Extensionmanager\Domain\Model\Extension;
 use TYPO3\CMS\Extensionmanager\Domain\Repository\ExtensionRepository;
 use TYPO3\CMS\Extensionmanager\Exception;
+use TYPO3\CMS\Extensionmanager\Exception\MissingExtensionDependencyException;
+use TYPO3\CMS\Extensionmanager\Exception\MissingVersionDependencyException;
+use TYPO3\CMS\Extensionmanager\Exception\UnresolvedDependencyException;
+use TYPO3\CMS\Extensionmanager\Exception\UnresolvedPhpDependencyException;
+use TYPO3\CMS\Extensionmanager\Exception\UnresolvedTypo3DependencyException;
 use TYPO3\CMS\Extensionmanager\Service\ExtensionManagementService;
 
 /**
@@ -150,7 +156,7 @@ class DependencyUtility implements SingletonInterface
                         $this->checkExtensionDependency($dependency);
                     }
                 }
-            } catch (Exception\UnresolvedDependencyException $e) {
+            } catch (UnresolvedDependencyException $e) {
                 if (in_array($identifier, Dependency::$specialDependencies)) {
                     $extensionKey = $extension->getExtensionKey();
                 } else {
@@ -199,19 +205,19 @@ class DependencyUtility implements SingletonInterface
         $lowerCaseIdentifier = strtolower($dependency->getIdentifier());
         if ($lowerCaseIdentifier === 'typo3') {
             if (!($dependency->getLowestVersion() === '') && version_compare(VersionNumberUtility::getNumericTypo3Version(), $dependency->getLowestVersion()) === -1) {
-                throw new Exception\UnresolvedTypo3DependencyException(
+                throw new UnresolvedTypo3DependencyException(
                     'Your TYPO3 version is lower than this extension requires. It requires TYPO3 versions ' . $dependency->getLowestVersion() . ' - ' . $dependency->getHighestVersion(),
                     1399144499
                 );
             }
             if (!($dependency->getHighestVersion() === '') && version_compare($dependency->getHighestVersion(), VersionNumberUtility::getNumericTypo3Version()) === -1) {
-                throw new Exception\UnresolvedTypo3DependencyException(
+                throw new UnresolvedTypo3DependencyException(
                     'Your TYPO3 version is higher than this extension requires. It requires TYPO3 versions ' . $dependency->getLowestVersion() . ' - ' . $dependency->getHighestVersion(),
                     1399144521
                 );
             }
         } else {
-            throw new Exception\UnresolvedTypo3DependencyException(
+            throw new UnresolvedTypo3DependencyException(
                 'checkTypo3Dependency can only check TYPO3 dependencies. Found dependency with identifier "' . $dependency->getIdentifier() . '"',
                 1399144551
             );
@@ -231,19 +237,19 @@ class DependencyUtility implements SingletonInterface
         $lowerCaseIdentifier = strtolower($dependency->getIdentifier());
         if ($lowerCaseIdentifier === 'php') {
             if (!($dependency->getLowestVersion() === '') && version_compare(PHP_VERSION, $dependency->getLowestVersion()) === -1) {
-                throw new Exception\UnresolvedPhpDependencyException(
+                throw new UnresolvedPhpDependencyException(
                     'Your PHP version is lower than necessary. You need at least PHP version ' . $dependency->getLowestVersion(),
                     1377977857
                 );
             }
             if (!($dependency->getHighestVersion() === '') && version_compare($dependency->getHighestVersion(), PHP_VERSION) === -1) {
-                throw new Exception\UnresolvedPhpDependencyException(
+                throw new UnresolvedPhpDependencyException(
                     'Your PHP version is higher than allowed. You can use PHP versions ' . $dependency->getLowestVersion() . ' - ' . $dependency->getHighestVersion(),
                     1377977856
                 );
             }
         } else {
-            throw new Exception\UnresolvedPhpDependencyException(
+            throw new UnresolvedPhpDependencyException(
                 'checkPhpDependency can only check PHP dependencies. Found dependency with identifier "' . $dependency->getIdentifier() . '"',
                 1377977858
             );
@@ -277,15 +283,15 @@ class DependencyUtility implements SingletonInterface
             if (version_compare($loadedVersion, $dependency->getHighestVersion()) === -1) {
                 try {
                     $this->getExtensionFromRepository($extensionKey, $dependency);
-                } catch (Exception\UnresolvedDependencyException $e) {
-                    throw new Exception\MissingVersionDependencyException(
+                } catch (UnresolvedDependencyException $e) {
+                    throw new MissingVersionDependencyException(
                         'The extension ' . $extensionKey . ' is installed in version ' . $loadedVersion
                             . ' but needed in version ' . $dependency->getLowestVersion() . ' - ' . $dependency->getHighestVersion() . ' and could not be fetched from TER',
                         1396302624
                     );
                 }
             } else {
-                throw new Exception\MissingVersionDependencyException(
+                throw new MissingVersionDependencyException(
                     'The extension ' . $extensionKey . ' is installed in version ' . $loadedVersion .
                     ' but needed in version ' . $dependency->getLowestVersion() . ' - ' . $dependency->getHighestVersion(),
                     1430561927
@@ -305,9 +311,9 @@ class DependencyUtility implements SingletonInterface
                     if (version_compare($availableVersion, $dependency->getHighestVersion()) === -1) {
                         try {
                             $this->getExtensionFromRepository($extensionKey, $dependency);
-                        } catch (Exception\MissingExtensionDependencyException $e) {
+                        } catch (MissingExtensionDependencyException $e) {
                             if (!$this->skipDependencyCheck) {
-                                throw new Exception\MissingVersionDependencyException(
+                                throw new MissingVersionDependencyException(
                                     'The extension ' . $extensionKey . ' is available in version ' . $availableVersion
                                     . ' but is needed in version ' . $dependency->getLowestVersion() . ' - ' . $dependency->getHighestVersion() . ' and could not be fetched from TER',
                                     1430560390
@@ -316,7 +322,7 @@ class DependencyUtility implements SingletonInterface
                         }
                     } else {
                         if (!$this->skipDependencyCheck) {
-                            throw new Exception\MissingVersionDependencyException(
+                            throw new MissingVersionDependencyException(
                                 'The extension ' . $extensionKey . ' is available in version ' . $availableVersion
                                 . ' but is needed in version ' . $dependency->getLowestVersion() . ' - ' . $dependency->getHighestVersion(),
                                 1430562374
@@ -362,6 +368,7 @@ class DependencyUtility implements SingletonInterface
     {
         if ($this->localExtensionStorage !== '' && is_dir($this->localExtensionStorage)) {
             $extList = GeneralUtility::get_dirs($this->localExtensionStorage);
+            $extList = is_array($extList) ? $extList : [];
             if (in_array($extensionKey, $extList)) {
                 $this->managementService->markExtensionForCopy($extensionKey, $this->localExtensionStorage);
                 return true;
@@ -384,12 +391,12 @@ class DependencyUtility implements SingletonInterface
         if (!$isExtensionDownloadableFromTer) {
             if (!$this->skipDependencyCheck) {
                 if ($this->extensionRepository->countAll() > 0) {
-                    throw new Exception\MissingExtensionDependencyException(
+                    throw new MissingExtensionDependencyException(
                         'The extension ' . $extensionKey . ' is not available from TER.',
                         1399161266
                     );
                 }
-                throw new Exception\MissingExtensionDependencyException(
+                throw new MissingExtensionDependencyException(
                     'The extension ' . $extensionKey . ' could not be checked. Please update your Extension-List from TYPO3 Extension Repository (TER).',
                     1430580308
                 );
@@ -400,7 +407,7 @@ class DependencyUtility implements SingletonInterface
         $isDownloadableVersionCompatible = $this->isDownloadableVersionCompatible($dependency);
         if (!$isDownloadableVersionCompatible) {
             if (!$this->skipDependencyCheck) {
-                throw new Exception\MissingVersionDependencyException(
+                throw new MissingVersionDependencyException(
                     'No compatible version found for extension ' . $extensionKey,
                     1399161284
                 );
@@ -411,7 +418,7 @@ class DependencyUtility implements SingletonInterface
         $latestCompatibleExtensionByIntegerVersionDependency = $this->getLatestCompatibleExtensionByIntegerVersionDependency($dependency);
         if (!$latestCompatibleExtensionByIntegerVersionDependency instanceof Extension) {
             if (!$this->skipDependencyCheck) {
-                throw new Exception\MissingExtensionDependencyException(
+                throw new MissingExtensionDependencyException(
                     'Could not resolve dependency for "' . $dependency->getIdentifier() . '"',
                     1399161302
                 );
@@ -518,6 +525,32 @@ class DependencyUtility implements SingletonInterface
         return !empty($count);
     }
 
+    /**
+     * Get the latest compatible version of an extension that's
+     * compatible with the current core and PHP version.
+     *
+     * @param iterable $extensions
+     * @return Extension|null
+     */
+    protected function getCompatibleExtension(iterable $extensions): ?Extension
+    {
+        foreach ($extensions as $extension) {
+            /** @var Extension $extension */
+            $this->checkDependencies($extension);
+            $extensionKey = $extension->getExtensionKey();
+
+            if (isset($this->dependencyErrors[$extensionKey])) {
+                // reset dependencyErrors and continue with next version
+                unset($this->dependencyErrors[$extensionKey]);
+                continue;
+            }
+
+            return $extension;
+        }
+
+        return null;
+    }
+
     /**
      * Get the latest compatible version of an extension that
      * fulfills the given dependency from TER
@@ -533,7 +566,7 @@ class DependencyUtility implements SingletonInterface
             $versions['lowestIntegerVersion'],
             $versions['highestIntegerVersion']
         );
-        return $compatibleDataSets->getFirst();
+        return $this->getCompatibleExtension($compatibleDataSets);
     }
 
     /**
@@ -590,7 +623,7 @@ class DependencyUtility implements SingletonInterface
                         if ($this->checkTypo3Dependency($dependency)) {
                             $suitableExtensions[] = $extension;
                         }
-                    } catch (Exception\UnresolvedTypo3DependencyException $e) {
+                    } catch (UnresolvedTypo3DependencyException $e) {
                     }
                     break;
                 }
