@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extensionmanager\Utility;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Extensionmanager\Utility;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extensionmanager\Utility;
+
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
 use TYPO3\CMS\Core\Core\Environment;
@@ -275,6 +276,7 @@ class FileHandlingUtility implements SingletonInterface, LoggerAwareInterface
                     'siteRelPath' => PathUtility::stripPathSitePrefix($rootPath)
                 ]
             );
+            $emConfFileData = is_array($emConfFileData) ? $emConfFileData : [];
         }
         $extensionData['EM_CONF'] = array_replace_recursive($emConfFileData, $extensionData['EM_CONF']);
         $emConfContent = $this->emConfUtility->constructEmConf($extensionData, $extension);
@@ -390,6 +392,7 @@ class FileHandlingUtility implements SingletonInterface, LoggerAwareInterface
 
         // Make paths relative to extension root directory.
         $files = GeneralUtility::removePrefixPathFromList($files, $extensionPath);
+        $files = is_array($files) ? $files : [];
 
         // Remove the one empty path that is the extension dir itself.
         $files = array_filter($files);
