@@ -1,7 +1,5 @@
 <?php
 
-namespace TYPO3\CMS\Extensionmanager\Utility;
-
 /*
  * This file is part of the TYPO3 CMS project.
  *
@@ -15,10 +13,13 @@ namespace TYPO3\CMS\Extensionmanager\Utility;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extensionmanager\Utility;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
 use Symfony\Component\Finder\Finder;
+use TYPO3\CMS\Core\Cache\CacheManager;
 use TYPO3\CMS\Core\Configuration\ExtensionConfiguration;
 use TYPO3\CMS\Core\Configuration\SiteConfiguration;
 use TYPO3\CMS\Core\Core\Bootstrap;
@@ -27,18 +28,24 @@ use TYPO3\CMS\Core\Database\Schema\SchemaMigrator;
 use TYPO3\CMS\Core\Database\Schema\SqlReader;
 use TYPO3\CMS\Core\Package\Event\AfterPackageActivationEvent;
 use TYPO3\CMS\Core\Package\Event\AfterPackageDeactivationEvent;
+use TYPO3\CMS\Core\Package\PackageManager;
+use TYPO3\CMS\Core\Registry;
 use TYPO3\CMS\Core\Service\OpcodeCacheService;
 use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Site\Entity\Site;
 use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Extbase\Utility\LocalizationUtility;
 use TYPO3\CMS\Extensionmanager\Domain\Model\Extension;
+use TYPO3\CMS\Extensionmanager\Domain\Repository\ExtensionRepository;
 use TYPO3\CMS\Extensionmanager\Event\AfterExtensionDatabaseContentHasBeenImportedEvent;
 use TYPO3\CMS\Extensionmanager\Event\AfterExtensionFilesHaveBeenImportedEvent;
+use TYPO3\CMS\Extensionmanager\Event\AfterExtensionSiteFilesHaveBeenImportedEvent;
 use TYPO3\CMS\Extensionmanager\Event\AfterExtensionStaticDatabaseContentHasBeenImportedEvent;
 use TYPO3\CMS\Extensionmanager\Exception\ExtensionManagerException;
 use TYPO3\CMS\Impexp\Import;
 use TYPO3\CMS\Impexp\Utility\ImportExportUtility;
+use TYPO3\CMS\Install\Service\LateBootService;
 
 /**
  * Extension Manager Install Utility
@@ -88,6 +95,11 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
      */
     protected $eventDispatcher;
 
+    /**
+     * @var LateBootService
+     */
+    protected $lateBootService;
+
     public function injectEventDispatcher(EventDispatcherInterface $eventDispatcher)
     {
         $this->eventDispatcher = $eventDispatcher;
@@ -96,7 +108,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
     /**
      * @param \TYPO3\CMS\Extensionmanager\Utility\DependencyUtility $dependencyUtility
      */
-    public function injectDependencyUtility(\TYPO3\CMS\Extensionmanager\Utility\DependencyUtility $dependencyUtility)
+    public function injectDependencyUtility(DependencyUtility $dependencyUtility)
     {
         $this->dependencyUtility = $dependencyUtility;
     }
@@ -104,7 +116,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
     /**
      * @param \TYPO3\CMS\Extensionmanager\Utility\FileHandlingUtility $fileHandlingUtility
      */
-    public function injectFileHandlingUtility(\TYPO3\CMS\Extensionmanager\Utility\FileHandlingUtility $fileHandlingUtility)
+    public function injectFileHandlingUtility(FileHandlingUtility $fileHandlingUtility)
     {
         $this->fileHandlingUtility = $fileHandlingUtility;
     }
@@ -112,7 +124,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
     /**
      * @param \TYPO3\CMS\Extensionmanager\Utility\ListUtility $listUtility
      */
-    public function injectListUtility(\TYPO3\CMS\Extensionmanager\Utility\ListUtility $listUtility)
+    public function injectListUtility(ListUtility $listUtility)
     {
         $this->listUtility = $listUtility;
     }
@@ -120,7 +132,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
     /**
      * @param \TYPO3\CMS\Extensionmanager\Domain\Repository\ExtensionRepository $extensionRepository
      */
-    public function injectExtensionRepository(\TYPO3\CMS\Extensionmanager\Domain\Repository\ExtensionRepository $extensionRepository)
+    public function injectExtensionRepository(ExtensionRepository $extensionRepository)
     {
         $this->extensionRepository = $extensionRepository;
     }
@@ -128,7 +140,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
     /**
      * @param \TYPO3\CMS\Core\Package\PackageManager $packageManager
      */
-    public function injectPackageManager(\TYPO3\CMS\Core\Package\PackageManager $packageManager)
+    public function injectPackageManager(PackageManager $packageManager)
     {
         $this->packageManager = $packageManager;
     }
@@ -136,7 +148,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
     /**
      * @param \TYPO3\CMS\Core\Cache\CacheManager $cacheManager
      */
-    public function injectCacheManager(\TYPO3\CMS\Core\Cache\CacheManager $cacheManager)
+    public function injectCacheManager(CacheManager $cacheManager)
     {
         $this->cacheManager = $cacheManager;
     }
@@ -144,16 +156,24 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
     /**
      * @param \TYPO3\CMS\Core\Registry $registry
      */
-    public function injectRegistry(\TYPO3\CMS\Core\Registry $registry)
+    public function injectRegistry(Registry $registry)
     {
         $this->registry = $registry;
     }
 
+    /**
+     * @param  LateBootService $lateBootService
+     */
+    public function injectLateBootService(LateBootService $lateBootService)
+    {
+        $this->lateBootService = $lateBootService;
+    }
+
     /**
      * Helper function to install an extension
      * also processes db updates and clears the cache if the extension asks for it
      *
-     * @param array $extensionKeys
+     * @param string ...$extensionKeys
      * @throws ExtensionManagerException
      */
     public function install(...$extensionKeys)
@@ -173,13 +193,21 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
         } else {
             $this->cacheManager->flushCachesInGroup('system');
         }
+
+        // Load a new container as reloadCaches will load ext_localconf
+        $container = $this->lateBootService->getContainer();
+        $backup = $this->lateBootService->makeCurrent($container);
+
         $this->reloadCaches();
         $this->updateDatabase();
 
         foreach ($extensionKeys as $extensionKey) {
             $this->processExtensionSetup($extensionKey);
-            $this->eventDispatcher->dispatch(new AfterPackageActivationEvent($extensionKey, 'typo3-cms-extension', $this));
+            $container->get(EventDispatcherInterface::class)->dispatch(new AfterPackageActivationEvent($extensionKey, 'typo3-cms-extension', $this));
         }
+
+        // Reset to the original container instance
+        $this->lateBootService->makeCurrent(null, $backup);
     }
 
     /**
@@ -191,7 +219,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
         $this->importInitialFiles($extension['siteRelPath'] ?? '', $extensionKey);
         $this->importStaticSqlFile($extensionKey, $extension['siteRelPath']);
         $import = $this->importT3DFile($extensionKey, $extension['siteRelPath']);
-        $this->importSiteConfiguration($extension['siteRelPath'], $import);
+        $this->importSiteConfiguration($extensionKey, $extension['siteRelPath'], $import);
     }
 
     /**
@@ -205,11 +233,11 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
         $dependentExtensions = $this->dependencyUtility->findInstalledExtensionsThatDependOnMe($extensionKey);
         if (is_array($dependentExtensions) && !empty($dependentExtensions)) {
             throw new ExtensionManagerException(
-                \TYPO3\CMS\Extbase\Utility\LocalizationUtility::translate(
+                LocalizationUtility::translate(
                     'extensionList.uninstall.dependencyError',
                     'extensionmanager',
                     [$extensionKey, implode(',', $dependentExtensions)]
-                ),
+                ) ?? '',
                 1342554622
             );
         }
@@ -365,9 +393,12 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
             if (empty($updateStatements[$action])) {
                 continue;
             }
+
+            $statements = array_combine(array_keys($updateStatements[$action]), array_fill(0, count($updateStatements[$action]), true));
+            $statements = is_array($statements) ? $statements : [];
             $selectedStatements = array_merge(
                 $selectedStatements,
-                array_combine(array_keys($updateStatements[$action]), array_fill(0, count($updateStatements[$action]), true))
+                $statements
             );
         }
 
@@ -433,7 +464,6 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
         // Only check for update for TER extensions
         $version = $extensionData->getIntegerVersion();
 
-        /** @var $extensionUpdates [] \TYPO3\CMS\Extensionmanager\Domain\Model\Extension */
         $extensionUpdates = $this->extensionRepository->findByVersionRangeAndExtensionKeyOrderedByVersion(
             $extensionData->getExtensionKey(),
             $version,
@@ -442,6 +472,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
         );
         if ($extensionUpdates->count() > 0) {
             foreach ($extensionUpdates as $extensionUpdate) {
+                /** @var \TYPO3\CMS\Extensionmanager\Domain\Model\Extension $extensionUpdate */
                 try {
                     $this->dependencyUtility->checkDependencies($extensionUpdate);
                     if (!$this->dependencyUtility->hasDependencyErrors()) {
@@ -513,7 +544,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
             $extTablesStaticSqlFile = Environment::getPublicPath() . '/' . $extTablesStaticSqlRelFile;
             $shortFileHash = '';
             if (file_exists($extTablesStaticSqlFile)) {
-                $extTablesStaticSqlContent = file_get_contents($extTablesStaticSqlFile);
+                $extTablesStaticSqlContent = (string)file_get_contents($extTablesStaticSqlFile);
                 $shortFileHash = md5($extTablesStaticSqlContent);
                 $this->importStaticSql($extTablesStaticSqlContent);
             }
@@ -550,10 +581,11 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
     }
 
     /**
+     * @param string $extensionKey
      * @param string $extensionSiteRelPath
      * @param Import|null $import
      */
-    protected function importSiteConfiguration(string $extensionSiteRelPath, Import $import = null): void
+    protected function importSiteConfiguration(string $extensionKey, string $extensionSiteRelPath, Import $import = null): void
     {
         $importRelFolder = $extensionSiteRelPath . 'Initialisation/Site';
         $importAbsFolder = Environment::getPublicPath() . '/' . $importRelFolder;
@@ -563,10 +595,7 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
             return;
         }
 
-        $siteConfiguration = GeneralUtility::makeInstance(
-            SiteConfiguration::class,
-            $destinationFolder
-        );
+        $siteConfiguration = GeneralUtility::makeInstance(SiteConfiguration::class);
         $existingSites = $siteConfiguration->resolveAllExistingSites(false);
 
         GeneralUtility::mkdir($destinationFolder);
@@ -596,23 +625,30 @@ class InstallUtility implements SingletonInterface, LoggerAwareInterface
 
         /** @var Site[] $newSites */
         $newSites = array_diff_key($siteConfiguration->resolveAllExistingSites(false), $existingSites);
-        $importedPages = $import->import_mapId['pages'] ?? null;
+        $importedPages = [];
+        if ($import instanceof Import && !empty($import->import_mapId['pages'])) {
+            $importedPages = $import->import_mapId['pages'];
+        }
 
+        $newSiteIdentifierList = [];
         foreach ($newSites as $newSite) {
             $exportedPageId = $newSite->getRootPageId();
+            $siteIdentifier = $newSite->getIdentifier();
+            $newSiteIdentifierList[] = $siteIdentifier;
             $importedPageId = $importedPages[$exportedPageId] ?? null;
             if ($importedPageId === null) {
                 $this->logger->warning(
                     sprintf(
                         'Imported site configuration with identifier %s could not be mapped to imported page id',
-                        $newSite->getIdentifier()
+                        $siteIdentifier
                     )
                 );
                 continue;
             }
-            $configuration = $siteConfiguration->load($newSite->getIdentifier());
+            $configuration = $siteConfiguration->load($siteIdentifier);
             $configuration['rootPageId'] = $importedPageId;
-            $siteConfiguration->write($newSite->getIdentifier(), $configuration);
+            $siteConfiguration->write($siteIdentifier, $configuration);
         }
+        $this->eventDispatcher->dispatch(new AfterExtensionSiteFilesHaveBeenImportedEvent($extensionKey, $newSiteIdentifierList));
     }
 }
