@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Extensionmanager\Utility;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,11 +13,14 @@ namespace TYPO3\CMS\Extensionmanager\Utility;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Extensionmanager\Utility;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Package\Event\PackagesMayHaveChangedEvent;
 use TYPO3\CMS\Core\Package\PackageInterface;
 use TYPO3\CMS\Core\Package\PackageManager;
+use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\PathUtility;
@@ -35,7 +37,7 @@ use TYPO3\CMS\Extensionmanager\Domain\Repository\ExtensionRepository;
  * - The name 'listUtility' is not good, the methods could be moved to some 'extensionInformationUtility', or a repository?
  * @internal This class is a specific ExtensionManager implementation and is not part of the Public TYPO3 API.
  */
-class ListUtility implements \TYPO3\CMS\Core\SingletonInterface
+class ListUtility implements SingletonInterface
 {
     /**
      * @var EmConfUtility
@@ -107,7 +109,7 @@ class ListUtility implements \TYPO3\CMS\Core\SingletonInterface
     /**
      * Returns the list of available, but not necessarily loaded extensions
      *
-     * @param string
+     * @param string $filter
      * @return array[] All extensions with info
      */
     public function getAvailableExtensions(string $filter = ''): array
@@ -193,7 +195,7 @@ class ListUtility implements \TYPO3\CMS\Core\SingletonInterface
     {
         foreach ($extensions as $extensionKey => $properties) {
             $emconf = $this->emConfUtility->includeEmConf($extensionKey, $properties);
-            if ($emconf) {
+            if (is_array($emconf)) {
                 $extensions[$extensionKey] = array_merge($emconf, $properties);
             } else {
                 unset($extensions[$extensionKey]);
@@ -262,7 +264,7 @@ class ListUtility implements \TYPO3\CMS\Core\SingletonInterface
      * Gets all available and installed extension with additional information
      * from em_conf and TER (if available)
      *
-     * @param string
+     * @param string $filter
      * @return array
      */
     public function getAvailableAndInstalledExtensionsWithAdditionalInformation(string $filter = ''): array
