@@ -1,4 +1,5 @@
 <?php
+
 defined('TYPO3_MODE') or die();
 
 \TYPO3\CMS\Extbase\Utility\ExtensionUtility::registerModule(
@@ -13,7 +14,8 @@ defined('TYPO3_MODE') or die();
         \TYPO3\CMS\Extensionmanager\Controller\UpdateScriptController::class => 'show',
         \TYPO3\CMS\Extensionmanager\Controller\UpdateFromTerController::class => 'updateExtensionListFromTer',
         \TYPO3\CMS\Extensionmanager\Controller\UploadExtensionFileController::class => 'form,extract',
-        \TYPO3\CMS\Extensionmanager\Controller\DistributionController::class => 'show'
+        \TYPO3\CMS\Extensionmanager\Controller\DistributionController::class => 'show',
+        \TYPO3\CMS\Extensionmanager\Controller\ExtensionComposerStatusController::class => 'list,detail'
     ],
     [
         'access' => 'systemMaintainer',
