@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Felogin\Controller;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Felogin\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Felogin\Controller;
+
 use Symfony\Component\Mime\Address;
 use TYPO3\CMS\Core\Authentication\LoginType;
 use TYPO3\CMS\Core\Context\Context;
@@ -25,6 +26,7 @@ use TYPO3\CMS\Core\Database\Query\Restriction\FrontendRestrictionContainer;
 use TYPO3\CMS\Core\Mail\MailMessage;
 use TYPO3\CMS\Core\Session\SessionManager;
 use TYPO3\CMS\Core\Site\SiteFinder;
+use TYPO3\CMS\Core\Utility\ArrayUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\HttpUtility;
 use TYPO3\CMS\Core\Utility\MailUtility;
@@ -35,6 +37,7 @@ use TYPO3\CMS\FrontendLogin\Validation\RedirectUrlValidator;
  * Plugin 'Website User Login' for the 'felogin' extension.
  *
  * @internal this is a concrete TYPO3 implementation and solely used for EXT:felogin and not part of TYPO3's Core API.
+ * @deprecated The pibase felogin plugin is deprecated since TYPO3 10.4 and will be removed in version 11.0
  */
 class FrontendLoginController extends AbstractPlugin
 {
@@ -113,13 +116,17 @@ class FrontendLoginController extends AbstractPlugin
      * @param array $conf The PlugIn configuration
      * @return string The content that is displayed on the website
      * @throws \RuntimeException when no storage PID was configured.
+     * @deprecated The pibase felogin plugin is deprecated since TYPO3 10.4 and will be removed in version 11.0
      */
     public function main($content, $conf)
     {
+        trigger_error(
+            'The pibase felogin plugin is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+            E_USER_DEPRECATED
+        );
         $this->urlValidator = GeneralUtility::makeInstance(
             RedirectUrlValidator::class,
-            GeneralUtility::makeInstance(SiteFinder::class),
-            (int)$this->frontendController->id
+            GeneralUtility::makeInstance(SiteFinder::class)
         );
 
         // Loading TypoScript array into object variable:
@@ -197,15 +204,31 @@ class FrontendLoginController extends AbstractPlugin
                 ];
                 foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['beforeRedirect'] ?? [] as $_funcRef) {
                     if ($_funcRef) {
+                        trigger_error(
+                            sprintf(
+                                'Hook "%s" got called by "%s" which is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+                                '$GLOBALS[\'TYPO3_CONF_VARS\'][\'EXTCONF\'][\'felogin\'][\'beforeRedirect\']',
+                                $_funcRef
+                            ),
+                            E_USER_DEPRECATED
+                        );
                         $ref = $this; // introduced for phpstan to not lose type information when passing $this into callUserFunction
                         GeneralUtility::callUserFunction($_funcRef, $_params, $ref);
                     }
                 }
-                \TYPO3\CMS\Core\Utility\HttpUtility::redirect($this->redirectUrl);
+                HttpUtility::redirect($this->redirectUrl);
             }
         }
         // Adds hook for processing of extra item markers / special
         foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['postProcContent'] ?? [] as $_funcRef) {
+            trigger_error(
+                sprintf(
+                    'Hook "%s" got called by "%s" which is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+                    '$GLOBALS[\'TYPO3_CONF_VARS\'][\'EXTCONF\'][\'felogin\'][\'postProcContent\']',
+                    $_funcRef
+                ),
+                E_USER_DEPRECATED
+            );
             $_params = [
                 'content' => $content
             ];
@@ -336,13 +359,15 @@ class FrontendLoginController extends AbstractPlugin
             $user = $this->pi_getRecord('fe_users', (int)$uid);
             $userHash = $user['felogin_forgotHash'];
             $compareHash = explode('|', $userHash);
-            if (strlen($compareHash[1]) === 40) {
+            if (!$compareHash || !$compareHash[1] || $compareHash[0] < time() || !hash_equals($compareHash[0], $hash[0])) {
+                $hashEquals = false;
+            } elseif (strlen($compareHash[1]) === 40) {
                 $hashEquals = hash_equals($compareHash[1], GeneralUtility::hmac((string)$hash[1]));
             } else {
                 // backward-compatibility for previous MD5 hashes
                 $hashEquals = hash_equals($compareHash[1], md5($hash[1]));
             }
-            if (!$compareHash || !$compareHash[1] || $compareHash[0] < time() || !hash_equals($compareHash[0], $hash[0]) || !$hashEquals) {
+            if (!$hashEquals) {
                 $markerArray['###STATUS_MESSAGE###'] = $this->getDisplayText(
                     'change_password_notvalid_message',
                     $this->conf['changePasswordNotValidMessage_stdWrap.']
@@ -384,6 +409,14 @@ class FrontendLoginController extends AbstractPlugin
                                 'passwordInvalidMessage' => '',
                             ];
                             foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['password_changed'] as $_funcRef) {
+                                trigger_error(
+                                    sprintf(
+                                        'Hook "%s" got called by "%s" which is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+                                        '$GLOBALS[\'TYPO3_CONF_VARS\'][\'EXTCONF\'][\'felogin\'][\'password_changed\']',
+                                        $_funcRef
+                                    ),
+                                    E_USER_DEPRECATED
+                                );
                                 if ($_funcRef) {
                                     GeneralUtility::callUserFunction($_funcRef, $_params, $this);
                                 }
@@ -482,7 +515,7 @@ class FrontendLoginController extends AbstractPlugin
         $isAbsRefPrefix = !empty($this->frontendController->absRefPrefix);
         $isBaseURL = !empty($this->frontendController->baseUrl);
         $isFeloginBaseURL = !empty($this->conf['feloginBaseURL']);
-        $link = $this->pi_getPageLink($this->frontendController->id, '', [
+        $link = $this->pi_getPageLink((int)$this->frontendController->id, '', [
             $this->prefixId . '[user]' => $user['uid'],
             $this->prefixId . '[forgothash]' => $randHash
         ]);
@@ -513,6 +546,14 @@ class FrontendLoginController extends AbstractPlugin
             'user' => &$user
         ];
         foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['forgotPasswordMail'] ?? [] as $reference) {
+            trigger_error(
+                sprintf(
+                    'Hook "%s" got called by "%s" which is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+                    '$GLOBALS[\'TYPO3_CONF_VARS\'][\'EXTCONF\'][\'felogin\'][\'forgotPasswordMail\']',
+                    $reference
+                ),
+                E_USER_DEPRECATED
+            );
             if ($reference) {
                 GeneralUtility::callUserFunction($reference, $params, $this);
             }
@@ -576,6 +617,14 @@ class FrontendLoginController extends AbstractPlugin
                 // Hook for general actions after after login has been confirmed (by Thomas Danzl <thomas@danzl.org>)
                 foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['login_confirmed'] ?? [] as $_funcRef) {
                     $_params = [];
+                    trigger_error(
+                        sprintf(
+                            'Hook "%s" got called by "%s" which is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+                            '$GLOBALS[\'TYPO3_CONF_VARS\'][\'EXTCONF\'][\'felogin\'][\'login_confirmed\']',
+                            $_funcRef
+                        ),
+                        E_USER_DEPRECATED
+                    );
                     if ($_funcRef) {
                         GeneralUtility::callUserFunction($_funcRef, $_params, $this);
                     }
@@ -589,6 +638,14 @@ class FrontendLoginController extends AbstractPlugin
                 // Hook for general actions on login error
                 $params = [];
                 foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['login_error'] ?? [] as $funcRef) {
+                    trigger_error(
+                        sprintf(
+                            'Hook "%s" got called by "%s" which is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+                            '$GLOBALS[\'TYPO3_CONF_VARS\'][\'EXTCONF\'][\'felogin\'][\'login_error\']',
+                            $funcRef
+                        ),
+                        E_USER_DEPRECATED
+                    );
                     if ($funcRef) {
                         GeneralUtility::callUserFunction($funcRef, $params, $this);
                     }
@@ -628,6 +685,14 @@ class FrontendLoginController extends AbstractPlugin
         }
         $_params = [];
         foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['loginFormOnSubmitFuncs'] ?? [] as $funcRef) {
+            trigger_error(
+                sprintf(
+                    'Hook "%s" got called by "%s" which is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+                    '$GLOBALS[\'TYPO3_CONF_VARS\'][\'EXTCONF\'][\'felogin\'][\'loginFormOnSubmitFuncs\']',
+                    $funcRef
+                ),
+                E_USER_DEPRECATED
+            );
             [$onSub, $hid] = GeneralUtility::callUserFunction($funcRef, $_params, $this);
             $onSubmitAr[] = $onSub;
             $extraHiddenAr[] = $hid;
@@ -830,6 +895,14 @@ class FrontendLoginController extends AbstractPlugin
                     // after logout
                     // Hook for general actions after after logout has been confirmed
                     foreach ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['felogin']['logout_confirmed'] ?? [] as $_funcRef) {
+                        trigger_error(
+                            sprintf(
+                                'Hook "%s" got called by "%s" which is deprecated since TYPO3 10.4 and will be removed in version 11.0',
+                                '$GLOBALS[\'TYPO3_CONF_VARS\'][\'EXTCONF\'][\'felogin\'][\'logout_confirmed\']',
+                                $_funcRef
+                            ),
+                            E_USER_DEPRECATED
+                        );
                         $_params = [];
                         if ($_funcRef) {
                             $ref = $this; // introduced for phpstan to not lose type information when passing $this into callUserFunction
@@ -857,7 +930,9 @@ class FrontendLoginController extends AbstractPlugin
         }
         // Remove empty values, but keep "0" as value (that's why "strlen" is used as second parameter)
         if (!empty($redirect_url)) {
-            return array_filter($redirect_url, 'strlen');
+            return array_filter($redirect_url, static function (string $value) {
+                return $value !== '';
+            });
         }
         return [];
     }
@@ -901,7 +976,7 @@ class FrontendLoginController extends AbstractPlugin
         if ($this->flexFormValue('redirectPageLogout', 's_redirect')) {
             $flex['redirectPageLogout'] = $this->flexFormValue('redirectPageLogout', 's_redirect');
         }
-        $pid = $flex['pages'] ? $this->pi_getPidList($flex['pages'], $flex['recursive']) : 0;
+        $pid = $flex['pages'] ? $this->pi_getPidList($flex['pages'], (int)$flex['recursive']) : 0;
         if ($pid > 0) {
             $flex['storagePid'] = $pid;
         }
@@ -970,7 +1045,7 @@ class FrontendLoginController extends AbstractPlugin
             $preserveQueryStringProperties = GeneralUtility::trimExplode(',', $this->conf['preserveGETvars']);
             $preserveQueryParts = [];
             parse_str(implode('=1&', $preserveQueryStringProperties) . '=1', $preserveQueryParts);
-            $preserveQueryParts = \TYPO3\CMS\Core\Utility\ArrayUtility::intersectRecursive($getVars, $preserveQueryParts);
+            $preserveQueryParts = ArrayUtility::intersectRecursive($getVars, $preserveQueryParts);
         }
         return $preserveQueryParts;
     }
@@ -1067,7 +1142,7 @@ class FrontendLoginController extends AbstractPlugin
         }
         $parsedReplyTo = MailUtility::parseAddresses($replyTo);
         if (!empty($parsedReplyTo)) {
-            $mail->replyTo($parsedReplyTo);
+            $mail->replyTo(...$parsedReplyTo);
         }
         // First line is subject
         $messageParts = explode(LF, trim($message), 2);
