@@ -1,7 +1,5 @@
 <?php
 
-namespace TYPO3\CMS\Filelist\Controller;
-
 /*
  * This file is part of the TYPO3 CMS project.
  *
@@ -15,6 +13,8 @@ namespace TYPO3\CMS\Filelist\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Filelist\Controller;
+
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
 use TYPO3\CMS\Backend\Clipboard\Clipboard;
@@ -29,8 +29,11 @@ use TYPO3\CMS\Core\Localization\LanguageService;
 use TYPO3\CMS\Core\Messaging\FlashMessage;
 use TYPO3\CMS\Core\Resource\DuplicationBehavior;
 use TYPO3\CMS\Core\Resource\Exception;
+use TYPO3\CMS\Core\Resource\Exception\InsufficientFolderAccessPermissionsException;
+use TYPO3\CMS\Core\Resource\FileRepository;
 use TYPO3\CMS\Core\Resource\Folder;
 use TYPO3\CMS\Core\Resource\ResourceFactory;
+use TYPO3\CMS\Core\Resource\ResourceStorage;
 use TYPO3\CMS\Core\Resource\Search\FileSearchDemand;
 use TYPO3\CMS\Core\Resource\Utility\ListUtility;
 use TYPO3\CMS\Core\Type\Bitmask\JsConfirmation;
@@ -137,14 +140,14 @@ class FileListController extends ActionController implements LoggerAwareInterfac
     /**
      * BackendTemplateView Container
      *
-     * @var BackendTemplateView
+     * @var string
      */
     protected $defaultViewObjectName = BackendTemplateView::class;
 
     /**
      * @param \TYPO3\CMS\Core\Resource\FileRepository $fileRepository
      */
-    public function injectFileRepository(\TYPO3\CMS\Core\Resource\FileRepository $fileRepository)
+    public function injectFileRepository(FileRepository $fileRepository)
     {
         $this->fileRepository = $fileRepository;
     }
@@ -169,7 +172,7 @@ class FileListController extends ActionController implements LoggerAwareInterfac
 
         try {
             if ($combinedIdentifier) {
-                /** @var ResourceFactory $resourceFactory */
+                $this->getBackendUser()->evaluateUserSpecificFileFilterSettings();
                 $resourceFactory = GeneralUtility::makeInstance(ResourceFactory::class);
                 $storage = $resourceFactory->getStorageObjectFromCombinedIdentifier($combinedIdentifier);
                 $identifier = substr($combinedIdentifier, strpos($combinedIdentifier, ':') + 1);
@@ -180,7 +183,7 @@ class FileListController extends ActionController implements LoggerAwareInterfac
                 $this->folderObject = $resourceFactory->getFolderObjectFromCombinedIdentifier($storage->getUid() . ':' . $identifier);
                 // Disallow access to fallback storage 0
                 if ($storage->getUid() === 0) {
-                    throw new Exception\InsufficientFolderAccessPermissionsException(
+                    throw new InsufficientFolderAccessPermissionsException(
                         'You are not allowed to access files outside your storages',
                         1434539815
                     );
@@ -203,7 +206,7 @@ class FileListController extends ActionController implements LoggerAwareInterfac
             if ($this->folderObject && !$this->folderObject->getStorage()->isWithinFileMountBoundaries($this->folderObject)) {
                 throw new \RuntimeException('Folder not accessible.', 1430409089);
             }
-        } catch (Exception\InsufficientFolderAccessPermissionsException $permissionException) {
+        } catch (InsufficientFolderAccessPermissionsException $permissionException) {
             $this->folderObject = null;
             $this->errorMessage = GeneralUtility::makeInstance(
                 FlashMessage::class,
@@ -220,7 +223,7 @@ class FileListController extends ActionController implements LoggerAwareInterfac
             // Take the first object of the first storage
             $fileStorages = $this->getBackendUser()->getFileStorages();
             $fileStorage = reset($fileStorages);
-            if ($fileStorage instanceof \TYPO3\CMS\Core\Resource\ResourceStorage) {
+            if ($fileStorage instanceof ResourceStorage) {
                 $this->folderObject = $fileStorage->getRootLevelFolder();
                 if (!$fileStorage->isWithinFileMountBoundaries($this->folderObject)) {
                     $this->folderObject = null;
@@ -292,9 +295,17 @@ class FileListController extends ActionController implements LoggerAwareInterfac
         parent::initializeView($view);
         $pageRenderer = $this->view->getModuleTemplate()->getPageRenderer();
         $pageRenderer->loadRequireJsModule('TYPO3/CMS/Filelist/FileListLocalisation');
+        $pageRenderer->loadRequireJsModule('TYPO3/CMS/Filelist/FileList');
         $pageRenderer->loadRequireJsModule('TYPO3/CMS/Filelist/FileSearch');
         $pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/ContextMenu');
         $this->registerDocHeaderButtons();
+        if ($this->folderObject instanceof Folder) {
+            $view->assign(
+                'currentFolderHash',
+                'folder' . GeneralUtility::md5int($this->folderObject->getCombinedIdentifier())
+            );
+        }
+        $view->assign('currentIdentifier', $this->id);
     }
 
     protected function initializeIndexAction()
@@ -363,8 +374,9 @@ class FileListController extends ActionController implements LoggerAwareInterfac
                 if (!empty($items)) {
                     // Make command array:
                     $FILE = [];
-                    foreach ($items as $v) {
-                        $FILE['delete'][] = ['data' => $v];
+                    foreach ($items as $clipboardIdentifier => $combinedIdentifier) {
+                        $FILE['delete'][] = ['data' => $combinedIdentifier];
+                        $this->filelist->clipObj->removeElement($clipboardIdentifier);
                     }
                     // Init file processing object for deleting and pass the cmd array.
                     /** @var ExtendedFileUtility $fileProcessor */
@@ -373,6 +385,9 @@ class FileListController extends ActionController implements LoggerAwareInterfac
                     $fileProcessor->setExistingFilesConflictMode($this->overwriteExistingFiles);
                     $fileProcessor->start($FILE);
                     $fileProcessor->processData();
+                    // Clean & Save clipboard state
+                    $this->filelist->clipObj->cleanCurrent();
+                    $this->filelist->clipObj->endClipboard();
                 }
             }
             // Start up filelisting object, include settings.
@@ -395,8 +410,6 @@ class FileListController extends ActionController implements LoggerAwareInterfac
                 );
             }
 
-            // Set top JavaScript:
-            $this->addJumpToUrl();
             $pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/ClipboardComponent');
             $pageRenderer->loadRequireJsModule('TYPO3/CMS/Filelist/FileDelete');
             $pageRenderer->addInlineLanguageLabelFile('EXT:backend/Resources/Private/Language/locallang_alt_doc.xlf', 'buttons');
@@ -522,7 +535,7 @@ class FileListController extends ActionController implements LoggerAwareInterfac
         if (count($files) === 0) {
             $this->controllerContext->getFlashMessageQueue('core.template.flashMessages')->addMessage(
                 new FlashMessage(
-                    LocalizationUtility::translate('flashmessage.no_results', 'filelist'),
+                    LocalizationUtility::translate('flashmessage.no_results', 'filelist') ?? '',
                     '',
                     FlashMessage::INFO
                 )
@@ -535,10 +548,6 @@ class FileListController extends ActionController implements LoggerAwareInterfac
 
         $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
 
-        $pageRenderer = $this->view->getModuleTemplate()->getPageRenderer();
-        $pageRenderer->addInlineSetting('ShowItem', 'moduleUrl', (string)$uriBuilder->buildUriFromRoute('show_item'));
-        $pageRenderer->loadRequireJsModule('TYPO3/CMS/Filelist/FileList');
-
         $thumbnailConfiguration = GeneralUtility::makeInstance(ThumbnailConfiguration::class);
         $this->view->assign('thumbnail', [
             'width' => $thumbnailConfiguration->getWidth(),
@@ -553,12 +562,12 @@ class FileListController extends ActionController implements LoggerAwareInterfac
         ]);
         $this->view->assign('moduleSettings', $this->MOD_SETTINGS);
 
+        $pageRenderer = $this->view->getModuleTemplate()->getPageRenderer();
         $pageRenderer->loadRequireJsModule('TYPO3/CMS/Filelist/FileDelete');
         $pageRenderer->addInlineLanguageLabelFile('EXT:backend/Resources/Private/Language/locallang_alt_doc.xlf', 'buttons');
 
         $this->initClipboard();
         $this->buildListOptionCheckboxes($searchWord);
-        $this->addJumpToUrl();
     }
 
     /**
@@ -637,11 +646,11 @@ class FileListController extends ActionController implements LoggerAwareInterfac
             if ($parentFolder->getIdentifier() !== $this->folderObject->getIdentifier()
                 && $currentStorage->isWithinFileMountBoundaries($parentFolder)
             ) {
-                $levelUpClick = 'top.document.getElementsByName("nav_frame")[0].contentWindow.Tree.highlightActiveItem("file","folder'
-                    . GeneralUtility::md5int($parentFolder->getCombinedIdentifier()) . '_"+top.fsMod.currentBank)';
                 $levelUpButton = $buttonBar->makeLinkButton()
+                    ->setDataAttributes([
+                        'tree-update-request' => htmlspecialchars('folder' . GeneralUtility::md5int($parentFolder->getCombinedIdentifier())),
+                    ])
                     ->setHref((string)$uriBuilder->buildUriFromRoute('file_FilelistList', ['id' => $parentFolder->getCombinedIdentifier()]))
-                    ->setOnClick($levelUpClick)
                     ->setTitle($lang->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:labels.upOneLevel'))
                     ->setIcon($iconFactory->getIcon('actions-view-go-up', Icon::SIZE_SMALL));
                 $buttonBar->addButton($levelUpButton, ButtonBar::BUTTON_POSITION_LEFT, 1);
@@ -836,16 +845,4 @@ class FileListController extends ActionController implements LoggerAwareInterfac
         $this->view->assign('showClipBoard', (bool)$this->MOD_SETTINGS['clipBoard']);
         $this->view->assign('clipBoardHtml', $this->filelist->clipObj->printClipboard());
     }
-
-    /**
-     * add javascript jumpToUrl function
-     */
-    protected function addJumpToUrl(): void
-    {
-        $this->view->getModuleTemplate()->addJavaScriptCode(
-            'FileListIndex',
-            'if (top.fsMod) top.fsMod.recentIds["file"] = "' . rawurlencode($this->id) . '";
-                '
-        );
-    }
 }
