@@ -10,4 +10,4 @@
  *
  * The TYPO3 project - inspiring people to share!
  */
-define(["require","exports","jquery"],(function(t,e,r){"use strict";return new class{constructor(){r(()=>{r("a.filelist-translationToggler").click(t=>{const e=r(t.currentTarget).attr("data-fileid");r('div[data-fileid="'+e+'"]').toggle()})})}}}));
\ No newline at end of file
+var __importDefault=this&&this.__importDefault||function(t){return t&&t.__esModule?t:{default:t}};define(["require","exports","jquery"],(function(t,e,r){"use strict";r=__importDefault(r);return new class{constructor(){r.default(()=>{r.default("a.filelist-translationToggler").click(t=>{const e=r.default(t.currentTarget).attr("data-fileid");r.default('div[data-fileid="'+e+'"]').toggle()})})}}}));
\ No newline at end of file
