@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Fluid\ViewHelpers\Be\Menus;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +13,9 @@ namespace TYPO3\CMS\Fluid\ViewHelpers\Be\Menus;
  * The TYPO3 project - inspiring people to share!
  */
 
-use TYPO3\CMS\Extbase\Mvc\Web\Routing\UriBuilder;
+namespace TYPO3\CMS\Fluid\ViewHelpers\Be\Menus;
+
+use TYPO3\CMS\Core\Utility\ArrayUtility;
 use TYPO3Fluid\Fluid\Core\ViewHelper\AbstractTagBasedViewHelper;
 
 /**
@@ -80,17 +81,37 @@ class ActionMenuItemViewHelper extends AbstractTagBasedViewHelper
         $action = $this->arguments['action'];
         $arguments = $this->arguments['arguments'];
 
-        /** @var UriBuilder $uriBuilder */
-        $uriBuilder = $this->renderingContext->getControllerContext()->getUriBuilder();
-        $uri = $uriBuilder->reset()->uriFor($action, $arguments, $controller);
+        $uri = $this->renderingContext->getControllerContext()->getUriBuilder()->reset()->uriFor($action, $arguments, $controller);
         $this->tag->addAttribute('value', $uri);
-        $currentRequest = $this->renderingContext->getControllerContext()->getRequest();
-        $currentController = $currentRequest->getControllerName();
-        $currentAction = $currentRequest->getControllerActionName();
-        if ($action === $currentAction && $controller === $currentController) {
-            $this->tag->addAttribute('selected', 'selected');
+
+        if (!$this->tag->hasAttribute('selected')) {
+            $this->evaluateSelectItemState($controller, $action, $arguments);
         }
-        $this->tag->setContent($label);
+
+        $this->tag->setContent(
+            // Double encode can be set to true, once the typo3fluid/fluid fix is released and required
+            htmlspecialchars($label, ENT_QUOTES, null, false)
+        );
         return $this->tag->render();
     }
+
+    protected function evaluateSelectItemState(string $controller, string $action, array $arguments): void
+    {
+        $currentRequest = $this->renderingContext->getControllerContext()->getRequest();
+        $flatRequestArguments = ArrayUtility::flatten(
+            array_merge([
+                'controller' => $currentRequest->getControllerName(),
+                'action' => $currentRequest->getControllerActionName()
+            ], $currentRequest->getArguments())
+        );
+        $flatViewHelperArguments = ArrayUtility::flatten(
+            array_merge(['controller' => $controller, 'action' => $action], $arguments)
+        );
+        if (
+            $this->arguments['selected'] ||
+            array_diff($flatRequestArguments, $flatViewHelperArguments) === []
+        ) {
+            $this->tag->addAttribute('selected', 'selected');
+        }
+    }
 }
