@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Fluid\ViewHelpers\Form;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +13,12 @@ namespace TYPO3\CMS\Fluid\ViewHelpers\Form;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Fluid\ViewHelpers\Form;
+
+use TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface;
+use TYPO3\CMS\Extbase\Error\Result;
 use TYPO3\CMS\Extbase\Reflection\ObjectAccess;
+use TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper;
 
 /**
  * Abstract Form ViewHelper. Bundles functionality related to direct property access of objects in other Form ViewHelpers.
@@ -37,7 +41,7 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
     /**
      * @param \TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface $configurationManager
      */
-    public function injectConfigurationManager(\TYPO3\CMS\Extbase\Configuration\ConfigurationManagerInterface $configurationManager)
+    public function injectConfigurationManager(ConfigurationManagerInterface $configurationManager)
     {
         $this->configurationManager = $configurationManager;
     }
@@ -110,7 +114,7 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
     {
         if ($this->isObjectAccessorMode()) {
             $formObjectName = $this->renderingContext->getViewHelperVariableContainer()->get(
-                \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+                FormViewHelper::class,
                 'formObjectName'
             );
             if (!empty($formObjectName)) {
@@ -226,7 +230,7 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
      */
     protected function getLastSubmittedFormData()
     {
-        $propertyPath = rtrim(preg_replace('/(\\]\\[|\\[|\\])/', '.', $this->getNameWithoutPrefix()), '.');
+        $propertyPath = rtrim(preg_replace('/(\\]\\[|\\[|\\])/', '.', $this->getNameWithoutPrefix()) ?? '', '.');
         $value = ObjectAccess::getPropertyPath(
             $this->renderingContext->getControllerContext()->getRequest()->getOriginalRequest()->getArguments(),
             $propertyPath
@@ -246,7 +250,7 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
 
         $viewHelperVariableContainer = $this->renderingContext->getViewHelperVariableContainer();
         if (!$viewHelperVariableContainer->exists(
-            \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+            FormViewHelper::class,
             'formObject'
         )
         ) {
@@ -258,11 +262,11 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
             return;
         }
         $formObject = $viewHelperVariableContainer->get(
-            \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+            FormViewHelper::class,
             'formObject'
         );
         $objectName = $viewHelperVariableContainer->get(
-            \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+            FormViewHelper::class,
             'formObjectName'
         );
         // If count == 2 -> we need to go through the for-loop exactly once
@@ -273,12 +277,12 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
             $hiddenIdentityField = $this->renderHiddenIdentityField($object, $objectName);
             // Add the hidden identity field to the ViewHelperVariableContainer
             $additionalIdentityProperties = $viewHelperVariableContainer->get(
-                \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+                FormViewHelper::class,
                 'additionalIdentityProperties'
             );
             $additionalIdentityProperties[$objectName] = $hiddenIdentityField;
             $viewHelperVariableContainer->addOrUpdate(
-                \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+                FormViewHelper::class,
                 'additionalIdentityProperties',
                 $additionalIdentityProperties
             );
@@ -292,16 +296,19 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
      */
     protected function getPropertyValue()
     {
+        if ($this->arguments['property'] === null) {
+            return null;
+        }
         $viewHelperVariableContainer = $this->renderingContext->getViewHelperVariableContainer();
         if (!$viewHelperVariableContainer->exists(
-            \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+            FormViewHelper::class,
             'formObject'
         )
         ) {
             return null;
         }
         $formObject = $viewHelperVariableContainer->get(
-            \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+            FormViewHelper::class,
             'formObject'
         );
         return ObjectAccess::getPropertyPath($formObject, $this->arguments['property']);
@@ -315,7 +322,7 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
     protected function isObjectAccessorMode()
     {
         return $this->hasArgument('property') && $this->renderingContext->getViewHelperVariableContainer()->exists(
-            \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+            FormViewHelper::class,
             'formObjectName'
         );
     }
@@ -350,11 +357,11 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
     protected function getMappingResultsForProperty()
     {
         if (!$this->isObjectAccessorMode()) {
-            return new \TYPO3\CMS\Extbase\Error\Result();
+            return new Result();
         }
         $originalRequestMappingResults = $this->getRequest()->getOriginalRequestMappingResults();
         $formObjectName = $this->renderingContext->getViewHelperVariableContainer()->get(
-            \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+            FormViewHelper::class,
             'formObjectName'
         );
         return $originalRequestMappingResults->forProperty($formObjectName)->forProperty($this->arguments['property']);
@@ -371,12 +378,12 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
         $hiddenFieldNames = [];
         $viewHelperVariableContainer = $this->renderingContext->getViewHelperVariableContainer();
         if ($viewHelperVariableContainer->exists(
-            \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+            FormViewHelper::class,
             'renderedHiddenFields'
         )
         ) {
             $hiddenFieldNames = $viewHelperVariableContainer->get(
-                \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+                FormViewHelper::class,
                 'renderedHiddenFields'
             );
         }
@@ -384,10 +391,10 @@ abstract class AbstractFormFieldViewHelper extends AbstractFormViewHelper
         if (substr($fieldName, -2) === '[]') {
             $fieldName = substr($fieldName, 0, -2);
         }
-        if (!in_array($fieldName, $hiddenFieldNames)) {
+        if (!in_array($fieldName, $hiddenFieldNames, true)) {
             $hiddenFieldNames[] = $fieldName;
             $viewHelperVariableContainer->addOrUpdate(
-                \TYPO3\CMS\Fluid\ViewHelpers\FormViewHelper::class,
+                FormViewHelper::class,
                 'renderedHiddenFields',
                 $hiddenFieldNames
             );
