@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Fluid\ViewHelpers;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,11 @@ namespace TYPO3\CMS\Fluid\ViewHelpers;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Fluid\ViewHelpers;
+
+use TYPO3\CMS\Fluid\Core\Widget\Exception\RenderingContextNotFoundException;
+use TYPO3\CMS\Fluid\Core\Widget\Exception\WidgetRequestNotFoundException;
+use TYPO3\CMS\Fluid\Core\Widget\WidgetRequest;
 use TYPO3Fluid\Fluid\Core\Rendering\RenderingContextInterface;
 use TYPO3Fluid\Fluid\Core\ViewHelper\AbstractViewHelper;
 use TYPO3Fluid\Fluid\Core\ViewHelper\Traits\CompileWithRenderStatic;
@@ -70,8 +74,8 @@ class RenderChildrenViewHelper extends AbstractViewHelper
     protected static function getWidgetRenderingContext(RenderingContextInterface $renderingContext)
     {
         $subRenderingContext = static::getWidgetContext($renderingContext)->getViewHelperChildNodeRenderingContext();
-        if (!$subRenderingContext instanceof \TYPO3Fluid\Fluid\Core\Rendering\RenderingContextInterface) {
-            throw new \TYPO3\CMS\Fluid\Core\Widget\Exception\RenderingContextNotFoundException('Rendering Context not found inside Widget. <f:renderChildren> has been used in an AJAX Request, but is only usable in non-ajax mode.', 1284986604);
+        if (!$subRenderingContext instanceof RenderingContextInterface) {
+            throw new RenderingContextNotFoundException('Rendering Context not found inside Widget. <f:renderChildren> has been used in an AJAX Request, but is only usable in non-ajax mode.', 1284986604);
         }
         return $subRenderingContext;
     }
@@ -93,8 +97,8 @@ class RenderChildrenViewHelper extends AbstractViewHelper
     protected static function getWidgetContext(RenderingContextInterface $renderingContext)
     {
         $request = $renderingContext->getControllerContext()->getRequest();
-        if (!$request instanceof \TYPO3\CMS\Fluid\Core\Widget\WidgetRequest) {
-            throw new \TYPO3\CMS\Fluid\Core\Widget\Exception\WidgetRequestNotFoundException('The Request is not a WidgetRequest! <f:renderChildren> must be called inside a Widget Template.', 1284986120);
+        if (!$request instanceof WidgetRequest) {
+            throw new WidgetRequestNotFoundException('The Request is not a WidgetRequest! <f:renderChildren> must be called inside a Widget Template.', 1284986120);
         }
         return $request->getWidgetContext();
     }
