@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Form\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Form\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Form\Controller;
+
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Template\Components\ButtonBar;
 use TYPO3\CMS\Backend\View\BackendTemplateView;
@@ -53,7 +55,7 @@ class FormEditorController extends AbstractBackendController
     /**
      * Default View Container
      *
-     * @var BackendTemplateView
+     * @var string
      */
     protected $defaultViewObjectName = BackendTemplateView::class;
 
@@ -76,6 +78,10 @@ class FormEditorController extends AbstractBackendController
         $this->view->getModuleTemplate()->setModuleName($this->request->getPluginName() . '_' . $this->request->getControllerName());
         $this->view->getModuleTemplate()->setFlashMessageQueue($this->controllerContext->getFlashMessageQueue());
 
+        if (!$this->formPersistenceManager->isAllowedPersistencePath($formPersistenceIdentifier)) {
+            throw new PersistenceManagerException(sprintf('Read "%s" is not allowed', $formPersistenceIdentifier), 1614500662);
+        }
+
         if (
             strpos($formPersistenceIdentifier, 'EXT:') === 0
             && !$this->formSettings['persistenceManager']['allowSaveToExtensionPaths']
@@ -174,6 +180,9 @@ class FormEditorController extends AbstractBackendController
         ];
 
         try {
+            if (!$this->formPersistenceManager->isAllowedPersistencePath($formPersistenceIdentifier)) {
+                throw new PersistenceManagerException(sprintf('Save "%s" is not allowed', $formPersistenceIdentifier), 1614500663);
+            }
             $this->formPersistenceManager->save($formPersistenceIdentifier, $formDefinition);
             $configurationService = $this->objectManager->get(ConfigurationService::class);
             $this->prototypeConfiguration = $configurationService->getPrototypeConfiguration($formDefinition['prototypeName']);
@@ -261,7 +270,7 @@ class FormEditorController extends AbstractBackendController
      */
     protected function getInsertRenderablesPanelConfiguration(array $formElementsDefinition): array
     {
-        /** @var array<string, array<string,string>> $formElementsByGroup */
+        /** @var array<string, array<string, string>> $formElementsByGroup */
         $formElementsByGroup = [];
 
         foreach ($formElementsDefinition as $formElementName => $formElementConfiguration) {
@@ -519,6 +528,7 @@ class FormEditorController extends AbstractBackendController
 
         $formDefinitionConversionService = $this->getFormDefinitionConversionService();
         $formDefinition = $formDefinitionConversionService->addHmacData($formDefinition);
+        $formDefinition = $formDefinitionConversionService->migrateFinisherConfiguration($formDefinition);
 
         return $formDefinition;
     }
@@ -695,6 +705,7 @@ class FormEditorController extends AbstractBackendController
             $recipientName = $finisherConfiguration['options']['recipientName'] ?? '';
             $carbonCopyAddress = $finisherConfiguration['options']['carbonCopyAddress'] ?? '';
             $blindCarbonCopyAddress = $finisherConfiguration['options']['blindCarbonCopyAddress'] ?? '';
+            $replyToAddress = $finisherConfiguration['options']['replyToAddress'] ?? '';
 
             if (!empty($recipientAddress)) {
                 $finisherConfiguration['options']['recipients'][$recipientAddress] = $recipientName;
@@ -708,11 +719,16 @@ class FormEditorController extends AbstractBackendController
                 $finisherConfiguration['options']['blindCarbonCopyRecipients'][$blindCarbonCopyAddress] = '';
             }
 
+            if (!empty($replyToAddress)) {
+                $finisherConfiguration['options']['replyToRecipients'][$replyToAddress] = '';
+            }
+
             unset(
                 $finisherConfiguration['options']['recipientAddress'],
                 $finisherConfiguration['options']['recipientName'],
                 $finisherConfiguration['options']['carbonCopyAddress'],
-                $finisherConfiguration['options']['blindCarbonCopyAddress']
+                $finisherConfiguration['options']['blindCarbonCopyAddress'],
+                $finisherConfiguration['options']['replyToAddress']
             );
             $formDefinition['finishers'][$i] = $finisherConfiguration;
         }
