@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Form\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,7 +15,10 @@ namespace TYPO3\CMS\Form\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Form\Controller;
+
 use Symfony\Component\Yaml\Yaml;
+use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Template\Components\ButtonBar;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Backend\View\BackendTemplateView;
@@ -52,7 +55,7 @@ class FormManagerController extends AbstractBackendController
      * @param \TYPO3\CMS\Form\Service\DatabaseService $databaseService
      * @internal
      */
-    public function injectDatabaseService(\TYPO3\CMS\Form\Service\DatabaseService $databaseService)
+    public function injectDatabaseService(DatabaseService $databaseService)
     {
         $this->databaseService = $databaseService;
     }
@@ -60,7 +63,7 @@ class FormManagerController extends AbstractBackendController
     /**
      * Default View Container
      *
-     * @var BackendTemplateView
+     * @var string
      */
     protected $defaultViewObjectName = BackendTemplateView::class;
 
@@ -103,10 +106,15 @@ class FormManagerController extends AbstractBackendController
      * @param string $prototypeName
      * @param string $savePath
      * @throws FormException
+     * @throws PersistenceManagerException
      * @internal
      */
     public function createAction(string $formName, string $templatePath, string $prototypeName, string $savePath)
     {
+        if (!$this->formPersistenceManager->isAllowedPersistencePath($savePath)) {
+            throw new PersistenceManagerException(sprintf('Save to path "%s" is not allowed', $savePath), 1614500657);
+        }
+
         if (!$this->isValidTemplatePath($prototypeName, $templatePath)) {
             throw new FormException(sprintf('The template path "%s" is not allowed', $templatePath), 1329233410);
         }
@@ -115,7 +123,7 @@ class FormManagerController extends AbstractBackendController
         }
 
         $templatePath = GeneralUtility::getFileAbsFileName($templatePath);
-        $form = Yaml::parse(file_get_contents($templatePath));
+        $form = Yaml::parse((string)file_get_contents($templatePath));
         $form['label'] = $formName;
         $form['identifier'] = $this->formPersistenceManager->getUniqueIdentifier($this->convertFormNameToIdentifier($formName));
         $form['prototypeName'] = $prototypeName;
@@ -172,10 +180,18 @@ class FormManagerController extends AbstractBackendController
      * @param string $formName
      * @param string $formPersistenceIdentifier persistence identifier of the form to duplicate
      * @param string $savePath
+     * @throws PersistenceManagerException
      * @internal
      */
     public function duplicateAction(string $formName, string $formPersistenceIdentifier, string $savePath)
     {
+        if (!$this->formPersistenceManager->isAllowedPersistencePath($savePath)) {
+            throw new PersistenceManagerException(sprintf('Save to path "%s" is not allowed', $savePath), 1614500658);
+        }
+        if (!$this->formPersistenceManager->isAllowedPersistencePath($formPersistenceIdentifier)) {
+            throw new PersistenceManagerException(sprintf('Read of "%s" is not allowed', $formPersistenceIdentifier), 1614500659);
+        }
+
         $formToDuplicate = $this->formPersistenceManager->load($formPersistenceIdentifier);
         $formToDuplicate['label'] = $formName;
         $formToDuplicate['identifier'] = $this->formPersistenceManager->getUniqueIdentifier($this->convertFormNameToIdentifier($formName));
@@ -230,10 +246,15 @@ class FormManagerController extends AbstractBackendController
      * Show references to this persistence identifier
      *
      * @param string $formPersistenceIdentifier persistence identifier of the form to duplicate
+     * @throws PersistenceManagerException
      * @internal
      */
     public function referencesAction(string $formPersistenceIdentifier)
     {
+        if (!$this->formPersistenceManager->isAllowedPersistencePath($formPersistenceIdentifier)) {
+            throw new PersistenceManagerException(sprintf('Read from "%s" is not allowed', $formPersistenceIdentifier), 1614500660);
+        }
+
         $this->view->assign('references', $this->getProcessedReferencesRows($formPersistenceIdentifier));
         $this->view->assign('formPersistenceIdentifier', $formPersistenceIdentifier);
         // referencesAction uses the extbase JsonView::class.
@@ -248,10 +269,15 @@ class FormManagerController extends AbstractBackendController
      * Delete a formDefinition identified by the $formPersistenceIdentifier.
      *
      * @param string $formPersistenceIdentifier persistence identifier to delete
+     * @throws PersistenceManagerException
      * @internal
      */
     public function deleteAction(string $formPersistenceIdentifier)
     {
+        if (!$this->formPersistenceManager->isAllowedPersistencePath($formPersistenceIdentifier)) {
+            throw new PersistenceManagerException(sprintf('Delete "%s" is not allowed', $formPersistenceIdentifier), 1614500661);
+        }
+
         if (empty($this->databaseService->getReferencesByPersistenceIdentifier($formPersistenceIdentifier))) {
             foreach ($GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['ext/form']['beforeFormDelete'] ?? [] as $className) {
                 $hookObj = GeneralUtility::makeInstance($className);
@@ -502,7 +528,7 @@ class FormManagerController extends AbstractBackendController
         $csConverter = GeneralUtility::makeInstance(CharsetConverter::class);
 
         $formIdentifier = $csConverter->specCharsToASCII('utf-8', $formName);
-        $formIdentifier = preg_replace('/[^a-zA-Z0-9-_]/', '', $formIdentifier);
+        $formIdentifier = (string)preg_replace('/[^a-zA-Z0-9-_]/', '', $formIdentifier);
         $formIdentifier = lcfirst($formIdentifier);
         return $formIdentifier;
     }
@@ -542,7 +568,7 @@ class FormManagerController extends AbstractBackendController
     protected function getModuleUrl(string $moduleName, array $urlParameters = []): string
     {
         /** @var \TYPO3\CMS\Backend\Routing\UriBuilder $uriBuilder */
-        $uriBuilder = GeneralUtility::makeInstance(\TYPO3\CMS\Backend\Routing\UriBuilder::class);
+        $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
         return (string)$uriBuilder->buildUriFromRoute($moduleName, $urlParameters);
     }
 
