@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Form\Domain\Configuration\FormDefinition\Validators;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Form\Domain\Configuration\FormDefinition\Validators;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Form\Domain\Configuration\FormDefinition\Validators;
+
 use TYPO3\CMS\Core\Utility\ArrayUtility;
 use TYPO3\CMS\Form\Domain\Configuration\Exception\PropertyException;
 
@@ -30,6 +32,10 @@ class CreatablePropertyCollectionElementPropertiesValidator extends CollectionBa
      * the "predefinedDefaults" in the form editor setup
      * and the property value matches the predefined value
      * or if there is a valid hmac hash for the value.
+     * If the property collection element property is defined within the form editor setup
+     * and there is no valid hmac hash for the value
+     * and is the form property collection element property configured to only allow a limited set of values,
+     * check the current (submitted) value against the allowed set of values (defined within the form setup).
      *
      * @param string $key
      * @param mixed $value
@@ -38,20 +44,22 @@ class CreatablePropertyCollectionElementPropertiesValidator extends CollectionBa
     {
         $dto = $this->validationDto->withPropertyPath($key);
 
-        if (!$this->getConfigurationService()->isPropertyCollectionPropertyDefinedInFormEditorSetup($dto)) {
-            if (
-                $this->getConfigurationService()->isPropertyCollectionPropertyDefinedInPredefinedDefaultsInFormEditorSetup($dto)
-                && !ArrayUtility::isValidPath($this->currentElement, $this->buildHmacDataPath($dto->getPropertyPath()), '.')
-            ) {
-                $this->validatePropertyCollectionElementPredefinedDefaultValue($value, $dto);
-            } else {
-                $this->validatePropertyCollectionElementPropertyValueByHmacData(
-                    $this->currentElement,
-                    $value,
-                    $this->sessionToken,
-                    $dto
-                );
+        if ($this->getConfigurationService()->isPropertyCollectionPropertyDefinedInFormEditorSetup($dto)) {
+            if ($this->getConfigurationService()->propertyCollectionPropertyHasLimitedAllowedValuesDefinedWithinFormEditorSetup($dto)) {
+                $this->validatePropertyCollectionPropertyValue($value, $dto);
             }
+        } elseif (
+            $this->getConfigurationService()->isPropertyCollectionPropertyDefinedInPredefinedDefaultsInFormEditorSetup($dto)
+            && !ArrayUtility::isValidPath($this->currentElement, $this->buildHmacDataPath($dto->getPropertyPath()), '.')
+        ) {
+            $this->validatePropertyCollectionElementPredefinedDefaultValue($value, $dto);
+        } else {
+            $this->validatePropertyCollectionElementPropertyValueByHmacData(
+                $this->currentElement,
+                $value,
+                $this->sessionToken,
+                $dto
+            );
         }
     }
 
@@ -67,7 +75,7 @@ class CreatablePropertyCollectionElementPropertiesValidator extends CollectionBa
         $value,
         ValidationDto $dto
     ): void {
-        // If the property collection element is newely created, we have to compare the $value (form definition) with $predefinedDefaultValue (form setup)
+        // If the property collection element is newly created, we have to compare the $value (form definition) with $predefinedDefaultValue (form setup)
         // to check the integrity (at this time we don't have a hmac on the value to check the integrity)
         $predefinedDefaultValue = $this->getConfigurationService()->getPropertyCollectionPredefinedDefaultValueFromFormEditorSetup($dto);
         if ($value !== $predefinedDefaultValue) {
@@ -106,4 +114,56 @@ class CreatablePropertyCollectionElementPropertiesValidator extends CollectionBa
             }
         }
     }
+
+    /**
+     * Throws an exception if the value from a property collection property
+     * does not match the allowed set of values (defined within the form setup).
+     *
+     * @param mixed $value
+     * @param ValidationDto $dto
+     * @throws PropertyException
+     */
+    protected function validatePropertyCollectionPropertyValue(
+        $value,
+        ValidationDto $dto
+    ): void {
+        $allowedValues = $this->getConfigurationService()->getAllowedValuesForPropertyCollectionPropertyFromFormEditorSetup($dto);
+
+        if (!in_array($value, $allowedValues, true)) {
+            $untranslatedAllowedValues = $this->getConfigurationService()->getAllowedValuesForPropertyCollectionPropertyFromFormEditorSetup($dto, false);
+            // Compare the $value against the untranslated set of allowed values
+            if (in_array($value, $untranslatedAllowedValues, true)) {
+                // All good, $value is within the untranslated set of allowed values
+                return;
+            }
+            // Get all translations (from all backend languages) for the untranslated! $allowedValues and
+            // compare the (already translated) $value (from the form definition) against all possible
+            // translations for $untranslatedAllowedValues.
+            $allPossibleAllowedValuesTranslations = $this->getConfigurationService()->getAllBackendTranslationsForTranslationKeys(
+                $untranslatedAllowedValues,
+                $dto->getPrototypeName()
+            );
+
+            foreach ($allPossibleAllowedValuesTranslations as $translations) {
+                if (in_array($value, $translations, true)) {
+                    // All good, $value is within the set of translated allowed values
+                    return;
+                }
+            }
+
+            // Last chance:
+            // If $value is not configured within the form setup as an allowed value
+            // but was written within the form definition by hand (and therefore contains a hmac),
+            // check if $value is manipulated.
+            // If $value has no hmac or if the hmac exists but is not valid,
+            // then $this->validatePropertyCollectionElementPropertyValueByHmacData() will
+            // throw an exception.
+            $this->validatePropertyCollectionElementPropertyValueByHmacData(
+                $this->currentElement,
+                $value,
+                $this->sessionToken,
+                $dto
+            );
+        }
+    }
 }
