@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Form\Domain\Finishers;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Form\Domain\Finishers;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Form\Domain\Finishers;
+
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Extbase\Mvc\Exception\StopActionException;
 use TYPO3\CMS\Extbase\Mvc\Web\Routing\UriBuilder;
@@ -64,8 +66,10 @@ class RedirectFinisher extends AbstractFinisher
         $this->uriBuilder = $this->objectManager->get(UriBuilder::class);
         $this->uriBuilder->setRequest($this->request);
 
-        $pageUid = (int)str_replace('pages_', '', $this->parseOption('pageUid'));
+        $pageUid = $this->parseOption('pageUid');
+        $pageUid = (int)str_replace('pages_', '', (string)$pageUid);
         $additionalParameters = $this->parseOption('additionalParameters');
+        $additionalParameters = is_string($additionalParameters) ? $additionalParameters : '';
         $additionalParameters = '&' . ltrim($additionalParameters, '&');
         $delay = (int)$this->parseOption('delay');
         $statusCode = (int)$this->parseOption('statusCode');
