@@ -1,12 +1,10 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Form\Mvc\Persistence;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
  *
- * It originated from the Neos.Form package (www.neos.io)
- *
  * It is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, either version 2
  * of the License, or any later version.
@@ -17,6 +15,12 @@ namespace TYPO3\CMS\Form\Mvc\Persistence;
  * The TYPO3 project - inspiring people to share!
  */
 
+/*
+ * Inspired by and partially taken from the Neos.Form package (www.neos.io)
+ */
+
+namespace TYPO3\CMS\Form\Mvc\Persistence;
+
 use TYPO3\CMS\Core\Cache\CacheManager;
 use TYPO3\CMS\Core\Cache\Frontend\FrontendInterface;
 use TYPO3\CMS\Core\Resource\Exception\FolderDoesNotExistException;
@@ -26,13 +30,16 @@ use TYPO3\CMS\Core\Resource\Filter\FileExtensionFilter;
 use TYPO3\CMS\Core\Resource\Folder;
 use TYPO3\CMS\Core\Resource\ResourceFactory;
 use TYPO3\CMS\Core\Resource\ResourceStorage;
+use TYPO3\CMS\Core\Resource\StorageRepository;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Core\Utility\MathUtility;
 use TYPO3\CMS\Core\Utility\PathUtility;
 use TYPO3\CMS\Core\Utility\StringUtility;
 use TYPO3\CMS\Extbase\Object\ObjectManager;
 use TYPO3\CMS\Form\Mvc\Configuration\ConfigurationManagerInterface;
 use TYPO3\CMS\Form\Mvc\Configuration\Exception\FileWriteException;
 use TYPO3\CMS\Form\Mvc\Configuration\Exception\NoSuchFileException;
+use TYPO3\CMS\Form\Mvc\Configuration\YamlSource;
 use TYPO3\CMS\Form\Mvc\Persistence\Exception\NoUniqueIdentifierException;
 use TYPO3\CMS\Form\Mvc\Persistence\Exception\NoUniquePersistenceIdentifierException;
 use TYPO3\CMS\Form\Mvc\Persistence\Exception\PersistenceManagerException;
@@ -81,7 +88,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
      * @param \TYPO3\CMS\Form\Mvc\Configuration\YamlSource $yamlSource
      * @internal
      */
-    public function injectYamlSource(\TYPO3\CMS\Form\Mvc\Configuration\YamlSource $yamlSource)
+    public function injectYamlSource(YamlSource $yamlSource)
     {
         $this->yamlSource = $yamlSource;
     }
@@ -90,7 +97,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
      * @param \TYPO3\CMS\Core\Resource\StorageRepository $storageRepository
      * @internal
      */
-    public function injectStorageRepository(\TYPO3\CMS\Core\Resource\StorageRepository $storageRepository)
+    public function injectStorageRepository(StorageRepository $storageRepository)
     {
         $this->storageRepository = $storageRepository;
     }
@@ -98,7 +105,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
     /**
      * @param \TYPO3\CMS\Form\Slot\FilePersistenceSlot $filePersistenceSlot
      */
-    public function injectFilePersistenceSlot(\TYPO3\CMS\Form\Slot\FilePersistenceSlot $filePersistenceSlot)
+    public function injectFilePersistenceSlot(FilePersistenceSlot $filePersistenceSlot)
     {
         $this->filePersistenceSlot = $filePersistenceSlot;
     }
@@ -106,7 +113,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
     /**
      * @param \TYPO3\CMS\Core\Resource\ResourceFactory $resourceFactory
      */
-    public function injectResourceFactory(\TYPO3\CMS\Core\Resource\ResourceFactory $resourceFactory)
+    public function injectResourceFactory(ResourceFactory $resourceFactory)
     {
         $this->resourceFactory = $resourceFactory;
     }
@@ -176,7 +183,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
             throw new PersistenceManagerException(sprintf('The file "%s" could not be saved.', $persistenceIdentifier), 1477679820);
         }
 
-        if (strpos($persistenceIdentifier, 'EXT:') === 0) {
+        if ($this->pathIsIntendedAsExtensionPath($persistenceIdentifier)) {
             if (!$this->formSettings['persistenceManager']['allowSaveToExtensionPaths']) {
                 throw new PersistenceManagerException('Save to extension paths is not allowed.', 1477680881);
             }
@@ -216,7 +223,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
         if (!$this->exists($persistenceIdentifier)) {
             throw new PersistenceManagerException(sprintf('The file "%s" could not be removed.', $persistenceIdentifier), 1472239535);
         }
-        if (strpos($persistenceIdentifier, 'EXT:') === 0) {
+        if ($this->pathIsIntendedAsExtensionPath($persistenceIdentifier)) {
             if (!$this->formSettings['persistenceManager']['allowDeleteFromExtensionPaths']) {
                 throw new PersistenceManagerException(sprintf('The file "%s" could not be removed.', $persistenceIdentifier), 1472239536);
             }
@@ -248,7 +255,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
     {
         $exists = false;
         if ($this->hasValidFileExtension($persistenceIdentifier)) {
-            if (strpos($persistenceIdentifier, 'EXT:') === 0) {
+            if ($this->pathIsIntendedAsExtensionPath($persistenceIdentifier)) {
                 if ($this->isFileWithinAccessibleExtensionFolders($persistenceIdentifier)) {
                     $exists = file_exists(GeneralUtility::getFileAbsFileName($persistenceIdentifier));
                 }
@@ -350,9 +357,8 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
 
         foreach ($this->getAccessibleFormStorageFolders() as $folder) {
             $storage = $folder->getStorage();
-            $storage->addFileAndFolderNameFilter([
-                $fileExtensionFilter,
-                'filterFileList'
+            $storage->setFileAndFolderNameFilters([
+                [$fileExtensionFilter, 'filterFileList']
             ]);
 
             $files = $folder->getFiles(
@@ -372,7 +378,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
      * Retrieves yaml files from extension folders for further processing.
      * At this time it's not determined yet, whether these files contain form data.
      *
-     * @return File[]
+     * @return array<string, string>
      * @internal
      */
     public function retrieveYamlFilesFromExtensionFolders(): array
@@ -415,9 +421,9 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
         }
 
         foreach ($this->formSettings['persistenceManager']['allowedFileMounts'] as $allowedFileMount) {
+            $allowedFileMount = rtrim($allowedFileMount, '/') . '/';
+            // $fileMountPath is like "/form_definitions/" or "/group_homes/1/form_definitions/"
             [$storageUid, $fileMountPath] = explode(':', $allowedFileMount, 2);
-            // like "/form_definitions/" or "/group_homes/1/form_definitions/"
-            $fileMountPath = rtrim($fileMountPath, '/') . '/';
 
             try {
                 $storage = $this->getStorageByUid((int)$storageUid);
@@ -493,7 +499,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
         }
 
         foreach ($this->formSettings['persistenceManager']['allowedExtensionPaths'] as $allowedExtensionPath) {
-            if (strpos($allowedExtensionPath, 'EXT:') !== 0) {
+            if (!$this->pathIsIntendedAsExtensionPath($allowedExtensionPath)) {
                 continue;
             }
 
@@ -576,7 +582,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
     }
 
     /**
-     * Check if an identifier is already used by a formDefintion.
+     * Check if an identifier is already used by a formDefinition.
      *
      * @param string $identifier
      * @return bool
@@ -594,6 +600,83 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
         return $identifierUsed;
     }
 
+    /**
+     * Check if a persistence path or if a persistence identifier path
+     * is configured within the form setup
+     * (TYPO3.CMS.Form.persistenceManager.allowedExtensionPaths / TYPO3.CMS.Form.persistenceManager.allowedFileMounts).
+     * If the input is a persistence identifier an additional check for a
+     * valid file extension will be performed.
+     * .
+     * @param string $persistencePath
+     * @return bool
+     * @internal
+     */
+    public function isAllowedPersistencePath(string $persistencePath): bool
+    {
+        $pathinfo = PathUtility::pathinfo($persistencePath);
+        $persistencePathIsFile = isset($pathinfo['extension']);
+
+        if (
+            $persistencePathIsFile
+            && $this->pathIsIntendedAsExtensionPath($persistencePath)
+            && $this->hasValidFileExtension($persistencePath)
+            && $this->isFileWithinAccessibleExtensionFolders($persistencePath)
+        ) {
+            return true;
+        }
+        if (
+            $persistencePathIsFile
+            && $this->pathIsIntendedAsFileMountPath($persistencePath)
+            && $this->hasValidFileExtension($persistencePath)
+            && $this->isFileWithinAccessibleFormStorageFolders($persistencePath)
+        ) {
+            return true;
+        }
+        if (
+            !$persistencePathIsFile
+            && $this->pathIsIntendedAsExtensionPath($persistencePath)
+            && $this->isAccessibleExtensionFolder($persistencePath)
+        ) {
+            return true;
+        }
+        if (
+            !$persistencePathIsFile
+            && $this->pathIsIntendedAsFileMountPath($persistencePath)
+            && $this->isAccessibleFormStorageFolder($persistencePath)
+        ) {
+            return true;
+        }
+
+        return false;
+    }
+
+    /**
+     * @param string $path
+     * @return bool
+     */
+    protected function pathIsIntendedAsExtensionPath(string $path): bool
+    {
+        return strpos($path, 'EXT:') === 0;
+    }
+
+    /**
+     * @param string $path
+     * @return bool
+     */
+    protected function pathIsIntendedAsFileMountPath(string $path): bool
+    {
+        if (empty($path)) {
+            return false;
+        }
+
+        [$storageUid, $pathIdentifier] = explode(':', $path, 2);
+        if (empty($storageUid) || empty($pathIdentifier)) {
+            return false;
+        }
+
+        return MathUtility::canBeInterpretedAsInteger($storageUid);
+    }
+
     /**
      * Returns a File object for a given $persistenceIdentifier.
      * If no file for this identifier exists a new object will be
@@ -747,7 +830,7 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
         }
 
         if (
-            strpos($persistenceIdentifier, 'EXT:') === 0
+            $this->pathIsIntendedAsExtensionPath($persistenceIdentifier)
             && !$this->isFileWithinAccessibleExtensionFolders($persistenceIdentifier)
         ) {
             $message = sprintf('The file "%s" could not be loaded. Please check your configuration option "persistenceManager.allowedExtensionPaths"', $persistenceIdentifier);
@@ -787,10 +870,44 @@ class FormPersistenceManager implements FormPersistenceManagerInterface
      */
     protected function isFileWithinAccessibleExtensionFolders(string $fileName): bool
     {
-        $dirName = rtrim(PathUtility::pathinfo($fileName, PATHINFO_DIRNAME), '/') . '/';
+        $pathInfo = PathUtility::pathinfo($fileName, PATHINFO_DIRNAME);
+        $pathInfo = is_string($pathInfo) ? $pathInfo : '';
+        $dirName = rtrim($pathInfo, '/') . '/';
         return array_key_exists($dirName, $this->getAccessibleExtensionFolders());
     }
 
+    /**
+     * @param string $fileName
+     * @return bool
+     */
+    protected function isFileWithinAccessibleFormStorageFolders(string $fileName): bool
+    {
+        $pathInfo = PathUtility::pathinfo($fileName, PATHINFO_DIRNAME);
+        $pathInfo = is_string($pathInfo) ? $pathInfo : '';
+        $dirName = rtrim($pathInfo, '/') . '/';
+        return array_key_exists($dirName, $this->getAccessibleFormStorageFolders());
+    }
+
+    /**
+     * @param string $folderName
+     * @return bool
+     */
+    protected function isAccessibleExtensionFolder(string $folderName): bool
+    {
+        $folderName = rtrim($folderName, '/') . '/';
+        return array_key_exists($folderName, $this->getAccessibleExtensionFolders());
+    }
+
+    /**
+     * @param string $folderName
+     * @return bool
+     */
+    protected function isAccessibleFormStorageFolder(string $folderName): bool
+    {
+        $folderName = rtrim($folderName, '/') . '/';
+        return array_key_exists($folderName, $this->getAccessibleFormStorageFolders());
+    }
+
     /**
      * @param array $data
      * @return bool
