@@ -1,12 +1,10 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Form\ViewHelpers\Form;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
  *
- * It originated from the Neos.Form package (www.neos.io)
- *
  * It is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License, either version 2
  * of the License, or any later version.
@@ -17,6 +15,13 @@ namespace TYPO3\CMS\Form\ViewHelpers\Form;
  * The TYPO3 project - inspiring people to share!
  */
 
+/*
+ * Inspired by and partially taken from the Neos.Form package (www.neos.io)
+ */
+
+namespace TYPO3\CMS\Form\ViewHelpers\Form;
+
+use TYPO3\CMS\Extbase\Property\PropertyMapper;
 use TYPO3\CMS\Fluid\ViewHelpers\Form\AbstractFormFieldViewHelper;
 use TYPO3\CMS\Form\Domain\Runtime\FormRuntime;
 use TYPO3\CMS\Form\ViewHelpers\RenderRenderableViewHelper;
@@ -43,7 +48,7 @@ class TimePickerViewHelper extends AbstractFormFieldViewHelper
      * @param \TYPO3\CMS\Extbase\Property\PropertyMapper $propertyMapper
      * @internal
      */
-    public function injectPropertyMapper(\TYPO3\CMS\Extbase\Property\PropertyMapper $propertyMapper)
+    public function injectPropertyMapper(PropertyMapper $propertyMapper)
     {
         $this->propertyMapper = $propertyMapper;
     }
@@ -114,6 +119,8 @@ class TimePickerViewHelper extends AbstractFormFieldViewHelper
         if ($this->hasArgument('initialDate')) {
             return new \DateTime($this->arguments['initialDate']);
         }
+
+        return null;
     }
 
     /**
@@ -129,7 +136,7 @@ class TimePickerViewHelper extends AbstractFormFieldViewHelper
         foreach (range(0, 23) as $hour) {
             $hour = str_pad((string)$hour, 2, '0', STR_PAD_LEFT);
             $selected = $hour === $value ? ' selected="selected"' : '';
-            $options .= '<option value="' . $hour . '"' . $selected . '>' . $hour . '</option>';
+            $options .= '<option value="' . htmlspecialchars($hour) . '" ' . $selected . '>' . htmlspecialchars($hour) . '</option>';
         }
         $hourSelector->setContent($options);
         return $hourSelector->render();
@@ -151,7 +158,7 @@ class TimePickerViewHelper extends AbstractFormFieldViewHelper
         foreach (range(0, 59) as $minute) {
             $minute = str_pad((string)$minute, 2, '0', STR_PAD_LEFT);
             $selected = $minute === $value ? ' selected="selected"' : '';
-            $options .= '<option value="' . $minute . '"' . $selected . '>' . $minute . '</option>';
+            $options .= '<option value="' . htmlspecialchars($minute) . '"' . $selected . '>' . htmlspecialchars($minute) . '</option>';
         }
         $minuteSelector->setContent($options);
         return $minuteSelector->render();
