@@ -815,18 +815,6 @@ define(['jquery',
         );
       };
 
-      /**
-       * @public
-       *
-       * @param object formElement
-       * @return object|null
-       */
-      function findEnclosingGridContainerFormElement(formElement) {
-        return _getRepository().findEnclosingGridContainerFormElement(
-          _getRepository().findFormElement(formElement)
-        );
-      };
-
       /**
        * @public
        *
@@ -1105,7 +1093,6 @@ define(['jquery',
         getCurrentlySelectedPage: getCurrentlySelectedPage,
         getLastTopLevelElementOnCurrentPage: getLastTopLevelElementOnCurrentPage,
         findEnclosingCompositeFormElementWhichIsNotOnTopLevel: findEnclosingCompositeFormElementWhichIsNotOnTopLevel,
-        findEnclosingGridContainerFormElement: findEnclosingGridContainerFormElement,
         findEnclosingGridRowFormElement: findEnclosingGridRowFormElement,
         isRootFormElementSelected: isRootFormElementSelected,
         getLastFormElementWithinParentFormElement: getLastFormElementWithinParentFormElement,
