@@ -114,7 +114,7 @@ define(['jquery',
     var _formEditorApp = null;
 
     /* *************************************************************
-     * Private Methodes
+     * Private Methods
      * ************************************************************/
 
     /**
@@ -775,7 +775,7 @@ define(['jquery',
     };
 
     /* *************************************************************
-     * Public Methodes
+     * Public Methods
      * ************************************************************/
 
     /**
@@ -1185,25 +1185,14 @@ define(['jquery',
       };
 
       collectionElementConfiguration = getFormEditorApp().getFormEditorDefinition(collectionName, collectionElementIdentifier);
-      if (collectionName === 'validators') {
-        Icons.getIcon(
-          collectionElementConfiguration['iconIdentifier'],
-          Icons.sizes.small,
-          null,
-          Icons.states.default
-        ).then(function(icon) {
-          setData(icon);
-        });
-      } else {
-        Icons.getIcon(
-          collectionElementConfiguration['iconIdentifier'],
-          Icons.sizes.small,
-          null,
-          Icons.states.default
-        ).then(function(icon) {
-          setData(icon);
-        });
-      }
+      Icons.getIcon(
+        collectionElementConfiguration['iconIdentifier'],
+        Icons.sizes.small,
+        null,
+        Icons.states.default
+      ).then(function(icon) {
+        setData(icon);
+      });
 
       if (editorConfiguration['label']) {
         getHelper().getTemplatePropertyDomElement('label', editorHtml).append(editorConfiguration['label']);
@@ -2546,7 +2535,7 @@ define(['jquery',
               $('a', itemTemplate).on('click', function() {
                 var propertyData;
 
-                propertyData = getCurrentlySelectedFormElement().get(propertyPath);
+                propertyData = getCurrentlySelectedFormElement().get(propertyPath) || '';
 
                 if (propertyData.length === 0) {
                   propertyData = '{' + $(this).attr('data-formelement-identifier') + '}';
