@@ -19,11 +19,14 @@ define(['jquery',
   'TYPO3/CMS/Backend/Severity',
   'TYPO3/CMS/Backend/MultiStepWizard',
   'TYPO3/CMS/Backend/Icons',
-  'TYPO3/CMS/Backend/Notification'
-], function($, Modal, Severity, MultiStepWizard, Icons, Notification) {
+  'TYPO3/CMS/Backend/Notification',
+  'TYPO3/CMS/Core/SecurityUtility'
+], function($, Modal, Severity, MultiStepWizard, Icons, Notification, SecurityUtility) {
   'use strict';
 
-  return (function($, Modal, Severity, MultiStepWizard, Icons, Notification) {
+  return (function($, Modal, Severity, MultiStepWizard, Icons, Notification, SecurityUtility) {
+
+    var securityUtility = new SecurityUtility();
 
     /**
      * @private
@@ -50,7 +53,7 @@ define(['jquery',
         duplicateFormModalTrigger: {identifier: '[data-identifier="duplicateForm"]'},
         removeFormModalTrigger: {identifier: '[data-identifier="removeForm"]'},
 
-        newFormMode: {identifier: '[data-identifier="newFormMode"]'},
+        newFormMode: {identifier: '[data-identifier="newFormMode"]', button: '[data-identifier="newFormModeButton"]'},
         newFormName: {identifier: '[data-identifier="newFormName"]'},
         newFormSavePath: {identifier: '[data-identifier="newFormSavePath"]'},
         newFormPrototypeName: {identifier: '[data-identifier="newFormPrototypeName"]'},
@@ -88,7 +91,7 @@ define(['jquery',
         MultiStepWizard.addSlide('new-form-step-1', TYPO3.lang['formManager.newFormWizard.step1.title'], '', Severity.info, null, function(slide) {
           Icons.getIcon('actions-document-duplicates-select', Icons.sizes.large).then(function (duplicateIconMarkup) {
             Icons.getIcon('actions-document-new', Icons.sizes.large).then(function (blankIconMarkup) {
-              var advandecWizardHasOptions, folders, html, modal, cancelButton, nextButton, prototypes,
+              var advancedWizardHasOptions, folders, html, modal, cancelButton, nextButton, prototypes,
                 templates;
 
               modal = MultiStepWizard.setup.$carousel.closest('.modal');
@@ -128,18 +131,24 @@ define(['jquery',
               html += '<div class="row">'
                 + '<div class="col-sm-6">'
                 + '<p>'
-                + '<label class="btn btn-block btn-default btn-block btn-createform">'
+                + '<label class="label-block">'
+                + '<button class="btn btn-block btn-default btn-block btn-createform" data-identifier="newFormModeButton" type="button">'
                 + blankIconMarkup
                 + '<input type="radio" name="newformmode" id="mode_blank" value="blank" data-identifier="newFormMode" style="display: none">'
-                + '<br>' + TYPO3.lang['formManager.blankForm.label'] + '</label>'
+                + '<br>' + TYPO3.lang['formManager.blankForm.label']
+                + '</button>'
+                + '</label>'
                 + '</p>'
                 + '</div>'
                 + '<div class="col-sm-6">'
                 + '<p>'
-                + '<label class="btn btn-block btn-default btn-block btn-createform">'
+                + '<label class="label-block">'
+                + '<button class="btn btn-block btn-default btn-block btn-createform" data-identifier="newFormModeButton" type="button">'
                 + duplicateIconMarkup
                 + '<input type="radio" name="newformmode" id="mode_predefined" value="predefined" data-identifier="newFormMode" style="display: none">'
-                + '<br>' + TYPO3.lang['formManager.predefinedForm.label'] + '</label>'
+                + '<br>' + TYPO3.lang['formManager.predefinedForm.label']
+                + '</button>'
+                + '</label>'
                 + '</p>'
                 + '</div>'
                 + '</div>';
@@ -157,6 +166,12 @@ define(['jquery',
                 }
               });
 
+              $(getDomElementIdentifier('newFormMode', 'button'), modal).on('click', function (e) {
+                $(getDomElementIdentifier('newFormMode'), $(this)).prop('checked', true).trigger('change');
+              });
+
+              $(getDomElementIdentifier('newFormMode', 'button'), modal).first().focus();
+
               nextButton.on('click', function() {
                 Icons.getIcon('spinner-circle', Icons.sizes.default, null, null).then(function(markup) {
                   slide.html($('<div />', {class: 'text-center'}).append(markup));
@@ -244,7 +259,7 @@ define(['jquery',
 
           html += '<label class="control-label" for="new-form-name">' + TYPO3.lang['formManager.form_name'] + '</label>';
           if (settings['formName']) {
-            html += '<input class="new-form-name form-control has-error" id="new-form-name" data-identifier="newFormName" value="' + settings['formName'] + '" />';
+            html += '<input class="new-form-name form-control has-error" id="new-form-name" data-identifier="newFormName" value="' + securityUtility.encodeHtml(settings['formName']) + '" />';
 
             setTimeout(
               function() {
@@ -320,6 +335,9 @@ define(['jquery',
               $(this).removeClass('has-error');
               MultiStepWizard.unlockNextStep();
               MultiStepWizard.set('formName', $(this).val());
+              if (e.code === 'Enter') {
+                MultiStepWizard.triggerStepButton('next');
+              }
             } else {
               $(this).addClass('has-error');
               MultiStepWizard.lockNextStep();
@@ -367,7 +385,7 @@ define(['jquery',
               + '</div>'
               + '<div class="col-sm-9">'
               + '<p>'
-              + settings['prototypeNameName']
+              + securityUtility.encodeHtml(settings['prototypeNameName'])
               + '</p>'
               + '</div>'
               + '</div>';
@@ -380,7 +398,7 @@ define(['jquery',
               + '</div>'
               + '<div class="col-sm-9">'
               + '<p>'
-              + settings['templatePathName']
+              + securityUtility.encodeHtml(settings['templatePathName'])
               + '</p>'
               + '</div>'
               + '</div>';
@@ -392,7 +410,7 @@ define(['jquery',
             + '</div>'
             + '<div class="col-sm-9">'
             + '<p>'
-            + settings['formName']
+            + securityUtility.encodeHtml(settings['formName'])
             + '</p>'
             + '</div>'
             + '</div>'
@@ -402,7 +420,7 @@ define(['jquery',
             + '</div>'
             + '<div class="col-sm-9">'
             + '<p>'
-            + settings['savePathName']
+            + securityUtility.encodeHtml(settings['savePathName'])
             + '</p>'
             + '</div>'
             + '</div>';
@@ -413,6 +431,8 @@ define(['jquery',
 
           slide.html(html);
 
+          nextButton.focus();
+
           nextButton.on('click', function(e) {
             MultiStepWizard.setup.forceSelection = false;
             Icons.getIcon('spinner-circle', Icons.sizes.default, null, null).then(function(markup) {
@@ -586,6 +606,9 @@ define(['jquery',
               $(this).removeClass('has-error');
               MultiStepWizard.unlockNextStep();
               MultiStepWizard.set('formName', $(this).val());
+              if (e.code === 'Enter') {
+                MultiStepWizard.triggerStepButton('next');
+              }
             } else {
               $(this).addClass('has-error');
               MultiStepWizard.lockNextStep();
@@ -595,11 +618,12 @@ define(['jquery',
           nextButton.on('click', function(e) {
             Icons.getIcon('spinner-circle', Icons.sizes.default, null, null).then(function(markup) {
               MultiStepWizard.set('confirmationDuplicateFormName', that.data('formName'));
-              MultiStepWizard.set('savePath', $(getDomElementIdentifier('duplicateFormSavePath') + ' option:selected', modal).val());
 
               if (folders.length > 1) {
+                MultiStepWizard.set('savePath', $(getDomElementIdentifier('duplicateFormSavePath') + ' option:selected', modal).val());
                 MultiStepWizard.set('confirmationDuplicateFormSavePath', $(getDomElementIdentifier('duplicateFormSavePath') + ' option:selected', modal).text());
               } else {
+                MultiStepWizard.set('savePath', folders[0]['value']);
                 MultiStepWizard.set('confirmationDuplicateFormSavePath', folders[0]['label']);
               }
 
@@ -612,8 +636,7 @@ define(['jquery',
          * Wizard step 3
          */
         MultiStepWizard.addSlide('duplicate-form-step-3', TYPO3.lang['formManager.newFormWizard.step3.title'], '', Severity.info, null, function(slide, settings) {
-          var addOnTemplateChangeEvents, folders, html, modal, nextButton, prototypes, prototypeNameSelect,
-            savePathSelect, templates, templateSelect;
+          var html, modal, nextButton;
 
           modal = MultiStepWizard.setup.$carousel.closest('.modal');
           nextButton = modal.find('.modal-footer').find('button[name="next"]');
@@ -630,7 +653,7 @@ define(['jquery',
             + '</div>'
             + '<div class="col-sm-9">'
             + '<p>'
-            + settings['confirmationDuplicateFormName']
+            + securityUtility.encodeHtml(settings['confirmationDuplicateFormName'])
             + '</p>'
             + '</div>'
             + '</div>'
@@ -640,7 +663,7 @@ define(['jquery',
             + '</div>'
             + '<div class="col-sm-9">'
             + '<p>'
-            + settings['formName']
+            + securityUtility.encodeHtml(settings['formName'])
             + '</p>'
             + '</div>'
             + '</div>'
@@ -650,7 +673,7 @@ define(['jquery',
             + '</div>'
             + '<div class="col-sm-9">'
             + '<p>'
-            + settings['confirmationDuplicateFormSavePath']
+            + securityUtility.encodeHtml(settings['confirmationDuplicateFormSavePath'])
             + '</p>'
             + '</div>'
             + '</div>';
@@ -661,6 +684,8 @@ define(['jquery',
 
           slide.html(html);
 
+          nextButton.focus();
+
           nextButton.on('click', function(e) {
             Icons.getIcon('spinner-circle', Icons.sizes.default, null, null).then(function(markup) {
               slide.html($('<div />', {class: 'text-center'}).append(markup));
@@ -829,5 +854,5 @@ define(['jquery',
     return {
       bootstrap: bootstrap
     };
-  })($, Modal, Severity, MultiStepWizard, Icons, Notification);
+  })($, Modal, Severity, MultiStepWizard, Icons, Notification, SecurityUtility);
 });
