@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Frontend\Authentication;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Frontend\Authentication;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend\Authentication;
+
 use TYPO3\CMS\Core\Authentication\AbstractUserAuthentication;
 use TYPO3\CMS\Core\Authentication\AuthenticationService;
 use TYPO3\CMS\Core\Configuration\Features;
@@ -499,9 +500,6 @@ class FrontendUserAuthentication extends AbstractUserAuthentication
             $this->user = null;
         } else {
             parent::performLogoff();
-            if ($this->isCookieSet()) {
-                $this->removeCookie($this->name);
-            }
         }
     }
 
