@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Frontend\ContentObject;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +13,11 @@ namespace TYPO3\CMS\Frontend\ContentObject;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend\ContentObject;
+
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Frontend\ContentObject\Menu\Exception\NoSuchMenuTypeException;
+use TYPO3\CMS\Frontend\ContentObject\Menu\MenuContentObjectFactory;
 
 /**
  * Contains HMENU class object.
@@ -37,16 +40,20 @@ class HierarchicalMenuContentObject extends AbstractContentObject
         $menuType = $conf[1];
         try {
             /** @var Menu\MenuContentObjectFactory $menuObjectFactory */
-            $menuObjectFactory = GeneralUtility::makeInstance(Menu\MenuContentObjectFactory::class);
+            $menuObjectFactory = GeneralUtility::makeInstance(MenuContentObjectFactory::class);
             $menu = $menuObjectFactory->getMenuObjectByType($menuType);
-            $GLOBALS['TSFE']->register['count_HMENU']++;
+            if (isset($GLOBALS['TSFE']->register['count_HMENU'])) {
+                $GLOBALS['TSFE']->register['count_HMENU']++;
+            } else {
+                $GLOBALS['TSFE']->register['count_HMENU'] = 1;
+            }
             $GLOBALS['TSFE']->register['count_HMENU_MENUOBJ'] = 0;
             $GLOBALS['TSFE']->register['count_MENUOBJ'] = 0;
             $menu->parent_cObj = $this->cObj;
             $menu->start($GLOBALS['TSFE']->tmpl, $GLOBALS['TSFE']->sys_page, '', $conf, 1);
             $menu->makeMenu();
             $theValue .= $menu->writeMenu();
-        } catch (Menu\Exception\NoSuchMenuTypeException $e) {
+        } catch (NoSuchMenuTypeException $e) {
         }
         $wrap = isset($conf['wrap.']) ? $this->cObj->stdWrap($conf['wrap'], $conf['wrap.']) : $conf['wrap'];
         if ($wrap) {
