@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Frontend\ContentObject\Menu;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Frontend\ContentObject\Menu;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend\ContentObject\Menu;
+
 use TYPO3\CMS\Core\Cache\CacheManager;
 use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Context\LanguageAspect;
@@ -30,6 +31,7 @@ use TYPO3\CMS\Core\TypoScript\TypoScriptService;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
 use TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer;
+use TYPO3\CMS\Frontend\ContentObject\Menu\Exception\NoSuchMenuTypeException;
 use TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController;
 use TYPO3\CMS\Frontend\Typolink\PageLinkBuilder;
 
@@ -61,7 +63,7 @@ abstract class AbstractMenuContentObject
      *
      * @var int[]
      */
-    protected $excludedDoktypes = [PageRepository::DOKTYPE_BE_USER_SECTION];
+    protected $excludedDoktypes = [PageRepository::DOKTYPE_BE_USER_SECTION, PageRepository::DOKTYPE_SYSFOLDER];
 
     /**
      * @var int[]
@@ -239,8 +241,14 @@ abstract class AbstractMenuContentObject
                 }
                 $this->alwaysActivePIDlist = GeneralUtility::intExplode(',', $this->conf['alwaysActivePIDlist']);
             }
+            // includeNotInMenu initialized:
+            $includeNotInMenu = $this->conf['includeNotInMenu'];
+            $includeNotInMenuConf = $this->conf['includeNotInMenu.'] ?? null;
+            $this->conf['includeNotInMenu'] = is_array($includeNotInMenuConf)
+                ? $this->parent_cObj->stdWrap($includeNotInMenu, $includeNotInMenuConf)
+                : $includeNotInMenu;
             // exclude doktypes that should not be shown in menu (e.g. backend user section)
-            if ($this->conf['excludeDoktypes']) {
+            if ($this->conf['excludeDoktypes'] ?? false) {
                 $this->excludedDoktypes = GeneralUtility::intExplode(',', $this->conf['excludeDoktypes']);
             }
             // EntryLevel
@@ -262,7 +270,7 @@ abstract class AbstractMenuContentObject
                 // (MP var for ->id is picked up in the next part of the code...)
                 foreach ($this->tmpl->rootLine as $entryLevel => $levelRec) {
                     // For overlaid mount points, set the variable right now:
-                    if ($levelRec['_MP_PARAM'] && $levelRec['_MOUNT_OL']) {
+                    if (($levelRec['_MP_PARAM'] ?? false) && ($levelRec['_MOUNT_OL'] ?? false)) {
                         $this->MP_array[] = $levelRec['_MP_PARAM'];
                     }
                     // Break when entry level is reached:
@@ -293,7 +301,7 @@ abstract class AbstractMenuContentObject
                 $rl_MParray = [];
                 foreach ($this->tmpl->rootLine as $v_rl) {
                     // For overlaid mount points, set the variable right now:
-                    if ($v_rl['_MP_PARAM'] && $v_rl['_MOUNT_OL']) {
+                    if (($v_rl['_MP_PARAM'] ?? false) && ($v_rl['_MOUNT_OL'] ?? false)) {
                         $rl_MParray[] = $v_rl['_MP_PARAM'];
                     }
                     // Add to register:
@@ -304,7 +312,7 @@ abstract class AbstractMenuContentObject
                             : ''
                         );
                     // For normal mount points, set the variable for next level.
-                    if ($v_rl['_MP_PARAM'] && !$v_rl['_MOUNT_OL']) {
+                    if (($v_rl['_MP_PARAM'] ?? false) && !($v_rl['_MOUNT_OL'] ?? false)) {
                         $rl_MParray[] = $v_rl['_MP_PARAM'];
                     }
                 }
@@ -326,7 +334,7 @@ abstract class AbstractMenuContentObject
             // Notice: The automatic expansion of a menu is designed to work only when no "special" modes (except "directory") are used.
             $startLevel = $directoryLevel ?: $this->entryLevel;
             $currentLevel = $startLevel + $this->menuNumber;
-            if (is_array($this->tmpl->rootLine[$currentLevel])) {
+            if (is_array($this->tmpl->rootLine[$currentLevel] ?? null)) {
                 $nextMParray = $this->MP_array;
                 if (empty($nextMParray) && !$this->tmpl->rootLine[$currentLevel]['_MOUNT_OL'] && $currentLevel > 0) {
                     // Make sure to slide-down any mount point information (_MP_PARAM) to children records in the rootline
@@ -369,7 +377,7 @@ abstract class AbstractMenuContentObject
 
         // Initializing showAccessRestrictedPages
         $SAVED_where_groupAccess = '';
-        if ($this->mconf['showAccessRestrictedPages']) {
+        if ($this->mconf['showAccessRestrictedPages'] ?? false) {
             // SAVING where_groupAccess
             $SAVED_where_groupAccess = $this->sys_page->where_groupAccess;
             // Temporarily removing fe_group checking!
@@ -380,9 +388,10 @@ abstract class AbstractMenuContentObject
 
         $c = 0;
         $c_b = 0;
-        $minItems = (int)($this->mconf['minItems'] ?: $this->conf['minItems']);
-        $maxItems = (int)($this->mconf['maxItems'] ?: $this->conf['maxItems']);
-        $begin = $this->parent_cObj->calc($this->mconf['begin'] ?: $this->conf['begin']);
+
+        $minItems = (int)(($this->mconf['minItems'] ?? 0) ?: ($this->conf['minItems'] ?? 0));
+        $maxItems = (int)(($this->mconf['maxItems'] ?? 0) ?: ($this->conf['maxItems'] ?? 0));
+        $begin = $this->parent_cObj->calc(($this->mconf['begin'] ?? 0) ?: ($this->conf['begin'] ?? 0));
         $minItemsConf = $this->mconf['minItems.'] ?? $this->conf['minItems.'] ?? null;
         $minItems = is_array($minItemsConf) ? $this->parent_cObj->stdWrap($minItems, $minItemsConf) : $minItems;
         $maxItemsConf = $this->mconf['maxItems.'] ?? $this->conf['maxItems.'] ?? null;
@@ -419,7 +428,7 @@ abstract class AbstractMenuContentObject
             }
         }
         //	Passing the menuArr through a user defined function:
-        if ($this->mconf['itemArrayProcFunc']) {
+        if ($this->mconf['itemArrayProcFunc'] ?? false) {
             $this->menuArr = $this->userProcess('itemArrayProcFunc', $this->menuArr);
         }
         // Setting number of menu items
@@ -431,7 +440,7 @@ abstract class AbstractMenuContentObject
             json_encode($this->MP_array)
         );
         // Get the cache timeout:
-        if ($this->conf['cache_period']) {
+        if ($this->conf['cache_period'] ?? false) {
             $cacheTimeout = $this->conf['cache_period'];
         } else {
             $cacheTimeout = $this->getTypoScriptFrontendController()->get_cache_timeout();
@@ -445,7 +454,7 @@ abstract class AbstractMenuContentObject
             $this->result = $cachedData;
         }
         // End showAccessRestrictedPages
-        if ($this->mconf['showAccessRestrictedPages']) {
+        if ($this->mconf['showAccessRestrictedPages'] ?? false) {
             // RESTORING where_groupAccess
             $this->sys_page->where_groupAccess = $SAVED_where_groupAccess;
         }
@@ -494,13 +503,14 @@ abstract class AbstractMenuContentObject
     protected function prepareMenuItems()
     {
         $menuItems = [];
-        $alternativeSortingField = trim($this->mconf['alternativeSortingField']) ?: 'sorting';
+        $alternativeSortingField = trim($this->mconf['alternativeSortingField'] ?? '') ?: 'sorting';
 
         // Additional where clause, usually starts with AND (as usual with all additionalWhere functionality in TS)
         $additionalWhere = $this->mconf['additionalWhere'] ?? '';
         if (isset($this->mconf['additionalWhere.'])) {
             $additionalWhere = $this->parent_cObj->stdWrap($additionalWhere, $this->mconf['additionalWhere.']);
         }
+        $additionalWhere .= $this->getDoktypeExcludeWhere();
 
         // ... only for the FIRST level of a HMENU
         if ($this->menuNumber == 1 && $this->conf['special']) {
@@ -544,7 +554,7 @@ abstract class AbstractMenuContentObject
                     $menuItems = $this->prepareMenuItemsForBrowseMenu($value, $alternativeSortingField, $additionalWhere);
                     break;
             }
-            if ($this->mconf['sectionIndex']) {
+            if ($this->mconf['sectionIndex'] ?? false) {
                 $sectionIndexes = [];
                 foreach ($menuItems as $page) {
                     $sectionIndexes = $sectionIndexes + $this->sectionIndex($alternativeSortingField, $page['uid']);
@@ -616,7 +626,7 @@ abstract class AbstractMenuContentObject
             if (GeneralUtility::hideIfNotTranslated($tsfe->page['l18n_cfg']) && $sUid &&
                 empty($lRecs) || GeneralUtility::hideIfDefaultLanguage($tsfe->page['l18n_cfg']) &&
                 (!$sUid || empty($lRecs)) ||
-                !$this->conf['special.']['normalWhenNoLanguage'] && $sUid && empty($lRecs)
+                !($this->conf['special.']['normalWhenNoLanguage'] ?? false) && $sUid && empty($lRecs)
             ) {
                 $iState = $currentLanguageId === $sUid ? 'USERDEF2' : 'USERDEF1';
             } else {
@@ -675,8 +685,16 @@ abstract class AbstractMenuContentObject
                 $id = $mount_info['mount_pid'];
             }
             // Get sub-pages:
-            $rows = $this->sys_page->getMenu($id, '*', $sortingField);
-            foreach ($rows as $row) {
+            $statement = $this->parent_cObj->exec_getQuery('pages', ['pidInList' => $id, 'orderBy' => $sortingField]);
+            while ($row = $statement->fetch()) {
+                // When the site language configuration is in "free" mode, then the page without overlay is fetched
+                // (which is kind-of strange for pages, but this is what exec_getQuery() is doing)
+                // this means, that $row is a translated page, but hasn't been overlaid. For this reason, we fetch
+                // the default translation page again, (which does a ->getPageOverlay() again - doing this on a
+                // translated page would result in no record at all)
+                if ($row['l10n_parent'] > 0 && !isset($row['_PAGES_OVERLAY'])) {
+                    $row = $this->sys_page->getPage($row['l10n_parent'], true);
+                }
                 $tsfe->sys_page->versionOL('pages', $row, true);
                 if (!empty($row)) {
                     // Keep mount point?
@@ -847,6 +865,14 @@ abstract class AbstractMenuContentObject
             'max' => $limit
         ]);
         while ($row = $statement->fetch()) {
+            // When the site language configuration is in "free" mode, then the page without overlay is fetched
+            // (which is kind-of strange for pages, but this is what exec_getQuery() is doing)
+            // this means, that $row is a translated page, but hasn't been overlaid. For this reason, we fetch
+            // the default translation page again, (which does a ->getPageOverlay() again - doing this on a
+            // translated page would result in no record at all)
+            if ($row['l10n_parent'] > 0 && !isset($row['_PAGES_OVERLAY'])) {
+                $row = $this->sys_page->getPage($row['l10n_parent'], true);
+            }
             $tsfe->sys_page->versionOL('pages', $row, true);
             if (is_array($row)) {
                 $menuItems[$row['uid']] = $this->sys_page->getPageOverlay($row);
@@ -1291,7 +1317,7 @@ abstract class AbstractMenuContentObject
         $tsfe = $this->getTypoScriptFrontendController();
 
         // If a user script returned the value overrideId in the menu array we use that as page id
-        if ($this->mconf['overrideId'] || $this->menuArr[$key]['overrideId']) {
+        if (($this->mconf['overrideId'] ?? false) || ($this->menuArr[$key]['overrideId'] ?? false)) {
             $overrideId = (int)($this->mconf['overrideId'] ?: $this->menuArr[$key]['overrideId']);
             $overrideId = $overrideId > 0 ? $overrideId : null;
             // Clear MP parameters since ID was changed.
@@ -1310,13 +1336,13 @@ abstract class AbstractMenuContentObject
             $mainTarget = $this->mconf['target'];
         }
         // Creating link:
-        $addParams = $this->mconf['addParams'] . $MP_params;
-        if ($this->mconf['collapse'] && $this->isActive($this->menuArr[$key]['uid'], $this->getMPvar($key))) {
+        $addParams = ($this->mconf['addParams'] ?? '') . $MP_params;
+        if (($this->mconf['collapse'] ?? false) && $this->isActive($this->menuArr[$key]['uid'], $this->getMPvar($key))) {
             $thePage = $this->sys_page->getPage($this->menuArr[$key]['pid']);
             $addParams .= $this->menuArr[$key]['_ADD_GETVARS'];
             $LD = $this->menuTypoLink($thePage, $mainTarget, $addParams, $typeOverride, $overrideId);
         } else {
-            $addParams .= $this->I['val']['additionalParams'] . $this->menuArr[$key]['_ADD_GETVARS'];
+            $addParams .= ($this->I['val']['additionalParams'] ?? '') . $this->menuArr[$key]['_ADD_GETVARS'];
             $LD = $this->menuTypoLink($this->menuArr[$key], $mainTarget, $addParams, $typeOverride, $overrideId);
         }
         // Override default target configuration if option is set
@@ -1325,7 +1351,7 @@ abstract class AbstractMenuContentObject
         }
         // Override URL if using "External URL"
         if ((int)$this->menuArr[$key]['doktype'] === PageRepository::DOKTYPE_LINK) {
-            $externalUrl = $this->sys_page->getExtURL($this->menuArr[$key]);
+            $externalUrl = (string)$this->sys_page->getExtURL($this->menuArr[$key]);
             // Create link using typolink (concerning spamProtectEmailAddresses) for email links
             $LD['totalURL'] = $this->parent_cObj->typoLink_URL(['parameter' => $externalUrl]);
             // Links to emails should not have any target
@@ -1350,6 +1376,9 @@ abstract class AbstractMenuContentObject
                     [],
                     true
                 );
+                if (isset($menuItem['_PAGES_OVERLAY_LANGUAGE'])) {
+                    $shortcut = $tsfe->sys_page->getPageOverlay($shortcut, $menuItem['_PAGES_OVERLAY_LANGUAGE']);
+                }
             } catch (\Exception $ex) {
             }
             if (!is_array($shortcut)) {
@@ -1359,7 +1388,7 @@ abstract class AbstractMenuContentObject
             // Only setting url, not target
             $LD['totalURL'] = $this->parent_cObj->typoLink_URL([
                 'parameter' => $shortcut['uid'],
-                'language' => 'current',
+                'language' => $shortcut['_PAGES_OVERLAY_REQUESTEDLANGUAGE'] ?? 'current',
                 'additionalParams' => $addParams . $this->I['val']['additionalParams'] . $menuItem['_ADD_GETVARS'],
                 'linkAccessRestrictedPages' => !empty($this->mconf['showAccessRestrictedPages'])
             ]);
@@ -1373,7 +1402,7 @@ abstract class AbstractMenuContentObject
         // Manipulation in case of access restricted pages:
         $this->changeLinksForAccessRestrictedPages($LD, $pageData, $mainTarget, $typeOverride);
         // Overriding URL / Target if set to do so:
-        if ($this->menuArr[$key]['_OVERRIDE_HREF']) {
+        if ($this->menuArr[$key]['_OVERRIDE_HREF'] ?? false) {
             $LD['totalURL'] = $this->menuArr[$key]['_OVERRIDE_HREF'];
             if ($this->menuArr[$key]['_OVERRIDE_TARGET']) {
                 $LD['target'] = $this->menuArr[$key]['_OVERRIDE_TARGET'];
@@ -1381,7 +1410,7 @@ abstract class AbstractMenuContentObject
         }
         // OnClick open in windows.
         $onClick = '';
-        if ($this->mconf['JSWindow']) {
+        if ($this->mconf['JSWindow'] ?? false) {
             $conf = $this->mconf['JSWindow.'];
             $url = $LD['totalURL'];
             $LD['totalURL'] = '#';
@@ -1401,16 +1430,18 @@ abstract class AbstractMenuContentObject
         $targetIsType = $LD['target'] && MathUtility::canBeInterpretedAsInteger($LD['target']) ? (int)$LD['target'] : false;
         if (preg_match('/([0-9]+[\\s])?(([0-9]+)x([0-9]+))?(:.+)?/s', $LD['target'], $matches) || $targetIsType) {
             // has type?
-            if ((int)$matches[1] || $targetIsType) {
+            if ((int)($matches[1] ?? 0) || $targetIsType) {
                 $LD['totalURL'] .= (strpos($LD['totalURL'], '?') === false ? '?' : '&') . 'type=' . ($targetIsType ?: (int)$matches[1]);
                 $LD['target'] = $targetIsType ? '' : trim(substr($LD['target'], strlen($matches[1]) + 1));
             }
             // Open in popup window?
-            if ($matches[3] && $matches[4]) {
+            if (($matches[3] ?? false) && ($matches[4] ?? false)) {
+                $target = $LD['target'] ?? 'FEopenLink';
                 $JSparamWH = 'width=' . $matches[3] . ',height=' . $matches[4] . ($matches[5] ? ',' . substr($matches[5], 1) : '');
-                $onClick = 'vHWin=window.open('
+                $onClick = 'openPic('
                     . GeneralUtility::quoteJSvalue($tsfe->baseUrlWrap($LD['totalURL']))
-                    . ',\'FEopenLink\',' . GeneralUtility::quoteJSvalue($JSparamWH) . ');vHWin.focus();return false;';
+                    . ',' . GeneralUtility::quoteJSvalue($target) . ',' . GeneralUtility::quoteJSvalue($JSparamWH) . ');vHWin.focus();return false;';
+                $tsfe->setJS('openPic');
                 $LD['target'] = '';
             }
         }
@@ -1467,7 +1498,7 @@ abstract class AbstractMenuContentObject
     protected function changeLinksForAccessRestrictedPages(&$LD, $page, $mainTarget, $typeOverride)
     {
         // If access restricted pages should be shown in menus, change the link of such pages to link to a redirection page:
-        if ($this->mconf['showAccessRestrictedPages'] && $this->mconf['showAccessRestrictedPages'] !== 'NONE' && !$this->getTypoScriptFrontendController()->checkPageGroupAccess($page)) {
+        if (($this->mconf['showAccessRestrictedPages'] ?? false) && $this->mconf['showAccessRestrictedPages'] !== 'NONE' && !$this->getTypoScriptFrontendController()->checkPageGroupAccess($page)) {
             $thePage = $this->sys_page->getPage($this->mconf['showAccessRestrictedPages']);
             $addParams = str_replace(
                 [
@@ -1495,16 +1526,16 @@ abstract class AbstractMenuContentObject
     {
         // Setting alternative menu item array if _SUB_MENU has been defined in the current ->menuArr
         $altArray = '';
-        if (is_array($this->menuArr[$this->I['key']]['_SUB_MENU']) && !empty($this->menuArr[$this->I['key']]['_SUB_MENU'])) {
+        if (is_array($this->menuArr[$this->I['key']]['_SUB_MENU'] ?? null) && !empty($this->menuArr[$this->I['key']]['_SUB_MENU'])) {
             $altArray = $this->menuArr[$this->I['key']]['_SUB_MENU'];
         }
         // Make submenu if the page is the next active
-        $menuType = $this->conf[($this->menuNumber + 1) . $objSuffix];
+        $menuType = $this->conf[($this->menuNumber + 1) . $objSuffix] ?? '';
         // stdWrap for expAll
         if (isset($this->mconf['expAll.'])) {
             $this->mconf['expAll'] = $this->parent_cObj->stdWrap($this->mconf['expAll'], $this->mconf['expAll.']);
         }
-        if (($this->mconf['expAll'] || $this->isNext($uid, $this->getMPvar($this->I['key'])) || is_array($altArray)) && !$this->mconf['sectionIndex']) {
+        if ((($this->mconf['expAll'] ?? false) || $this->isNext($uid, $this->getMPvar($this->I['key'])) || is_array($altArray)) && !($this->mconf['sectionIndex'] ?? false)) {
             try {
                 $menuObjectFactory = GeneralUtility::makeInstance(MenuContentObjectFactory::class);
                 /** @var AbstractMenuContentObject $submenu */
@@ -1535,7 +1566,7 @@ abstract class AbstractMenuContentObject
                     $tsfe->register['count_menuItems'] = count($this->menuArr);
                     return $content;
                 }
-            } catch (Exception\NoSuchMenuTypeException $e) {
+            } catch (NoSuchMenuTypeException $e) {
             }
         }
         return '';
@@ -1735,7 +1766,7 @@ abstract class AbstractMenuContentObject
     protected function userProcess($mConfKey, $passVar)
     {
         if ($this->mconf[$mConfKey]) {
-            $funcConf = $this->mconf[$mConfKey . '.'];
+            $funcConf = (array)($this->mconf[$mConfKey . '.'] ?? []);
             $funcConf['parentObj'] = $this;
             $passVar = $this->parent_cObj->callUserFunction($this->mconf[$mConfKey], $funcConf, $passVar);
         }
@@ -1777,7 +1808,7 @@ abstract class AbstractMenuContentObject
         if ($GLOBALS['TYPO3_CONF_VARS']['FE']['enable_mount_pids']) {
             $localMP_array = $this->MP_array;
             // NOTICE: "_MP_PARAM" is allowed to be a commalist of PID pairs!
-            if ($this->menuArr[$key]['_MP_PARAM']) {
+            if ($this->menuArr[$key]['_MP_PARAM'] ?? false) {
                 $localMP_array[] = $this->menuArr[$key]['_MP_PARAM'];
             }
             return !empty($localMP_array) ? implode(',', $localMP_array) : '';
