@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Frontend\ContentObject;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Frontend\ContentObject;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend\ContentObject;
+
 /**
  * Contains USER_INT class object.
  */
@@ -31,9 +32,7 @@ class UserInternalContentObject extends AbstractContentObject
         $tsfe = $this->getTypoScriptFrontendController();
         $substKey = 'INT_SCRIPT.' . $tsfe->uniqueHash();
         $content = '<!--' . $substKey . '-->';
-        $includeLibs = isset($conf['includeLibs.']) ? $this->cObj->stdWrap($conf['includeLibs'], $conf['includeLibs.']) : $conf['includeLibs'];
         $tsfe->config['INTincScript'][$substKey] = [
-            'file' => $includeLibs,
             'conf' => $conf,
             'cObj' => serialize($this->cObj),
             'type' => 'FUNC'
