@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Frontend;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,9 +13,13 @@ namespace TYPO3\CMS\Frontend;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend;
+
+use TYPO3\CMS\Core\Exception as CoreException;
+
 /**
- * A generic frontend exception
+ * A generic Frontend exception
  */
-class Exception extends \Exception
+class Exception extends CoreException
 {
 }
