@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Frontend\Middleware;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Frontend\Middleware;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend\Middleware;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use Psr\Http\Server\MiddlewareInterface;
@@ -47,6 +49,7 @@ class ShortcutAndMountPointRedirect implements MiddlewareInterface
         // Check for shortcut page and mount point redirect
         $redirectToUri = $this->getRedirectUri($request);
         if ($redirectToUri !== null && $redirectToUri !== (string)$request->getUri()) {
+            $this->releaseTypoScriptFrontendControllerLocks();
             return new RedirectResponse($redirectToUri, 307);
         }
 
@@ -58,6 +61,7 @@ class ShortcutAndMountPointRedirect implements MiddlewareInterface
                 $request->getAttribute('normalizedParams')->getSiteUrl()
             );
             if (!empty($externalUrl)) {
+                $this->releaseTypoScriptFrontendControllerLocks();
                 return new RedirectResponse($externalUrl, 303);
             }
         }
@@ -95,4 +99,16 @@ class ShortcutAndMountPointRedirect implements MiddlewareInterface
         }
         return $redirectTo;
     }
+
+    /**
+     * Release TSFE locks. They have been acquired in the earlier middleware PrepareTypoScriptFrontendRendering
+     * by calling tsfe->getFromCache(). TSFE locks are usually released by the RequestHandler 'final' middleware.
+     * However, when this middleware returns early without calling below middlewares, locks need to be released explicitly.
+     *
+     * @todo: It would be better if lock acquiring and releasing would be encapsulated in ONE middleware.
+     */
+    protected function releaseTypoScriptFrontendControllerLocks(): void
+    {
+        $this->controller->releaseLocks();
+    }
 }
