@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Frontend\Page;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Frontend\Page;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend\Page;
+
 use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
@@ -158,7 +159,7 @@ class CacheHashCalculator implements SingletonInterface
      */
     protected function isAdminPanelParameter($key)
     {
-        return $key === 'ADMCMD_noBeUser' || $key === 'ADMCMD_simUser' || $key === 'ADMCMD_simTime' || $key === 'ADMCMD_prev';
+        return $key === 'ADMCMD_simUser' || $key === 'ADMCMD_simTime' || $key === 'ADMCMD_prev';
     }
 
     /**
@@ -215,7 +216,7 @@ class CacheHashCalculator implements SingletonInterface
     /**
      * Check whether the given parameter may be used even with an empty value
      *
-     * @param $key
+     * @param string $key
      * @return bool
      */
     protected function isAllowedWithEmptyValue($key)
