@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Frontend\Plugin;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Frontend\Plugin;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend\Plugin;
+
 use Doctrine\DBAL\Driver\Statement;
 use TYPO3\CMS\Core\Database\Connection;
 use TYPO3\CMS\Core\Database\ConnectionPool;
@@ -85,9 +86,9 @@ class AbstractPlugin
     ];
 
     /**
-     * Local pointer variabe array.
+     * Local pointer variable array.
      * Holds pointer information for the MVC like approach Kasper
-     * initially proposed
+     * initially proposed.
      *
      * @var array
      */
@@ -401,7 +402,7 @@ class AbstractPlugin
             ArrayUtility::mergeRecursiveWithOverrule($piVars, $overrulePIvars);
             $overrulePIvars = $piVars;
             if ($this->pi_autoCacheEn) {
-                $cache = $this->pi_autoCache($overrulePIvars);
+                $cache = (bool)$this->pi_autoCache($overrulePIvars);
             }
         }
         return $this->pi_linkTP($str, [$this->prefixId => $overrulePIvars], $cache, $altPageId);
@@ -448,7 +449,7 @@ class AbstractPlugin
             } else {
                 $overrulePIvars = ['showUid' => $uid ?: ''];
                 $overrulePIvars = array_merge($overrulePIvars, (array)$mergeArr);
-                $str = $this->pi_linkTP_keepPIvars($str, $overrulePIvars, $cache, 0, $altPageId);
+                $str = $this->pi_linkTP_keepPIvars($str, $overrulePIvars, $cache, false, $altPageId);
             }
             // If urlOnly flag, return only URL as it has recently be generated.
             if ($urlOnly) {
@@ -469,7 +470,8 @@ class AbstractPlugin
     public function pi_openAtagHrefInJSwindow($str, $winName = '', $winParams = 'width=670,height=500,status=0,menubar=0,scrollbars=1,resizable=1')
     {
         if (preg_match('/(.*)(<a[^>]*>)(.*)/i', $str, $match)) {
-            $aTagContent = GeneralUtility::get_tag_attributes($match[2]);
+            // decode HTML entities, `href` is used in escaped JavaScript context
+            $aTagContent = GeneralUtility::get_tag_attributes($match[2], true);
             $onClick = 'vHWin=window.open('
                 . GeneralUtility::quoteJSvalue($this->frontendController->baseUrlWrap($aTagContent['href'])) . ','
                 . GeneralUtility::quoteJSvalue($winName ?: md5($aTagContent['href'])) . ','
@@ -536,9 +538,9 @@ class AbstractPlugin
         $pointer = (int)$this->piVars[$pointerName];
         $count = (int)$this->internal['res_count'];
         $results_at_a_time = MathUtility::forceIntegerInRange($this->internal['results_at_a_time'], 1, 1000);
-        $totalPages = ceil($count / $results_at_a_time);
+        $totalPages = (int)ceil($count / $results_at_a_time);
         $maxPages = MathUtility::forceIntegerInRange($this->internal['maxPages'], 1, 100);
-        $pi_isOnlyFields = $this->pi_isOnlyFields($this->pi_isOnlyFields);
+        $pi_isOnlyFields = (bool)$this->pi_isOnlyFields($this->pi_isOnlyFields);
         if (!$forceOutput && $count <= $results_at_a_time) {
             return '';
         }
@@ -689,7 +691,7 @@ class AbstractPlugin
         $cells = [];
         foreach ($items as $k => $v) {
             $cells[] = '
-					<td' . ($this->piVars['mode'] == $k ? $this->pi_classParam('modeSelector-SCell') : '') . '><p>' . $this->pi_linkTP_keepPIvars(htmlspecialchars($v), ['mode' => $k], $this->pi_isOnlyFields($this->pi_isOnlyFields)) . '</p></td>';
+					<td' . ($this->piVars['mode'] == $k ? $this->pi_classParam('modeSelector-SCell') : '') . '><p>' . $this->pi_linkTP_keepPIvars(htmlspecialchars($v), ['mode' => $k], (bool)$this->pi_isOnlyFields($this->pi_isOnlyFields)) . '</p></td>';
         }
         $sTables = '
 
@@ -1165,7 +1167,7 @@ class AbstractPlugin
             $pid_list = $this->frontendController->id;
         }
         $recursive = MathUtility::forceIntegerInRange($recursive, 0);
-        $pid_list_arr = array_unique(GeneralUtility::trimExplode(',', $pid_list, true));
+        $pid_list_arr = array_unique(GeneralUtility::intExplode(',', $pid_list, true));
         $pid_list = [];
         foreach ($pid_list_arr as $val) {
             $val = MathUtility::forceIntegerInRange($val, 0);
@@ -1274,7 +1276,7 @@ class AbstractPlugin
             }
         }
         if (empty($tempPiVars)) {
-            //@TODO: How do we deal with this? return TRUE would be the right thing to do here but that might be breaking
+            // @TODO: How do we deal with this? return TRUE would be the right thing to do here but that might be breaking
             return 1;
         }
         return null;
@@ -1306,7 +1308,7 @@ class AbstractPlugin
             }
         }
         if (empty($inArray)) {
-            //@TODO: How do we deal with this? return TRUE would be the right thing to do here but that might be breaking
+            // @TODO: How do we deal with this? return TRUE would be the right thing to do here but that might be breaking
             return 1;
         }
         return null;
