@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Frontend\Typolink;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Frontend\Typolink;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Frontend\Typolink;
+
 use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Domain\Repository\PageRepository;
 use TYPO3\CMS\Core\Http\ServerRequestFactory;
@@ -42,7 +44,7 @@ abstract class AbstractTypolinkBuilder
     protected $contentObjectRenderer;
 
     /**
-     * @var TypoScriptFrontendController
+     * @var TypoScriptFrontendController|null
      */
     protected $typoScriptFrontendController;
 
@@ -55,7 +57,7 @@ abstract class AbstractTypolinkBuilder
     public function __construct(ContentObjectRenderer $contentObjectRenderer, TypoScriptFrontendController $typoScriptFrontendController = null)
     {
         $this->contentObjectRenderer = $contentObjectRenderer;
-        $this->typoScriptFrontendController = $typoScriptFrontendController ?? $GLOBALS['TSFE'];
+        $this->typoScriptFrontendController = $typoScriptFrontendController ?? $GLOBALS['TSFE'] ?? null;
     }
 
     /**
@@ -103,9 +105,14 @@ abstract class AbstractTypolinkBuilder
                 $isUrlModified = true;
             }
             // Override scheme:
-            $forceAbsoluteUrl = &$configuration['forceAbsoluteUrl.']['scheme'];
-            if (!empty($forceAbsoluteUrl) && $urlParts['scheme'] !== $forceAbsoluteUrl) {
-                $urlParts['scheme'] = $forceAbsoluteUrl;
+            $forcedScheme = $configuration['forceAbsoluteUrl.']['scheme'] ?? null;
+            if (!empty($forcedScheme) && $urlParts['scheme'] !== $forcedScheme) {
+                $urlParts['scheme'] = $forcedScheme;
+                $isUrlModified = true;
+            }
+            // Also ensure the path has a "/" at the beginning when concatenating everything else together
+            if ($urlParts['path'] !== '') {
+                $urlParts['path'] = '/' . ltrim($urlParts['path'], '/');
                 $isUrlModified = true;
             }
             // Recreate the absolute URL:
@@ -183,7 +190,7 @@ abstract class AbstractTypolinkBuilder
         $target = '';
         if (isset($conf[$name])) {
             $target = $conf[$name];
-        } elseif ($targetAttributeAllowed && !$conf['directImageLink']) {
+        } elseif ($targetAttributeAllowed && !($conf['directImageLink'] ?? false)) {
             $target = $fallbackTarget;
         }
         if (isset($conf[$name . '.']) && $conf[$name . '.']) {
