@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Impexp\ContextMenu;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Impexp\ContextMenu;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Impexp\ContextMenu;
+
 use TYPO3\CMS\Backend\ContextMenu\ItemProviders\AbstractProvider;
 
 /**
@@ -48,8 +50,7 @@ class ItemProvider extends AbstractProvider
      */
     public function canHandle(): bool
     {
-        return !in_array($this->table, ['sys_file', 'sys_filemounts', 'sys_file_storage'], true)
-            && strpos($this->table, '-drag') === false;
+        return $this->table !== 'sys_file' && strpos($this->table, '-drag') === false;
     }
 
     /**
