@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Impexp;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Impexp;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Impexp;
+
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Configuration\FlexForm\FlexFormTools;
 use TYPO3\CMS\Core\Core\Environment;
@@ -25,6 +26,7 @@ use TYPO3\CMS\Core\Resource\File;
 use TYPO3\CMS\Core\Resource\FileInterface;
 use TYPO3\CMS\Core\Resource\ResourceFactory;
 use TYPO3\CMS\Core\Resource\ResourceStorage;
+use TYPO3\CMS\Core\Resource\Security\FileNameValidator;
 use TYPO3\CMS\Core\Resource\StorageRepository;
 use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
@@ -392,6 +394,7 @@ class Import extends ImportExport
             // check, if there is an identical file
             try {
                 if ($storage->hasFile($fileRecord['identifier'])) {
+                    /** @var File $file */
                     $file = $storage->getFile($fileRecord['identifier']);
                     if ($file->getSha1() === $fileRecord['sha1']) {
                         $newFile = $file;
@@ -592,7 +595,7 @@ class Import extends ImportExport
             if (!empty($pageRecords)) {
                 $remainingPageUids = array_keys($pageRecords);
                 foreach ($remainingPageUids as $pUid) {
-                    $this->addSingle('pages', $pUid, $pid);
+                    $this->addSingle('pages', (int)$pUid, $pid);
                 }
             }
             // Now write to database:
@@ -693,6 +696,7 @@ class Import extends ImportExport
         $this->import_data = [];
         if (is_array($this->dat['header']['records'])) {
             foreach ($this->dat['header']['records'] as $table => $recs) {
+                $table = (string)$table;
                 $this->addGeneralErrorsByTable($table);
                 if ($table !== 'pages') {
                     foreach ($recs as $uid => $thisRec) {
@@ -952,14 +956,10 @@ class Import extends ImportExport
     public function unlinkTempFiles()
     {
         foreach ($this->unlinkFiles as $fileName) {
-            if (GeneralUtility::isFirstPartOfStr($fileName, Environment::getPublicPath() . '/typo3temp/')) {
-                GeneralUtility::unlink_tempfile($fileName);
-                clearstatcache();
-                if (is_file($fileName)) {
-                    $this->error('Error: ' . $fileName . ' was NOT unlinked as it should have been!');
-                }
-            } else {
-                $this->error('Error: ' . $fileName . ' was not in temp-path. Not removed!');
+            GeneralUtility::unlink_tempfile($fileName);
+            clearstatcache();
+            if (is_file($fileName)) {
+                $this->error('Error: ' . $fileName . ' was NOT unlinked as it should have been!');
             }
         }
         $this->unlinkFiles = [];
@@ -968,7 +968,6 @@ class Import extends ImportExport
     /***************************
      * Import / Relations setting
      ***************************/
-
     /**
      * At the end of the import process all file and DB relations should be set properly (that is relations
      * to imported records are all re-created so imported records are correctly related again)
@@ -979,7 +978,7 @@ class Import extends ImportExport
     public function setRelations()
     {
         $updateData = [];
-        // import_newId contains a register of all records that was in the import memorys "records" key
+        // import_newId contains a register of all records that was in the import memory's "records" key
         foreach ($this->import_newId as $nId => $dat) {
             $table = $dat['table'];
             $uid = $dat['uid'];
@@ -1119,7 +1118,7 @@ class Import extends ImportExport
     public function setFlexFormRelations()
     {
         $updateData = [];
-        // import_newId contains a register of all records that was in the import memorys "records" key
+        // import_newId contains a register of all records that were in the import memory's "records" key
         foreach ($this->import_newId as $nId => $dat) {
             $table = $dat['table'];
             $uid = $dat['uid'];
@@ -1416,7 +1415,7 @@ class Import extends ImportExport
             if (GeneralUtility::isFirstPartOfStr($dirPrefix, $this->fileadminFolderName . '/')) {
                 // File in fileadmin/ folder:
                 // Create file (and possible resources)
-                $newFileName = $this->processSoftReferences_saveFile_createRelFile($dirPrefix, PathUtility::basename($relFileName), $cfg['file_ID'], $table, $uid);
+                $newFileName = $this->processSoftReferences_saveFile_createRelFile($dirPrefix, PathUtility::basename($relFileName), $cfg['file_ID'], $table, $uid) ?: '';
                 if (strlen($newFileName)) {
                     $relFileName = $newFileName;
                 } else {
@@ -1450,7 +1449,7 @@ class Import extends ImportExport
             return PathUtility::stripPathSitePrefix($this->fileIDMap[$fileID]);
         }
         // Verify FileMount access to dir-prefix. Returns the best alternative relative path if any
-        $dirPrefix = $this->verifyFolderAccess($origDirPrefix);
+        $dirPrefix = (string)$this->verifyFolderAccess($origDirPrefix);
         if ($dirPrefix && (!$this->update || $origDirPrefix === $dirPrefix) && $this->checkOrCreateDir($dirPrefix)) {
             $fileHeaderInfo = $this->dat['header']['files'][$fileID];
             $updMode = $this->update && $this->import_mapId[$table][$uid] === $uid && $this->import_mode[$table . ':' . $uid] !== 'as_new';
@@ -1463,7 +1462,7 @@ class Import extends ImportExport
             } else {
                 // Create unique filename:
                 $fileProcObj = $this->getFileProcObj();
-                $newName = $fileProcObj->getUniqueName($fileName, Environment::getPublicPath() . '/' . $dirPrefix);
+                $newName = (string)$fileProcObj->getUniqueName($fileName, Environment::getPublicPath() . '/' . $dirPrefix);
             }
             if ($this->writeFileVerify($newName, $fileID)) {
                 // If the resource was an HTML/CSS file with resources attached, we will write those as well!
@@ -1498,7 +1497,7 @@ class Import extends ImportExport
                         if (GeneralUtility::mkdir($resourceDir)) {
                             foreach ($fileHeaderInfo['EXT_RES_ID'] as $res_fileID) {
                                 if ($this->dat['files'][$res_fileID]['filename']) {
-                                    $absResourceFileName = $fileProcObj->getUniqueName($this->dat['files'][$res_fileID]['filename'], $resourceDir);
+                                    $absResourceFileName = (string)$fileProcObj->getUniqueName($this->dat['files'][$res_fileID]['filename'], $resourceDir);
                                     $relResourceFileName = substr($absResourceFileName, strlen(PathUtility::dirname($resourceDir)) + 1);
                                     $this->writeFileVerify($absResourceFileName, $res_fileID);
                                     $tokenizedContent = str_replace('{EXT_RES_ID:' . $res_fileID . '}', $relResourceFileName, $tokenizedContent);
@@ -1543,7 +1542,7 @@ class Import extends ImportExport
             }
         }
         $fI = GeneralUtility::split_fileref($fileName);
-        if (!GeneralUtility::verifyFilenameAgainstDenyPattern($fI['file'])) {
+        if (!GeneralUtility::makeInstance(FileNameValidator::class)->isValid($fI['file'])) {
             $this->error('ERROR: Filename "' . $fileName . '" failed against extension check or deny-pattern!');
             return false;
         }
@@ -1557,7 +1556,7 @@ class Import extends ImportExport
         }
         GeneralUtility::writeFile($fileName, $this->dat['files'][$fileID]['content']);
         $this->fileIDMap[$fileID] = $fileName;
-        if (md5(file_get_contents($fileName)) == $this->dat['files'][$fileID]['content_md5']) {
+        if (hash_equals(md5((string)file_get_contents($fileName)), $this->dat['files'][$fileID]['content_md5'])) {
             return true;
         }
         $this->error('ERROR: File content "' . $fileName . '" was corrupted');
@@ -1626,7 +1625,7 @@ class Import extends ImportExport
         }
         if (strtolower($fI['extension']) === 'xml') {
             // XML:
-            $xmlContent = file_get_contents($filename);
+            $xmlContent = (string)file_get_contents($filename);
             if (strlen($xmlContent)) {
                 $this->dat = GeneralUtility::xml2array($xmlContent, '', true);
                 if (is_array($this->dat)) {
@@ -1644,18 +1643,17 @@ class Import extends ImportExport
         } else {
             // T3D
             if ($fd = fopen($filename, 'rb')) {
-                $this->dat['header'] = $this->getNextFilePart($fd, 1, 'header');
+                $this->dat['header'] = $this->getNextFilePart($fd, true, 'header');
                 if ($all) {
-                    $this->dat['records'] = $this->getNextFilePart($fd, 1, 'records');
-                    $this->dat['files'] = $this->getNextFilePart($fd, 1, 'files');
-                    $this->dat['files_fal'] = $this->getNextFilePart($fd, 1, 'files_fal');
+                    $this->dat['records'] = $this->getNextFilePart($fd, true, 'records');
+                    $this->dat['files'] = $this->getNextFilePart($fd, true, 'files');
+                    $this->dat['files_fal'] = $this->getNextFilePart($fd, true, 'files_fal');
                 }
                 $this->loadInit();
+                fclose($fd);
                 return true;
             }
             $this->error('Error opening file: ' . $filename);
-
-            fclose($fd);
         }
         return false;
     }
@@ -1688,12 +1686,12 @@ class Import extends ImportExport
             $this->error('File read error: InitString had a wrong length. (' . $name . ')');
             return null;
         }
-        $datString = fread($fd, (int)$initStrDat[2]);
+        $datString = (string)fread($fd, (int)$initStrDat[2]);
         fread($fd, 1);
-        if (md5($datString) === $initStrDat[0]) {
+        if (hash_equals($initStrDat[0], md5($datString))) {
             if ($initStrDat[1]) {
                 if ($this->compress) {
-                    $datString = gzuncompress($datString);
+                    $datString = (string)gzuncompress($datString);
                 } else {
                     $this->error('Content read error: This file requires decompression, but this server does not offer gzcompress()/gzuncompress() functions.');
                     return null;
@@ -1715,9 +1713,9 @@ class Import extends ImportExport
     public function loadContent($filecontent)
     {
         $pointer = 0;
-        $this->dat['header'] = $this->getNextContentPart($filecontent, $pointer, 1, 'header');
-        $this->dat['records'] = $this->getNextContentPart($filecontent, $pointer, 1, 'records');
-        $this->dat['files'] = $this->getNextContentPart($filecontent, $pointer, 1, 'files');
+        $this->dat['header'] = $this->getNextContentPart($filecontent, $pointer, true, 'header');
+        $this->dat['records'] = $this->getNextContentPart($filecontent, $pointer, true, 'records');
+        $this->dat['files'] = $this->getNextContentPart($filecontent, $pointer, true, 'files');
         $this->loadInit();
     }
 
@@ -1741,12 +1739,12 @@ class Import extends ImportExport
             $this->error('Content read error: InitString had a wrong length. (' . $name . ')');
             return null;
         }
-        $datString = substr($filecontent, $pointer, (int)$initStrDat[2]);
+        $datString = (string)substr($filecontent, $pointer, (int)$initStrDat[2]);
         $pointer += (int)$initStrDat[2] + 1;
-        if (md5($datString) === $initStrDat[0]) {
+        if (hash_equals($initStrDat[0], md5($datString))) {
             if ($initStrDat[1]) {
                 if ($this->compress) {
-                    $datString = gzuncompress($datString);
+                    $datString = (string)gzuncompress($datString);
                     return $unserialize ? unserialize($datString, ['allowed_classes' => false]) : $datString;
                 }
                 $this->error('Content read error: This file requires decompression, but this server does not offer gzcompress()/gzuncompress() functions.');
