@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\IndexedSearch;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\IndexedSearch;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\IndexedSearch;
+
 use TYPO3\CMS\Core\Configuration\ExtensionConfiguration;
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Utility\CommandUtility;
@@ -435,7 +436,7 @@ class FileContentParser
     /**
      * Wraps the "splitLabel function" of the language object.
      *
-     * @param string $reference: Reference/key of the label
+     * @param string $reference Reference/key of the label
      * @return string The label of the reference/key to be fetched
      */
     protected function sL($reference)
@@ -484,7 +485,7 @@ class FileContentParser
                         $cmd = $this->app['pdftotext'] . ' -f ' . $low . ' -l ' . $high . ' -enc UTF-8 -q ' . escapeshellarg($absFile) . ' ' . $tempFileName;
                         CommandUtility::exec($cmd);
                         if (@is_file($tempFileName)) {
-                            $content = file_get_contents($tempFileName);
+                            $content = (string)file_get_contents($tempFileName);
                             unlink($tempFileName);
                         } else {
                             $content = '';
@@ -564,6 +565,9 @@ class FileContentParser
                             // Read sheet1.xml:
                             $cmd = $this->app['unzip'] . ' -p ' . escapeshellarg($absFile) . ' xl/worksheets/sheet1.xml';
                             break;
+                        default:
+                            $cmd = '';
+                            break;
                     }
                     CommandUtility::exec($cmd, $res);
                     $content_xml = implode(LF, $res);
@@ -727,7 +731,7 @@ class FileContentParser
             if ($this->lastLocale !== null) {
                 throw new \RuntimeException('Cannot set new locale as locale has already been changed before.', 1357064437);
             }
-            $this->lastLocale = setlocale(LC_CTYPE, 0);
+            $this->lastLocale = setlocale(LC_CTYPE, '0');
             setlocale(LC_CTYPE, $GLOBALS['TYPO3_CONF_VARS']['SYS']['systemLocale']);
         }
     }
@@ -805,7 +809,7 @@ class FileContentParser
      */
     public function removeEndJunk($string)
     {
-        return trim(preg_replace('/[' . LF . chr(12) . ']*$/', '', $string));
+        return trim((string)preg_replace('/[' . LF . chr(12) . ']*$/', '', $string));
     }
 
     /************************
