@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Install\Configuration\Cache;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,14 +13,18 @@ namespace TYPO3\CMS\Install\Configuration\Cache;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\Configuration\Cache;
+
 use TYPO3\CMS\Core\Cache\Backend\Typo3DatabaseBackend;
 use TYPO3\CMS\Install\Configuration;
+use TYPO3\CMS\Install\Configuration\AbstractCustomPreset;
+use TYPO3\CMS\Install\Configuration\CustomPresetInterface;
 
 /**
  * Custom preset is a fallback if no other preset fits
  * @internal only to be used within EXT:install
  */
-class CustomCachePreset extends Configuration\AbstractCustomPreset implements Configuration\CustomPresetInterface
+class CustomCachePreset extends AbstractCustomPreset implements CustomPresetInterface
 {
     /**
      * @var array Configuration values handled by this preset
