@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Install\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,9 +15,12 @@ namespace TYPO3\CMS\Install\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use Symfony\Component\Mime\Address;
+use Symfony\Component\Mime\Exception\RfcComplianceException;
 use TYPO3\CMS\Backend\Toolbar\Enumeration\InformationStatus;
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Database\ConnectionPool;
@@ -36,8 +39,10 @@ use TYPO3\CMS\Core\Utility\MathUtility;
 use TYPO3\CMS\Core\Utility\StringUtility;
 use TYPO3\CMS\Install\FolderStructure\DefaultFactory;
 use TYPO3\CMS\Install\FolderStructure\DefaultPermissionsCheck;
+use TYPO3\CMS\Install\Service\LateBootService;
 use TYPO3\CMS\Install\SystemEnvironment\Check;
 use TYPO3\CMS\Install\SystemEnvironment\DatabaseCheck;
+use TYPO3\CMS\Install\SystemEnvironment\ServerResponse\ServerResponseCheck;
 use TYPO3\CMS\Install\SystemEnvironment\SetupCheck;
 
 /**
@@ -46,6 +51,19 @@ use TYPO3\CMS\Install\SystemEnvironment\SetupCheck;
  */
 class EnvironmentController extends AbstractController
 {
+    private const IMAGE_FILE_EXT = ['gif', 'jpg', 'png', 'tif', 'ai', 'pdf'];
+
+    /**
+     * @var LateBootService
+     */
+    private $lateBootService;
+
+    public function __construct(
+        LateBootService $lateBootService
+    ) {
+        $this->lateBootService = $lateBootService;
+    }
+
     /**
      * Main "show the cards" view
      *
@@ -71,7 +89,7 @@ class EnvironmentController extends AbstractController
     {
         $view = $this->initializeStandaloneView($request, 'Environment/SystemInformation.html');
         $view->assignMultiple([
-            'systemInformationCgiDetected' => GeneralUtility::isRunningOnCgiServerApi(),
+            'systemInformationCgiDetected' => Environment::isRunningOnCgiServer(),
             'systemInformationDatabaseConnections' => $this->getDatabaseConnectionInformation(),
             'systemInformationOperatingSystem' => Environment::isWindows() ? 'Windows' : 'Unix',
             'systemInformationApplicationContext' => $this->getApplicationContextInformation(),
@@ -120,6 +138,10 @@ class EnvironmentController extends AbstractController
         foreach ($databaseMessages as $message) {
             $messageQueue->enqueue($message);
         }
+        $serverResponseMessages = (new ServerResponseCheck(false))->getStatus();
+        foreach ($serverResponseMessages as $message) {
+            $messageQueue->enqueue($message);
+        }
         return new JsonResponse([
             'success' => true,
             'status' => [
@@ -237,6 +259,8 @@ class EnvironmentController extends AbstractController
      */
     public function mailTestAction(ServerRequestInterface $request): ResponseInterface
     {
+        $container = $this->lateBootService->getContainer();
+        $backup = $this->lateBootService->makeCurrent($container);
         $messages = new FlashMessageQueue('install');
         $recipient = $request->getParsedBody()['install']['email'];
         if (empty($recipient) || !GeneralUtility::validEmail($recipient)) {
@@ -265,7 +289,7 @@ class EnvironmentController extends AbstractController
                     'Recipient: ' . $recipient,
                     'Test mail sent'
                 ));
-            } catch (\Symfony\Component\Mime\Exception\RfcComplianceException $exception) {
+            } catch (RfcComplianceException $exception) {
                 $messages->enqueue(new FlashMessage(
                     'Please verify $GLOBALS[\'TYPO3_CONF_VARS\'][\'MAIL\'][\'defaultMailFromAddress\'] is a valid mail address.'
                     . ' Error message: ' . $exception->getMessage(),
@@ -281,6 +305,7 @@ class EnvironmentController extends AbstractController
                 ));
             }
         }
+        $this->lateBootService->makeCurrent(null, $backup);
         return new JsonResponse([
             'success' => true,
             'status' => $messages,
@@ -432,10 +457,10 @@ class EnvironmentController extends AbstractController
         if ($imResult !== null && is_file($imResult[3])) {
             if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['gif_compress']) {
                 clearstatcache();
-                $previousSize = GeneralUtility::formatSize(filesize($imResult[3]));
+                $previousSize = GeneralUtility::formatSize((int)filesize($imResult[3]));
                 $methodUsed = GraphicalFunctions::gifCompress($imResult[3], '');
                 clearstatcache();
-                $compressedSize = GeneralUtility::formatSize(filesize($imResult[3]));
+                $compressedSize = GeneralUtility::formatSize((int)filesize($imResult[3]));
                 $messages->enqueue(new FlashMessage(
                     'Method used by compress: ' . $methodUsed . LF
                     . ' Previous filesize: ' . $previousSize . '. Current filesize:' . $compressedSize,
@@ -888,6 +913,7 @@ class EnvironmentController extends AbstractController
         $imageProcessor->filenamePrefix = 'installTool-';
         $imageProcessor->dontCompress = true;
         $imageProcessor->alternativeOutputKey = 'typo3InstallTest';
+        $imageProcessor->setImageFileExt(self::IMAGE_FILE_EXT);
         return $imageProcessor;
     }
 
@@ -1063,12 +1089,12 @@ class EnvironmentController extends AbstractController
             'success' => true,
         ];
         foreach ($testResult as $resultKey => $value) {
-            if ($resultKey === 'referenceFile') {
+            if ($resultKey === 'referenceFile' && !empty($testResult['referenceFile'])) {
                 $fileExt = end(explode('.', $testResult['referenceFile']));
-                $responseData['referenceFile'] = 'data:image/' . $fileExt . ';base64,' . base64_encode(file_get_contents($testResult['referenceFile']));
-            } elseif ($resultKey === 'outputFile') {
+                $responseData['referenceFile'] = 'data:image/' . $fileExt . ';base64,' . base64_encode((string)file_get_contents($testResult['referenceFile']));
+            } elseif ($resultKey === 'outputFile' && !empty($testResult['outputFile'])) {
                 $fileExt = end(explode('.', $testResult['outputFile']));
-                $responseData['outputFile'] = 'data:image/' . $fileExt . ';base64,' . base64_encode(file_get_contents($testResult['outputFile']));
+                $responseData['outputFile'] = 'data:image/' . $fileExt . ';base64,' . base64_encode((string)file_get_contents($testResult['outputFile']));
             } else {
                 $responseData[$resultKey] = $value;
             }
