@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Install\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Install\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Core\Configuration\ExtensionConfiguration;
@@ -35,6 +37,17 @@ use TYPO3\CMS\Install\Service\SilentConfigurationUpgradeService;
  */
 class LayoutController extends AbstractController
 {
+    /**
+     * @var SilentConfigurationUpgradeService
+     */
+    private $silentConfigurationUpgradeService;
+
+    public function __construct(
+        SilentConfigurationUpgradeService $silentConfigurationUpgradeService
+    ) {
+        $this->silentConfigurationUpgradeService = $silentConfigurationUpgradeService;
+    }
+
     /**
      * The init action renders an HTML response with HTML view having <head> section
      * containing resources to main .js routing.
@@ -88,10 +101,9 @@ class LayoutController extends AbstractController
      */
     public function executeSilentConfigurationUpdateAction(): ResponseInterface
     {
-        $silentUpdate = new SilentConfigurationUpgradeService();
         $success = true;
         try {
-            $silentUpdate->execute();
+            $this->silentConfigurationUpgradeService->execute();
         } catch (ConfigurationChangedException $e) {
             $success = false;
         }
