@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Install\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Install\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Core\Configuration\ConfigurationManager;
@@ -27,7 +29,7 @@ use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\FormProtection\FormProtectionFactory;
 use TYPO3\CMS\Core\FormProtection\InstallToolFormProtection;
 use TYPO3\CMS\Core\Http\JsonResponse;
-use TYPO3\CMS\Core\Localization\LanguageService;
+use TYPO3\CMS\Core\Localization\LanguageServiceFactory;
 use TYPO3\CMS\Core\Messaging\FlashMessage;
 use TYPO3\CMS\Core\Messaging\FlashMessageQueue;
 use TYPO3\CMS\Core\Package\PackageManager;
@@ -44,6 +46,31 @@ use TYPO3\CMS\Install\Service\LocalConfigurationValueService;
  */
 class SettingsController extends AbstractController
 {
+    /**
+     * @var PackageManager
+     */
+    private $packageManager;
+
+    /**
+     * @var ExtensionConfigurationService
+     */
+    private $extensionConfigurationService;
+
+    /**
+     * @var LanguageServiceFactory
+     */
+    private $languageServiceFactory;
+
+    public function __construct(
+        PackageManager $packageManager,
+        ExtensionConfigurationService $extensionConfigurationService,
+        LanguageServiceFactory $languageServiceFactory
+    ) {
+        $this->packageManager = $packageManager;
+        $this->extensionConfigurationService = $extensionConfigurationService;
+        $this->languageServiceFactory = $languageServiceFactory;
+    }
+
     /**
      * Main "show the cards" view
      *
@@ -98,14 +125,14 @@ class SettingsController extends AbstractController
 
         if ($password !== $passwordCheck) {
             $messageQueue->enqueue(new FlashMessage(
-                'Install tool password not changed. Given passwords do not match.',
-                '',
+                'Given passwords do not match.',
+                'Install tool password not changed',
                 FlashMessage::ERROR
             ));
         } elseif (strlen($password) < 8) {
             $messageQueue->enqueue(new FlashMessage(
-                'Install tool password not changed. Given password must be at least eight characters long.',
-                '',
+                'Given password must be at least eight characters long.',
+                'Install tool password not changed',
                 FlashMessage::ERROR
             ));
         } else {
@@ -115,7 +142,10 @@ class SettingsController extends AbstractController
                 'BE/installToolPassword',
                 $hashInstance->getHashedPassword($password)
             );
-            $messageQueue->enqueue(new FlashMessage('Install tool password changed'));
+            $messageQueue->enqueue(new FlashMessage(
+                'The Install tool password has been changed successfully.',
+                'Install tool password changed'
+            ));
         }
         return new JsonResponse([
             'success' => true,
@@ -168,7 +198,6 @@ class SettingsController extends AbstractController
         }
         return new JsonResponse([
             'success' => true,
-            'status' => [],
             'users' => $users,
             'html' => $view->render(),
             'buttons' => [
@@ -224,14 +253,14 @@ class SettingsController extends AbstractController
         $messages = [];
         if (empty($validatedUserList)) {
             $messages[] = new FlashMessage(
-                '',
-                'Set system maintainer list to an empty array',
+                'The system has no maintainers enabled anymore. Please use the standalone Admin Tools from now on.',
+                'Cleared system maintainer list',
                 FlashMessage::INFO
             );
         } else {
             $messages[] = new FlashMessage(
-                implode(', ', $validatedUserList),
-                'New system maintainer uid list',
+                'New system maintainer uid list: ' . implode(', ', $validatedUserList),
+                'Updated system maintainers',
                 FlashMessage::INFO
             );
         }
@@ -290,10 +319,10 @@ class SettingsController extends AbstractController
         }
         $localConfigurationValueService = new LocalConfigurationValueService();
         $messageQueue = $localConfigurationValueService->updateLocalConfigurationValues($settings);
-        if (empty($messageQueue)) {
+        if ($messageQueue->count() === 0) {
             $messageQueue->enqueue(new FlashMessage(
-                '',
-                'No values changed',
+                'No configuration changes have been detected in the submitted form.',
+                'Configuration not updated',
                 FlashMessage::WARNING
             ));
         }
@@ -349,6 +378,9 @@ class SettingsController extends AbstractController
             $configurationManager->setLocalConfigurationValuesByPathValuePairs($configurationValues);
             $messageBody = [];
             foreach ($configurationValues as $configurationKey => $configurationValue) {
+                if (is_array($configurationValue)) {
+                    $configurationValue = json_encode($configurationValue);
+                }
                 $messageBody[] = '\'' . $configurationKey . '\' => \'' . $configurationValue . '\'';
             }
             $messages->enqueue(new FlashMessage(
@@ -377,15 +409,14 @@ class SettingsController extends AbstractController
     public function extensionConfigurationGetContentAction(ServerRequestInterface $request): ResponseInterface
     {
         // Extension configuration needs initialized $GLOBALS['LANG']
-        $GLOBALS['LANG'] = LanguageService::create('default');
-        $extensionConfigurationService = new ExtensionConfigurationService();
+        $GLOBALS['LANG'] = $this->languageServiceFactory->create('default');
         $extensionsWithConfigurations = [];
-        $activePackages = GeneralUtility::makeInstance(PackageManager::class)->getActivePackages();
+        $activePackages = $this->packageManager->getActivePackages();
         foreach ($activePackages as $extensionKey => $activePackage) {
             if (@file_exists($activePackage->getPackagePath() . 'ext_conf_template.txt')) {
                 $extensionsWithConfigurations[$extensionKey] = [
                     'packageInfo' => $activePackage,
-                    'configuration' => $extensionConfigurationService->getConfigurationPreparedForView($extensionKey),
+                    'configuration' => $this->extensionConfigurationService->getConfigurationPreparedForView($extensionKey),
                 ];
             }
         }
@@ -419,8 +450,8 @@ class SettingsController extends AbstractController
         (new ExtensionConfiguration())->set($extensionKey, '', $nestedConfiguration);
         $messages = [
             new FlashMessage(
-                'Successfully saved configuration for extension "' . $extensionKey . '"',
-                '',
+                'Successfully saved configuration for extension "' . $extensionKey . '".',
+                'Configuration saved',
                 FlashMessage::OK
             )
         ];
@@ -486,10 +517,10 @@ class SettingsController extends AbstractController
     {
         $configurationManager = GeneralUtility::makeInstance(ConfigurationManager::class);
         $enabledFeaturesFromPost = $request->getParsedBody()['install']['values'] ?? [];
-        $allFeatures = array_keys($GLOBALS['TYPO3_CONF_VARS']['SYS']['features'] ?? []);
+        $allFeatures = $GLOBALS['TYPO3_CONF_VARS']['SYS']['features'] ?? [];
         $configurationDescription = GeneralUtility::makeInstance(YamlFileLoader::class)
             ->load($configurationManager->getDefaultConfigurationDescriptionFileLocation());
-        foreach ($allFeatures as $featureName) {
+        foreach (array_keys($allFeatures) as $featureName) {
             // Only features that have a .yml description will be listed. There is currently no
             // way for extensions to extend this, so feature toggles of non-core extensions are
             // not considered.
@@ -501,10 +532,14 @@ class SettingsController extends AbstractController
                 }
             }
         }
+        $configurationManager->exportConfiguration();
+
+        $allFeaturesUpdated = $GLOBALS['TYPO3_CONF_VARS']['SYS']['features'] ?? [];
+        $changedFeatures = array_diff_assoc($allFeaturesUpdated, $allFeatures);
         $messages = [
             new FlashMessage(
-                'Successfully updated feature toggles',
-                '',
+                'Successfully updated the following feature toggles: ' . implode(', ', array_keys($changedFeatures)),
+                'Features updated',
                 FlashMessage::OK
             )
         ];
