@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Install\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Install\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\Controller;
+
 use PhpParser\NodeTraverser;
 use PhpParser\NodeVisitor\NameResolver;
 use PhpParser\ParserFactory;
@@ -24,6 +26,7 @@ use Symfony\Component\Finder\Finder;
 use Symfony\Component\Finder\SplFileInfo;
 use TYPO3\CMS\Core\Core\Environment;
 use TYPO3\CMS\Core\Database\ConnectionPool;
+use TYPO3\CMS\Core\Database\Schema\Exception\StatementException;
 use TYPO3\CMS\Core\FormProtection\FormProtectionFactory;
 use TYPO3\CMS\Core\FormProtection\InstallToolFormProtection;
 use TYPO3\CMS\Core\Http\JsonResponse;
@@ -36,6 +39,8 @@ use TYPO3\CMS\Core\Registry;
 use TYPO3\CMS\Core\Service\OpcodeCacheService;
 use TYPO3\CMS\Core\Utility\ExtensionManagementUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Core\Utility\StringUtility;
+use TYPO3\CMS\Install\CoreVersion\CoreRelease;
 use TYPO3\CMS\Install\ExtensionScanner\Php\CodeStatistics;
 use TYPO3\CMS\Install\ExtensionScanner\Php\GeneratorClassesResolver;
 use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\ArrayDimensionMatcher;
@@ -43,6 +48,7 @@ use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\ArrayGlobalMatcher;
 use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\ClassConstantMatcher;
 use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\ClassNameMatcher;
 use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\ConstantMatcher;
+use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\ConstructorArgumentMatcher;
 use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\FunctionCallMatcher;
 use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\InterfaceMethodChangedMatcher;
 use TYPO3\CMS\Install\ExtensionScanner\Php\Matcher\MethodAnnotationMatcher;
@@ -82,6 +88,11 @@ class UpgradeController extends AbstractController
      */
     protected $coreVersionService;
 
+    /**
+     * @var UpgradeWizardsService
+     */
+    private $upgradeWizardsService;
+
     /**
      * @var PackageManager
      */
@@ -92,14 +103,14 @@ class UpgradeController extends AbstractController
      */
     private $lateBootService;
 
-    /**
-     * @param PackageManager $packageManager
-     * @param LateBootService $lateBootService
-     */
-    public function __construct(PackageManager $packageManager, LateBootService $lateBootService)
-    {
+    public function __construct(
+        PackageManager $packageManager,
+        LateBootService $lateBootService,
+        UpgradeWizardsService $upgradeWizardsService
+    ) {
         $this->packageManager = $packageManager;
         $this->lateBootService = $lateBootService;
+        $this->upgradeWizardsService = $upgradeWizardsService;
     }
 
     /**
@@ -129,6 +140,10 @@ class UpgradeController extends AbstractController
             'class' => ConstantMatcher::class,
             'configurationFile' => 'EXT:install/Configuration/ExtensionScanner/Php/ConstantMatcher.php',
         ],
+        [
+            'class' => ConstructorArgumentMatcher::class,
+            'configurationFile' => 'EXT:install/Configuration/ExtensionScanner/Php/ConstructorArgumentMatcher.php',
+        ],
         [
             'class' => PropertyAnnotationMatcher::class,
             'configurationFile' => 'EXT:install/Configuration/ExtensionScanner/Php/PropertyAnnotationMatcher.php',
@@ -196,6 +211,7 @@ class UpgradeController extends AbstractController
     public function cardsAction(ServerRequestInterface $request): ResponseInterface
     {
         $view = $this->initializeStandaloneView($request, 'Upgrade/Cards.html');
+        $view->assign('extensionFoldersInTypo3conf', (new Finder())->directories()->in(Environment::getExtensionsPath())->depth(0)->count());
         return new JsonResponse([
             'success' => true,
             'html' => $view->render(),
@@ -302,32 +318,113 @@ class UpgradeController extends AbstractController
         $action = null;
         $this->coreUpdateInitialize();
         $messageQueue = new FlashMessageQueue('install');
+
+        $messages = [];
+
         if ($this->coreVersionService->isInstalledVersionAReleasedVersion()) {
-            $isUpdateAvailable = $this->coreVersionService->isYoungerPatchReleaseAvailable();
-            $isUpdateSecurityRelevant = $this->coreVersionService->isUpdateSecurityRelevant();
-            if (!$isUpdateAvailable) {
-                $messageQueue->enqueue(new FlashMessage(
-                    '',
-                    'No regular update available',
-                    FlashMessage::NOTICE
-                ));
-            } elseif ($isUpdateAvailable) {
-                $newVersion = $this->coreVersionService->getYoungestPatchRelease();
-                if ($isUpdateSecurityRelevant) {
-                    $messageQueue->enqueue(new FlashMessage(
-                        '',
-                        'Update to security relevant released version ' . $newVersion . ' is available!',
-                        FlashMessage::WARNING
-                    ));
-                    $action = ['title' => 'Update now', 'action' => 'updateRegular'];
-                } else {
-                    $messageQueue->enqueue(new FlashMessage(
-                        '',
-                        'Update to regular released version ' . $newVersion . ' is available!',
-                        FlashMessage::INFO
-                    ));
-                    $action = ['title' => 'Update now', 'action' => 'updateRegular'];
+            $versionMaintenanceWindow = $this->coreVersionService->getMaintenanceWindow();
+            $renderVersionInformation = false;
+
+            if (!$versionMaintenanceWindow->isSupportedByCommunity() && !$versionMaintenanceWindow->isSupportedByElts()) {
+                $messages[] = [
+                    'title' => 'Outdated version',
+                    'message' => 'The currently installed TYPO3 version ' . $this->coreVersionService->getInstalledVersion() . ' does not receive any further updates, please consider upgrading to a supported version!',
+                    'severity' => FlashMessage::ERROR,
+                ];
+                $renderVersionInformation = true;
+            } else {
+                $currentVersion = $this->coreVersionService->getInstalledVersion();
+                $isCurrentVersionElts = $this->coreVersionService->isCurrentInstalledVersionElts();
+                $latestRelease = $this->coreVersionService->getYoungestPatchRelease();
+
+                $availableReleases = [];
+                if ($this->coreVersionService->isPatchReleaseSuitableForUpdate($latestRelease)) {
+                    $availableReleases[] = $latestRelease;
                 }
+                if (!$versionMaintenanceWindow->isSupportedByCommunity()) {
+                    if ($latestRelease->isElts()) {
+                        // Check if there's a public release left that's not installed yet
+                        $latestCommunityDrivenRelease = $this->coreVersionService->getYoungestCommunityPatchRelease();
+                        if ($this->coreVersionService->isPatchReleaseSuitableForUpdate($latestCommunityDrivenRelease)) {
+                            $availableReleases[] = $latestCommunityDrivenRelease;
+                            $action = ['title' => 'Update now to version ' . $latestCommunityDrivenRelease->getVersion(), 'action' => 'updateRegular'];
+                        }
+                    } elseif (!$isCurrentVersionElts) {
+                        // Inform user about ELTS being available soon if:
+                        // - regular support ran out
+                        // - the current installed version is no ELTS
+                        // - no ELTS update was released, yet
+                        $messages[] = [
+                            'title' => 'ELTS will be available soon',
+                            'message' => sprintf('The currently installed TYPO3 version %s doesn\'t receive any community-driven updates anymore, consider subscribing to Extended Long Term Support (ELTS) releases. Please read the information below.', $currentVersion),
+                            'severity' => FlashMessage::WARNING,
+                        ];
+                        $renderVersionInformation = true;
+                    }
+                }
+
+                if ($availableReleases === []) {
+                    $messages[] = [
+                        'title' => 'Up to date',
+                        'message' => 'There are no TYPO3 updates available.',
+                        'severity' => FlashMessage::NOTICE,
+                    ];
+                } else {
+                    foreach ($availableReleases as $availableRelease) {
+                        $isUpdateSecurityRelevant = $this->coreVersionService->isUpdateSecurityRelevant($availableRelease);
+                        $versionString = $availableRelease->getVersion();
+                        if ($availableRelease->isElts()) {
+                            $versionString .= ' ELTS';
+                        }
+
+                        if ($isUpdateSecurityRelevant) {
+                            $title = ($availableRelease->isElts() ? 'ELTS ' : '') . 'Security update available!';
+                            $message = sprintf('The currently installed version is %s, update to security relevant released version %s is available.', $currentVersion, $versionString);
+                            $severity = FlashMessage::ERROR;
+                        } else {
+                            $title = ($availableRelease->isElts() ? 'ELTS ' : '') . 'Update available!';
+                            $message = sprintf('Currently installed version is %s, update to regular released version %s is available.', $currentVersion, $versionString);
+                            $severity = FlashMessage::WARNING;
+                        }
+
+                        if ($availableRelease->isElts()) {
+                            if ($isCurrentVersionElts) {
+                                $message .= ' Please visit my.typo3.org to download the release in your ELTS area.';
+                            } else {
+                                $message .= ' ' . sprintf('The currently installed TYPO3 version %s doesn\'t receive any community-driven updates anymore, consider subscribing to Extended Long Term Support (ELTS) releases. Please read the information below.', $currentVersion);
+                            }
+
+                            $renderVersionInformation = true;
+                        }
+
+                        $messages[] = [
+                            'title' => $title,
+                            'message' => $message,
+                            'severity' => $severity,
+                        ];
+                    }
+                }
+            }
+
+            if ($renderVersionInformation) {
+                $supportedMajorReleases = $this->coreVersionService->getSupportedMajorReleases();
+                $supportMessages = [];
+                if (!empty($supportedMajorReleases['community'])) {
+                    $supportMessages[] = sprintf('Currently community-supported TYPO3 versions: %s (more information at https://get.typo3.org).', implode(', ', $supportedMajorReleases['community']));
+                }
+                if (!empty($supportedMajorReleases['elts'])) {
+                    $supportMessages[] = sprintf('Currently supported TYPO3 ELTS versions: %s (more information at https://typo3.com/elts).', implode(', ', $supportedMajorReleases['elts']));
+                }
+
+                $messages[] = [
+                    'title' => 'TYPO3 Version information',
+                    'message' => implode(' ', $supportMessages),
+                    'severity' => FlashMessage::INFO,
+                ];
+            }
+
+            foreach ($messages as $message) {
+                $messageQueue->enqueue(new FlashMessage($message['message'], $message['title'], $message['severity']));
             }
         } else {
             $messageQueue->enqueue(new FlashMessage(
@@ -623,11 +720,12 @@ class UpgradeController extends AbstractController
             }
 
             // Build array of file (hashes) not affected by current scan, if they are tagged as "FullyScanned"
-            $parsedRestFile = array_pop($documentationFile->getListEntry(str_replace(
+            $listEntries = $documentationFile->getListEntry(str_replace(
                 '\\',
                 '/',
-                realpath($restFile->getPathname())
-            )));
+                (string)realpath($restFile->getPathname())
+            ));
+            $parsedRestFile = array_pop($listEntries);
             if (!in_array($parsedRestFile['file_hash'], $foundRestFileHashes, true)
                 && in_array('FullyScanned', $parsedRestFile['tags'], true)
             ) {
@@ -685,11 +783,17 @@ class UpgradeController extends AbstractController
         // Parse PHP file to AST and traverse tree calling visitors
         $statements = $parser->parse(file_get_contents($absoluteFilePath));
 
-        $traverser = new NodeTraverser();
         // The built in NameResolver translates class names shortened with 'use' to fully qualified
         // class names at all places. Incredibly useful for us and added as first visitor.
+        // IMPORTANT: first process completely to resolve fully qualified names of arguments
+        // (otherwise GeneratorClassesResolver will NOT get reliable results)
+        $traverser = new NodeTraverser();
         $traverser->addVisitor(new NameResolver());
-        // Understand makeInstance('My\\Package\\Foo\\Bar') as fqdn class name in first argument
+        $statements = $traverser->traverse($statements);
+
+        // IMPORTANT: second process to actually work on the pre-resolved statements
+        $traverser = new NodeTraverser();
+        // Understand GeneralUtility::makeInstance('My\\Package\\Foo\\Bar') as fqdn class name in first argument
         $traverser->addVisitor(new GeneratorClassesResolver());
         // Count ignored lines, effective code lines, ...
         $statistics = new CodeStatistics();
@@ -718,7 +822,7 @@ class UpgradeController extends AbstractController
         $preparedMatches = [];
         foreach ($matches as $match) {
             $preparedHit = [];
-            $preparedHit['uniqueId'] = str_replace('.', '', uniqid((string)random_int(0, mt_getrandmax()), true));
+            $preparedHit['uniqueId'] = StringUtility::getUniqueId();
             $preparedHit['message'] = $match['message'];
             $preparedHit['line'] = $match['line'];
             $preparedHit['indicator'] = $match['indicator'];
@@ -738,16 +842,17 @@ class UpgradeController extends AbstractController
                     $restFileLocation = $restFile->getPathname();
                     break;
                 }
-                $parsedRestFile = array_pop($documentationFile->getListEntry(str_replace(
+                $listEntries = $documentationFile->getListEntry(str_replace(
                     '\\',
                     '/',
-                    realpath($restFileLocation)
-                )));
+                    (string)realpath($restFileLocation)
+                ));
+                $parsedRestFile = array_pop($listEntries);
                 $version = GeneralUtility::trimExplode(DIRECTORY_SEPARATOR, $restFileLocation);
                 array_pop($version);
                 // something like "8.2" .. "8.7" .. "master"
                 $parsedRestFile['version'] = array_pop($version);
-                $parsedRestFile['uniqueId'] = str_replace('.', '', uniqid((string)random_int(0, mt_getrandmax()), true));
+                $parsedRestFile['uniqueId'] = StringUtility::getUniqueId();
                 $preparedHit['restFiles'][] = $parsedRestFile;
             }
             $preparedMatches[] = $preparedHit;
@@ -774,7 +879,11 @@ class UpgradeController extends AbstractController
         $loadTcaService = GeneralUtility::makeInstance(LoadTcaService::class);
         $loadTcaService->loadExtensionTablesWithoutMigration();
         $baseTca = $GLOBALS['TCA'];
+        $container = $this->lateBootService->getContainer();
+        $backup = $this->lateBootService->makeCurrent($container);
         foreach ($this->packageManager->getActivePackages() as $package) {
+            $this->extensionCompatTesterLoadExtLocalconfForExtension($package);
+
             $extensionKey = $package->getPackageKey();
             $extTablesPath = $package->getPackagePath() . 'ext_tables.php';
             if (@file_exists($extTablesPath)) {
@@ -790,6 +899,7 @@ class UpgradeController extends AbstractController
                 $baseTca = $newTca;
             }
         }
+        $this->lateBootService->makeCurrent(null, $backup);
         return new JsonResponse([
             'success' => true,
             'status' => $messageQueue,
@@ -925,12 +1035,16 @@ class UpgradeController extends AbstractController
     public function upgradeWizardsBlockingDatabaseAddsAction(): ResponseInterface
     {
         // ext_localconf, db and ext_tables must be loaded for the updates :(
-        $this->loadExtLocalconfDatabaseAndExtTables(false);
-        $upgradeWizardsService = new UpgradeWizardsService();
-        $adds = $upgradeWizardsService->getBlockingDatabaseAdds();
-        $this->resetGlobalContainer();
+        $this->lateBootService->loadExtLocalconfDatabaseAndExtTables(false);
+        $adds = [];
         $needsUpdate = false;
-        if (!empty($adds)) {
+        try {
+            $adds = $this->upgradeWizardsService->getBlockingDatabaseAdds();
+            $this->lateBootService->resetGlobalContainer();
+            if (!empty($adds)) {
+                $needsUpdate = true;
+            }
+        } catch (StatementException $exception) {
             $needsUpdate = true;
         }
         return new JsonResponse([
@@ -948,10 +1062,9 @@ class UpgradeController extends AbstractController
     public function upgradeWizardsBlockingDatabaseExecuteAction(): ResponseInterface
     {
         // ext_localconf, db and ext_tables must be loaded for the updates :(
-        $this->loadExtLocalconfDatabaseAndExtTables(false);
-        $upgradeWizardsService = new UpgradeWizardsService();
-        $upgradeWizardsService->addMissingTablesAndFields();
-        $this->resetGlobalContainer();
+        $this->lateBootService->loadExtLocalconfDatabaseAndExtTables(false);
+        $this->upgradeWizardsService->addMissingTablesAndFields();
+        $this->lateBootService->resetGlobalContainer();
         $messages = new FlashMessageQueue('install');
         $messages->enqueue(new FlashMessage(
             '',
@@ -970,8 +1083,7 @@ class UpgradeController extends AbstractController
      */
     public function upgradeWizardsBlockingDatabaseCharsetFixAction(): ResponseInterface
     {
-        $upgradeWizardsService = new UpgradeWizardsService();
-        $upgradeWizardsService->setDatabaseCharsetUtf8();
+        $this->upgradeWizardsService->setDatabaseCharsetUtf8();
         $messages = new FlashMessageQueue('install');
         $messages->enqueue(new FlashMessage(
             '',
@@ -990,8 +1102,7 @@ class UpgradeController extends AbstractController
      */
     public function upgradeWizardsBlockingDatabaseCharsetTestAction(): ResponseInterface
     {
-        $upgradeWizardsService = new UpgradeWizardsService();
-        $result = !$upgradeWizardsService->isDatabaseCharsetUtf8();
+        $result = !$this->upgradeWizardsService->isDatabaseCharsetUtf8();
         return new JsonResponse([
             'success' => true,
             'needsUpdate' => $result,
@@ -1005,11 +1116,10 @@ class UpgradeController extends AbstractController
      */
     public function upgradeWizardsDoneUpgradesAction(): ResponseInterface
     {
-        $this->loadExtLocalconfDatabaseAndExtTables(false);
-        $upgradeWizardsService = new UpgradeWizardsService();
-        $wizardsDone = $upgradeWizardsService->listOfWizardsDone();
-        $rowUpdatersDone = $upgradeWizardsService->listOfRowUpdatersDone();
-        $this->resetGlobalContainer();
+        $this->lateBootService->loadExtLocalconfDatabaseAndExtTables(false);
+        $wizardsDone = $this->upgradeWizardsService->listOfWizardsDone();
+        $rowUpdatersDone = $this->upgradeWizardsService->listOfRowUpdatersDone();
+        $this->lateBootService->resetGlobalContainer();
         $messages = new FlashMessageQueue('install');
         if (empty($wizardsDone) && empty($rowUpdatersDone)) {
             $messages->enqueue(new FlashMessage(
@@ -1034,11 +1144,10 @@ class UpgradeController extends AbstractController
     public function upgradeWizardsExecuteAction(ServerRequestInterface $request): ResponseInterface
     {
         // ext_localconf, db and ext_tables must be loaded for the updates :(
-        $this->loadExtLocalconfDatabaseAndExtTables(false);
-        $upgradeWizardsService = new UpgradeWizardsService();
+        $this->lateBootService->loadExtLocalconfDatabaseAndExtTables(false);
         $identifier = $request->getParsedBody()['install']['identifier'];
-        $messages = $upgradeWizardsService->executeWizard($identifier);
-        $this->resetGlobalContainer();
+        $messages = $this->upgradeWizardsService->executeWizard($identifier);
+        $this->lateBootService->resetGlobalContainer();
         return new JsonResponse([
             'success' => true,
             'status' => $messages,
@@ -1054,11 +1163,10 @@ class UpgradeController extends AbstractController
     public function upgradeWizardsInputAction(ServerRequestInterface $request): ResponseInterface
     {
         // ext_localconf, db and ext_tables must be loaded for the updates :(
-        $this->loadExtLocalconfDatabaseAndExtTables(false);
-        $upgradeWizardsService = new UpgradeWizardsService();
+        $this->lateBootService->loadExtLocalconfDatabaseAndExtTables(false);
         $identifier = $request->getParsedBody()['install']['identifier'];
-        $result = $upgradeWizardsService->getWizardUserInput($identifier);
-        $this->resetGlobalContainer();
+        $result = $this->upgradeWizardsService->getWizardUserInput($identifier);
+        $this->lateBootService->resetGlobalContainer();
         return new JsonResponse([
             'success' => true,
             'status' => [],
@@ -1074,10 +1182,9 @@ class UpgradeController extends AbstractController
     public function upgradeWizardsListAction(): ResponseInterface
     {
         // ext_localconf, db and ext_tables must be loaded for the updates :(
-        $this->loadExtLocalconfDatabaseAndExtTables(false);
-        $upgradeWizardsService = new UpgradeWizardsService();
-        $wizards = $upgradeWizardsService->getUpgradeWizardsList();
-        $this->resetGlobalContainer();
+        $this->lateBootService->loadExtLocalconfDatabaseAndExtTables(false);
+        $wizards = $this->upgradeWizardsService->getUpgradeWizardsList();
+        $this->lateBootService->resetGlobalContainer();
         return new JsonResponse([
             'success' => true,
             'status' => [],
@@ -1093,20 +1200,21 @@ class UpgradeController extends AbstractController
      */
     public function upgradeWizardsMarkUndoneAction(ServerRequestInterface $request): ResponseInterface
     {
-        $this->loadExtLocalconfDatabaseAndExtTables(false);
+        $this->lateBootService->loadExtLocalconfDatabaseAndExtTables(false);
         $wizardToBeMarkedAsUndoneIdentifier = $request->getParsedBody()['install']['identifier'];
-        $upgradeWizardsService = new UpgradeWizardsService();
-        $result = $upgradeWizardsService->markWizardUndone($wizardToBeMarkedAsUndoneIdentifier);
-        $this->resetGlobalContainer();
+        $wizardToBeMarkedAsUndone = $this->upgradeWizardsService->getWizardInformationByIdentifier($wizardToBeMarkedAsUndoneIdentifier);
+        $result = $this->upgradeWizardsService->markWizardUndone($wizardToBeMarkedAsUndoneIdentifier);
+        $this->lateBootService->resetGlobalContainer();
         $messages = new FlashMessageQueue('install');
         if ($result) {
             $messages->enqueue(new FlashMessage(
-                'Wizard has been marked undone'
+                'The wizard "' . $wizardToBeMarkedAsUndone['title'] . '" has been marked as undone.',
+                'Wizard marked as undone'
             ));
         } else {
             $messages->enqueue(new FlashMessage(
+                'The wizard "' . $wizardToBeMarkedAsUndone['title'] . '" has not been marked as undone.',
                 'Wizard has not been marked undone',
-                '',
                 FlashMessage::ERROR
             ));
         }
@@ -1153,7 +1261,7 @@ class UpgradeController extends AbstractController
             );
         }
         // @todo: Does the core updater really depend on loaded ext_* files?
-        $this->loadExtLocalconfDatabaseAndExtTables();
+        $this->lateBootService->loadExtLocalconfDatabaseAndExtTables();
     }
 
     /**
@@ -1162,9 +1270,9 @@ class UpgradeController extends AbstractController
      *
      * @param ServerRequestInterface $request
      * @throws \RuntimeException
-     * @return string Version to handle, eg. 6.2.2
+     * @return CoreRelease
      */
-    protected function coreUpdateGetVersionToHandle(ServerRequestInterface $request): string
+    protected function coreUpdateGetVersionToHandle(ServerRequestInterface $request): CoreRelease
     {
         $type = $request->getQueryParams()['install']['type'];
         if (!isset($type) || empty($type)) {
@@ -1173,7 +1281,7 @@ class UpgradeController extends AbstractController
                 1380975303
             );
         }
-        return $this->coreVersionService->getYoungestPatchRelease();
+        return $this->coreVersionService->getYoungestCommunityPatchRelease();
     }
 
     /**
@@ -1211,7 +1319,7 @@ class UpgradeController extends AbstractController
     {
         $documentationFileService = new DocumentationFile();
         $documentationDirectories = $documentationFileService->findDocumentationDirectories(
-            str_replace('\\', '/', realpath(ExtensionManagementUtility::extPath('core') . 'Documentation/Changelog'))
+            str_replace('\\', '/', (string)realpath(ExtensionManagementUtility::extPath('core') . 'Documentation/Changelog'))
         );
         return array_reverse($documentationDirectories);
     }
@@ -1226,9 +1334,8 @@ class UpgradeController extends AbstractController
     {
         $documentationFileService = new DocumentationFile();
         $documentationFiles = $documentationFileService->findDocumentationFiles(
-            str_replace('\\', '/', realpath(ExtensionManagementUtility::extPath('core') . 'Documentation/Changelog/' . $version))
+            str_replace('\\', '/', (string)realpath(ExtensionManagementUtility::extPath('core') . 'Documentation/Changelog/' . $version))
         );
-        $documentationFiles = array_reverse($documentationFiles);
 
         $queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable('sys_registry');
         $filesMarkedAsRead = $queryBuilder
