@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Install\ExtensionScanner\Php\Matcher;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Install\ExtensionScanner\Php\Matcher;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\ExtensionScanner\Php\Matcher;
+
 use PhpParser\Node;
 use PhpParser\Node\Stmt\Class_;
 use PhpParser\NodeVisitorAbstract;
@@ -30,6 +32,8 @@ use TYPO3\CMS\Install\ExtensionScanner\CodeScannerInterface;
  */
 abstract class AbstractCoreMatcher extends NodeVisitorAbstract implements CodeScannerInterface
 {
+    public const NODE_RESOLVED_AS = 'nodeResolvedAs';
+
     /**
      * Incoming main configuration array.
      *
@@ -90,31 +94,36 @@ abstract class AbstractCoreMatcher extends NodeVisitorAbstract implements CodeSc
     protected function validateMatcherDefinitions(array $requiredArrayKeys = [])
     {
         foreach ($this->matcherDefinitions as $key => $matcherDefinition) {
-            // Each config must point to at least one .rst file
-            if (empty($matcherDefinition['restFiles'])) {
+            $this->validateMatcherDefinitionKeys($key, $matcherDefinition, $requiredArrayKeys);
+        }
+    }
+
+    protected function validateMatcherDefinitionKeys(string $key, array $matcherDefinition, array $requiredArrayKeys = []): void
+    {
+        // Each config must point to at least one .rst file
+        if (empty($matcherDefinition['restFiles'])) {
+            throw new \InvalidArgumentException(
+                'Each configuration must have at least one referenced "restFiles" entry. Offending key: ' . $key,
+                1500496068
+            );
+        }
+        foreach ($matcherDefinition['restFiles'] as $file) {
+            if (empty($file)) {
                 throw new \InvalidArgumentException(
-                    'Each configuration must have at least one referenced "restFiles" entry. Offending key: ' . $key,
-                    1500496068
-                );
-            }
-            foreach ($matcherDefinition['restFiles'] as $file) {
-                if (empty($file)) {
-                    throw new \InvalidArgumentException(
-                        'Empty restFiles definition',
-                        1500735983
-                    );
-                }
-            }
-            // Config broken if not all required array keys are specified in config
-            $sharedArrays = array_intersect(array_keys($matcherDefinition), $requiredArrayKeys);
-            if ($sharedArrays !== $requiredArrayKeys) {
-                $missingKeys = array_diff($requiredArrayKeys, array_keys($matcherDefinition));
-                throw new \InvalidArgumentException(
-                    'Required matcher definitions missing: ' . implode(', ', $missingKeys) . ' offending key: ' . $key,
-                    1500492001
+                    'Empty restFiles definition',
+                    1500735983
                 );
             }
         }
+        // Config broken if not all required array keys are specified in config
+        $sharedArrays = array_intersect(array_keys($matcherDefinition), $requiredArrayKeys);
+        if (count($sharedArrays) !== count($requiredArrayKeys)) {
+            $missingKeys = array_diff($requiredArrayKeys, array_keys($matcherDefinition));
+            throw new \InvalidArgumentException(
+                'Required matcher definitions missing: ' . implode(', ', $missingKeys) . ' offending key: ' . $key,
+                1500492001
+            );
+        }
     }
 
     /**
