@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Install\FolderStructure\Exception;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,9 +13,13 @@ namespace TYPO3\CMS\Install\FolderStructure\Exception;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\FolderStructure\Exception;
+
+use TYPO3\CMS\Install\FolderStructure\Exception;
+
 /**
  * An invalid argument exception
  */
-class InvalidArgumentException extends \TYPO3\CMS\Install\FolderStructure\Exception
+class InvalidArgumentException extends Exception
 {
 }
