@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Install\Service;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,9 +15,14 @@ namespace TYPO3\CMS\Install\Service;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\Service;
+
 use TYPO3\CMS\Core\Information\Typo3Version;
-use TYPO3\CMS\Core\Registry;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Install\CoreVersion\CoreRelease;
+use TYPO3\CMS\Install\CoreVersion\MaintenanceWindow;
+use TYPO3\CMS\Install\CoreVersion\MajorRelease;
+use TYPO3\CMS\Install\Service\Exception\RemoteFetchException;
 
 /**
  * Core version service
@@ -26,11 +30,6 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  */
 class CoreVersionService
 {
-    /**
-     * @var \TYPO3\CMS\Core\Registry
-     */
-    protected $registry;
-
     /**
      * Base URI for TYPO3 Version REST api
      *
@@ -38,14 +37,6 @@ class CoreVersionService
      */
     protected $apiBaseUrl = 'https://get.typo3.org/v1/api/';
 
-    /**
-     * Initialize update URI
-     */
-    public function __construct()
-    {
-        $this->registry = GeneralUtility::makeInstance(Registry::class);
-    }
-
     /**
      * Development git checkout versions always end with '-dev'. They are
      * not "released" as such and can not be updated.
@@ -58,21 +49,6 @@ class CoreVersionService
         return substr($version, -4) !== '-dev';
     }
 
-    /**
-     * Get sha1 of a version from version matrix
-     *
-     * @param string $version A version to get sha1 of
-     * @return string sha1 of version
-     * @throws Exception\CoreVersionServiceException
-     */
-    public function getTarGzSha1OfVersion(string $version): string
-    {
-        $url = 'release/' . $version;
-        $result = $this->fetchFromRemote($url);
-
-        return $result['tar_package']['sha1sum'] ?? '';
-    }
-
     /**
      * Get current installed version number
      *
@@ -83,33 +59,48 @@ class CoreVersionService
         return (string)GeneralUtility::makeInstance(Typo3Version::class);
     }
 
-    /**
-     * Checks if TYPO3 version (e.g. 6.2) is an actively maintained version
-     *
-     * @return bool TRUE if version is actively maintained
-     * @throws \TYPO3\CMS\Install\Service\Exception\RemoteFetchException
-     */
-    public function isVersionActivelyMaintained(): bool
+    public function getMaintenanceWindow(): MaintenanceWindow
     {
         $url = 'major/' . $this->getInstalledMajorVersion();
         $result = $this->fetchFromRemote($url);
 
-        return !isset($result['maintained_until']) ||
-               (
-                   new \DateTimeImmutable($result['maintained_until']) >=
-                   new \DateTimeImmutable('now', new \DateTimeZone('UTC'))
-               );
+        return MaintenanceWindow::fromApiResponse($result);
     }
 
     /**
-     * Returns TRUE if a younger patch level release exists in version matrix.
-     *
-     * @return bool TRUE if younger patch release is exists
-     * @throws \TYPO3\CMS\Install\Service\Exception\RemoteFetchException
+     * @return array{community: string[], elts: string[]}
      */
-    public function isYoungerPatchReleaseAvailable(): bool
+    public function getSupportedMajorReleases(): array
     {
-        return version_compare($this->getInstalledVersion(), $this->getYoungestPatchRelease()) === -1;
+        $url = 'major';
+        $result = $this->fetchFromRemote($url);
+
+        $majorReleases = [
+            'community' => [],
+            'elts' => [],
+        ];
+        foreach ($result as $release) {
+            $majorRelease = MajorRelease::fromApiResponse($release);
+            $maintenanceWindow = $majorRelease->getMaintenanceWindow();
+
+            if ($maintenanceWindow->isSupportedByCommunity()) {
+                $group = 'community';
+            } elseif ($maintenanceWindow->isSupportedByElts()) {
+                $group = 'elts';
+            } else {
+                // Major version is unsupported
+                continue;
+            }
+
+            $majorReleases[$group][] = $majorRelease->getLts() ?? $majorRelease->getVersion();
+        }
+
+        return $majorReleases;
+    }
+
+    public function isPatchReleaseSuitableForUpdate(CoreRelease $coreRelease): bool
+    {
+        return version_compare($this->getInstalledVersion(), $coreRelease->getVersion()) === -1;
     }
 
     /**
@@ -118,28 +109,70 @@ class CoreVersionService
      * @return bool TRUE if there is a pending security update
      * @throws \TYPO3\CMS\Install\Service\Exception\RemoteFetchException
      */
-    public function isUpdateSecurityRelevant(): bool
+    public function isUpdateSecurityRelevant(CoreRelease $releaseToCheck): bool
     {
-        $url = 'major/' . $this->getInstalledMajorVersion() . '/release/latest/security';
+        $url = 'major/' . $this->getInstalledMajorVersion() . '/release';
         $result = $this->fetchFromRemote($url);
 
-        if (isset($result['version'])) {
-            return version_compare($this->getInstalledVersion(), $result['version']) === -1;
+        $installedVersion = $this->getInstalledVersion();
+        foreach ($result as $release) {
+            $coreRelease = CoreRelease::fromApiResponse($release);
+            if ($coreRelease->isSecurityUpdate()
+                && version_compare($installedVersion, $coreRelease->getVersion()) === -1 // installed version is lower than release
+                && version_compare($releaseToCheck->getVersion(), $coreRelease->getVersion()) > -1 // release to check is equal or higher than release
+            ) {
+                return true;
+            }
         }
+
+        return false;
+    }
+
+    public function isCurrentInstalledVersionElts(): bool
+    {
+        $url = 'major/' . $this->getInstalledMajorVersion() . '/release';
+        $result = $this->fetchFromRemote($url);
+
+        $installedVersion = $this->getInstalledVersion();
+        foreach ($result as $release) {
+            if (version_compare($installedVersion, $release['version']) === 0) {
+                return $release['elts'] ?? false;
+            }
+        }
+
         return false;
     }
 
     /**
-     * Youngest patch release, e.g., 6.2.2
+     * Youngest patch release
      *
-     * @return string Version string of youngest patch level release
+     * @return CoreRelease
      * @throws \TYPO3\CMS\Install\Service\Exception\RemoteFetchException
      */
-    public function getYoungestPatchRelease(): string
+    public function getYoungestPatchRelease(): CoreRelease
     {
         $url = 'major/' . $this->getInstalledMajorVersion() . '/release/latest';
         $result = $this->fetchFromRemote($url);
-        return $result['version'];
+        return CoreRelease::fromApiResponse($result);
+    }
+
+    public function getYoungestCommunityPatchRelease(): CoreRelease
+    {
+        $url = 'major/' . $this->getInstalledMajorVersion() . '/release';
+        $result = $this->fetchFromRemote($url);
+
+        // Make sure all releases are sorted by their version
+        $columns = array_column($result, 'version');
+        array_multisort($columns, SORT_NATURAL, $result);
+
+        // Remove any ELTS release
+        $releases = array_filter($result, static function (array $release) {
+            return ($release['elts'] ?? false) === false;
+        });
+
+        $latestRelease = end($releases);
+
+        return CoreRelease::fromApiResponse($latestRelease);
     }
 
     /**
@@ -176,7 +209,7 @@ class CoreVersionService
      */
     protected function throwFetchException(string $url): void
     {
-        throw new Exception\RemoteFetchException(
+        throw new RemoteFetchException(
             'Fetching ' .
             $url .
             ' failed. Maybe this instance can not connect to the remote system properly.',
