@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Install\Service;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,11 +15,12 @@ namespace TYPO3\CMS\Install\Service;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\Service;
+
 use TYPO3\CMS\Core\Configuration\Exception\ExtensionConfigurationPathDoesNotExistException;
 use TYPO3\CMS\Core\Configuration\ExtensionConfiguration;
 use TYPO3\CMS\Core\Package\PackageManager;
 use TYPO3\CMS\Core\TypoScript\Parser\ConstantConfigurationParser;
-use TYPO3\CMS\Core\Utility\GeneralUtility;
 
 /**
  * Service to prepare extension configuration settings from ext_conf_template.txt
@@ -33,15 +34,22 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  */
 class ExtensionConfigurationService
 {
+    /**
+     * @var PackageManager
+     */
+    private $packageManager;
 
     /**
-     * @var \TYPO3\CMS\Core\TypoScript\Parser\ConstantConfigurationParser
+     * @var ConstantConfigurationParser
      */
     private $configurationParser;
 
-    public function __construct(ConstantConfigurationParser $configurationParser = null)
-    {
-        $this->configurationParser = $configurationParser ?? GeneralUtility::makeInstance(ConstantConfigurationParser::class);
+    public function __construct(
+        PackageManager $packageManager,
+        ConstantConfigurationParser $configurationParser
+    ) {
+        $this->packageManager = $packageManager;
+        $this->configurationParser = $configurationParser;
     }
     /**
      * Compiles ext_conf_template file and merges it with values from LocalConfiguration['EXTENSIONS'].
@@ -52,7 +60,7 @@ class ExtensionConfigurationService
      */
     public function getConfigurationPreparedForView(string $extensionKey): array
     {
-        $package = GeneralUtility::makeInstance(PackageManager::class)->getPackage($extensionKey);
+        $package = $this->packageManager->getPackage($extensionKey);
         if (!@is_file($package->getPackagePath() . 'ext_conf_template.txt')) {
             return [];
         }
