@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Install\SystemEnvironment;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,6 +15,8 @@ namespace TYPO3\CMS\Install\SystemEnvironment;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\SystemEnvironment;
+
 use TYPO3\CMS\Core\Information\Typo3Information;
 use TYPO3\CMS\Core\Messaging\FlashMessage;
 use TYPO3\CMS\Core\Messaging\FlashMessageQueue;
@@ -65,6 +66,8 @@ class Check implements CheckInterface
         'gd',
         'hash',
         'json',
+        'libxml',
+        'PDO',
         'session',
         'SPL',
         'standard',
@@ -137,7 +140,7 @@ class Check implements CheckInterface
      */
     protected function checkCurrentDirectoryIsInIncludePath()
     {
-        $includePath = ini_get('include_path');
+        $includePath = (string)ini_get('include_path');
         $delimiter = $this->isWindowsOs() ? ';' : ':';
         $pathArray = $this->trimExplode($delimiter, $includePath);
         if (!in_array('.', $pathArray)) {
@@ -187,8 +190,8 @@ class Check implements CheckInterface
      */
     protected function checkPostUploadSizeIsHigherOrEqualMaximumFileUploadSize()
     {
-        $maximumUploadFilesize = $this->getBytesFromSizeMeasurement(ini_get('upload_max_filesize'));
-        $maximumPostSize = $this->getBytesFromSizeMeasurement(ini_get('post_max_size'));
+        $maximumUploadFilesize = $this->getBytesFromSizeMeasurement((string)ini_get('upload_max_filesize'));
+        $maximumPostSize = $this->getBytesFromSizeMeasurement((string)ini_get('post_max_size'));
         if ($maximumPostSize > 0 && $maximumPostSize < $maximumUploadFilesize) {
             $this->messageQueue->enqueue(new FlashMessage(
                 'upload_max_filesize=' . ini_get('upload_max_filesize') . LF
@@ -199,10 +202,15 @@ class Check implements CheckInterface
                 'Maximum size for POST requests is smaller than maximum upload filesize in PHP',
                 FlashMessage::ERROR
             ));
+        } elseif ($maximumPostSize === $maximumUploadFilesize) {
+            $this->messageQueue->enqueue(new FlashMessage(
+                'The maximum size for file uploads is set to ' . ini_get('upload_max_filesize'),
+                'Maximum post upload size correlates with maximum upload file size in PHP'
+            ));
         } else {
             $this->messageQueue->enqueue(new FlashMessage(
-                'The maximum size for file uploads is actually set to ' . ini_get('upload_max_filesize'),
-                'Maximum post upload size correlates with maximum upload file size in PHP'
+                'The maximum size for file uploads is set to ' . ini_get('upload_max_filesize'),
+                'Maximum post upload size is higher than maximum upload file size in PHP, which is fine.'
             ));
         }
     }
@@ -214,7 +222,7 @@ class Check implements CheckInterface
     {
         $minimumMemoryLimit = 64;
         $recommendedMemoryLimit = 128;
-        $memoryLimit = $this->getBytesFromSizeMeasurement(ini_get('memory_limit'));
+        $memoryLimit = $this->getBytesFromSizeMeasurement((string)ini_get('memory_limit'));
         if ($memoryLimit <= 0) {
             $this->messageQueue->enqueue(new FlashMessage(
                 'PHP is configured not to limit memory usage at all. This is a risk'
@@ -363,7 +371,7 @@ class Check implements CheckInterface
      */
     protected function checkDisableFunctions()
     {
-        $disabledFunctions = trim(ini_get('disable_functions'));
+        $disabledFunctions = trim((string)ini_get('disable_functions'));
 
         // Filter "disable_functions"
         $disabledFunctionsArray = $this->trimExplode(',', $disabledFunctions);
@@ -414,7 +422,7 @@ class Check implements CheckInterface
      */
     protected function checkDocRoot()
     {
-        $docRootSetting = trim(ini_get('doc_root'));
+        $docRootSetting = trim((string)ini_get('doc_root'));
         if ($docRootSetting !== '') {
             $this->messageQueue->enqueue(new FlashMessage(
                 'doc_root=' . $docRootSetting . LF
@@ -439,7 +447,7 @@ class Check implements CheckInterface
      */
     protected function checkOpenBaseDir()
     {
-        $openBaseDirSetting = trim(ini_get('open_basedir'));
+        $openBaseDirSetting = trim((string)ini_get('open_basedir'));
         if ($openBaseDirSetting !== '') {
             $this->messageQueue->enqueue(new FlashMessage(
                 'open_basedir = ' . ini_get('open_basedir') . LF
@@ -563,7 +571,7 @@ class Check implements CheckInterface
                     . '* The PHP extension eaccelerator is known to break this if'
                     . ' it is compiled without --with-eaccelerator-doc-comment-inclusion flag.'
                     . ' This compile flag must be specified, otherwise TYPO3 CMS will not work.' . LF
-                    . 'For more information take a look in our wiki ' . Typo3Information::URL_OPCACHE . '.',
+                    . 'For more information take a look in our documentation ' . Typo3Information::URL_OPCACHE . '.',
                 'PHP Doc comment reflection broken',
                 FlashMessage::ERROR
             ));
@@ -810,6 +818,7 @@ class Check implements CheckInterface
     protected function trimExplode($delimiter, $string)
     {
         $explodedValues = explode($delimiter, $string);
+        $explodedValues = is_array($explodedValues) ? $explodedValues : [];
         $resultWithPossibleEmptyValues = array_map('trim', $explodedValues);
         $result = [];
         foreach ($resultWithPossibleEmptyValues as $value) {
