@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Install\Updates;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Install\Updates;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Install\Updates;
+
 use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
@@ -34,8 +36,14 @@ use TYPO3\CMS\Core\Utility\GeneralUtility;
  */
 class PopulatePageSlugs implements UpgradeWizardInterface
 {
+    /**
+     * @var string
+     */
     protected $table = 'pages';
 
+    /**
+     * @var string
+     */
     protected $fieldName = 'slug';
 
     /**
@@ -130,11 +138,10 @@ class PopulatePageSlugs implements UpgradeWizardInterface
         if ($this->checkIfTableExists('tx_realurl_pathdata')) {
             $suggestedSlugs = $this->getSuggestedSlugs('tx_realurl_pathdata');
         } elseif ($this->checkIfTableExists('tx_realurl_pathcache')) {
-            $suggestedSlugs = $this->getSuggestedSlugs('tx_realurl_pathcache');
+            $suggestedSlugs = $this->getSuggestedSlugs('tx_realurl_pathcache', 'cache_id');
         }
 
-        $fieldConfig = $GLOBALS['TCA'][$this->table]['columns'][$this->fieldName]['config'];
-        $fieldConfig['generatorOptions']['fields'] = ['tx_realurl_pathsegment,title'];
+        $fieldConfig = $this->getSlugFieldConfig();
         $evalInfo = !empty($fieldConfig['eval']) ? GeneralUtility::trimExplode(',', $fieldConfig['eval'], true) : [];
         $hasToBeUniqueInSite = in_array('uniqueInSite', $evalInfo, true);
         $hasToBeUniqueInPid = in_array('uniqueInPid', $evalInfo, true);
@@ -215,9 +222,10 @@ class PopulatePageSlugs implements UpgradeWizardInterface
      * Resolve prepared realurl "pagepath" for pages
      *
      * @param string $tableName
+     * @param string $identityField
      * @return array with pageID (default language) and language ID as two-dimensional array containing the page path
      */
-    protected function getSuggestedSlugs(string $tableName): array
+    protected function getSuggestedSlugs(string $tableName, string $identityField = 'uid'): array
     {
         $context = GeneralUtility::makeInstance(Context::class);
         $currentTimestamp = $context->getPropertyFromAspect('date', 'timestamp');
@@ -233,7 +241,7 @@ class PopulatePageSlugs implements UpgradeWizardInterface
                     $queryBuilder->expr()->gt('expire', $queryBuilder->createNamedParameter($currentTimestamp))
                 )
             )
-            ->orderBy('uid', 'DESC')
+            ->orderBy('expire', 'ASC')
             ->execute();
         $suggestedSlugs = [];
         while ($row = $statement->fetch()) {
@@ -261,4 +269,20 @@ class PopulatePageSlugs implements UpgradeWizardInterface
 
         return $tableExists;
     }
+
+    /**
+     * Load the TCA field configuration for the slug field
+     * and add further static fields to generatorOptions.
+     *
+     * @return array
+     */
+    protected function getSlugFieldConfig(): array
+    {
+        $fieldConfig = $GLOBALS['TCA'][$this->table]['columns'][$this->fieldName]['config'];
+
+        // Add the EXT:realurl specific field to generatorOptions
+        $fieldConfig['generatorOptions']['fields'] = ['tx_realurl_pathsegment,title'];
+
+        return $fieldConfig;
+    }
 }
