@@ -1,4 +1,5 @@
 <?php
+
 return [
     '$GLOBALS[\'TYPO3_DB\']' => [
         'restFiles' => [
@@ -15,11 +16,6 @@ return [
             'Breaking-82893-RemoveGlobalVariablePARSETIME_START.rst'
         ],
     ],
-    '$GLOBALS[\'TYPO3_REQUEST\']' => [
-        'restFiles' => [
-            'Deprecation-83736-DeprecatedGlobalsTYPO3_REQUEST.rst',
-        ],
-    ],
     '$GLOBALS[\'TYPO3_LOADED_EXT\']' => [
         'restFiles' => [
             'Deprecation-86404-GLOBALSTYPO3_LOADED_EXT.rst',
