@@ -1,4 +1,5 @@
 <?php
+
 return [
     'TYPO3_DLOG' => [
         'restFiles' => [
@@ -220,4 +221,14 @@ return [
             'Deprecation-89866-Global-TYPO3-information-related-constants.rst'
         ]
     ],
+    'FILE_DENY_PATTERN_DEFAULT' => [
+        'restFiles' => [
+            'Deprecation-90147-UnifiedFileNameValidator.rst'
+        ]
+    ],
+    'PHP_EXTENSIONS_DEFAULT' => [
+        'restFiles' => [
+            'Deprecation-90147-UnifiedFileNameValidator.rst'
+        ]
+    ],
 ];
