@@ -1,4 +1,5 @@
 <?php
+
 return [
     'TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName' => [
         'maximumNumberOfArguments' => 1,
@@ -65,4 +66,10 @@ return [
             'Deprecation-87332-AvoidRuntimeReflectionCallsInObjectAccess.rst',
         ],
     ],
+    'TYPO3\CMS\Core\Utility\GeneralUtility::getUrl' => [
+        'maximumNumberOfArguments' => 1,
+        'restFiles' => [
+            'Deprecation-90956-AlternativeFetchMethodsAndReportsForGeneralUtilitygetUrl.rst',
+        ],
+    ],
 ];
