@@ -1,4 +1,5 @@
 <?php
+
 return [
     // Properties changed from public to protected
     'TYPO3\CMS\Core\DataHandling\DataHandler->recUpdateAccessCache' => [
@@ -1258,4 +1259,14 @@ return [
             'Deprecation-89468-DeprecateInjectionOfEnvironmentServiceInWebRequest.rst',
         ],
     ],
+    'TYPO3\CMS\Core\Localization\LanguageService->LL_files_cache' => [
+        'restFiles' => [
+            'Deprecation-90964-LanguageServiceFunctionalityAndInternalProperties.rst',
+        ],
+    ],
+    'TYPO3\CMS\Core\Localization\LanguageService->LL_labels_cache' => [
+        'restFiles' => [
+            'Deprecation-90964-LanguageServiceFunctionalityAndInternalProperties.rst',
+        ],
+    ],
 ];
