@@ -7,7 +7,7 @@ var require = {
     'TYPO3/CMS/Install': 'sysext/install/Resources/Public/JavaScript',
     'jquery': 'sysext/core/Resources/Public/JavaScript/Contrib/jquery/jquery.min',
     'jquery.clearable': 'sysext/backend/Resources/Public/JavaScript/jquery.clearable',
-    'TYPO3/CMS/Core/Contrib/jquery.minicolors': 'sysext/core/Resources/Public/JavaScript/Contrib/jquery.minicolors',
+    'jquery/minicolors': 'sysext/core/Resources/Public/JavaScript/Contrib/jquery.minicolors',
     'bootstrap': 'sysext/core/Resources/Public/JavaScript/Contrib/bootstrap/bootstrap',
     'chosen': 'sysext/install/Resources/Public/JavaScript/chosen.jquery.min',
     'nprogress': 'sysext/core/Resources/Public/JavaScript/Contrib/nprogress'
