@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Linkvalidator;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Linkvalidator;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Linkvalidator;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Database\Connection;
@@ -24,6 +25,7 @@ use TYPO3\CMS\Core\Database\Query\Restriction\HiddenRestriction;
 use TYPO3\CMS\Core\Html\HtmlParser;
 use TYPO3\CMS\Core\Localization\LanguageService;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Linkvalidator\Event\BeforeRecordIsAnalyzedEvent;
 use TYPO3\CMS\Linkvalidator\Linktype\AbstractLinktype;
 use TYPO3\CMS\Linkvalidator\Repository\BrokenLinkRepository;
 
@@ -37,7 +39,7 @@ class LinkAnalyzer
     /**
      * Array of tables and fields to search for broken links
      *
-     * @var array
+     * @var array<string, array<int, string>>
      */
     protected $searchFields = [];
 
@@ -162,7 +164,9 @@ class LinkAnalyzer
                 $selectFields[] = $GLOBALS['TCA'][$table]['ctrl']['languageField'];
             }
             if ($GLOBALS['TCA'][$table]['ctrl']['type'] ?? false) {
-                $selectFields[] = $GLOBALS['TCA'][$table]['ctrl']['type'];
+                if (isset($GLOBALS['TCA'][$table]['columns'][$GLOBALS['TCA'][$table]['ctrl']['type']])) {
+                    $selectFields[] = $GLOBALS['TCA'][$table]['ctrl']['type'];
+                }
             }
 
             $result = $queryBuilder->select(...$selectFields)
@@ -266,7 +270,7 @@ class LinkAnalyzer
             $queryBuilder->getRestrictions()->removeByType(HiddenRestriction::class);
         }
 
-        $row = $queryBuilder->select('uid', 'pid', $GLOBALS['TCA'][$table]['ctrl']['label'], $field)
+        $row = $queryBuilder->select('uid', 'pid', $GLOBALS['TCA'][$table]['ctrl']['label'], $field, 'tstamp')
             ->from($table)
             ->where(
                 $queryBuilder->expr()->eq(
@@ -282,7 +286,7 @@ class LinkAnalyzer
             $this->brokenLinkRepository->removeBrokenLinksForRecord($table, $recordUid);
             return;
         }
-        if ($timestamp === (int)$row['timestamp']) {
+        if (($row['tstamp'] ?? 0) && $timestamp && ((int)($row['tstamp']) < $timestamp)) {
             // timestamp has not changed: no need to recheck
             return;
         }
@@ -306,7 +310,7 @@ class LinkAnalyzer
      */
     public function analyzeRecord(array &$results, $table, array $fields, array $record)
     {
-        $event = new Event\BeforeRecordIsAnalyzedEvent($table, $record, $fields, $this, $results);
+        $event = new BeforeRecordIsAnalyzedEvent($table, $record, $fields, $this, $results);
         $this->eventDispatcher->dispatch($event);
         $results = $event->getResults();
         $record = $event->getRecord();
@@ -349,7 +353,7 @@ class LinkAnalyzer
 
                 // Do processing
                 $resultArray = $softRefObj->findRef($table, $field, $idRecord, $valueField, $spKey, $softRefParams);
-                if (empty($resultArray['elements'])) {
+                if (!is_array($resultArray) || !isset($resultArray['elements']) || !is_array($resultArray['elements'])) {
                     continue;
                 }
 
