@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Linkvalidator\Report;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Linkvalidator\Report;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Linkvalidator\Report;
+
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Template\ModuleTemplate;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
@@ -508,7 +509,7 @@ class LinkValidatorReport
             '&last_edited_record_uid=' . $row['record_uid'] .
             '&last_edited_record_table=' . $row['table_name'] .
             '&last_edited_record_field=' . $row['field'] .
-            '&last_edited_record_timestamp=' . $row['timestamp'];
+            '&last_edited_record_timestamp=' . $GLOBALS['EXEC_TIME'];
 
         $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
         $url = (string)$uriBuilder->buildUriFromRoute('record_edit', [
@@ -526,8 +527,8 @@ class LinkValidatorReport
         if ($GLOBALS['TCA'][$table]['columns'][$row['field']]['label']) {
             $fieldName = $languageService->sL($GLOBALS['TCA'][$table]['columns'][$row['field']]['label']);
             // Crop colon from end if present
-            if (substr($fieldName, '-1', '1') === ':') {
-                $fieldName = substr($fieldName, '0', strlen($fieldName) - 1);
+            if (substr($fieldName, -1, 1) === ':') {
+                $fieldName = substr($fieldName, 0, strlen($fieldName) - 1);
             }
         }
         // Fallback, if there is no label
