@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Lowlevel\Command;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Lowlevel\Command;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Lowlevel\Command;
+
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Output\OutputInterface;
@@ -43,6 +44,7 @@ class ListSysLogCommand extends Command
      *
      * @param InputInterface $input
      * @param OutputInterface $output
+     * @return int
      */
     protected function execute(InputInterface $input, OutputInterface $output)
     {
@@ -112,6 +114,7 @@ class ListSysLogCommand extends Command
             $content[] = $result;
         }
         $io->table($tableHeaders, $content);
+        return 0;
     }
 
     /**
