@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Lowlevel\Command;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Lowlevel\Command;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Lowlevel\Command;
+
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Input\InputOption;
@@ -47,7 +49,7 @@ Assumptions:
 - index.html, .htaccess files (ignored)
 - Files found in deleted records are included (otherwise you would see a false list of lost files)
 
-The assumptions are not requirements by the TYPO3 API but reflects the de facto implementation of most TYPO3 installations and therefore a practical approach to cleaning up the uploads/ or costum folder.
+The assumptions are not requirements by the TYPO3 API but reflect the de facto implementation of most TYPO3 installations and therefore are a practical approach to clean up the uploads/ or custom folder.
 Therefore, if all "group" type fields in TCA and flexforms are positioned inside the uploads/ folder and if no files inside are managed manually it should be safe to clean out files with no relations found in the system.
 Under such circumstances there should theoretically be no lost files in the uploads/ or custom folder since DataHandler should have managed relations automatically including adding and deleting files.
 However, there is at least one reason known to why files might be found lost and that is when FlexForms are used. In such a case a change of/in the Data Structure XML (or the ability of the system to find the Data Structure definition!) used for the flexform could leave lost files behind. This is not unlikely to happen when records are deleted. More details can be found in a note to the function FlexFormTools->getDataStructureIdentifier()
@@ -91,6 +93,7 @@ If you want to get more detailed information, use the --verbose option.')
      *
      * @param InputInterface $input
      * @param OutputInterface $output
+     * @return int
      */
     protected function execute(InputInterface $input, OutputInterface $output)
     {
@@ -106,7 +109,9 @@ If you want to get more detailed information, use the --verbose option.')
 
         // Find the lost files
         if ($input->hasOption('exclude') && !empty($input->getOption('exclude'))) {
-            $excludedPaths = GeneralUtility::trimExplode(',', $input->getOption('exclude'), true);
+            $exclude = $input->getOption('exclude');
+            $exclude = is_string($exclude) ? $exclude : '';
+            $excludedPaths = GeneralUtility::trimExplode(',', $exclude, true);
         } else {
             $excludedPaths = [];
         }
@@ -115,6 +120,7 @@ If you want to get more detailed information, use the --verbose option.')
         $customPaths = '';
         if ($input->hasOption('custom-path') && !empty($input->getOption('custom-path'))) {
             $customPaths = $input->getOption('custom-path');
+            $customPaths = is_string($customPaths) ? $customPaths : '';
         }
 
         $lostFiles = $this->findLostFiles($excludedPaths, $customPaths);
@@ -134,6 +140,7 @@ If you want to get more detailed information, use the --verbose option.')
         } else {
             $io->success('Nothing to do, no lost files found');
         }
+        return 0;
     }
 
     /**
@@ -185,7 +192,7 @@ If you want to get more detailed information, use the --verbose option.')
             $customPaths = GeneralUtility::trimExplode(',', $customPaths, true);
             foreach ($customPaths as $customPath) {
                 if (false === realpath(Environment::getPublicPath() . '/' . $customPath)
-                    || !GeneralUtility::isFirstPartOfStr(realpath(Environment::getPublicPath() . '/' . $customPath), realpath(Environment::getPublicPath()))) {
+                    || !GeneralUtility::isFirstPartOfStr((string)realpath(Environment::getPublicPath() . '/' . $customPath), (string)realpath(Environment::getPublicPath()))) {
                     throw new \Exception('The path: "' . $customPath . '" is invalid', 1450086736);
                 }
                 $files = GeneralUtility::getAllFilesAndFoldersInPath($files, Environment::getPublicPath() . '/' . $customPath);
