@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Lowlevel\Command;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Lowlevel\Command;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Lowlevel\Command;
+
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Input\InputOption;
@@ -80,6 +82,7 @@ If you want to get more detailed information, use the --verbose option.')
      *
      * @param InputInterface $input
      * @param OutputInterface $output
+     * @return int
      */
     protected function execute(InputInterface $input, OutputInterface $output)
     {
@@ -113,6 +116,7 @@ If you want to get more detailed information, use the --verbose option.')
         if (!count($missingSoftReferencedFiles) && !count($missingReferencedFiles)) {
             $io->success('Nothing to do, no missing files found. Everything is in place.');
         }
+        return 0;
     }
 
     /**
@@ -172,7 +176,7 @@ If you want to get more detailed information, use the --verbose option.')
 
         // Traverse the references and check if the files exists
         while ($record = $result->fetch()) {
-            $fileName = $record['ref_string'];
+            $fileName = $this->getFileNameWithoutAnchor($record['ref_string']);
             if (empty($record['softref_key']) && !@is_file(Environment::getPublicPath() . '/' . $fileName)) {
                 $missingReferences[$fileName][$record['hash']] = $this->formatReferenceIndexEntryToString($record);
             }
@@ -205,7 +209,7 @@ If you want to get more detailed information, use the --verbose option.')
 
         // Traverse the references and check if the files exists
         while ($record = $result->fetch()) {
-            $fileName = $record['ref_string'];
+            $fileName = $this->getFileNameWithoutAnchor($record['ref_string']);
             if (!@is_file(Environment::getPublicPath() . '/' . $fileName)) {
                 $missingReferences[] = $fileName . ' - ' . $record['hash'] . ' - ' . $this->formatReferenceIndexEntryToString($record);
             }
@@ -213,6 +217,20 @@ If you want to get more detailed information, use the --verbose option.')
         return $missingReferences;
     }
 
+    /**
+     * Remove a possible anchor like 'my-path/file.pdf#page15'
+     *
+     * @param string $fileName a filename as found in sys_refindex.ref_string
+     * @return string the filename but leaving everything behind #page15 behind
+     */
+    protected function getFileNameWithoutAnchor(string $fileName): string
+    {
+        if (strpos($fileName, '#') !== false) {
+            [$fileName] = explode('#', $fileName);
+        }
+        return $fileName;
+    }
+
     /**
      * Removes all references in the sys_file_reference where files were not found
      *
