@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Lowlevel\Controller;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,12 +15,16 @@ namespace TYPO3\CMS\Lowlevel\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Lowlevel\Controller;
+
 use Psr\Container\ContainerInterface;
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Configuration\SiteTcaConfiguration;
 use TYPO3\CMS\Backend\Routing\Router;
+use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Template\ModuleTemplate;
+use TYPO3\CMS\Backend\View\ArrayBrowser;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\EventDispatcher\ListenerProvider;
 use TYPO3\CMS\Core\Http\HtmlResponse;
@@ -32,7 +36,6 @@ use TYPO3\CMS\Extbase\Object\ObjectManager;
 use TYPO3\CMS\Fluid\View\StandaloneView;
 use TYPO3\CMS\Form\Mvc\Configuration\ConfigurationManager;
 use TYPO3\CMS\Form\Mvc\Configuration\ConfigurationManagerInterface;
-use TYPO3\CMS\Lowlevel\Utility\ArrayBrowser;
 
 /**
  * View configuration arrays in the backend
@@ -138,6 +141,9 @@ class ConfigurationController
      */
     protected $blindedConfigurationOptions = [
         'TYPO3_CONF_VARS' => [
+            'BE' => [
+                'installToolPassword' => '******'
+            ],
             'DB' => [
                 'database' => '******',
                 'host' => '******',
@@ -156,6 +162,16 @@ class ConfigurationController
                     ],
                 ],
             ],
+            'HTTP' => [
+                'cert' => '******',
+                'ssl_key' => '******'
+            ],
+            'MAIL' => [
+                'transport_smtp_encrypt' => '******',
+                'transport_smtp_password' => '******',
+                'transport_smtp_server' => '******',
+                'transport_smtp_username' => '******',
+            ],
             'SYS' => [
                 'encryptionKey' => '******'
             ],
@@ -267,9 +283,8 @@ class ConfigurationController
         }
 
         // Prepare array renderer class, apply search and expand / collapse states
-        $arrayBrowser = GeneralUtility::makeInstance(ArrayBrowser::class);
-        $arrayBrowser->dontLinkVar = true;
-        $arrayBrowser->searchKeysToo = true;
+        $route = GeneralUtility::makeInstance(Router::class)->match(GeneralUtility::_GP('route'));
+        $arrayBrowser = GeneralUtility::makeInstance(ArrayBrowser::class, $route);
         $arrayBrowser->regexMode = $moduleState['regexSearch'];
         $node = $queryParams['node'];
         if ($searchString) {
@@ -319,7 +334,7 @@ class ConfigurationController
         foreach ($this->treeSetup as $treeKey => $treeDetails) {
             $menuItem = $menu->makeMenuItem();
             /** @var \TYPO3\CMS\Backend\Routing\UriBuilder $uriBuilder */
-            $uriBuilder = GeneralUtility::makeInstance(\TYPO3\CMS\Backend\Routing\UriBuilder::class);
+            $uriBuilder = GeneralUtility::makeInstance(UriBuilder::class);
             $menuItem->setHref((string)$uriBuilder->buildUriFromRoute('system_config', ['tree' => $treeKey]))
                 ->setTitle($languageService->sL(
                     'LLL:EXT:lowlevel/Resources/Private/Language/locallang.xlf:' . $treeDetails['label']
