@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Recordlist\Controller;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Recordlist\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Recordlist\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Clipboard\Clipboard;
@@ -23,8 +24,8 @@ use TYPO3\CMS\Backend\Template\ModuleTemplate;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Database\ConnectionPool;
-use TYPO3\CMS\Core\Database\Query\Restriction\BackendWorkspaceRestriction;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
+use TYPO3\CMS\Core\Database\Query\Restriction\WorkspaceRestriction;
 use TYPO3\CMS\Core\DataHandling\DataHandler;
 use TYPO3\CMS\Core\Http\HtmlResponse;
 use TYPO3\CMS\Core\Imaging\Icon;
@@ -111,9 +112,9 @@ class RecordListController
     /**
      * Page select perms clause
      *
-     * @var int
+     * @var string
      */
-    protected $perms_clause;
+    protected $perms_clause = '';
 
     /**
      * Module TSconfig
@@ -330,7 +331,7 @@ class RecordListController
                 if (!empty($items)) {
                     $cmd = [];
                     foreach ($items as $iK => $value) {
-                        $iKParts = explode('|', $iK);
+                        $iKParts = explode('|', (string)$iK);
                         $cmd[$iKParts[0]][$iKParts[1]]['delete'] = 1;
                     }
                     $tce = GeneralUtility::makeInstance(DataHandler::class);
@@ -408,19 +409,21 @@ class RecordListController
         $this->moduleTemplate->setTitle($title);
 
         $output = '';
-        // Show the selector to add page translations and the list of translations of the current page
-        // but only when in "default" mode
+        // Show the selector to add page translations, but only when in "default" mode.
+        // If not disabled via module TSconfig and the user is allowed, also show the page translations table.
         if ($this->id && !$dblist->csvOutput && !$this->search_field && !$this->cmd && !$this->table) {
             $output .= $this->languageSelector($this->id);
-            $pageTranslationsDatabaseRecordList = clone $dblist;
-            $pageTranslationsDatabaseRecordList->listOnlyInSingleTableMode = false;
-            $pageTranslationsDatabaseRecordList->disableSingleTableView = true;
-            $pageTranslationsDatabaseRecordList->deniedNewTables = ['pages'];
-            $pageTranslationsDatabaseRecordList->hideTranslations = '';
-            $pageTranslationsDatabaseRecordList->iLimit = $pageTranslationsDatabaseRecordList->itemsLimitPerTable;
-            $pageTranslationsDatabaseRecordList->setLanguagesAllowedForUser($this->siteLanguages);
-            $pageTranslationsDatabaseRecordList->showOnlyTranslatedRecords(true);
-            $output .= $pageTranslationsDatabaseRecordList->getTable('pages', $this->id);
+            if ($this->showPageTranslations()) {
+                $pageTranslationsDatabaseRecordList = clone $dblist;
+                $pageTranslationsDatabaseRecordList->listOnlyInSingleTableMode = false;
+                $pageTranslationsDatabaseRecordList->disableSingleTableView = true;
+                $pageTranslationsDatabaseRecordList->deniedNewTables = ['pages'];
+                $pageTranslationsDatabaseRecordList->hideTranslations = '';
+                $pageTranslationsDatabaseRecordList->iLimit = $pageTranslationsDatabaseRecordList->itemsLimitPerTable;
+                $pageTranslationsDatabaseRecordList->setLanguagesAllowedForUser($this->siteLanguages);
+                $pageTranslationsDatabaseRecordList->showOnlyTranslatedRecords(true);
+                $output .= $pageTranslationsDatabaseRecordList->getTable('pages', $this->id);
+            }
         }
 
         if (!empty($dblist->HTMLcode)) {
@@ -471,7 +474,7 @@ class RecordListController
             if ($this->modTSconfig['properties']['enableDisplayBigControlPanel'] === 'selectable') {
                 $this->body .= '<div class="checkbox">' .
                     '<label for="checkLargeControl">' .
-                    BackendUtility::getFuncCheck($this->id, 'SET[bigControlPanel]', $this->MOD_SETTINGS['bigControlPanel'], '', $this->table ? '&table=' . $this->table : '', 'id="checkLargeControl"') .
+                    BackendUtility::getFuncCheck($this->id, 'SET[bigControlPanel]', $this->MOD_SETTINGS['bigControlPanel'] ?? '', '', $this->table ? '&table=' . $this->table : '', 'id="checkLargeControl"') .
                     BackendUtility::wrapInHelp('xMOD_csh_corebe', 'list_options', htmlspecialchars($lang->getLL('largeControl'))) .
                     '</label>' .
                     '</div>';
@@ -482,7 +485,7 @@ class RecordListController
                 if ($dblist->showClipboard) {
                     $this->body .= '<div class="checkbox">' .
                         '<label for="checkShowClipBoard">' .
-                        BackendUtility::getFuncCheck($this->id, 'SET[clipBoard]', $this->MOD_SETTINGS['clipBoard'], '', $this->table ? '&table=' . $this->table : '', 'id="checkShowClipBoard"') .
+                        BackendUtility::getFuncCheck($this->id, 'SET[clipBoard]', $this->MOD_SETTINGS['clipBoard'] ?? '', '', $this->table ? '&table=' . $this->table : '', 'id="checkShowClipBoard"') .
                         BackendUtility::wrapInHelp('xMOD_csh_corebe', 'list_options', htmlspecialchars($lang->getLL('showClipBoard'))) .
                         '</label>' .
                         '</div>';
@@ -509,7 +512,7 @@ class RecordListController
         $dblist->getDocHeaderButtons($this->moduleTemplate);
         // search box toolbar
         $content = '';
-        if (!$this->modTSconfig['properties']['disableSearchBox'] && ($dblist->HTMLcode || !empty($dblist->searchString))) {
+        if (!($this->modTSconfig['properties']['disableSearchBox'] ?? false) && ($dblist->HTMLcode || !empty($dblist->searchString))) {
             $content .= $dblist->getSearchBox();
             $this->moduleTemplate->getPageRenderer()->loadRequireJsModule('TYPO3/CMS/Backend/ToggleSearchToolbox');
 
@@ -559,7 +562,7 @@ class RecordListController
      * that are not disabled with page TS.
      *
      * @param int $id Page id for which to create a new translation record of pages
-     * @return string <select> HTML element (if there were items for the box anyways...)
+     * @return string HTML <select> element (if there were items for the box anyways...)
      */
     protected function languageSelector(int $id): string
     {
@@ -579,7 +582,7 @@ class RecordListController
         $queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable('pages');
         $queryBuilder->getRestrictions()->removeAll()
             ->add(GeneralUtility::makeInstance(DeletedRestriction::class))
-            ->add(GeneralUtility::makeInstance(BackendWorkspaceRestriction::class));
+            ->add(GeneralUtility::makeInstance(WorkspaceRestriction::class, (int)$this->getBackendUserAuthentication()->workspace));
         $statement = $queryBuilder->select('uid', $languageField)
             ->from('pages')
             ->where(
@@ -615,13 +618,29 @@ class RecordListController
 
             return '<div class="form-inline form-inline-spaced">'
                 . '<div class="form-group">'
-                . '<select class="form-control input-sm" name="createNewLanguage" onchange="window.location.href=this.options[this.selectedIndex].value">'
+                . '<select class="form-control input-sm" name="createNewLanguage" data-global-event="change" data-action-navigate="$value">'
                 . $output
                 . '</select></div></div>';
         }
         return '';
     }
 
+    protected function showPageTranslations(): bool
+    {
+        if (!$this->getBackendUserAuthentication()->check('tables_select', 'pages')) {
+            return false;
+        }
+
+        if (isset($this->modTSconfig['properties']['table.']['pages.']['hideTable'])) {
+            return !$this->modTSconfig['properties']['table.']['pages.']['hideTable'];
+        }
+
+        $hideTables = $this->modTSconfig['properties']['hideTables'] ?? '';
+        return !($GLOBALS['TCA']['pages']['ctrl']['hideTable'] ?? false)
+            && $hideTables !== '*'
+            && !in_array('pages', GeneralUtility::trimExplode(',', $hideTables), true);
+    }
+
     /**
      * @return ModuleTemplate
      */
