@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Recycler\Controller;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Recycler\Controller;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Recycler\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Template\Components\ButtonBar;
@@ -181,7 +182,7 @@ class RecyclerModuleController
             'startUid' => $this->id,
             'isSSL' => $normalizedParams->isHttps(),
             'deleteDisable' => !$this->allowDelete,
-            'depthSelection' => $this->getDataFromSession('depthSelection', 0),
+            'depthSelection' => $this->getDataFromSession('depthSelection', '0'),
             'tableSelection' => $this->getDataFromSession('tableSelection', ''),
             'States' => $this->getBackendUser()->uc['moduleData']['web_recycler']['States']
         ];
