@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Redirects\Service;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Redirects\Service;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Redirects\Service;
+
 use TYPO3\CMS\Core\Cache\CacheManager;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\Restriction\DeletedRestriction;
@@ -66,7 +68,6 @@ class RedirectCacheService
     public function rebuild(): array
     {
         $redirects = [];
-        $this->flush();
         $queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable('sys_redirect');
         $queryBuilder->getRestrictions()->removeAll()
             ->add(GeneralUtility::makeInstance(HiddenRestriction::class))
@@ -85,15 +86,7 @@ class RedirectCacheService
                 $redirects[$host]['flat'][rtrim($row['source_path'], '/') . '/'][$row['uid']] = $row;
             }
         }
-        $this->cache->set('redirects', $redirects, ['redirects']);
+        $this->cache->set('redirects', $redirects);
         return $redirects;
     }
-
-    /**
-     * Flushes all redirects from the cache
-     */
-    protected function flush()
-    {
-        $this->cache->flushByTag('redirects');
-    }
 }
