@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Redirects\Service;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Redirects\Service;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Redirects\Service;
+
 use Psr\Http\Message\UriInterface;
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
@@ -108,7 +110,7 @@ class RedirectService implements LoggerAwareInterface
             if (!empty($allRedirects[$domainName]['regexp'])) {
                 $allRegexps = array_keys($allRedirects[$domainName]['regexp']);
                 foreach ($allRegexps as $regexp) {
-                    $matchResult = @preg_match($regexp, $path);
+                    $matchResult = @preg_match((string)$regexp, $path);
                     if ($matchResult) {
                         $possibleRedirects += $allRedirects[$domainName]['regexp'][$regexp];
                     } elseif ($matchResult === false) {
@@ -124,6 +126,8 @@ class RedirectService implements LoggerAwareInterface
                 }
             }
         }
+
+        return null;
     }
 
     /**
@@ -259,7 +263,7 @@ class RedirectService implements LoggerAwareInterface
      * Called when TypoScript/TSFE is available, so typolink is used to generate the URL
      *
      * @param array $redirectRecord
-     * @param FrontendUserAuthentication|null $frontendUserAuthentication
+     * @param FrontendUserAuthentication $frontendUserAuthentication
      * @param SiteInterface|null $site
      * @param array $linkDetails
      * @param array $queryParams
@@ -281,6 +285,7 @@ class RedirectService implements LoggerAwareInterface
             $configuration = [
                 'parameter' => (string)$redirectRecord['target'],
                 'forceAbsoluteUrl' => true,
+                'linkAccessRestrictedPages' => true,
             ];
             if ($redirectRecord['force_https']) {
                 $configuration['forceAbsoluteUrl.']['scheme'] = 'https';
@@ -313,7 +318,7 @@ class RedirectService implements LoggerAwareInterface
      *
      * So a link to a page can be generated.
      *
-     * @param FrontendUserAuthentication|null $frontendUserAuthentication
+     * @param FrontendUserAuthentication $frontendUserAuthentication
      * @param SiteInterface|null $site
      * @param array $queryParams
      * @return TypoScriptFrontendController
