@@ -1,7 +1,6 @@
 <?php
-namespace TYPO3\CMS\Reports;
 
-/**
+/*
  * This file is part of the TYPO3 CMS project.
  *
  * It is free software; you can redistribute it and/or modify it under
@@ -14,18 +13,17 @@ namespace TYPO3\CMS\Reports;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Reports;
+
 /**
  * Interface for classes which provide a status report entry.
- *
- * @author Ingo Renner <ingo@typo3.org>
  */
-interface StatusProviderInterface {
-
-	/**
-	 * Returns the status of an extension or (sub)system
-	 *
-	 * @return array An array of \TYPO3\CMS\Reports\Status objects
-	 */
-	public function getStatus();
-
+interface StatusProviderInterface
+{
+    /**
+     * Returns the status of an extension or (sub)system
+     *
+     * @return array An array of \TYPO3\CMS\Reports\Status objects
+     */
+    public function getStatus();
 }
