@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Scheduler;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,9 @@ namespace TYPO3\CMS\Scheduler;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Scheduler;
+
+use Doctrine\DBAL\DBALException;
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
 use Psr\Log\LoggerInterface;
@@ -25,6 +27,7 @@ use TYPO3\CMS\Core\Log\LogManager;
 use TYPO3\CMS\Core\Registry;
 use TYPO3\CMS\Core\SingletonInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Scheduler\Task\AbstractTask;
 
 /**
  * TYPO3 Scheduler. This class handles scheduling and execution of tasks.
@@ -58,7 +61,7 @@ class Scheduler implements SingletonInterface, LoggerAwareInterface
      * @param Task\AbstractTask $task The object representing the task to add
      * @return bool TRUE if the task was successfully added, FALSE otherwise
      */
-    public function addTask(Task\AbstractTask $task)
+    public function addTask(AbstractTask $task)
     {
         $taskUid = $task->getTaskUid();
         if (empty($taskUid)) {
@@ -127,7 +130,7 @@ class Scheduler implements SingletonInterface, LoggerAwareInterface
                 }
             }
             $executionCount = count($executions);
-            if (count($serialized_executions) !== $executionCount) {
+            if (!is_array($serialized_executions) || count($serialized_executions) !== $executionCount) {
                 if ($executionCount === 0) {
                     $value = '';
                 } else {
@@ -151,7 +154,7 @@ class Scheduler implements SingletonInterface, LoggerAwareInterface
      * @return bool Whether the task was saved successfully to the database or not
      * @throws \Throwable
      */
-    public function executeTask(Task\AbstractTask $task)
+    public function executeTask(AbstractTask $task)
     {
         $task->setRunOnNextCronJob(false);
         // Trigger the saving of the task, as this will calculate its next execution time
@@ -222,7 +225,7 @@ class Scheduler implements SingletonInterface, LoggerAwareInterface
      * @param Task\AbstractTask $task The object representing the task to delete
      * @return bool TRUE if task was successfully deleted, FALSE otherwise
      */
-    public function removeTask(Task\AbstractTask $task)
+    public function removeTask(AbstractTask $task)
     {
         $taskUid = $task->getTaskUid();
         if (!empty($taskUid)) {
@@ -241,7 +244,7 @@ class Scheduler implements SingletonInterface, LoggerAwareInterface
      * @param Task\AbstractTask $task Scheduler task object
      * @return bool False if submitted task was not of proper class
      */
-    public function saveTask(Task\AbstractTask $task)
+    public function saveTask(AbstractTask $task)
     {
         $result = true;
         $taskUid = $task->getTaskUid();
@@ -274,7 +277,7 @@ class Scheduler implements SingletonInterface, LoggerAwareInterface
                         ['uid' => $taskUid],
                         ['serialized_task_object' => Connection::PARAM_LOB]
                     );
-            } catch (\Doctrine\DBAL\DBALException $e) {
+            } catch (DBALException $e) {
                 $result = false;
             }
         } else {
@@ -346,6 +349,10 @@ class Scheduler implements SingletonInterface, LoggerAwareInterface
         if ($this->isValidTaskObject($task)) {
             // The task is valid, return it
             $task->setScheduler();
+            if ($task->getTaskGroup() === null) {
+                // Fix invalid task_group=NULL settings in order to avoid exceptions when saving on PostgreSQL
+                $task->setTaskGroup(0);
+            }
         } else {
             // Forcibly set the disable flag to 1 in the database,
             // so that the task does not come up again and again for execution
@@ -450,7 +457,7 @@ class Scheduler implements SingletonInterface, LoggerAwareInterface
      */
     public function isValidTaskObject($task)
     {
-        return $task instanceof Task\AbstractTask && get_class($task->getExecution()) !== \__PHP_Incomplete_Class::class;
+        return $task instanceof AbstractTask && get_class($task->getExecution()) !== \__PHP_Incomplete_Class::class;
     }
 
     /**
