@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Scheduler\Task;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Scheduler\Task;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Scheduler\Task;
+
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
 use TYPO3\CMS\Core\Core\Environment;
@@ -23,6 +24,7 @@ use TYPO3\CMS\Core\Localization\LanguageService;
 use TYPO3\CMS\Core\Log\LogManager;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Scheduler\Execution;
+use TYPO3\CMS\Scheduler\Scheduler;
 
 /**
  * This is the base class for all Scheduler tasks
@@ -90,7 +92,7 @@ abstract class AbstractTask implements LoggerAwareInterface
      *
      * @var int
      */
-    protected $taskGroup;
+    protected $taskGroup = 0;
 
     /**
      * Constructor
@@ -98,7 +100,7 @@ abstract class AbstractTask implements LoggerAwareInterface
     public function __construct()
     {
         // Using makeInstance instead of setScheduler() here as the logger is injected due to LoggerAwareTrait
-        $this->scheduler = GeneralUtility::makeInstance(\TYPO3\CMS\Scheduler\Scheduler::class);
+        $this->scheduler = GeneralUtility::makeInstance(Scheduler::class);
         $this->execution = GeneralUtility::makeInstance(Execution::class);
     }
 
@@ -286,7 +288,7 @@ abstract class AbstractTask implements LoggerAwareInterface
      */
     public function setScheduler()
     {
-        $this->scheduler = GeneralUtility::makeInstance(\TYPO3\CMS\Scheduler\Scheduler::class);
+        $this->scheduler = GeneralUtility::makeInstance(Scheduler::class);
         $this->logger = GeneralUtility::makeInstance(LogManager::class)->getLogger(__CLASS__);
     }
 
