@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Scheduler\Task;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,9 @@ namespace TYPO3\CMS\Scheduler\Task;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Scheduler\Task;
+
+use Symfony\Component\Console\Exception\InvalidArgumentException;
 use Symfony\Component\Console\Exception\InvalidOptionException;
 use Symfony\Component\Console\Input\ArrayInput;
 use Symfony\Component\Console\Output\NullOutput;
@@ -95,7 +98,7 @@ class ExecuteSchedulableCommandTask extends AbstractTask
             );
         }
 
-        $input = new ArrayInput($this->getParameters(false), $schedulableCommand->getDefinition());
+        $input = new ArrayInput($this->getParameters(false));
         $output = new NullOutput();
 
         return $schedulableCommand->run($input, $output) === 0;
@@ -123,7 +126,7 @@ class ExecuteSchedulableCommandTask extends AbstractTask
         try {
             $input = new ArrayInput($this->getParameters(true), $schedulableCommand->getDefinition());
             $arguments = $input->__toString();
-        } catch (\Symfony\Component\Console\Exception\RuntimeException $e) {
+        } catch (\Symfony\Component\Console\Exception\RuntimeException|InvalidArgumentException $e) {
             return $label . "\n"
                 . sprintf(
                     $this->getLanguageService()->sL('LLL:EXT:scheduler/Resources/Private/Language/locallang.xlf:msg.errorParsingArguments'),
