@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Scheduler\Task;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,14 +13,18 @@ namespace TYPO3\CMS\Scheduler\Task;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Scheduler\Task;
+
+use TYPO3\CMS\Core\Resource\Index\Indexer;
 use TYPO3\CMS\Core\Resource\ResourceFactory;
+use TYPO3\CMS\Core\Resource\ResourceStorage;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 
 /**
  * This task tries to find changes in storage and writes them back to DB
  * @internal This class is a specific scheduler task implementation is not considered part of the Public TYPO3 API.
  */
-class FileStorageIndexingTask extends \TYPO3\CMS\Scheduler\Task\AbstractTask
+class FileStorageIndexingTask extends AbstractTask
 {
     /**
      * Storage Uid
@@ -54,8 +57,8 @@ class FileStorageIndexingTask extends \TYPO3\CMS\Scheduler\Task\AbstractTask
      * @param \TYPO3\CMS\Core\Resource\ResourceStorage $storage
      * @return \TYPO3\CMS\Core\Resource\Index\Indexer
      */
-    protected function getIndexer(\TYPO3\CMS\Core\Resource\ResourceStorage $storage)
+    protected function getIndexer(ResourceStorage $storage)
     {
-        return GeneralUtility::makeInstance(\TYPO3\CMS\Core\Resource\Index\Indexer::class, $storage);
+        return GeneralUtility::makeInstance(Indexer::class, $storage);
     }
 }
