@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Seo\Canonical;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,9 +15,12 @@ namespace TYPO3\CMS\Seo\Canonical;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Seo\Canonical;
+
 use Psr\EventDispatcher\EventDispatcherInterface;
 use TYPO3\CMS\Core\Domain\Repository\PageRepository;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
+use TYPO3\CMS\Core\Utility\RootlineUtility;
 use TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController;
 use TYPO3\CMS\Frontend\Utility\CanonicalizationUtility;
 use TYPO3\CMS\Seo\Event\ModifyUrlForCanonicalTagEvent;
@@ -125,7 +127,19 @@ class CanonicalGenerator
      */
     protected function checkDefaultCanonical(): string
     {
-        return $this->typoScriptFrontendController->cObj->typoLink_URL([
+        // We should only create a canonical link to the target, if the target is within a valid site root
+        $inSiteRoot = $this->isPageWithinSiteRoot((int)$this->typoScriptFrontendController->id);
+        if (!$inSiteRoot) {
+            return '';
+        }
+
+        // Temporarily remove current mountpoint information as we want to have the
+        // URL of the target page and not of the page within the mountpoint if the
+        // current page is a mountpoint.
+        $previousMp = $this->typoScriptFrontendController->MP;
+        $this->typoScriptFrontendController->MP = '';
+
+        $link = $this->typoScriptFrontendController->cObj->typoLink_URL([
             'parameter' => $this->typoScriptFrontendController->id . ',' . $this->typoScriptFrontendController->type,
             'forceAbsoluteUrl' => true,
             'addQueryString' => true,
@@ -140,6 +154,19 @@ class CanonicalGenerator
                 )
             ]
         ]);
+        $this->typoScriptFrontendController->MP = $previousMp;
+        return $link;
+    }
+
+    protected function isPageWithinSiteRoot(int $id): bool
+    {
+        $rootline = GeneralUtility::makeInstance(RootlineUtility::class, $id)->get();
+        foreach ($rootline as $page) {
+            if ($page['is_siteroot']) {
+                return true;
+            }
+        }
+        return false;
     }
 
     /**
