@@ -1,7 +1,6 @@
 <?php
-declare(strict_types = 1);
 
-namespace TYPO3\CMS\Seo\XmlSitemap;
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -16,10 +15,14 @@ namespace TYPO3\CMS\Seo\XmlSitemap;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Seo\XmlSitemap;
+
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Core\Context\Context;
+use TYPO3\CMS\Core\Context\WorkspaceAspect;
 use TYPO3\CMS\Core\Database\ConnectionPool;
 use TYPO3\CMS\Core\Database\Query\QueryHelper;
+use TYPO3\CMS\Core\Database\Query\Restriction\WorkspaceRestriction;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer;
 use TYPO3\CMS\Seo\XmlSitemap\Exception\MissingConfigurationException;
@@ -99,6 +102,10 @@ class RecordsXmlSitemapDataProvider extends AbstractXmlSitemapDataProvider
             $constraints[] = QueryHelper::stripLogicalOperatorPrefix($this->config['additionalWhere']);
         }
 
+        $queryBuilder->getRestrictions()->add(
+            GeneralUtility::makeInstance(WorkspaceRestriction::class, $this->getCurrentWorkspaceAspect()->getId())
+        );
+
         $queryBuilder->select('*')
             ->from($table);
 
@@ -199,4 +206,12 @@ class RecordsXmlSitemapDataProvider extends AbstractXmlSitemapDataProvider
         $context = GeneralUtility::makeInstance(Context::class);
         return (int)$context->getPropertyFromAspect('language', 'id');
     }
+
+    /**
+     * @return WorkspaceAspect
+     */
+    protected function getCurrentWorkspaceAspect(): WorkspaceAspect
+    {
+        return GeneralUtility::makeInstance(Context::class)->getAspect('workspace');
+    }
 }
