@@ -1,4 +1,5 @@
 <?php
+
 defined('TYPO3_MODE') or die();
 
 \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addModule(
@@ -33,7 +34,7 @@ $GLOBALS['TYPO3_USER_SETTINGS'] = [
             'label' => 'LLL:EXT:setup/Resources/Private/Language/locallang.xlf:beUser_email',
             'table' => 'be_users',
             'csh' => 'beUser_email',
-            'max' => 80
+            'max' => 255
         ],
         'emailMeAtLogin' => [
             'type' => 'check',
@@ -121,7 +122,7 @@ $GLOBALS['TYPO3_USER_SETTINGS'] = [
             'confirm' => true,
             'confirmData' => [
                 'message' => 'LLL:EXT:setup/Resources/Private/Language/locallang.xlf:setToStandardQuestion',
-                'jsCodeAfterOk' => 'document.getElementById(\'setValuesToDefault\').value = 1; document.getElementById(\'SetupModuleController\').submit();'
+                'eventName' => 'setup:confirmation:response',
             ]
         ],
         'resizeTextareas_Flexible' => [
