@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\T3editor\Controller;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -13,6 +12,9 @@ namespace TYPO3\CMS\T3editor\Controller;
  *
  * The TYPO3 project - inspiring people to share!
  */
+
+namespace TYPO3\CMS\T3editor\Controller;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Core\Http\JsonResponse;
@@ -50,10 +52,15 @@ class TypoScriptReferenceController
     protected function loadFile($filepath)
     {
         // Disables the functionality to allow external entities to be loaded when parsing the XML, must be kept
-        $previousValueOfEntityLoader = libxml_disable_entity_loader();
+        $previousValueOfEntityLoader = null;
+        if (PHP_MAJOR_VERSION < 8) {
+            $previousValueOfEntityLoader = libxml_disable_entity_loader();
+        }
         $this->xmlDoc = new \DOMDocument('1.0', 'utf-8');
         $this->xmlDoc->loadXML(file_get_contents($filepath));
-        libxml_disable_entity_loader($previousValueOfEntityLoader);
+        if (PHP_MAJOR_VERSION < 8) {
+            libxml_disable_entity_loader($previousValueOfEntityLoader);
+        }
         // @TODO: oliver@typo3.org: I guess this is not required here
         $this->xmlDoc->saveXML();
     }
