@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Workspaces\Command;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,6 +15,8 @@ namespace TYPO3\CMS\Workspaces\Command;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Workspaces\Command;
+
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputInterface;
 use Symfony\Component\Console\Input\InputOption;
@@ -100,6 +102,7 @@ class WorkspaceVersionRecordsCommand extends Command
      *
      * @param InputInterface $input
      * @param OutputInterface $output
+     * @return int
      */
     protected function execute(InputInterface $input, OutputInterface $output)
     {
@@ -255,6 +258,7 @@ class WorkspaceVersionRecordsCommand extends Command
                 break;
         }
         $io->success('All done!');
+        return 0;
     }
 
     /**
@@ -419,7 +423,7 @@ class WorkspaceVersionRecordsCommand extends Command
                 ->execute();
 
             while ($placeholderRecord = $result->fetch()) {
-                $versions = BackendUtility::selectVersionsOfRecord($table, $placeholderRecord['uid'], 'uid', '*', null);
+                $versions = (array)BackendUtility::selectVersionsOfRecord($table, $placeholderRecord['uid'], 'uid', null);
                 if (count($versions) <= 1) {
                     $unusedPlaceholders[$table . ':' . $placeholderRecord['uid']] = [
                         'table' => $table,
