@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Workspaces\Controller\Remote;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,7 +13,11 @@ namespace TYPO3\CMS\Workspaces\Controller\Remote;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Workspaces\Controller\Remote;
+
 use TYPO3\CMS\Backend\Backend\Avatar\Avatar;
+use TYPO3\CMS\Backend\Form\FormDataCompiler;
+use TYPO3\CMS\Backend\Form\FormDataGroup\TcaDatabaseRecord;
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Database\ConnectionPool;
@@ -23,9 +26,12 @@ use TYPO3\CMS\Core\Imaging\IconFactory;
 use TYPO3\CMS\Core\Localization\LanguageService;
 use TYPO3\CMS\Core\Resource\FileReference;
 use TYPO3\CMS\Core\Resource\ProcessedFile;
+use TYPO3\CMS\Core\SysLog\Action\Database as DatabaseAction;
 use TYPO3\CMS\Core\Utility\DiffUtility;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Core\Utility\MathUtility;
+use TYPO3\CMS\Core\Utility\StringUtility;
+use TYPO3\CMS\Core\Versioning\VersionState;
 use TYPO3\CMS\Extbase\Utility\LocalizationUtility;
 use TYPO3\CMS\Workspaces\Domain\Model\CombinedRecord;
 use TYPO3\CMS\Workspaces\Service\GridDataService;
@@ -108,11 +114,7 @@ class RemoteServer
      */
     public function getStageActions()
     {
-        $currentWorkspace = $this->getCurrentWorkspace();
-        $stages = [];
-        if ($currentWorkspace != WorkspaceService::SELECT_ALL_WORKSPACES) {
-            $stages = $this->stagesService->getStagesForWSUser();
-        }
+        $stages = $this->stagesService->getStagesForWSUser();
         $data = [
             'total' => count($stages),
             'data' => $stages
@@ -131,15 +133,27 @@ class RemoteServer
         $diffReturnArray = [];
         $liveReturnArray = [];
         $diffUtility = $this->getDifferenceHandler();
-        $liveRecord = BackendUtility::getRecord($parameter->table, $parameter->t3ver_oid);
-        $versionRecord = BackendUtility::getRecord($parameter->table, $parameter->uid);
+        $liveRecord = (array)BackendUtility::getRecord($parameter->table, $parameter->t3ver_oid);
+        $versionRecord = (array)BackendUtility::getRecord($parameter->table, $parameter->uid);
+        $versionState = VersionState::cast((int)($versionRecord['t3ver_state'] ?? 0));
         $iconFactory = GeneralUtility::makeInstance(IconFactory::class);
         $icon_Live = $iconFactory->getIconForRecord($parameter->table, $liveRecord, Icon::SIZE_SMALL)->render();
         $icon_Workspace = $iconFactory->getIconForRecord($parameter->table, $versionRecord, Icon::SIZE_SMALL)->render();
         $stagePosition = $this->stagesService->getPositionOfCurrentStage($parameter->stage);
         $fieldsOfRecords = array_keys($liveRecord);
+        $isNewOrDeletePlaceholder = $versionState->equals(VersionState::NEW_PLACEHOLDER_VERSION) || $versionState->equals(VersionState::DELETE_PLACEHOLDER);
+        $suitableFields = ($isNewOrDeletePlaceholder && ($parameter->filterFields ?? false)) ? array_flip($this->getSuitableFields($parameter->table, $parameter->t3ver_oid)) : [];
         foreach ($fieldsOfRecords as $fieldName) {
-            if (empty($GLOBALS['TCA'][$parameter->table]['columns'][$fieldName]['config'])) {
+            if (
+                empty($GLOBALS['TCA'][$parameter->table]['columns'][$fieldName]['config'])
+            ) {
+                continue;
+            }
+            // Disable internal fields
+            if (($GLOBALS['TCA'][$parameter->table]['ctrl']['transOrigDiffSourceField'] ?? '') === $fieldName) {
+                continue;
+            }
+            if (($GLOBALS['TCA'][$parameter->table]['ctrl']['origUid'] ?? '') === $fieldName) {
                 continue;
             }
             // Get the field's label. If not available, use the field name
@@ -161,13 +175,13 @@ class RemoteServer
                         $useThumbnails = empty($differentExtensions);
                     }
 
-                    $liveFileReferences = BackendUtility::resolveFileReferences(
+                    $liveFileReferences = (array)BackendUtility::resolveFileReferences(
                         $parameter->table,
                         $fieldName,
                         $liveRecord,
                         0
                     );
-                    $versionFileReferences = BackendUtility::resolveFileReferences(
+                    $versionFileReferences = (array)BackendUtility::resolveFileReferences(
                         $parameter->table,
                         $fieldName,
                         $versionRecord,
@@ -193,6 +207,37 @@ class RemoteServer
                         'label' => $fieldTitle,
                         'content' => $fileReferenceDifferences['live']
                     ];
+                } elseif ($isNewOrDeletePlaceholder && isset($suitableFields[$fieldName])) {
+                    // If this is a new or delete placeholder, add diff view for all appropriate fields
+                    $newOrDeleteRecord[$fieldName] = BackendUtility::getProcessedValue(
+                        $parameter->table,
+                        $fieldName,
+                        $liveRecord[$fieldName], // Both (live and version) values are the same
+                        0,
+                        true,
+                        false,
+                        $liveRecord['uid'] // Relations of new/delete placeholder do always contain the live uid
+                    ) ?? '';
+
+                    // Don't add empty fields
+                    if ($newOrDeleteRecord[$fieldName] === '') {
+                        continue;
+                    }
+
+                    $diffReturnArray[] = [
+                        'field' => $fieldName,
+                        'label' => $fieldTitle,
+                        'content' => $versionState->equals(VersionState::NEW_PLACEHOLDER_VERSION)
+                            ? $diffUtility->makeDiffDisplay('', $newOrDeleteRecord[$fieldName])
+                            : $diffUtility->makeDiffDisplay($newOrDeleteRecord[$fieldName], '')
+                    ];
+
+                    // Generally not needed by Core, but let's make it available for further processing in hooks
+                    $liveReturnArray[] = [
+                        'field' => $fieldName,
+                        'label' => $fieldTitle,
+                        'content' => $newOrDeleteRecord[$fieldName]
+                    ];
                 } elseif ((string)$liveRecord[$fieldName] !== (string)$versionRecord[$fieldName]) {
                     // Select the human readable values before diff
                     $liveRecord[$fieldName] = BackendUtility::getProcessedValue(
@@ -200,7 +245,7 @@ class RemoteServer
                         $fieldName,
                         $liveRecord[$fieldName],
                         0,
-                        1,
+                        true,
                         false,
                         $liveRecord['uid']
                     );
@@ -209,7 +254,7 @@ class RemoteServer
                         $fieldName,
                         $versionRecord[$fieldName],
                         0,
-                        1,
+                        true,
                         false,
                         $versionRecord['uid']
                     );
@@ -240,15 +285,17 @@ class RemoteServer
         $historyService = GeneralUtility::makeInstance(HistoryService::class);
         $history = $historyService->getHistory($parameter->table, $parameter->t3ver_oid);
 
-        $prevStage = $this->stagesService->getPrevStage($parameter->stage);
-        $nextStage = $this->stagesService->getNextStage($parameter->stage);
-
-        if (isset($prevStage[0])) {
-            $prevStage = current($prevStage);
+        if ($this->stagesService->isPrevStageAllowedForUser($parameter->stage)) {
+            $prevStage = $this->stagesService->getPrevStage($parameter->stage);
+            if (isset($prevStage[0])) {
+                $prevStage = current($prevStage);
+            }
         }
-
-        if (isset($nextStage[0])) {
-            $nextStage = current($nextStage);
+        if ($this->stagesService->isNextStageAllowedForUser($parameter->stage)) {
+            $nextStage = $this->stagesService->getNextStage($parameter->stage);
+            if (isset($nextStage[0])) {
+                $nextStage = current($nextStage);
+            }
         }
 
         return [
@@ -265,8 +312,8 @@ class RemoteServer
                     // escape/sanitize the others
                     'path_Live' => htmlspecialchars(BackendUtility::getRecordPath($liveRecord['pid'], '', 999)),
                     'label_Stage' => htmlspecialchars($this->stagesService->getStageTitle($parameter->stage)),
-                    'label_PrevStage' => $prevStage,
-                    'label_NextStage' => $nextStage,
+                    'label_PrevStage' => $prevStage ?? false,
+                    'label_NextStage' => $nextStage ?? false,
                     'stage_position' => (int)$stagePosition['position'],
                     'stage_count' => (int)$stagePosition['count'],
                     'parent' => [
@@ -292,7 +339,7 @@ class RemoteServer
      */
     protected function prepareFileReferenceDifferences(array $liveFileReferences, array $versionFileReferences, $useThumbnails = false)
     {
-        $randomValue = uniqid('file');
+        $randomValue = StringUtility::getUniqueId('file');
 
         $liveValues = [];
         $versionValues = [];
@@ -368,7 +415,7 @@ class RemoteServer
             ->where(
                 $queryBuilder->expr()->eq(
                     'action',
-                    $queryBuilder->createNamedParameter(6, \PDO::PARAM_INT)
+                    $queryBuilder->createNamedParameter(DatabaseAction::UPDATE, \PDO::PARAM_INT)
                 ),
                 $queryBuilder->expr()->eq(
                     'details_nr',
@@ -536,4 +583,33 @@ class RemoteServer
     {
         return $this->workspaceService->getCurrentWorkspace();
     }
+
+    /**
+     * Gets the fields suitable for being displayed in new and delete diff views
+     *
+     * @param string $table
+     * @param int $uid
+     * @return array
+     */
+    protected function getSuitableFields(string $table, int $uid): array
+    {
+        $formDataCompiler = GeneralUtility::makeInstance(
+            FormDataCompiler::class,
+            GeneralUtility::makeInstance(TcaDatabaseRecord::class)
+        );
+
+        try {
+            $result = $formDataCompiler->compile(['command' => 'edit', 'tableName' => $table, 'vanillaUid' => $uid]);
+            $fieldList = array_unique(array_values($result['columnsToProcess']));
+        } catch (\Exception $exception) {
+            $fieldList = [];
+        }
+
+        // Skip sys_file_reference since it contains fields like "tablenames" in searchFields
+        $searchFields = $table !== 'sys_file_reference'
+            ? GeneralUtility::trimExplode(',', (string)($GLOBALS['TCA'][$table]['ctrl']['searchFields'] ?? ''))
+            : [];
+
+        return array_unique(array_merge($fieldList, $searchFields));
+    }
 }
