@@ -1,6 +1,6 @@
 <?php
-declare(strict_types = 1);
-namespace TYPO3\CMS\Workspaces\Middleware;
+
+declare(strict_types=1);
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -15,11 +15,15 @@ namespace TYPO3\CMS\Workspaces\Middleware;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Workspaces\Middleware;
+
 use Psr\Http\Message\ResponseInterface;
 use Psr\Http\Message\ServerRequestInterface;
+use Psr\Http\Message\UriInterface;
 use Psr\Http\Server\MiddlewareInterface;
 use Psr\Http\Server\RequestHandlerInterface;
 use Symfony\Component\HttpFoundation\Cookie;
+use TYPO3\CMS\Backend\FrontendBackendUserAuthentication;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Context\Context;
 use TYPO3\CMS\Core\Context\UserAspect;
@@ -30,7 +34,7 @@ use TYPO3\CMS\Core\Http\HtmlResponse;
 use TYPO3\CMS\Core\Http\NormalizedParams;
 use TYPO3\CMS\Core\Http\Stream;
 use TYPO3\CMS\Core\Localization\LanguageService;
-use TYPO3\CMS\Core\Routing\PageArguments;
+use TYPO3\CMS\Core\Routing\RouteResultInterface;
 use TYPO3\CMS\Core\Utility\GeneralUtility;
 use TYPO3\CMS\Frontend\Controller\TypoScriptFrontendController;
 use TYPO3\CMS\Workspaces\Authentication\PreviewUserAuthentication;
@@ -57,7 +61,7 @@ class WorkspacePreview implements MiddlewareInterface
     /**
      * Initializes a possible preview user (by checking for GET/cookie of name "ADMCMD_prev")
      *
-     * The GET parameter "ADMCMD_noBeUser" can be used to preview a live workspace from the backend even if the
+     * The GET parameter "ADMCMD_prev=LIVE" can be used to preview a live workspace from the backend even if the
      * backend user is in a different workspace.
      *
      * Additionally, if a workspace is previewed, an additional message text is shown.
@@ -71,56 +75,64 @@ class WorkspacePreview implements MiddlewareInterface
     {
         $addInformationAboutDisabledCache = false;
         $keyword = $this->getPreviewInputCode($request);
-        if ($keyword) {
-            switch ($keyword) {
-                case 'IGNORE':
-                    break;
-                case 'LOGOUT':
-                    // "log out", and unset the cookie
-                    $this->setCookie('', $request->getAttribute('normalizedParams'));
-                    $message = $this->getLogoutTemplateMessage($request->getQueryParams()['returnUrl'] ?? '');
-                    return new HtmlResponse($message);
-                default:
-                    $pageArguments = $request->getAttribute('routing', null);
-                    // A keyword was found in a query parameter or in a cookie
-                    // If the keyword is valid, activate a BE User and override any existing BE Users
-                    $configuration = $this->getPreviewConfigurationFromRequest($request, $keyword);
-                    if (is_array($configuration) && $configuration['fullWorkspace'] > 0 && $pageArguments instanceof PageArguments) {
-                        $previewUser = $this->initializePreviewUser(
-                            (int)$configuration['fullWorkspace'],
-                            $pageArguments->getPageId()
-                        );
-                        if ($previewUser) {
-                            $GLOBALS['BE_USER'] = $previewUser;
-                            // Register the preview user as aspect
-                            $this->setBackendUserAspect(GeneralUtility::makeInstance(Context::class), $previewUser);
-                        }
-                    }
+        $setCookieOnCurrentRequest = false;
+        /** @var NormalizedParams $normalizedParams */
+        $normalizedParams = $request->getAttribute('normalizedParams');
+        $context = GeneralUtility::makeInstance(Context::class);
+
+        // First, if a Log out is happening, a custom HTML output page is shown and the request exits with removing
+        // the cookie for the backend preview.
+        if ($keyword === 'LOGOUT') {
+            // "log out", and unset the cookie
+            $message = $this->getLogoutTemplateMessage($request->getUri());
+            $response = new HtmlResponse($message);
+            return $this->addCookie('', $normalizedParams, $response);
+        }
+
+        // If the keyword is ignore, then the preview is not managed as "Preview User" but handled
+        // via the regular backend user or even no user if the GET parameter ADMCMD_noBeUser is set
+        if (!empty($keyword) && $keyword !== 'IGNORE' && $keyword !== 'LIVE') {
+            $routeResult = $request->getAttribute('routing', null);
+            // A keyword was found in a query parameter or in a cookie
+            // If the keyword is valid, activate a BE User and override any existing BE Users
+            // (in case workspace ID was given and a corresponding site to be used was found)
+            $previewWorkspaceId = (int)$this->getWorkspaceIdFromRequest($request, $keyword);
+            if ($previewWorkspaceId > 0 && $routeResult instanceof RouteResultInterface) {
+                $previewUser = $this->initializePreviewUser($previewWorkspaceId);
+                if ($previewUser instanceof PreviewUserAuthentication) {
+                    $GLOBALS['BE_USER'] = $previewUser;
+                    // Register the preview user as aspect
+                    $this->setBackendUserAspect($context, $previewUser);
+                    // If the GET parameter is set, and we have a valid Preview User, the cookie needs to be
+                    // set and the GET parameter should be removed.
+                    $setCookieOnCurrentRequest = $request->getQueryParams()[$this->previewKey] ?? false;
+                }
             }
         }
 
-        // If "ADMCMD_noBeUser" is set, then ensure that there is no workspace preview and no BE User logged in.
+        // If keyword is set to "LIVE", then ensure that there is no workspace preview, but keep the BE User logged in.
         // This option is solely used to ensure that a be user can preview the live version of a page in the
         // workspace preview module.
-        if ($request->getQueryParams()['ADMCMD_noBeUser']) {
-            $GLOBALS['BE_USER'] = null;
+        if ($keyword === 'LIVE' && $GLOBALS['BE_USER'] instanceof FrontendBackendUserAuthentication) {
+            // We need to set the workspace to live here
+            $GLOBALS['BE_USER']->setTemporaryWorkspace(0);
             // Register the backend user as aspect
-            $this->setBackendUserAspect(GeneralUtility::makeInstance(Context::class), null);
-            // Caching is disabled, because otherwise generated URLs could include the ADMCMD_noBeUser parameter
+            $this->setBackendUserAspect($context, $GLOBALS['BE_USER']);
+            // Caching is disabled, because otherwise generated URLs could include the keyword parameter
             $request = $request->withAttribute('noCache', true);
             $addInformationAboutDisabledCache = true;
+            $setCookieOnCurrentRequest = false;
         }
 
         $response = $handler->handle($request);
 
-        // Caching is disabled, because otherwise generated URLs could include the ADMCMD_noBeUser parameter
-        if ($addInformationAboutDisabledCache) {
-            $GLOBALS['TSFE']->set_no_cache('GET Parameter ADMCMD_noBeUser was given', true);
+        if ($GLOBALS['TSFE'] instanceof TypoScriptFrontendController && $addInformationAboutDisabledCache) {
+            $GLOBALS['TSFE']->set_no_cache('GET Parameter ADMCMD_prev=LIVE was given', true);
         }
 
         // Add an info box to the frontend content
-        if ($GLOBALS['TSFE']->doWorkspacePreview() && $GLOBALS['TSFE']->isOutputting()) {
-            $previewInfo = $this->renderPreviewInfo($GLOBALS['TSFE'], $request->getAttribute('normalizedParams'));
+        if ($GLOBALS['TSFE'] instanceof TypoScriptFrontendController && $GLOBALS['TSFE']->isOutputting(true) && $context->getPropertyFromAspect('workspace', 'isOffline', false)) {
+            $previewInfo = $this->renderPreviewInfo($GLOBALS['TSFE'], $request->getUri());
             $body = $response->getBody();
             $body->rewind();
             $content = $body->getContents();
@@ -130,6 +142,10 @@ class WorkspacePreview implements MiddlewareInterface
             $response = $response->withBody($body);
         }
 
+        // If the GET parameter ADMCMD_prev is set, then a cookie is set for the next request to keep the preview user
+        if ($setCookieOnCurrentRequest) {
+            $response = $this->addCookie($keyword, $normalizedParams, $response);
+        }
         return $response;
     }
 
@@ -137,17 +153,16 @@ class WorkspacePreview implements MiddlewareInterface
      * Renders the logout template when the "logout" button was pressed.
      * Returns a string which can be put into a HttpResponse.
      *
-     * @param string $returnUrl
+     * @param UriInterface $currentUrl
      * @return string
      */
-    protected function getLogoutTemplateMessage(string $returnUrl = ''): string
+    protected function getLogoutTemplateMessage(UriInterface $currentUrl): string
     {
-        $returnUrl = GeneralUtility::sanitizeLocalUrl($returnUrl);
-        $returnUrl = $this->removePreviewParameterFromUrl($returnUrl);
+        $currentUrl = $this->removePreviewParameterFromUrl($currentUrl);
         if ($GLOBALS['TYPO3_CONF_VARS']['FE']['workspacePreviewLogoutTemplate']) {
             $templateFile = GeneralUtility::getFileAbsFileName($GLOBALS['TYPO3_CONF_VARS']['FE']['workspacePreviewLogoutTemplate']);
             if (@is_file($templateFile)) {
-                $message = file_get_contents($templateFile);
+                $message = (string)file_get_contents($templateFile);
             } else {
                 $message = $this->getLanguageService()->sL('LLL:EXT:workspaces/Resources/Private/Language/locallang_mod.xlf:previewLogoutError');
                 $message = htmlspecialchars($message);
@@ -156,9 +171,9 @@ class WorkspacePreview implements MiddlewareInterface
         } else {
             $message = $this->getLanguageService()->sL('LLL:EXT:workspaces/Resources/Private/Language/locallang_mod.xlf:previewLogoutSuccess');
             $message = htmlspecialchars($message);
-            $message = sprintf($message, '<a href="' . htmlspecialchars($returnUrl) . '">', '</a>');
+            $message = sprintf($message, '<a href="' . htmlspecialchars((string)$currentUrl) . '">', '</a>');
         }
-        return sprintf($message, htmlspecialchars($returnUrl));
+        return sprintf($message, htmlspecialchars((string)$currentUrl));
     }
 
     /**
@@ -174,14 +189,15 @@ class WorkspacePreview implements MiddlewareInterface
      *
      * @param ServerRequestInterface $request
      * @param string $inputCode
-     * @return array Preview configuration array from sys_preview record.
+     * @return int|null Workspace ID stored in the preview configuration array of a sys_preview record.
      * @throws \Exception
      */
-    protected function getPreviewConfigurationFromRequest(ServerRequestInterface $request, string $inputCode): array
+    protected function getWorkspaceIdFromRequest(ServerRequestInterface $request, string $inputCode): ?int
     {
         $previewData = $this->getPreviewData($inputCode);
         if (!is_array($previewData)) {
-            throw new \Exception('ADMCMD command could not be executed! (No keyword configuration found)', 1294585192);
+            // ADMCMD command could not be executed! (No keyword configuration found)
+            return null;
         }
         if ($request->getMethod() === 'POST') {
             throw new \Exception('POST requests are incompatible with keyword preview.', 1294585191);
@@ -191,39 +207,33 @@ class WorkspacePreview implements MiddlewareInterface
         if (!$previewConfig['fullWorkspace']) {
             throw new \Exception('Preview configuration did not include a workspace preview', 1294585190);
         }
-        // If the GET parameter ADMCMD_prev is set, then a cookie is set for the next request
-        if ($request->getQueryParams()[$this->previewKey] ?? false) {
-            $this->setCookie($inputCode, $request->getAttribute('normalizedParams'));
-        }
-        return $previewConfig;
+        return (int)$previewConfig['fullWorkspace'];
     }
 
     /**
-     * Creates a preview user and sets the workspace ID and the current page ID (for accessing the page)
+     * Creates a preview user and sets the workspace ID
      *
      * @param int $workspaceUid the workspace ID to set
-     * @param mixed $requestedPageId pageID to the current page
-     * @return PreviewUserAuthentication|bool if the set up of the workspace was successful, the user is returned.
+     * @return PreviewUserAuthentication|null if the set up of the workspace was successful, the user is returned.
      */
-    protected function initializePreviewUser(int $workspaceUid, $requestedPageId)
+    protected function initializePreviewUser(int $workspaceUid): ?PreviewUserAuthentication
     {
-        if ($workspaceUid > 0) {
-            $previewUser = GeneralUtility::makeInstance(PreviewUserAuthentication::class);
-            $previewUser->setWebmounts([$requestedPageId]);
-            if ($previewUser->setTemporaryWorkspace($workspaceUid)) {
-                return $previewUser;
-            }
+        $previewUser = GeneralUtility::makeInstance(PreviewUserAuthentication::class);
+        if ($previewUser->setTemporaryWorkspace($workspaceUid)) {
+            return $previewUser;
         }
-        return false;
+        return null;
     }
 
     /**
-     * Sets a cookie for logging in a preview user
+     * Adds a cookie for logging in a preview user into the HTTP response
      *
-     * @param string $inputCode
+     * @param string $keyword
      * @param NormalizedParams $normalizedParams
+     * @param ResponseInterface $response
+     * @return ResponseInterface
      */
-    protected function setCookie(string $inputCode, NormalizedParams $normalizedParams)
+    protected function addCookie(string $keyword, NormalizedParams $normalizedParams, ResponseInterface $response): ResponseInterface
     {
         $cookieSameSite = $this->sanitizeSameSiteCookieValue(
             strtolower($GLOBALS['TYPO3_CONF_VARS']['BE']['cookieSameSite'] ?? Cookie::SAMESITE_STRICT)
@@ -233,7 +243,7 @@ class WorkspacePreview implements MiddlewareInterface
 
         $cookie = new Cookie(
             $this->previewKey,
-            $inputCode,
+            $keyword,
             0,
             $normalizedParams->getSitePath(),
             null,
@@ -242,7 +252,7 @@ class WorkspacePreview implements MiddlewareInterface
             false,
             $cookieSameSite
         );
-        header('Set-Cookie: ' . $cookie->__toString(), false);
+        return $response->withAddedHeader('Set-Cookie', $cookie->__toString());
     }
 
     /**
@@ -301,10 +311,10 @@ class WorkspacePreview implements MiddlewareInterface
      * via TypoScript.
      *
      * @param TypoScriptFrontendController $tsfe
-     * @param NormalizedParams $normalizedParams
+     * @param UriInterface $currentUrl
      * @return string
      */
-    protected function renderPreviewInfo(TypoScriptFrontendController $tsfe, NormalizedParams $normalizedParams): string
+    protected function renderPreviewInfo(TypoScriptFrontendController $tsfe, UriInterface $currentUrl): string
     {
         $content = '';
         if (!isset($tsfe->config['config']['disablePreviewNotification']) || (int)$tsfe->config['config']['disablePreviewNotification'] !== 1) {
@@ -325,8 +335,7 @@ class WorkspacePreview implements MiddlewareInterface
                 $stopPreviewText = $this->getLanguageService()->sL('LLL:EXT:workspaces/Resources/Private/Language/locallang_mod.xlf:stopPreview');
                 $stopPreviewText = htmlspecialchars($stopPreviewText);
                 if ($GLOBALS['BE_USER'] instanceof PreviewUserAuthentication) {
-                    $url = $this->removePreviewParameterFromUrl($normalizedParams->getRequestUri());
-                    $urlForStoppingPreview = $normalizedParams->getSiteUrl() . 'index.php?returnUrl=' . rawurlencode($url) . '&ADMCMD_prev=LOGOUT';
+                    $urlForStoppingPreview = (string)$this->removePreviewParameterFromUrl($currentUrl, 'LOGOUT');
                     $text .= '<br><a style="color: #000; pointer-events: visible;" href="' . htmlspecialchars($urlForStoppingPreview) . '">' . $stopPreviewText . '</a>';
                 }
                 $styles = [];
@@ -354,7 +363,7 @@ class WorkspacePreview implements MiddlewareInterface
     /**
      * Fetches the title of the workspace
      *
-     * @param $workspaceId
+     * @param int $workspaceId
      * @return string the title of the workspace
      */
     protected function getWorkspaceTitle(int $workspaceId): string
@@ -378,12 +387,24 @@ class WorkspacePreview implements MiddlewareInterface
     /**
      * Used for generating URLs (e.g. in logout page) without the existing ADMCMD_prev keyword as GET variable
      *
-     * @param string $url
-     * @return string
+     * @param UriInterface $url
+     * @param string $newAdminCommand
+     * @return UriInterface
      */
-    protected function removePreviewParameterFromUrl(string $url): string
+    protected function removePreviewParameterFromUrl(UriInterface $url, string $newAdminCommand = ''): UriInterface
     {
-        return (string)preg_replace('/\\&?' . $this->previewKey . '=[[:alnum:]]+/', '', $url);
+        $queryString = $url->getQuery();
+        if (!empty($queryString)) {
+            $queryStringParts = GeneralUtility::explodeUrl2Array($queryString);
+            unset($queryStringParts[$this->previewKey]);
+        } else {
+            $queryStringParts = [];
+        }
+        if ($newAdminCommand !== '') {
+            $queryStringParts[$this->previewKey] = $newAdminCommand;
+        }
+        $queryString = http_build_query($queryStringParts, '', '&', PHP_QUERY_RFC3986);
+        return $url->withQuery($queryString);
     }
 
     /**
@@ -391,11 +412,11 @@ class WorkspacePreview implements MiddlewareInterface
      */
     protected function getLanguageService(): LanguageService
     {
-        return $GLOBALS['LANG'] ?: GeneralUtility::makeInstance(LanguageService::class);
+        return $GLOBALS['LANG'] ?: LanguageService::create('default');
     }
 
     /**
-     * Register the backend user as aspect
+     * Register or override the backend user as aspect, as well as the workspace information the user object is holding
      *
      * @param Context $context
      * @param BackendUserAuthentication $user
