@@ -1,5 +1,4 @@
 <?php
-namespace TYPO3\CMS\Workspaces\Service;
 
 /*
  * This file is part of the TYPO3 CMS project.
@@ -14,6 +13,8 @@ namespace TYPO3\CMS\Workspaces\Service;
  * The TYPO3 project - inspiring people to share!
  */
 
+namespace TYPO3\CMS\Workspaces\Service;
+
 use TYPO3\CMS\Backend\Utility\BackendUtility;
 use TYPO3\CMS\Core\Authentication\BackendUserAuthentication;
 use TYPO3\CMS\Core\Database\Connection;
@@ -553,7 +554,7 @@ class StagesService implements SingletonInterface
     }
 
     /**
-     * @param $grList
+     * @param string $grList
      * @param string $idList
      * @return array
      */
@@ -599,7 +600,7 @@ class StagesService implements SingletonInterface
     /**
      * Fetches particular groups recursively.
      *
-     * @param $grList
+     * @param string $grList
      * @param string $idList
      * @return array
      */
@@ -616,7 +617,7 @@ class StagesService implements SingletonInterface
             // traversing list
             // Get row:
             $row = $this->userGroups[$uid];
-            if (is_array($row) && !GeneralUtility::inList($idList, $uid)) {
+            if (is_array($row) && !GeneralUtility::inList($idList, (string)$uid)) {
                 // Must be an array and $uid should not be in the idList, because then it is somewhere previously in the grouplist
                 // If the localconf.php option isset the user of the sub- sub- groups will also be used
                 if ($GLOBALS['TYPO3_CONF_VARS']['BE']['customStageShowRecipientRecursive'] == 1) {
@@ -735,7 +736,7 @@ class StagesService implements SingletonInterface
     }
 
     /**
-     * @param $stageId
+     * @param int $stageId
      * @return bool
      */
     protected function isStageAllowedForUser($stageId)
