@@ -1,3 +1,10 @@
+#
+# Table structure for table 'be_users'
+#
+CREATE TABLE be_users (
+  workspace_perms tinyint(3) DEFAULT '0' NOT NULL
+);
+
 #
 # Table structure for table 'sys_preview'
 #
@@ -23,6 +30,7 @@ CREATE TABLE sys_workspace (
 	live_edit tinyint(3) DEFAULT '0' NOT NULL,
 	swap_modes tinyint(3) DEFAULT '0' NOT NULL,
 	publish_access tinyint(3) DEFAULT '0' NOT NULL,
+	previewlink_lifetime int(11) DEFAULT '0' NOT NULL,
 	custom_stages int(11) DEFAULT '0' NOT NULL,
 	stagechg_notification tinyint(3) DEFAULT '0' NOT NULL,
 	edit_notification_defaults varchar(255) DEFAULT '' NOT NULL,
